@@ -18,18 +18,15 @@ import org.eclipse.core.runtime.Platform;
 import org.eclipse.e4.ui.css.core.engine.CSSEngine;
 import org.eclipse.e4.ui.css.swt.helpers.URI;
 import org.eclipse.e4.ui.css.swt.properties.AbstractCSSPropertySWTHandler;
-import org.eclipse.e4.ui.internal.css.swt.CSSActivator;
 import org.eclipse.swt.custom.CTabFolder;
 import org.eclipse.swt.custom.CTabFolderRenderer;
 import org.eclipse.swt.widgets.Control;
 import org.osgi.framework.Bundle;
-import org.osgi.service.log.LogService;
 import org.w3c.dom.css.CSSPrimitiveValue;
 import org.w3c.dom.css.CSSValue;
 
 public class CSSPropertyTabRendererSWTHandler extends AbstractCSSPropertySWTHandler {
 
-	private boolean backwardsCompatURIsLogged = false;
 
 	@Override
 	protected void applyCSSProperty(Control control, String property,
@@ -40,19 +37,10 @@ public class CSSPropertyTabRendererSWTHandler extends AbstractCSSPropertySWTHand
 		if (value.getCssValueType() == CSSValue.CSS_PRIMITIVE_VALUE) {
 			if (((CSSPrimitiveValue) value).getPrimitiveType() == CSSPrimitiveValue.CSS_URI) {
 				String rendURL = ((CSSPrimitiveValue) value).getStringValue();
-				// translate old-style platform:/plugin/ class specifiers into new-style bundleclass:// URIs
-				if (rendURL.startsWith("platform:/plugin/")) { //$NON-NLS-1$
-					if(!backwardsCompatURIsLogged) {
-						CSSActivator.getDefault().log(LogService.LOG_ERROR,
-								"platform-style URIs deprecated for referencing types: use bundleclass://<bundlename>/<typename>"); //$NON-NLS-1$
-						backwardsCompatURIsLogged = true;
-					}
-					rendURL = rendURL.replace("platform:/plugin/", "bundleclass://"); //$NON-NLS-1$ //$NON-NLS-2$
-				}
 				URI uri = URI.createURI(rendURL);
 				Bundle bundle = Platform.getBundle(uri.authority());
 				if (bundle == null) {
-					CSSActivator.getDefault().log(LogService.LOG_ERROR, "Failed to get bundle for: " + rendURL); //$NON-NLS-1$
+					Platform.getLog(getClass()).error("Failed to get bundle for: " + rendURL); //$NON-NLS-1$
 				} else {
 					if (uri.segmentCount() > 1) {
 						//TODO: handle this case?
@@ -77,7 +65,7 @@ public class CSSPropertyTabRendererSWTHandler extends AbstractCSSPropertySWTHand
 						} catch (ClassNotFoundException e) {
 							String message = "Unable to load class '" + clazz + "' from bundle '" //$NON-NLS-1$ //$NON-NLS-2$
 									+ bundle.getBundleId() + "'"; //$NON-NLS-1$
-							CSSActivator.getDefault().log(LogService.LOG_ERROR, message);
+							Platform.getLog(getClass()).error(message);
 						}
 					}
 				}
