@@ -21,8 +21,6 @@ import org.eclipse.e4.ui.progress.IProgressService;
 import org.eclipse.e4.ui.progress.UIJob;
 import org.eclipse.jface.dialogs.IconAndMessageDialog;
 import org.eclipse.jface.resource.JFaceResources;
-import org.eclipse.jface.viewers.Viewer;
-import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
@@ -261,13 +259,7 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 	void showJobDetails(Composite parent) {
 		viewer = new DetailedProgressViewer(parent, SWT.MULTI | SWT.H_SCROLL
 				| SWT.V_SCROLL | SWT.BORDER, progressService, finishedJobs);
-		viewer.setComparator(new ViewerComparator() {
-			@Override
-			@SuppressWarnings("unchecked")
-			public int compare(Viewer testViewer, Object e1, Object e2) {
-				return ((Comparable<Object>) e1).compareTo(e2);
-			}
-		});
+		viewer.setComparator(ProgressManagerUtil.getProgressViewerComparator());
 		ProgressViewerContentProvider provider = getContentProvider();
 		viewer.setContentProvider(provider);
 		viewer.setInput(provider);
@@ -357,11 +349,12 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 	}
 
 	/**
-	 * Requests that the blocked jobs dialog be closed. The supplied monitor
-	 * must be the same one that was passed to the createBlockedDialog method.
+	 * Requests that the blocked jobs dialog be closed. The supplied monitor must be
+	 * the same one that was passed to the createBlockedDialog method.
 	 *
-	 * @param monitor
-	 * @return IProgressMonitor
+	 * @param monitor the monitor associated with this block dialog. Dialog will not
+	 *                close if it is another monitor.
+	 * @return <code>true</code> if successfully closed
 	 */
 	public boolean close(IProgressMonitor monitor) {
 		// ignore requests to close the dialog from all but the first monitor
