@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2017 IBM Corporation and others.
+ * Copyright (c) 2009, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -27,8 +27,8 @@ package org.eclipse.e4.ui.workbench.renderers.swt;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.HashSet;
+import java.util.IdentityHashMap;
 import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
@@ -43,7 +43,6 @@ import org.eclipse.e4.core.contexts.IContextFunction;
 import org.eclipse.e4.core.contexts.IEclipseContext;
 import org.eclipse.e4.core.contexts.RunAndTrack;
 import org.eclipse.e4.core.di.annotations.Optional;
-import org.eclipse.e4.core.services.events.IEventBroker;
 import org.eclipse.e4.core.services.log.Logger;
 import org.eclipse.e4.ui.di.UIEventTopic;
 import org.eclipse.e4.ui.internal.workbench.ContributionsAnalyzer;
@@ -87,6 +86,7 @@ import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Decorations;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.swt.widgets.MenuItem;
 import org.osgi.service.event.Event;
 
 /**
@@ -97,14 +97,14 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	private static final String NO_LABEL = "UnLabled"; //$NON-NLS-1$
 	public static final String GROUP_MARKER = "org.eclipse.jface.action.GroupMarker.GroupMarker(String)"; //$NON-NLS-1$
 
-	private Map<MMenu, MenuManager> modelToManager = new HashMap<>();
-	private Map<MenuManager, MMenu> managerToModel = new HashMap<>();
+	private Map<MMenu, MenuManager> modelToManager = new IdentityHashMap<>();
+	private Map<MenuManager, MMenu> managerToModel = new IdentityHashMap<>();
 
-	private Map<MMenuElement, IContributionItem> modelToContribution = new HashMap<>();
-	private Map<IContributionItem, MMenuElement> contributionToModel = new HashMap<>();
+	private Map<MMenuElement, IContributionItem> modelToContribution = new IdentityHashMap<>();
+	private Map<IContributionItem, MMenuElement> contributionToModel = new IdentityHashMap<>();
 
-	private Map<MMenuElement, ContributionRecord> modelContributionToRecord = new HashMap<>();
-	private Map<MMenuElement, ArrayList<ContributionRecord>> sharedElementToRecord = new HashMap<>();
+	private Map<MMenuElement, ContributionRecord> modelContributionToRecord = new IdentityHashMap<>();
+	private Map<MMenuElement, ArrayList<ContributionRecord>> sharedElementToRecord = new IdentityHashMap<>();
 
 	private Collection<IContributionManager> mgrToUpdate = new LinkedHashSet<>();
 
@@ -114,9 +114,6 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	@Inject
 	private MApplication application;
 
-	@Inject
-	IEventBroker eventBroker;
-
 	@Inject
 	@Optional
 	private void subscribeSelectionUpdated(@UIEventTopic(UIEvents.Item.TOPIC_SELECTED) Event event) {
@@ -135,88 +132,85 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 
 	@Inject
 	@Optional
-	private void subscribeUIElementTopicAllRenderedVisibility(@UIEventTopic(UIEvents.UIElement.TOPIC_ALL) Event event) {
+	private void subscribeUIElementTopicToBeRendered(@UIEventTopic(UIEvents.UIElement.TOPIC_TOBERENDERED) Event event) {
 		Object element = event.getProperty(UIEvents.EventTags.ELEMENT);
-		String attName = (String) event.getProperty(UIEvents.EventTags.ATTNAME);
 
 		if (element instanceof MMenuItem) {
 			MMenuItem itemModel = (MMenuItem) element;
-			if (UIEvents.UIElement.TOBERENDERED.equals(attName)) {
-				Object obj = itemModel.getParent();
-				if (!(obj instanceof MMenu)) {
-					return;
+			Object obj = itemModel.getParent();
+			if (!(obj instanceof MMenu)) {
+				return;
+			}
+			MenuManager parent = getManager((MMenu) obj);
+			if (itemModel.isToBeRendered()) {
+				if (parent != null) {
+					modelProcessSwitch(parent, itemModel);
 				}
-				MenuManager parent = getManager((MMenu) obj);
-				if (itemModel.isToBeRendered()) {
-					if (parent != null) {
-						modelProcessSwitch(parent, itemModel);
-					}
-				} else {
-					IContributionItem ici = getContribution(itemModel);
-					clearModelToContribution(itemModel, ici);
-					if (ici != null && parent != null) {
-						parent.remove(ici);
-					}
-					if (ici != null) {
-						ici.dispose();
-					}
+			} else {
+				IContributionItem ici = getContribution(itemModel);
+				clearModelToContribution(itemModel, ici);
+				if (ici != null && parent != null) {
+					parent.remove(ici);
+				}
+				if (ici != null) {
+					ici.dispose();
 				}
 			}
-		}
-
-		if (element instanceof MPart) {
+		} else if (element instanceof MPart) {
 			MPart part = (MPart) element;
-			if (UIEvents.UIElement.TOBERENDERED.equals(attName)) {
-				boolean tbr = (Boolean) event.getProperty(UIEvents.EventTags.NEW_VALUE);
-				if (!tbr) {
-					List<MMenu> menus = part.getMenus();
-					for (MMenu menu : menus) {
-						if (menu instanceof MPopupMenu)
-							unlinkMenu(menu);
-					}
+			boolean tbr = (Boolean) event.getProperty(UIEvents.EventTags.NEW_VALUE);
+			if (!tbr) {
+				List<MMenu> menus = part.getMenus();
+				for (MMenu menu : menus) {
+					if (menu instanceof MPopupMenu)
+						unlinkMenu(menu);
 				}
 			}
 		}
+	}
 
-		if (UIEvents.UIElement.VISIBLE.equals(attName)) {
-			if (element instanceof MMenu) {
-				MMenu menuModel = (MMenu) element;
-				MenuManager manager = getManager(menuModel);
-				if (manager == null) {
-					return;
-				}
-				boolean visible = menuModel.isVisible();
-				manager.setVisible(visible);
-				if (manager.getParent() != null) {
-					manager.getParent().markDirty();
-					scheduleManagerUpdate(manager.getParent());
-				}
-				if (menuModel.getParent() == null) {
-					if (menuModel instanceof MPopupMenu) {
-						Object data = menuModel.getTransientData().get(IPresentationEngine.RENDERING_PARENT_KEY);
-						if (data instanceof Control) {
-							Menu menu = (Menu) menuModel.getWidget();
-							if (visible && menuModel.isToBeRendered() && menu != null && !menu.isDisposed()) {
-								((Control) data).setMenu(menu);
-							}
-							if (!visible) {
-								((Control) data).setMenu(null);
-							}
+	@Inject
+	@Optional
+	private void subscribeUIElementTopicVisible(@UIEventTopic(UIEvents.UIElement.TOPIC_VISIBLE) Event event) {
+		Object element = event.getProperty(UIEvents.EventTags.ELEMENT);
+
+		if (element instanceof MMenu) {
+			MMenu menuModel = (MMenu) element;
+			MenuManager manager = getManager(menuModel);
+			if (manager == null) {
+				return;
+			}
+			boolean visible = menuModel.isVisible();
+			manager.setVisible(visible);
+			if (manager.getParent() != null) {
+				manager.getParent().markDirty();
+				scheduleManagerUpdate(manager.getParent());
+			}
+			if (menuModel.getParent() == null) {
+				if (menuModel instanceof MPopupMenu) {
+					Object data = menuModel.getTransientData().get(IPresentationEngine.RENDERING_PARENT_KEY);
+					if (data instanceof Control) {
+						Menu menu = (Menu) menuModel.getWidget();
+						if (visible && menuModel.isToBeRendered() && menu != null && !menu.isDisposed()) {
+							((Control) data).setMenu(menu);
+						}
+						if (!visible) {
+							((Control) data).setMenu(null);
 						}
 					}
 				}
-			} else if (element instanceof MMenuElement) {
-				MMenuElement itemModel = (MMenuElement) element;
-				Object obj = getContribution(itemModel);
-				if (!(obj instanceof ContributionItem)) {
-					return;
-				}
-				ContributionItem item = (ContributionItem) obj;
-				item.setVisible(itemModel.isVisible());
-				if (item.getParent() != null) {
-					item.getParent().markDirty();
-					scheduleManagerUpdate(item.getParent());
-				}
+			}
+		} else if (element instanceof MMenuElement) {
+			MMenuElement itemModel = (MMenuElement) element;
+			Object obj = getContribution(itemModel);
+			if (!(obj instanceof ContributionItem)) {
+				return;
+			}
+			ContributionItem item = (ContributionItem) obj;
+			item.setVisible(itemModel.isVisible());
+			if (item.getParent() != null) {
+				item.getParent().markDirty();
+				scheduleManagerUpdate(item.getParent());
 			}
 		}
 	}
@@ -240,14 +234,16 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	@Optional
 	private void subscribeItemEnabledUpdate(@UIEventTopic(UIEvents.Item.TOPIC_ENABLED) Event event) {
 		Object element = event.getProperty(UIEvents.EventTags.ELEMENT);
+
 		if (!(element instanceof MMenuItem)) {
 			return;
 		}
 
 		MMenuItem itemModel = (MMenuItem) element;
-		IContributionItem ici = getContribution(itemModel);
-		if (ici != null) {
-			ici.update();
+		Object widget = itemModel.getWidget();
+		if (widget instanceof MenuItem) {
+			boolean enabled = (boolean) event.getProperty(UIEvents.EventTags.NEW_VALUE);
+			((MenuItem) widget).setEnabled(enabled);
 		}
 	}
 
@@ -341,9 +337,13 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 		context.remove(MenuManagerRendererFilter.class);
 		Display display = context.get(Display.class);
 		if (display != null && !display.isDisposed() && rendererFilter != null) {
-			display.removeFilter(SWT.Show, rendererFilter);
-			display.removeFilter(SWT.Hide, rendererFilter);
-			display.removeFilter(SWT.Dispose, rendererFilter);
+			display.asyncExec(() -> {
+				if (!display.isDisposed()) {
+					display.removeFilter(SWT.Show, rendererFilter);
+					display.removeFilter(SWT.Hide, rendererFilter);
+					display.removeFilter(SWT.Dispose, rendererFilter);
+				}
+			});
 		}
 		if (rendererFilter != null) {
 			ContextInjectionFactory.uninject(rendererFilter, context);
@@ -478,6 +478,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 			clearModelToContribution(copy, ici);
 			if (ici != null) {
 				record.getManagerForModel().remove(ici);
+				ici.dispose();
 			}
 		}
 	}
@@ -526,8 +527,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 			toContribute.clear();
 
 			for (MMenuContribution menuContribution : curList) {
-				if (!processAddition(menuModel, manager, menuContribution, existingMenuIds, existingSeparatorNames,
-						menuBar)) {
+				if (!processAddition(menuModel, manager, menuContribution, menuBar)) {
 					toContribute.add(menuContribution);
 				}
 			}
@@ -545,7 +545,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	 * @return true if the menuContribution was processed
 	 */
 	private boolean processAddition(MMenu menuModel, final MenuManager manager, MMenuContribution menuContribution,
-			final HashSet<String> existingMenuIds, HashSet<String> existingSeparatorNames, boolean menuBar) {
+			boolean menuBar) {
 		final ContributionRecord record = new ContributionRecord(menuModel, menuContribution, this);
 		if (!record.mergeIntoModel()) {
 			return false;
@@ -599,7 +599,8 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 		}
 	}
 
-	void removeMenuContributions(final MMenu menuModel, final ArrayList<MMenuElement> menuContributionsToRemove) {
+	private void removeMenuContributions(final MMenu menuModel,
+			final List<MMenuElement> menuContributionsToRemove) {
 		for (MMenuElement item : menuContributionsToRemove) {
 			menuModel.getChildren().remove(item);
 
@@ -698,7 +699,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	 * @param menuManager
 	 * @param childME
 	 */
-	void modelProcessSwitch(MenuManager menuManager, MMenuElement childME) {
+	/* package */ void modelProcessSwitch(MenuManager menuManager, MMenuElement childME) {
 		if (!childME.isToBeRendered()) {
 			return;
 		}
@@ -713,7 +714,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 			processHandledItem(menuManager, itemModel);
 		} else if (childME instanceof MDirectMenuItem) {
 			MDirectMenuItem itemModel = (MDirectMenuItem) childME;
-			processDirectItem(menuManager, itemModel, null);
+			processDirectItem(menuManager, itemModel);
 		} else if (childME instanceof MMenuSeparator) {
 			MMenuSeparator sep = (MMenuSeparator) childME;
 			processSeparator(menuManager, sep);
@@ -733,7 +734,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	 * @param parentManager
 	 * @param itemModel
 	 */
-	void processRenderedItem(MenuManager parentManager, MMenuItem itemModel) {
+	private void processRenderedItem(MenuManager parentManager, MMenuItem itemModel) {
 		IContributionItem ici = getContribution(itemModel);
 		if (ici != null) {
 			return;
@@ -756,7 +757,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 		linkModelToContribution(itemModel, ici);
 	}
 
-	void processOpaqueItem(MenuManager parentManager, MMenuItem itemModel) {
+	private void processOpaqueItem(MenuManager parentManager, MMenuItem itemModel) {
 		IContributionItem ici = getContribution(itemModel);
 		if (ici != null) {
 			return;
@@ -802,9 +803,8 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	/**
 	 * @param parentManager
 	 * @param itemModel
-	 * @param id
 	 */
-	void processDirectItem(MenuManager parentManager, MDirectMenuItem itemModel, String id) {
+	private void processDirectItem(MenuManager parentManager, MDirectMenuItem itemModel) {
 		IContributionItem ici = getContribution(itemModel);
 		if (ici != null) {
 			return;
@@ -837,7 +837,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	 * @param parentManager
 	 * @param itemModel
 	 */
-	void processHandledItem(MenuManager parentManager, MHandledMenuItem itemModel) {
+	private void processHandledItem(MenuManager parentManager, MHandledMenuItem itemModel) {
 		IContributionItem ici = getContribution(itemModel);
 		if (ici != null) {
 			return;
@@ -1146,7 +1146,7 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	 * @param menuModel
 	 * @param dump
 	 */
-	public void removeDynamicMenuContributions(MenuManager menuManager, MMenu menuModel, ArrayList<MMenuElement> dump) {
+	public void removeDynamicMenuContributions(MenuManager menuManager, MMenu menuModel, List<MMenuElement> dump) {
 		removeMenuContributions(menuModel, dump);
 		for (MMenuElement mMenuElement : dump) {
 			IContributionItem ici = getContribution(mMenuElement);
@@ -1173,12 +1173,14 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 	 */
 	@SuppressWarnings("unchecked")
 	public void removeDynamicMenuContributions(MenuManager menuManager, MMenu menuModel) {
-		for (MMenuElement menuElement : new HashSet<>(modelToContribution.keySet())) {
+		List<MMenuElement> toBeRemoved = new ArrayList<>();
+		for (Entry<MMenuElement, IContributionItem> entry : modelToContribution.entrySet()) {
+			MMenuElement menuElement = entry.getKey();
 			if (menuElement instanceof MDynamicMenuContribution) {
 				//
 				// Find Dynamic MMenuElements for the MenuManager specified.
 				//
-				final IContributionItem contributionItem = modelToContribution.get(menuElement);
+				final IContributionItem contributionItem = entry.getValue();
 
 				if (contributionItem instanceof DynamicContributionContributionItem) {
 					final DynamicContributionContributionItem dynamicContributionItem = (DynamicContributionContributionItem) contributionItem;
@@ -1192,12 +1194,13 @@ public class MenuManagerRenderer extends SWTPartRenderer {
 								.getTransientData().get(MenuManagerShowProcessor.DYNAMIC_ELEMENT_STORAGE_KEY);
 
 						if (childElements != null) {
-							removeDynamicMenuContributions(menuManager, menuModel, childElements);
+							toBeRemoved.addAll(childElements);
 						}
 					}
 				}
 			}
 		}
+		removeDynamicMenuContributions(menuManager, menuModel, toBeRemoved);
 	}
 
 	private void unlinkMenu(MMenu menu) {
