@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2018 IBM Corporation and others.
+ * Copyright (c) 2008, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,9 +14,12 @@
  *     Andrey Loskutov <loskutov@gmx.de> - Bug 337588, 388476, 461573
  *     Simon Scholz <simon.scholz@vogella.com> - Bug 442285, 487348
  *     Patrik Suzzi <psuzzi@gmail.com> - Bug 497618
+ *     Christoph Läubrich - Bug 433465
  *******************************************************************************/
 package org.eclipse.e4.ui.workbench.renderers.swt;
 
+import static java.util.Collections.singletonList;
+
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
@@ -28,21 +31,18 @@ import javax.annotation.PreDestroy;
 import javax.inject.Inject;
 import javax.inject.Named;
 import org.eclipse.core.runtime.preferences.IEclipsePreferences;
-import org.eclipse.core.runtime.preferences.IEclipsePreferences.IPreferenceChangeListener;
-import org.eclipse.core.runtime.preferences.IEclipsePreferences.PreferenceChangeEvent;
 import org.eclipse.e4.core.contexts.IEclipseContext;
 import org.eclipse.e4.core.di.annotations.Optional;
 import org.eclipse.e4.core.di.extensions.Preference;
 import org.eclipse.e4.core.services.events.IEventBroker;
 import org.eclipse.e4.ui.css.swt.dom.WidgetElement;
-import org.eclipse.e4.ui.css.swt.properties.custom.CSSPropertyMruVisibleSWTHandler;
 import org.eclipse.e4.ui.di.UIEventTopic;
+import org.eclipse.e4.ui.di.UISynchronize;
 import org.eclipse.e4.ui.internal.workbench.OpaqueElementUtil;
 import org.eclipse.e4.ui.internal.workbench.renderers.swt.BasicPartList;
 import org.eclipse.e4.ui.internal.workbench.renderers.swt.SWTRenderersMessages;
 import org.eclipse.e4.ui.internal.workbench.swt.AbstractPartRenderer;
 import org.eclipse.e4.ui.internal.workbench.swt.CSSConstants;
-import org.eclipse.e4.ui.internal.workbench.swt.CSSRenderingUtils;
 import org.eclipse.e4.ui.model.application.ui.MDirtyable;
 import org.eclipse.e4.ui.model.application.ui.MElementContainer;
 import org.eclipse.e4.ui.model.application.ui.MUIElement;
@@ -100,7 +100,6 @@ import org.eclipse.swt.widgets.ToolItem;
 import org.eclipse.swt.widgets.Widget;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
-import org.w3c.dom.css.CSSValue;
 
 /**
  * SWT default renderer for a MPartStack model elements
@@ -109,15 +108,15 @@ import org.w3c.dom.css.CSSValue;
  * IPresentation.STYLE_OVERRIDE_KEY key
  *
  */
-public class StackRenderer extends LazyStackRenderer implements IPreferenceChangeListener {
+public class StackRenderer extends LazyStackRenderer {
 	/**
 	 *
 	 */
 	private static final String THE_PART_KEY = "thePart"; //$NON-NLS-1$
 
 	/**
-	 * Key to control the default default value of the "most recently used"
-	 * order enablement
+	 * Key to control the default default value of the "most recently used" order
+	 * enablement
 	 */
 	public static final String MRU_KEY_DEFAULT = "enableMRUDefault"; //$NON-NLS-1$
 
@@ -127,27 +126,11 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	 */
 	public static final String MRU_KEY = "enableMRU"; //$NON-NLS-1$
 
-	/**
-	 * Key to switch if the "most recently used" behavior controlled via CSS or
-	 * preferences
-	 */
-	public static final String MRU_CONTROLLED_BY_CSS_KEY = "MRUControlledByCSS"; //$NON-NLS-1$
-
 	/**
 	 * Default default value for MRU behavior.
 	 */
 	public static final boolean MRU_DEFAULT = true;
 
-	/*
-	 * org.eclipse.ui.internal.dialogs.ViewsPreferencePage controls currently
-	 * the MRU behavior via IEclipsePreferences, so that CSS values from the
-	 * themes aren't used.
-	 *
-	 * TODO once we can use preferences from CSS (and update the value on the
-	 * fly) we can switch this default to true, see discussion on bug 388476.
-	 */
-	private static final boolean MRU_CONTROLLED_BY_CSS_DEFAULT = false;
-
 	/*
 	 * JFace key for default workbench tab font
 	 */
@@ -166,9 +149,9 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	private static final String STACK_SELECTED_PART = "stack_selected_part"; //$NON-NLS-1$
 
 	/**
-	 * Add this tag to prevent the next tab's activation from granting focus
-	 * toac the part. This is used to keep the focus on the CTabFolder when
-	 * traversing the tabs using the keyboard.
+	 * Add this tag to prevent the next tab's activation from granting focus toac
+	 * the part. This is used to keep the focus on the CTabFolder when traversing
+	 * the tabs using the keyboard.
 	 */
 	private static final String INHIBIT_FOCUS = "InhibitFocus"; //$NON-NLS-1$
 
@@ -191,6 +174,8 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 
 	private TabStateHandler tabStateHandler;
 
+	private boolean imageChanged;
+
 	List<CTabItem> getItemsToSet(MPart part) {
 		List<CTabItem> itemsToSet = new ArrayList<>();
 
@@ -249,7 +234,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		List<CTabItem> itemsToSet = getItemsToSet(part);
 		for (CTabItem item : itemsToSet) {
 			if (key.equals(IPresentationEngine.OVERRIDE_ICON_IMAGE_KEY)) {
-				item.setImage(getImage(part));
+				changePartTabImage(part, item);
 			} else if (key.equals(IPresentationEngine.OVERRIDE_TITLE_TOOL_TIP_KEY)) {
 				String newTip = getToolTip(part);
 				item.setToolTipText(getToolTip(newTip));
@@ -295,28 +280,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	@Inject
 	@Optional
 	void subscribeTopicChildrenChanged(@UIEventTopic(UIEvents.ElementContainer.TOPIC_CHILDREN) Event event) {
-
-		Object changedObj = event.getProperty(UIEvents.EventTags.ELEMENT);
-		// only interested in changes to toolbars and view menu (not popup menus)
-		if (!(changedObj instanceof MToolBar)
-				&& !(changedObj instanceof MMenu && !(changedObj instanceof MPopupMenu))) {
-			return;
-		}
-
-		MUIElement container = modelService.getContainer((MUIElement) changedObj);
-		// check if this is a part's toolbar
-		if (container instanceof MPart) {
-			MElementContainer<?> parent = ((MPart) container).getParent();
-			// only relayout if this part is the selected element and we
-			// actually rendered this element
-			if (parent instanceof MPartStack && parent.getSelectedElement() == container
-					&& parent.getRenderer() == StackRenderer.this) {
-				Object widget = parent.getWidget();
-				if (widget instanceof CTabFolder) {
-					adjustTopRight((CTabFolder) widget);
-				}
-			}
-		}
+		shouldTopRightAdjusted(event);
 	}
 
 	@Inject
@@ -385,8 +349,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 
 	@Inject
 	@Optional
-	void subscribeTopicClosablePlaceholderChanged(
-			@UIEventTopic(UIEvents.Placeholder.TOPIC_CLOSEABLE) Event event) {
+	void subscribeTopicClosablePlaceholderChanged(@UIEventTopic(UIEvents.Placeholder.TOPIC_CLOSEABLE) Event event) {
 		updateClosableTab(event);
 	}
 
@@ -443,51 +406,57 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	@Inject
 	@Optional
 	void subscribeTopicVisibleChanged(@UIEventTopic(UIEvents.UIElement.TOPIC_VISIBLE) Event event) {
-		shouldViewMenuBeRendered(event);
+		shouldTopRightAdjusted(event);
 	}
 
 	@Inject
 	@Optional
 	void subscribeTopicToBeRenderedChanged(@UIEventTopic(UIEvents.UIElement.TOPIC_TOBERENDERED) Event event) {
-		shouldViewMenuBeRendered(event);
+		shouldTopRightAdjusted(event);
 	}
 
+	@Inject
+	@Optional
+	private UISynchronize synchronize;
+
 	/**
-	 * An event handler for listening to changes to the state of view menus and
-	 * its child menu items. Depending on what state these items are in, the
-	 * view menu should or should not be rendered in the tab folder.
+	 * An event handler for listening to changes to the state of view menus and part
+	 * toolbars. Depending on what state these items are in, the view menu and
+	 * toolbar should or should not be rendered on the tab folder.
 	 */
-	private void shouldViewMenuBeRendered(Event event) {
+	private void shouldTopRightAdjusted(Event event) {
 		Object objElement = event.getProperty(UIEvents.EventTags.ELEMENT);
 
-		// Ensure that this event is for a MMenuItem
-		if (!(objElement instanceof MMenuElement)) {
+		// Ensure that this event is for a MMenuItem or MToolBar
+		if (!(objElement instanceof MMenuElement && !(objElement instanceof MPopupMenu))
+				&& !(objElement instanceof MToolBar)) {
 			return;
 		}
 
-		// Ensure that it's a View part's menu
-		MMenuElement menuModel = (MMenuElement) objElement;
-		MUIElement menuParent = modelService.getContainer(menuModel);
-		if (!(menuParent instanceof MPart))
+		// Ensure that it's a View part's menu or toolbar
+		MUIElement uiElement = (MUIElement) objElement;
+		MUIElement parent = modelService.getContainer(uiElement);
+		if (!(parent instanceof MPart)) {
 			return;
+		}
 
-		MPart element = (MPart) menuParent;
+		// Get the partstack and the element in the partstack
+		MStackElement element = (MPart) parent;
+		if (element.getCurSharedRef() != null) {
+			element = element.getCurSharedRef();
+		}
 		MUIElement parentElement = element.getParent();
-		if (parentElement == null) {
-			MPlaceholder placeholder = element.getCurSharedRef();
-			if (placeholder == null) {
-				return;
-			}
 
-			parentElement = placeholder.getParent();
-			if (parentElement == null) {
-				return;
-			}
+		if (!(parentElement instanceof MPartStack)) {
+			return;
 		}
 
 		Object widget = parentElement.getWidget();
 		if (widget instanceof CTabFolder) {
-			adjustTopRight((CTabFolder) widget);
+			// The widget is created by the PartRenderingEngine, however the order of this
+			// call and the call in the engine are unknown. Therefore, call it
+			// asynchronously such that it is always last.
+			synchronize.asyncExec(() -> adjustTopRight((CTabFolder) widget));
 		}
 	}
 
@@ -519,10 +488,8 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 
 		MPartStack pStack = (MPartStack) (partParent instanceof MPartStack ? partParent : null);
 
-		List<String> tags = new ArrayList<>();
-		tags.add(CSSConstants.CSS_ACTIVE_CLASS);
 		List<MUIElement> activeElements = modelService.findElements(modelService.getTopLevelWindowFor(newActivePart),
-				null, MUIElement.class, tags);
+				null, MUIElement.class, singletonList(CSSConstants.CSS_ACTIVE_CLASS));
 		for (MUIElement element : activeElements) {
 			if (element instanceof MPartStack && element != pStack) {
 				styleElement(element, false);
@@ -561,9 +528,6 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	@PostConstruct
 	public void init() {
 		super.init(eventBroker);
-
-		preferences.addPreferenceChangeListener(this);
-		preferenceChange(null);
 	}
 
 	protected void updateTab(CTabItem cti, MPart part, String attName, Object newValue) {
@@ -577,7 +541,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 			cti.setText(getLabel(part, part.getLocalizedLabel()));
 			break;
 		case UIEvents.UILabel.ICONURI:
-			cti.setImage(getImage(part));
+			changePartTabImage(part, cti);
 			break;
 		case UIEvents.UILabel.TOOLTIP:
 		case UIEvents.UILabel.LOCALIZED_TOOLTIP:
@@ -593,6 +557,12 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		}
 	}
 
+	private void changePartTabImage(MPart part, CTabItem item) {
+		this.imageChanged = true;
+		item.setImage(getImage(part));
+		this.imageChanged = false;
+	}
+
 	@PreDestroy
 	public void contextDisposed() {
 		super.contextDisposed(eventBroker);
@@ -633,7 +603,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		int styleOverride = getStyleOverride(pStack);
 		int style = styleOverride == -1 ? SWT.BORDER : styleOverride;
 		final CTabFolder tabFolder = new CTabFolder(parentComposite, style);
-		tabFolder.setMRUVisible(getMRUValue(tabFolder));
+		tabFolder.setMRUVisible(getMRUValue());
 
 		// Adjust the minimum chars based on the location
 		int location = modelService.getElementLocation(element);
@@ -653,47 +623,20 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		return tabFolder;
 	}
 
-	private boolean getInitialMRUValue(Control control) {
-		CSSRenderingUtils util = context.get(CSSRenderingUtils.class);
-		if (util == null) {
-			return getMRUValueFromPreferences();
-		}
-
-		CSSValue value = util.getCSSValue(control, "MPartStack", "swt-mru-visible"); //$NON-NLS-1$ //$NON-NLS-2$
-
-		if (value == null) {
-			value = util.getCSSValue(control, "MPartStack", "mru-visible"); //$NON-NLS-1$ //$NON-NLS-2$
-		}
-		if (value == null) {
-			return getMRUValueFromPreferences();
-		}
-		return Boolean.parseBoolean(value.getCssText());
-	}
-
-	private boolean getMRUValue(Control control) {
-		if (CSSPropertyMruVisibleSWTHandler.isMRUControlledByCSS()) {
-			return getInitialMRUValue(control);
-		}
+	private boolean getMRUValue() {
 		return getMRUValueFromPreferences();
 	}
 
 	private boolean getMRUValueFromPreferences() {
 		boolean initialMRUValue = preferences.getBoolean(MRU_KEY_DEFAULT, MRU_DEFAULT);
-		boolean actualValue = preferences.getBoolean(MRU_KEY, initialMRUValue);
-		return actualValue;
+		return preferences.getBoolean(MRU_KEY, initialMRUValue);
 	}
 
 	private void updateMRUValue(CTabFolder tabFolder) {
-		boolean actualMRUValue = getMRUValue(tabFolder);
+		boolean actualMRUValue = getMRUValue();
 		tabFolder.setMRUVisible(actualMRUValue);
 	}
 
-	@Override
-	public void preferenceChange(PreferenceChangeEvent event) {
-		boolean mruControlledByCSS = preferences.getBoolean(MRU_CONTROLLED_BY_CSS_KEY, MRU_CONTROLLED_BY_CSS_DEFAULT);
-		CSSPropertyMruVisibleSWTHandler.setMRUControlledByCSS(mruControlledByCSS);
-	}
-
 	/**
 	 * @param tabFolder
 	 */
@@ -701,6 +644,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		Composite trComp = new Composite(tabFolder, SWT.NONE);
 		RowLayout rl = new RowLayout();
 		trComp.setLayout(rl);
+		rl.spacing = 0;
 		rl.marginBottom = rl.marginTop = rl.marginRight = rl.marginLeft = 0;
 		tabFolder.setTopRight(trComp, SWT.RIGHT | SWT.WRAP);
 
@@ -710,6 +654,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		// Create a toolbar for the view's drop-down menu
 		ToolBar menuTB = new ToolBar(trComp, SWT.FLAT | SWT.RIGHT);
 		menuTB.setData(TAG_VIEW_MENU);
+		tabFolder.setData(TAG_VIEW_MENU, menuTB);
 		RowData rd = new RowData();
 		menuTB.setLayoutData(rd);
 		ToolItem ti = new ToolItem(menuTB, SWT.PUSH);
@@ -749,85 +694,61 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		trComp.pack();
 	}
 
-	boolean adjusting = false;
 
 	public void adjustTopRight(final CTabFolder tabFolder) {
-		if (adjusting)
+		if (tabFolder.isDisposed()) {
 			return;
-
-		adjusting = true;
-
-		try {
-			// Gather the parameters...old part, new part...
-			MPartStack stack = (MPartStack) tabFolder.getData(OWNING_ME);
-			MUIElement element = stack.getSelectedElement();
-			MPart curPart = (MPart) tabFolder.getTopRight().getData(THE_PART_KEY);
-			MPart part = null;
-			if (element != null) {
-				part = (MPart) ((element instanceof MPart) ? element : ((MPlaceholder) element).getRef());
-			}
-
-			// Hide the old TB if we're changing
-			if (part != curPart && curPart != null && curPart.getToolbar() != null) {
-				curPart.getToolbar().setVisible(false);
-			}
-
-			Composite trComp = (Composite) tabFolder.getTopRight();
-			Control[] kids = trComp.getChildren();
-
-			boolean needsTB = part != null && part.getToolbar() != null && part.getToolbar().isToBeRendered();
-
-			// View menu (if any)
-			MMenu viewMenu = getViewMenu(part);
-			boolean needsMenu = viewMenu != null && hasVisibleMenuItems(viewMenu, part);
-
-			// Check the current state of the TB's
-			ToolBar menuTB = (ToolBar) kids[kids.length - 1];
-
-			// We need to modify the 'exclude' bit based on if the menuTB is
-			// visible or not
-			RowData rd = (RowData) menuTB.getLayoutData();
-			if (needsMenu) {
-				menuTB.getItem(0).setData(THE_PART_KEY, part);
-				menuTB.moveBelow(null);
-				menuTB.pack();
-				rd.exclude = false;
-				menuTB.setVisible(true);
-			} else {
-				menuTB.getItem(0).setData(THE_PART_KEY, null);
-				rd.exclude = true;
-				menuTB.setVisible(false);
-			}
-
-			ToolBar newViewTB = null;
-			if (needsTB && part != null && part.getObject() != null) {
-				part.getToolbar().setVisible(true);
-				newViewTB = (ToolBar) renderer.createGui(part.getToolbar(), tabFolder.getTopRight(), part.getContext());
-				// We can get calls during shutdown in which case the
-				// rendering engine will return 'null' because you can't
-				// render anything while a removeGui is taking place...
-				if (newViewTB == null) {
-					adjusting = false;
-					return;
-				}
-				newViewTB.moveAbove(null);
-				newViewTB.pack();
-			}
-
-			if (needsMenu || needsTB) {
-				tabFolder.getTopRight().setData(THE_PART_KEY, part);
-				tabFolder.getTopRight().pack(true);
-				tabFolder.getTopRight().setVisible(true);
-			} else {
-				tabFolder.getTopRight().setData(THE_PART_KEY, null);
-				tabFolder.getTopRight().setVisible(false);
-			}
-
-			// Pack the result
-			trComp.pack();
-		} finally {
-			adjusting = false;
 		}
+
+		// Gather the parameters
+		MPartStack stack = (MPartStack) tabFolder.getData(OWNING_ME);
+		MUIElement element = stack.getSelectedElement();
+		MPart part = null;
+		if (element != null) {
+			part = (MPart) ((element instanceof MPart) ? element : ((MPlaceholder) element).getRef());
+		}
+
+		Composite trComp = (Composite) tabFolder.getTopRight();
+
+		boolean needsTB = part != null && part.getToolbar() != null && part.getToolbar().isToBeRendered();
+
+		// View menu (if any)
+		MMenu viewMenu = getViewMenu(part);
+		boolean needsMenu = viewMenu != null && hasVisibleMenuItems(viewMenu, part);
+
+		// Check the current state of the TB's
+		ToolBar menuTB = (ToolBar) tabFolder.getData(TAG_VIEW_MENU);
+
+		// We need to modify the 'exclude' bit based on if the menuTB is
+		// visible or not
+		RowData rd = (RowData) menuTB.getLayoutData();
+		if (needsMenu) {
+			menuTB.getItem(0).setData(THE_PART_KEY, part);
+			rd.exclude = false;
+			menuTB.setVisible(true);
+		} else {
+			menuTB.getItem(0).setData(THE_PART_KEY, null);
+			rd.exclude = true;
+			menuTB.setVisible(false);
+		}
+
+		menuTB.moveBelow(null);
+
+		if (needsMenu || needsTB) {
+			tabFolder.getTopRight().setVisible(true);
+		} else {
+			tabFolder.getTopRight().setVisible(false);
+		}
+
+		// Pack the result
+		try {
+			trComp.setRedraw(false);
+			trComp.pack();
+			trComp.requestLayout();
+		} finally {
+			trComp.setRedraw(true);
+		}
+
 		updateMRUValue(tabFolder);
 	}
 
@@ -1084,7 +1005,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 
 				// If the user middle clicks on a tab, close it
 				if (item != null && e.button == 2) {
-					closePart(item, false);
+					closePart(item);
 				}
 
 				// If the user clicks on the tab or empty stack space, call
@@ -1118,7 +1039,7 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		CTabFolder2Adapter closeListener = new CTabFolder2Adapter() {
 			@Override
 			public void close(CTabFolderEvent event) {
-				event.doit = closePart(event.item, true);
+				event.doit = closePart(event.item);
 			}
 
 			@Override
@@ -1155,8 +1076,8 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 
 	/**
 	 * Shows a popup dialog with the list of editors availavle in a given
-	 * {@link CTabFolder}. By default the popup origin will be located close to
-	 * the chevron location.
+	 * {@link CTabFolder}. By default the popup origin will be located close to the
+	 * chevron location.
 	 *
 	 * @param stack
 	 * @param tabFolder
@@ -1168,18 +1089,17 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	/**
 	 * Shows a popup dialog with the list of editors available in the given
 	 * CTabFolder. If {@code forceCenter} enabled, the dialog is centered
-	 * horizontally; otherwise, the dialog origin is placed at chevron location.
-	 * he dialog is placed at
+	 * horizontally; otherwise, the dialog origin is placed at chevron location. he
+	 * dialog is placed at
 	 *
 	 * @param stack
 	 * @param tabFolder
-	 * @param forceCenter
-	 *            center the dialog if true
+	 * @param forceCenter center the dialog if true
 	 */
 	public void showAvailableItems(MElementContainer<?> stack, CTabFolder tabFolder, boolean forceCenter) {
 		IEclipseContext ctxt = getContext(stack);
-		final BasicPartList editorList = new BasicPartList(tabFolder.getShell(), SWT.ON_TOP, SWT.V_SCROLL | SWT.H_SCROLL,
-				ctxt.get(EPartService.class), stack, this, getMRUValueFromPreferences());
+		final BasicPartList editorList = new BasicPartList(tabFolder.getShell(), SWT.ON_TOP,
+				SWT.V_SCROLL | SWT.H_SCROLL, ctxt.get(EPartService.class), stack, this, getMRUValueFromPreferences());
 		editorList.setInput();
 
 		Point size = editorList.computeSizeHint();
@@ -1242,18 +1162,13 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	/**
 	 * Closes the part that's backed by the given widget.
 	 *
-	 * @param widget
-	 *            the part that owns this widget
-	 * @param check
-	 *            <tt>true</tt> if the part should be checked to see if it has
-	 *            been defined as being not closeable for users, <tt>false</tt>
-	 *            if this check should not be performed
+	 * @param widget the part that owns this widget
 	 * @return <tt>true</tt> if the part was closed, <tt>false</tt> otherwise
 	 */
-	private boolean closePart(Widget widget, boolean check) {
+	private boolean closePart(Widget widget) {
 		MUIElement uiElement = (MUIElement) widget.getData(AbstractPartRenderer.OWNING_ME);
 		MPart part = (MPart) ((uiElement instanceof MPart) ? uiElement : ((MPlaceholder) uiElement).getRef());
-		if (!check && !isClosable(part)) {
+		if (!isClosable(part)) {
 			return false;
 		}
 
@@ -1356,7 +1271,6 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		return viewMenuImage;
 	}
 
-
 	private void openMenuFor(MPart part, CTabFolder folder, Point point) {
 		Menu tabMenu = createTabMenu(folder, part);
 		tabMenu.setData(STACK_SELECTED_PART, part);
@@ -1365,9 +1279,13 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	}
 
 	protected boolean isClosable(MPart part) {
-		// if it's a shared part check its current ref
-		if (part.getCurSharedRef() != null) {
-			return !(part.getCurSharedRef().getTags().contains(IPresentationEngine.NO_CLOSE));
+		MPlaceholder curSharedRef = part.getCurSharedRef();
+		if (curSharedRef != null) {
+			// if it's a shared part check its current ref
+			if (curSharedRef.getTags().contains(IPresentationEngine.NO_CLOSE)) {
+				return false;
+			}
+			return curSharedRef.isCloseable();
 		}
 
 		return part.isCloseable();
@@ -1427,11 +1345,22 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 			}
 		}
 
-		if (closeableElements > 0) {
-			new MenuItem(menu, SWT.SEPARATOR);
-		}
-		createMenuItem(menu, SWTRenderersMessages.menuDetach, e -> detachActivePart(menu));
+		if (isDetachable(part)) {
+			if (closeableElements > 0) {
+				new MenuItem(menu, SWT.SEPARATOR);
+			}
 
+			createMenuItem(menu, SWTRenderersMessages.menuDetach, e -> detachActivePart(menu));
+		}
+	}
+
+	protected boolean isDetachable(MPart part) {
+		// if it's a shared part check its current ref
+		if (part.getCurSharedRef() != null) {
+			return !part.getCurSharedRef().getTags().contains(IPresentationEngine.NO_DETACH);
+		}
+
+		return !part.getTags().contains(IPresentationEngine.NO_DETACH);
 	}
 
 	/**
@@ -1652,10 +1581,8 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	/**
 	 * Determine whether the given view menu has any visible menu items.
 	 *
-	 * @param viewMenu
-	 *            the view menu to check
-	 * @param part
-	 *            the view menu's parent part
+	 * @param viewMenu the view menu to check
+	 * @param part     the view menu's parent part
 	 * @return <tt>true</tt> if the specified view menu has visible children,
 	 *         <tt>false</tt> otherwise
 	 */
@@ -1708,13 +1635,12 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 
 	/**
 	 * An event handler for listening to changes to the children of an element
-	 * container. The tab folder may need to layout itself again if a part's
-	 * toolbar has been changed.
+	 * container. The tab folder may need to layout itself again if a part's toolbar
+	 * has been changed.
 	 */
 	@SuppressWarnings("javadoc")
 	public class TabStateHandler implements EventHandler {
 
-		@SuppressWarnings("restriction")
 		@Override
 		public void handleEvent(Event event) {
 			Object element = event.getProperty(UIEvents.EventTags.ELEMENT);
@@ -1784,7 +1710,6 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 		}
 	}
 
-	@SuppressWarnings("restriction")
 	static boolean isCssEngineActive(CTabItem cti) {
 		return WidgetElement.getEngine(cti.getParent()) != null;
 	}
@@ -1804,8 +1729,8 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 	}
 
 	/**
-	 * Updates the visual for busy state of the part tab in case CSS engine is
-	 * not active
+	 * Updates the visual for busy state of the part tab in case CSS engine is not
+	 * active
 	 */
 	static void updateBusyStateNoCss(CTabItem cti, Object newValue, Object oldValue) {
 		Font updatedFont = null;
@@ -1818,4 +1743,9 @@ public class StackRenderer extends LazyStackRenderer implements IPreferenceChang
 			cti.setFont(updatedFont);
 		}
 	}
+
+	@Override
+	protected boolean imageChanged() {
+		return this.imageChanged;
+	}
 }
