@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 IBM Corporation and others.
+ * Copyright (c) 2009, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,6 +19,7 @@
  *     Patrik Suzzi <psuzzi@gmail.com> - Bug 473184
  *     Simon Scholz <simon.scholz@vogella.com> - Bug 506306
  *     Axel Richard <axel.richard@oebo.fr> - Bug 354538
+ *     Rolf Theunissen <rolf.theunissen@gmail.com> - Bug 378495
  *******************************************************************************/
 package org.eclipse.e4.ui.workbench.renderers.swt;
 
@@ -26,8 +27,8 @@ import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.HashSet;
+import java.util.IdentityHashMap;
 import java.util.List;
 import java.util.Map;
 import javax.annotation.PostConstruct;
@@ -41,6 +42,7 @@ import org.eclipse.e4.core.contexts.RunAndTrack;
 import org.eclipse.e4.core.di.annotations.Optional;
 import org.eclipse.e4.core.services.events.IEventBroker;
 import org.eclipse.e4.core.services.log.Logger;
+import org.eclipse.e4.ui.css.swt.dom.WidgetElement;
 import org.eclipse.e4.ui.di.UIEventTopic;
 import org.eclipse.e4.ui.internal.workbench.ContributionsAnalyzer;
 import org.eclipse.e4.ui.internal.workbench.OpaqueElementUtil;
@@ -68,7 +70,8 @@ import org.eclipse.e4.ui.workbench.Selector;
 import org.eclipse.e4.ui.workbench.UIEvents;
 import org.eclipse.e4.ui.workbench.UIEvents.ElementContainer;
 import org.eclipse.e4.ui.workbench.UIEvents.EventTags;
-import org.eclipse.e4.ui.workbench.modeling.EModelService;
+import org.eclipse.emf.common.util.ECollections;
+import org.eclipse.emf.common.util.EList;
 import org.eclipse.jface.action.AbstractGroupMarker;
 import org.eclipse.jface.action.ContributionItem;
 import org.eclipse.jface.action.GroupMarker;
@@ -84,7 +87,6 @@ import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.ToolBar;
-import org.eclipse.swt.widgets.ToolItem;
 import org.eclipse.swt.widgets.Widget;
 import org.osgi.service.event.Event;
 
@@ -103,33 +105,24 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 	public static final String UPDATE_VARS = "ToolBarManagerRenderer.updateVars"; //$NON-NLS-1$
 	private static final String DISPOSE_ADDED = "ToolBarManagerRenderer.disposeAdded"; //$NON-NLS-1$
 
-	private Map<MToolBar, ToolBarManager> modelToManager = new HashMap<>();
-	private Map<ToolBarManager, MToolBar> managerToModel = new HashMap<>();
+	private Map<MToolBar, ToolBarManager> modelToManager = new IdentityHashMap<>();
+	private Map<ToolBarManager, MToolBar> managerToModel = new IdentityHashMap<>();
 
-	private Map<MToolBarElement, IContributionItem> modelToContribution = new HashMap<>();
-	private Map<IContributionItem, MToolBarElement> contributionToModel = new HashMap<>();
+	private Map<MToolBarElement, IContributionItem> modelToContribution = new IdentityHashMap<>();
+	private Map<IContributionItem, MToolBarElement> contributionToModel = new IdentityHashMap<>();
 
-	private Map<MToolBarElement, ToolBarContributionRecord> modelContributionToRecord = new HashMap<>();
+	private Map<MToolBarElement, ToolBarContributionRecord> modelContributionToRecord = new IdentityHashMap<>();
 
-	private Map<MToolBarElement, ArrayList<ToolBarContributionRecord>> sharedElementToRecord = new HashMap<>();
+	private Map<MToolBarElement, ArrayList<ToolBarContributionRecord>> sharedElementToRecord = new IdentityHashMap<>();
 
 	private ToolItemUpdater enablementUpdater = new ToolItemUpdater();
 
-	// See Bug 536308
-	// remove disableThrottling system property in 4.11 if no problems are
-	// identified in 4.10
-	private static boolean disableThrottling = System.getProperty("bug_536308.disable.throttling") != null; //$NON-NLS-1$
-
-
 	@Inject
 	private Logger logger;
 
 	@Inject
 	private MApplication application;
 
-	@Inject
-	EModelService modelService;
-
 	@Inject
 	@Optional
 	private void subscribeTopicUpdateItems(@UIEventTopic(UIEvents.UILabel.TOPIC_ALL) Event event) {
@@ -158,79 +151,74 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 
 	@Inject
 	@Optional
-	private void subscribeTopicUpdateToBeRendered(@UIEventTopic(UIEvents.UIElement.TOPIC_ALL) Event event) {
+	private void subscribeUIElementTopicToBeRendered(@UIEventTopic(UIEvents.UIElement.TOPIC_TOBERENDERED) Event event) {
 		// Ensure that this event is for a MToolBarElement
 		if (!(event.getProperty(UIEvents.EventTags.ELEMENT) instanceof MToolBarElement)) {
 			return;
 		}
 
 		MToolBarElement itemModel = (MToolBarElement) event.getProperty(UIEvents.EventTags.ELEMENT);
-		String attName = (String) event.getProperty(UIEvents.EventTags.ATTNAME);
-		if (UIEvents.UIElement.TOBERENDERED.equals(attName)) {
-			Object obj = itemModel.getParent();
-			if (!(obj instanceof MToolBar)) {
-				return;
+		Object obj = itemModel.getParent();
+		if (!(obj instanceof MToolBar)) {
+			return;
+		}
+		ToolBarManager parent = getManager((MToolBar) obj);
+		if (itemModel.isToBeRendered()) {
+			if (parent != null) {
+				modelProcessSwitch(parent, itemModel);
+				updateWidget(parent);
 			}
-			ToolBarManager parent = getManager((MToolBar) obj);
-			if (itemModel.isToBeRendered()) {
-				if (parent != null) {
-					modelProcessSwitch(parent, itemModel);
-					parent.update(true);
-					ToolBar toolbar = parent.getControl();
-					if (toolbar != null && !toolbar.isDisposed()) {
-						toolbar.requestLayout();
-					}
-				}
-			} else {
-				IContributionItem ici = modelToContribution.remove(itemModel);
-				if (ici != null && parent != null) {
-					parent.remove(ici);
-				}
-				if (ici != null) {
-					ici.dispose();
-				}
-			}
-		} else if (UIEvents.UIElement.VISIBLE.equals(attName)) {
-			IContributionItem ici = getContribution(itemModel);
-			if (ici == null) {
-				return;
-			}
-
-			ToolBarManager parent = null;
-			if (ici instanceof MenuManager) {
-				parent = (ToolBarManager) ((MenuManager) ici).getParent();
-			} else if (ici instanceof ContributionItem) {
-				parent = (ToolBarManager) ((ContributionItem) ici).getParent();
-			}
-
-			if (parent == null) {
-				ici.setVisible(itemModel.isVisible());
-				return;
-			}
-
-			IContributionManagerOverrides ov = parent.getOverrides();
-			// partial fix for bug 383569: only change state if there are no
-			// extra override mechanics controlling element visibility
-			if (ov == null) {
-				ici.setVisible(itemModel.isVisible());
-			} else {
-				Boolean visible = ov.getVisible(ici);
-				if (visible == null) {
-					// same as above: only change state if there are no extra
-					// override mechanics controlling element visibility
-					ici.setVisible(itemModel.isVisible());
-				}
-			}
-
-			parent.markDirty();
-			parent.update(true);
-			ToolBar toolbar = parent.getControl();
-			if (toolbar != null && !toolbar.isDisposed()) {
-				toolbar.requestLayout();
+		} else {
+			removeElement(parent, itemModel);
+			if (parent != null) {
+				updateWidget(parent);
 			}
 		}
 	}
 
+	@Inject
+	@Optional
+	private void subscribeUIElementTopicVisible(@UIEventTopic(UIEvents.UIElement.TOPIC_VISIBLE) Event event) {
+		// Ensure that this event is for a MToolBarElement
+		if (!(event.getProperty(UIEvents.EventTags.ELEMENT) instanceof MToolBarElement)) {
+			return;
+		}
+
+		MToolBarElement itemModel = (MToolBarElement) event.getProperty(UIEvents.EventTags.ELEMENT);
+		IContributionItem ici = getContribution(itemModel);
+		if (ici == null) {
+			return;
+		}
+
+		ToolBarManager parent = null;
+		if (ici instanceof MenuManager) {
+			parent = (ToolBarManager) ((MenuManager) ici).getParent();
+		} else if (ici instanceof ContributionItem) {
+			parent = (ToolBarManager) ((ContributionItem) ici).getParent();
+		}
+
+		if (parent == null) {
+			ici.setVisible(itemModel.isVisible());
+			return;
+		}
+
+		IContributionManagerOverrides ov = parent.getOverrides();
+		// partial fix for bug 383569: only change state if there are no
+		// extra override mechanics controlling element visibility
+		if (ov == null) {
+			ici.setVisible(itemModel.isVisible());
+		} else {
+			Boolean visible = ov.getVisible(ici);
+			if (visible == null) {
+				// same as above: only change state if there are no extra
+				// override mechanics controlling element visibility
+				ici.setVisible(itemModel.isVisible());
+			}
+		}
+
+		updateWidget(parent);
+	}
+
 	@Inject
 	@Optional
 	private void subscribeTopicUpdateSelection(@UIEventTopic(UIEvents.Item.TOPIC_SELECTED) Event event) {
@@ -261,18 +249,42 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		}
 	}
 
-	@SuppressWarnings("unchecked")
 	@Inject
 	@Optional
-	private void subscribeTopicChildAdded(@UIEventTopic(ElementContainer.TOPIC_CHILDREN) Event event) {
+	private void subscribeTopicUpdateChildren(@UIEventTopic(ElementContainer.TOPIC_CHILDREN) Event event) {
 		// Ensure that this event is for a MToolBar
 		if (!(event.getProperty(UIEvents.EventTags.ELEMENT) instanceof MToolBar)) {
 			return;
 		}
+
 		MToolBar toolbarModel = (MToolBar) event.getProperty(UIEvents.EventTags.ELEMENT);
+		ToolBarManager parentManager = getManager(toolbarModel);
+		if (parentManager == null) {
+			return;
+		}
+
 		if (UIEvents.isADD(event)) {
-			Object obj = toolbarModel;
-			processContents((MElementContainer<MUIElement>) obj);
+			for (Object o : UIEvents.asIterable(event, UIEvents.EventTags.NEW_VALUE)) {
+				MToolBarElement added = (MToolBarElement) o;
+				modelProcessSwitch(parentManager, added);
+			}
+			updateWidget(parentManager);
+		} else if (UIEvents.isREMOVE(event)) {
+			for (Object o : UIEvents.asIterable(event, UIEvents.EventTags.OLD_VALUE)) {
+				MToolBarElement removed = (MToolBarElement) o;
+				removed.setRenderer(null);
+				removeElement(parentManager, removed);
+			}
+			updateWidget(parentManager);
+		} else if (UIEvents.isMOVE(event)) {
+			MToolBarElement moved = (MToolBarElement) event.getProperty(UIEvents.EventTags.NEW_VALUE);
+			Integer newPos = (Integer) event.getProperty(UIEvents.EventTags.POSITION);
+
+			IContributionItem ici = getContribution(moved);
+			parentManager.remove(ici);
+			parentManager.insert(newPos, ici);
+
+			updateWidget(parentManager);
 		}
 	}
 
@@ -363,14 +375,7 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 				for (String var : updateVariables) {
 					context.get(var);
 				}
-				// See Bug 536308
-				// remove disableThrottling system property in 4.11 if no problems are
-				// identified in 4.10
-				if (disableThrottling) {
-					getUpdater().updateContributionItems(ALL_SELECTOR);
-				} else {
-					throttler.throttledExec();
-				}
+				throttler.throttledExec();
 				return true;
 			}
 		};
@@ -378,7 +383,7 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 	}
 
 	@PreDestroy
-	void preDestroy() {
+	public void preDestroy() {
 		if (Policy.DEBUG_RENDERER) {
 			logger.debug("\nTBMR:dispose: modelToManager size = {0}, managerToModel size = {1}", //$NON-NLS-1$
 					modelToManager.size(), managerToModel.size());
@@ -396,7 +401,15 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		// CSS engine to target it
 		IStylingEngine engine = getContextForParent(element).get(IStylingEngine.class);
 		if (engine != null) {
-			engine.setId(toolbarComposite, "ToolbarComposite");//$NON-NLS-1$
+			String cssClass = WidgetElement.getCSSClass(toolbarComposite);
+			if (cssClass != null && !cssClass.isEmpty()) {
+				if (!cssClass.contains("ToolbarComposite")) {//$NON-NLS-1$
+					cssClass = cssClass + " ToolbarComposite"; //$NON-NLS-1$
+				}
+			} else {
+				cssClass = "ToolbarComposite"; //$NON-NLS-1$
+			}
+			engine.setClassname(toolbarComposite, cssClass);
 		}
 
 		final MToolBar toolbarModel = (MToolBar) element;
@@ -590,7 +603,7 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		}
 	}
 
-	int getOrientation(final MUIElement element) {
+	private int getOrientation(final MUIElement element) {
 		MUIElement theParent = element.getParent();
 		if (theParent instanceof MTrimBar) {
 			MTrimBar trimContainer = (MTrimBar) theParent;
@@ -624,45 +637,18 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 				modelProcessSwitch(parentManager, (MToolBarElement) childME);
 			}
 		}
-		parentManager.update(true);
 
-		ToolBar toolbar = getToolbarFrom(container.getWidget());
-		if (toolbar != null) {
+		updateWidget(parentManager);
+	}
+
+	private void updateWidget(ToolBarManager manager) {
+		manager.update(true);
+		ToolBar toolbar = manager.getControl();
+		if (toolbar != null && !toolbar.isDisposed()) {
 			toolbar.requestLayout();
 		}
 	}
 
-	private ToolBar getToolbarFrom(Object widget) {
-		if (widget instanceof ToolBar) {
-			return (ToolBar) widget;
-		}
-		if (widget instanceof Composite) {
-			Composite intermediate = (Composite) widget;
-			if (!intermediate.isDisposed()) {
-				Control[] children = intermediate.getChildren();
-				for (Control control : children) {
-					if (control.getData() instanceof ToolBarManager) {
-						return (ToolBar) control;
-					}
-				}
-			}
-		}
-		return null;
-	}
-
-	boolean hasOnlySeparators(ToolBar toolbar) {
-		ToolItem[] children = toolbar.getItems();
-		for (ToolItem toolItem : children) {
-			if ((toolItem.getStyle() & SWT.SEPARATOR) == 0) {
-				return false;
-			} else if (toolItem.getControl() != null
-					&& toolItem.getControl().getData(OWNING_ME) instanceof MToolControl) {
-				return false;
-			}
-		}
-		return true;
-	}
-
 	@Override
 	public void hideChild(MElementContainer<MUIElement> parentElement, MUIElement child) {
 		super.hideChild(parentElement, child);
@@ -717,8 +703,10 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		return null;
 	}
 
-	private void modelProcessSwitch(ToolBarManager parentManager,
-			MToolBarElement childME) {
+	private void modelProcessSwitch(ToolBarManager parentManager, MToolBarElement childME) {
+		if (!childME.isToBeRendered()) {
+			return;
+		}
 		if (OpaqueElementUtil.isOpaqueToolItem(childME)) {
 			MToolItem itemModel = (MToolItem) childME;
 			processOpaqueItem(parentManager, itemModel);
@@ -800,7 +788,7 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		linkModelToContribution(itemModel, ci);
 	}
 
-	void processOpaqueItem(ToolBarManager parentManager, MToolItem itemModel) {
+	private void processOpaqueItem(ToolBarManager parentManager, MToolItem itemModel) {
 		IContributionItem ici = getContribution(itemModel);
 		if (ici != null) {
 			return;
@@ -835,6 +823,19 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		}
 	}
 
+	private void removeElement(ToolBarManager parentManager, MToolBarElement toolBarElement) {
+		IContributionItem ici = getContribution(toolBarElement);
+		clearModelToContribution(toolBarElement, ici);
+		if (ici != null && parentManager != null) {
+			// Check if the ici is (still) in the manager; e.g. while reconciling
+			// Whoever removes an ici form the manager is responsible for disposal
+			ici = parentManager.remove(ici);
+		}
+		if (ici != null) {
+			ici.dispose();
+		}
+	}
+
 	/**
 	 * @param model
 	 * @return mapped manager, if any
@@ -973,46 +974,23 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 	 * @param toolBar
 	 */
 	public void reconcileManagerToModel(IToolBarManager menuManager, MToolBar toolBar) {
-		List<MToolBarElement> modelChildren = toolBar.getChildren();
-		HashSet<MToolItem> oldModelItems = new HashSet<>();
-		for (MToolBarElement itemModel : modelChildren) {
-			if (OpaqueElementUtil.isOpaqueToolItem(itemModel)) {
-				oldModelItems.add((MToolItem) itemModel);
-			}
-		}
+		List<MToolBarElement> newChildren = new ArrayList<>();
 
 		IContributionItem[] items = menuManager.getItems();
-		for (int src = 0, dest = 0; src < items.length; src++, dest++) {
-			IContributionItem item = items[src];
+		for (IContributionItem item : items) {
 			MToolBarElement element = getToolElement(item);
 			if (element == null) {
-				MToolItem legacyItem = OpaqueElementUtil.createOpaqueToolItem();
-				legacyItem.setElementId(item.getId());
-				legacyItem.setVisible(item.isVisible());
-				OpaqueElementUtil.setOpaqueItem(legacyItem, item);
-				linkModelToContribution(legacyItem, item);
-				modelChildren.add(dest, legacyItem);
-			} else if (OpaqueElementUtil.isOpaqueToolItem(element)) {
-				MToolItem legacyItem = (MToolItem) element;
-				oldModelItems.remove(legacyItem);
-				if (modelChildren.size() > dest) {
-					if (modelChildren.get(dest) != legacyItem) {
-						modelChildren.remove(legacyItem);
-						modelChildren.add(dest, legacyItem);
-					}
-				} else {
-					modelChildren.add(legacyItem);
-				}
+				element = OpaqueElementUtil.createOpaqueToolItem();
+				element.setElementId(item.getId());
+				OpaqueElementUtil.setOpaqueItem(element, item);
+				element.setRenderer(this);
+				linkModelToContribution(element, item);
 			}
+			element.setVisible(item.isVisible());
+			newChildren.add(element);
 		}
 
-		if (!oldModelItems.isEmpty()) {
-			modelChildren.removeAll(oldModelItems);
-			for (MToolItem model : oldModelItems) {
-				Object obj = OpaqueElementUtil.getOpaqueItem(model);
-				clearModelToContribution(model, (IContributionItem) obj);
-			}
-		}
+		ECollections.setEList((EList<MToolBarElement>) toolBar.getChildren(), newChildren);
 	}
 
 	@Override
@@ -1035,7 +1013,7 @@ public class ToolBarManagerRenderer extends SWTPartRenderer {
 		return super.getContext(el);
 	}
 
-	ToolItemUpdater getUpdater() {
+	/* package */ ToolItemUpdater getUpdater() {
 		return enablementUpdater;
 	}
 
