@@ -16,6 +16,9 @@
  *******************************************************************************/
 package org.eclipse.e4.ui.workbench.renderers.swt;
 
+import static java.util.Collections.singletonList;
+import static org.eclipse.jface.viewers.LabelProvider.createTextProvider;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -65,14 +68,12 @@ import org.eclipse.jface.util.Geometry;
 import org.eclipse.jface.util.Util;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.CheckboxTableViewer;
-import org.eclipse.jface.viewers.LabelProvider;
 import org.eclipse.jface.window.IShellProvider;
 import org.eclipse.jface.window.Window;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.ShellListener;
-import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Rectangle;
@@ -501,7 +502,7 @@ public class WBWRenderer extends SWTPartRenderer {
 		// no direct model parent, must be a detached window
 		if (window.getParent() == null) {
 			context.set(IWindowCloseHandler.class,
-					window1 -> closeDetachedWindow(window1));
+					this::closeDetachedWindow);
 		} else {
 			context.set(IWindowCloseHandler.class,
 					window1 -> {
@@ -603,8 +604,8 @@ public class WBWRenderer extends SWTPartRenderer {
 			return;
 		}
 
-		List<MPartStack> stacks = modelService.findElements(perspective, null,
-				MPartStack.class, Arrays.asList(CSSConstants.CSS_ACTIVE_CLASS));
+		List<MPartStack> stacks = modelService.findElements(perspective, null, MPartStack.class,
+				singletonList(CSSConstants.CSS_ACTIVE_CLASS));
 		if (stacks.isEmpty()) {
 			return;
 		}
@@ -740,8 +741,7 @@ public class WBWRenderer extends SWTPartRenderer {
 				shell.setMinimized(true);
 			}
 
-			shell.layout(true);
-			forceLayout(shell);
+			forceLayout(shell); // See Bug 375576
 		} finally {
 			if (shellME.isVisible()) {
 				shell.open();
@@ -807,12 +807,8 @@ public class WBWRenderer extends SWTPartRenderer {
 			data.heightHint = 250;
 			data.widthHint = 300;
 			tableViewer.getControl().setLayoutData(data);
-			tableViewer.setLabelProvider(new LabelProvider() {
-				@Override
-				public String getText(Object element) {
-					return ((MPart) element).getLocalizedLabel();
-				}
-			});
+			tableViewer.setLabelProvider(createTextProvider(element -> ((MPart) element).getLocalizedLabel()));
+
 			tableViewer.setContentProvider(ArrayContentProvider.getInstance());
 			tableViewer.setInput(collection);
 			tableViewer.setAllChecked(true);
@@ -882,8 +878,7 @@ public class WBWRenderer extends SWTPartRenderer {
 			if (registry instanceof SWTResourcesRegistry) {
 				return ((SWTResourcesRegistry) registry)
 						.removeResourcesByKeyTypeAndType(
-								ResourceByDefinitionKey.class, Font.class,
-								Color.class);
+								ResourceByDefinitionKey.class, Font.class);
 			}
 			return Collections.emptyList();
 		}
@@ -900,11 +895,11 @@ public class WBWRenderer extends SWTPartRenderer {
 
 	private void forceLayout(Shell shell) {
 		int i = 0;
-		while(shell.isLayoutDeferred()) {
+		while (shell.isLayoutDeferred()) {
 			shell.setLayoutDeferred(false);
 			i++;
 		}
-		while(i > 0) {
+		while (i > 0) {
 			shell.setLayoutDeferred(true);
 			i--;
 		}
