@@ -349,7 +349,6 @@ public class E4Application implements IApplication {
 	}
 
 	private MApplication loadApplicationModel(IApplicationContext appContext, IEclipseContext eclipseContext) {
-		MApplication theApp = null;
 
 		Location instanceLocation = WorkbenchSWTActivator.getDefault().getInstanceLocation();
 
@@ -358,7 +357,7 @@ public class E4Application implements IApplication {
 
 		// Save and restore
 		Boolean saveAndRestore = getArgValue(IWorkbench.PERSIST_STATE, appContext, false)
-				.map(value -> Boolean.parseBoolean(value)).orElse(Boolean.TRUE);
+				.map(Boolean::parseBoolean).orElse(Boolean.TRUE);
 
 		eclipseContext.set(IWorkbench.PERSIST_STATE, saveAndRestore);
 
@@ -371,7 +370,7 @@ public class E4Application implements IApplication {
 
 		// Persisted state
 		Boolean clearPersistedState = getArgValue(IWorkbench.CLEAR_PERSISTED_STATE, appContext, true)
-				.map(value -> Boolean.parseBoolean(value)).orElse(Boolean.FALSE);
+				.map(Boolean::parseBoolean).orElse(Boolean.FALSE);
 		eclipseContext.set(IWorkbench.CLEAR_PERSISTED_STATE, clearPersistedState);
 
 		String resourceHandler = getArgValue(IWorkbench.MODEL_RESOURCE_HANDLER, appContext, false)
@@ -383,9 +382,7 @@ public class E4Application implements IApplication {
 		eclipseContext.set(IModelResourceHandler.class, handler);
 
 		Resource resource = handler.loadMostRecentModel();
-		theApp = (MApplication) resource.getContents().get(0);
-
-		return theApp;
+		return (MApplication) resource.getContents().get(0);
 	}
 
 	/**
@@ -450,7 +447,7 @@ public class E4Application implements IApplication {
 
 		final String brandingProperty = appContext.getBrandingProperty(argName);
 
-		return Optional.ofNullable(brandingProperty).map(brandingPropertyValue -> Optional.of(brandingPropertyValue))
+		return Optional.ofNullable(brandingProperty).map(Optional::of)
 				.orElse(Optional.ofNullable(System.getProperty(argName)));
 	}
 
