@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2018 IBM Corporation and others.
+ * Copyright (c) 2008, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -33,7 +33,10 @@ import javax.inject.Inject;
 import javax.inject.Named;
 import org.eclipse.core.databinding.observable.Realm;
 import org.eclipse.core.runtime.FileLocator;
+import org.eclipse.core.runtime.IConfigurationElement;
+import org.eclipse.core.runtime.IExtensionRegistry;
 import org.eclipse.core.runtime.ISafeRunnable;
+import org.eclipse.core.runtime.InvalidRegistryObjectException;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.SafeRunner;
 import org.eclipse.core.runtime.preferences.DefaultScope;
@@ -101,8 +104,6 @@ import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Widget;
 import org.eclipse.ui.testing.TestableObject;
-import org.osgi.framework.Bundle;
-import org.osgi.framework.BundleContext;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
 import org.osgi.service.log.LogService;
@@ -177,11 +178,9 @@ public class PartRenderingEngine implements IPresentationEngine {
 			}
 
 			if (okToRender) {
-				// Un-maximize the element before tearing it down
-				if (changedElement.getTags().contains(MAXIMIZED)) {
-					changedElement.getTags().remove(MAXIMIZED);
-				}
-
+				// Un-maximize the element before tearing it down, required for example to show
+				// the views after the intro page is closed
+				changedElement.getTags().remove(MAXIMIZED);
 				// Note that the 'removeGui' protocol calls 'childRemoved'
 				removeGui(changedElement);
 			}
@@ -322,12 +321,12 @@ public class PartRenderingEngine implements IPresentationEngine {
 					}
 				}
 
-				// If the element being added is a placeholder, check to see
-				// if
-				// it's 'globally visible' and, if so, remove all other
-				// 'local' placeholders referencing the same element.
+				// If the element being added is a placeholder, check to see if it's 'globally
+				// visible' and, if so, remove all other 'local' placeholders referencing the
+				// same element.
 				int newLocation = modelService.getElementLocation(added);
-				if (newLocation == EModelService.IN_SHARED_AREA || newLocation == EModelService.OUTSIDE_PERSPECTIVE) {
+				if (added instanceof MPlaceholder && (newLocation == EModelService.IN_SHARED_AREA
+						|| newLocation == EModelService.OUTSIDE_PERSPECTIVE)) {
 					MWindow topWin = modelService.getTopLevelWindowFor(added);
 					modelService.hideLocalPlaceholders(topWin, null);
 				}
@@ -347,8 +346,7 @@ public class PartRenderingEngine implements IPresentationEngine {
 				if (removed.getWidget() instanceof Control) {
 					Control ctrl = (Control) removed.getWidget();
 					ctrl.setLayoutData(null);
-					// bug 487621
-					ctrl.getParent().layout(new Control[] { ctrl }, SWT.CHANGED | SWT.DEFER);
+					ctrl.requestLayout();
 				}
 
 				// Ensure that the element about to be removed is not the
@@ -437,26 +435,12 @@ public class PartRenderingEngine implements IPresentationEngine {
 				} else {
 					elementCtrl.moveAbove(null);
 				}
+				elementCtrl.requestLayout();
 				break;
 			} else if (kid.getWidget() instanceof Control && kid.isVisible()) {
 				prevCtrl = (Control) kid.getWidget();
 			}
 		}
-
-		Object widget = parent.getWidget();
-		if (widget instanceof Composite) {
-			Composite composite = (Composite) widget;
-			if (composite.getShell() == elementCtrl.getShell()) {
-				Composite temp = elementCtrl.getParent();
-				while (temp != composite) {
-					if (temp == null) {
-						return;
-					}
-					temp = temp.getParent();
-				}
-				composite.layout(true, true);
-			}
-		}
 	}
 
 	/**
@@ -1179,9 +1163,7 @@ public class PartRenderingEngine implements IPresentationEngine {
 						}
 					} catch (ThreadDeath th) {
 						throw th;
-					} catch (Exception ex) {
-						handle(ex, advisor);
-					} catch (Error err) {
+					} catch (Exception | Error err) {
 						handle(err, advisor);
 					}
 				}
@@ -1281,12 +1263,10 @@ public class PartRenderingEngine implements IPresentationEngine {
 			appContext.set(IStylingEngine.class, new IStylingEngine() {
 				@Override
 				public void setClassname(Object widget, String classname) {
-					WidgetElement.setCSSClass((Widget) widget, classname);
 				}
 
 				@Override
 				public void setId(Object widget, String id) {
-					WidgetElement.setID((Widget) widget, id);
 				}
 
 				@Override
@@ -1299,10 +1279,7 @@ public class PartRenderingEngine implements IPresentationEngine {
 				}
 
 				@Override
-				public void setClassnameAndId(Object widget, String classname,
-						String id) {
-					WidgetElement.setCSSClass((Widget) widget, classname);
-					WidgetElement.setID((Widget) widget, id);
+				public void setClassnameAndId(Object widget, String classname, String id) {
 				}
 			});
 		} else if (cssTheme != null) {
@@ -1354,7 +1331,7 @@ public class PartRenderingEngine implements IPresentationEngine {
 			WidgetElement.setEngine(display, cssEngine);
 			if (cssResourcesURI != null) {
 				cssEngine.getResourcesLocatorManager().registerResourceLocator(
-						new OSGiResourceLocator(cssResourcesURI.toString()));
+						new OSGiResourceLocator(cssResourcesURI));
 			}
 			// FIXME: is this needed?
 			display.setData("org.eclipse.e4.ui.css.context", appContext); //$NON-NLS-1$
@@ -1463,7 +1440,7 @@ public class PartRenderingEngine implements IPresentationEngine {
 		}
 
 		protected void resetOverriddenPreferences() {
-			for (IEclipsePreferences preferences : getPreferences()) {
+			for (IEclipsePreferences preferences : getThemeRelatedPreferences()) {
 				resetOverriddenPreferences(preferences);
 			}
 		}
@@ -1483,13 +1460,28 @@ public class PartRenderingEngine implements IPresentationEngine {
 			return EclipsePreferencesHelper.getOverriddenPropertyNames(preferences);
 		}
 
-		protected Set<IEclipsePreferences> getPreferences() {
+		protected Set<IEclipsePreferences> getThemeRelatedPreferences() {
 			if (prefs == null) {
 				prefs = new HashSet<>();
-				BundleContext context = WorkbenchSWTActivator.getDefault().getContext();
-				for (Bundle bundle : context.getBundles()) {
-					if (bundle.getSymbolicName() != null) {
-						prefs.add(InstanceScope.INSTANCE.getNode(bundle.getSymbolicName()));
+				final IExtensionRegistry registry = Platform.getExtensionRegistry();
+				Set<String> bundleIDs = new HashSet<>();
+				String[] themeRelatedExtensionPoints = { "org.eclipse.e4.ui.css.swt.theme", "org.eclipse.ui.themes" };
+				for (String extensionPoint : themeRelatedExtensionPoints) {
+					IConfigurationElement[] elements = registry.getConfigurationElementsFor(extensionPoint);
+					for (IConfigurationElement element : elements) {
+						try {
+							String nameSpace = element.getNamespaceIdentifier();
+							if (nameSpace != null) {
+								bundleIDs.add(nameSpace);
+							}
+						} catch (InvalidRegistryObjectException e) {
+							Activator.log(LogService.LOG_ERROR, e.getMessage(), e);
+						}
+					}
+				}
+				for (String bundleId : bundleIDs) {
+					if (bundleId != null) {
+						prefs.add(InstanceScope.INSTANCE.getNode(bundleId));
 					}
 				}
 			}
@@ -1498,7 +1490,7 @@ public class PartRenderingEngine implements IPresentationEngine {
 
 		private void overridePreferences(IThemeEngine themeEngine) {
 			if (themeEngine != null) {
-				for (IEclipsePreferences preferences : getPreferences()) {
+				for (IEclipsePreferences preferences : getThemeRelatedPreferences()) {
 					themeEngine.applyStyles(preferences, false);
 				}
 			}
