@@ -20,7 +20,6 @@ import java.util.Set;
 
 import org.eclipse.core.databinding.observable.map.IMapChangeListener;
 import org.eclipse.core.databinding.observable.map.IObservableMap;
-import org.eclipse.core.databinding.observable.map.MapChangeEvent;
 import org.eclipse.jface.viewers.CellLabelProvider;
 import org.eclipse.jface.viewers.LabelProviderChangedEvent;
 import org.eclipse.jface.viewers.ViewerCell;
@@ -44,20 +43,17 @@ public class ObservableMapCellLabelProvider extends CellLabelProvider {
 	 */
 	protected IObservableMap<Object, Object>[] attributeMaps;
 
-	private IMapChangeListener<Object, Object> mapChangeListener = new IMapChangeListener<Object, Object>() {
-		@Override
-		public void handleMapChange(MapChangeEvent<?, ?> event) {
-			Set<?> affectedElements = event.diff.getChangedKeys();
-			LabelProviderChangedEvent newEvent = new LabelProviderChangedEvent(ObservableMapCellLabelProvider.this,
-					affectedElements.toArray());
-			fireLabelProviderChanged(newEvent);
-		}
+	private IMapChangeListener<Object, Object> mapChangeListener = event -> {
+		Set<?> affectedElements = event.diff.getChangedKeys();
+		LabelProviderChangedEvent newEvent = new LabelProviderChangedEvent(ObservableMapCellLabelProvider.this,
+				affectedElements.toArray());
+		fireLabelProviderChanged(newEvent);
 	};
 
 	/**
 	 * Creates a new label provider that tracks changes to one attribute.
 	 *
-	 * @param attributeMap
+	 * @param attributeMap attribute map to track
 	 */
 	public ObservableMapCellLabelProvider(IObservableMap<?, ?> attributeMap) {
 		this(new IObservableMap[] { attributeMap });
@@ -68,7 +64,7 @@ public class ObservableMapCellLabelProvider extends CellLabelProvider {
 	 * attribute. This constructor should be used by subclasses that override
 	 * {@link #update(ViewerCell)} and make use of more than one attribute.
 	 *
-	 * @param attributeMaps
+	 * @param attributeMaps attribute maps to track
 	 */
 	@SuppressWarnings("unchecked")
 	protected ObservableMapCellLabelProvider(IObservableMap<?, ?>[] attributeMaps) {
