@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2016 IBM Corporation and others.
+ * Copyright (c) 2005, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -22,7 +22,6 @@ import org.eclipse.jface.bindings.keys.KeyStroke;
 import org.eclipse.jface.dialogs.PopupDialog;
 import org.eclipse.jface.preference.JFacePreferences;
 import org.eclipse.jface.resource.JFaceResources;
-import org.eclipse.jface.util.Util;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.FocusAdapter;
@@ -361,7 +360,7 @@ public class ContentProposalAdapter {
 					// Backspace should back out of any stored filter text
 					if (filterStyle != FILTER_NONE) {
 						// We have no filter to back out of, so do nothing
-						if (filterText.length() == 0) {
+						if (filterText.isEmpty()) {
 							return;
 						}
 						// There is filter to back out of
@@ -391,7 +390,7 @@ public class ContentProposalAdapter {
 					// and filter the proposals.
 					if (Character.isDefined(key)) {
 						if (filterStyle == FILTER_CUMULATIVE) {
-							filterText = filterText + String.valueOf(key);
+							filterText = filterText + key;
 						} else if (filterStyle == FILTER_CHARACTER) {
 							filterText = String.valueOf(key);
 						}
@@ -615,19 +614,13 @@ public class ContentProposalAdapter {
 		 */
 		@Override
 		protected final Control createDialogArea(final Composite parent) {
-			// Use virtual where appropriate (see flag definition).
-			if (USE_VIRTUAL) {
-				proposalTable = new Table(parent, SWT.H_SCROLL | SWT.V_SCROLL
-						| SWT.VIRTUAL);
-
-				Listener listener = event -> handleSetData(event);
-				proposalTable.addListener(SWT.SetData, listener);
-			} else {
-				proposalTable = new Table(parent, SWT.H_SCROLL | SWT.V_SCROLL);
-			}
+			proposalTable = new Table(parent, SWT.H_SCROLL | SWT.V_SCROLL | SWT.VIRTUAL);
 
+			Listener listener = this::handleSetData;
+			proposalTable.addListener(SWT.SetData, listener);
 			// set the proposals to force population of the table.
 			setProposals(filterProposals(proposals, filterText));
+			proposalTable.setTextDirection(SWT.AUTO_TEXT_DIRECTION);
 
 			proposalTable.setHeaderVisible(false);
 			proposalTable.addSelectionListener(new SelectionListener() {
@@ -683,6 +676,11 @@ public class ContentProposalAdapter {
 				popupSize = getShell().getSize();
 			}
 
+			int dir = proposalTable.getTextDirection();
+			if (dir == SWT.RIGHT_TO_LEFT) {
+				initialX = initialX - popupSize.x;
+			}
+
 			// Constrain to the display
 			Rectangle constrainedBounds = getConstrainedShellBounds(new Rectangle(initialX, initialY, popupSize.x, popupSize.y));
 
@@ -715,8 +713,6 @@ public class ContentProposalAdapter {
 				item.setText(getString(current));
 				item.setImage(getImage(current));
 				item.setData(current);
-			} else {
-				// this should not happen, but does on win32
 			}
 		}
 
@@ -733,25 +729,10 @@ public class ContentProposalAdapter {
 			// If there is a table
 			if (isValid()) {
 				final int newSize = newProposals.length;
-				if (USE_VIRTUAL) {
 					// Set and clear the virtual table. Data will be
 					// provided in the SWT.SetData event handler.
-					proposalTable.setItemCount(newSize);
-					proposalTable.clearAll();
-				} else {
-					// Populate the table manually
-					proposalTable.setRedraw(false);
-					proposalTable.setItemCount(newSize);
-					TableItem[] items = proposalTable.getItems();
-					for (int i = 0; i < items.length; i++) {
-						TableItem item = items[i];
-						IContentProposal proposal = newProposals[i];
-						item.setText(getString(proposal));
-						item.setImage(getImage(proposal));
-						item.setData(proposal);
-					}
-					proposalTable.setRedraw(true);
-				}
+				proposalTable.setItemCount(newSize);
+				proposalTable.clearAll();
 				// Default to the first selection if there is content.
 				if (newProposals.length > 0) {
 					selectProposal(0);
@@ -895,6 +876,13 @@ public class ContentProposalAdapter {
 			return ret;
 		}
 
+		/**
+		 * Asynchronously recompute proposals.
+		 */
+		private void refresh() {
+			asyncRecomputeProposals(filterText);
+		}
+
 		/*
 		 * Show the currently selected proposal's description in a secondary
 		 * popup.
@@ -999,7 +987,7 @@ public class ContentProposalAdapter {
 		 */
 		private IContentProposal[] filterProposals(
 				IContentProposal[] proposals, String filterString) {
-			if (filterString.length() == 0) {
+			if (filterString.isEmpty()) {
 				return proposals;
 			}
 
@@ -1076,14 +1064,6 @@ public class ContentProposalAdapter {
 	@Deprecated
 	public static final int FILTER_CUMULATIVE = 3;
 
-	/*
-	 * Set to <code>true</code> to use a Table with SWT.VIRTUAL. This is a
-	 * workaround for https://bugs.eclipse.org/bugs/show_bug.cgi?id=98585#c40
-	 * The corresponding SWT bug is
-	 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=90321
-	 */
-	private static final boolean USE_VIRTUAL = !Util.isMotif();
-
 	/*
 	 * The delay before showing a secondary popup.
 	 */
@@ -1566,7 +1546,6 @@ public class ContentProposalAdapter {
 	/**
 	 * Add the specified listener to the list of content proposal listeners that
 	 * are notified when content proposals are chosen.
-	 * </p>
 	 *
 	 * @param listener
 	 *            the IContentProposalListener to be added as a listener. Must
@@ -1583,7 +1562,6 @@ public class ContentProposalAdapter {
 	/**
 	 * Removes the specified listener from the list of content proposal
 	 * listeners that are notified when content proposals are chosen.
-	 * </p>
 	 *
 	 * @param listener
 	 *            the IContentProposalListener to be removed as a listener. Must
@@ -1600,7 +1578,6 @@ public class ContentProposalAdapter {
 	/**
 	 * Add the specified listener to the list of content proposal listeners that
 	 * are notified when a content proposal popup is opened or closed.
-	 * </p>
 	 *
 	 * @param listener
 	 *            the IContentProposalListener2 to be added as a listener. Must
@@ -1618,7 +1595,6 @@ public class ContentProposalAdapter {
 	/**
 	 * Remove the specified listener from the list of content proposal listeners
 	 * that are notified when a content proposal popup is opened or closed.
-	 * </p>
 	 *
 	 * @param listener
 	 *            the IContentProposalListener2 to be removed as a listener.
@@ -1890,25 +1866,27 @@ public class ContentProposalAdapter {
 	}
 
 	/**
-	 * Open the proposal popup and display the proposals provided by the
-	 * proposal provider. This method returns immediately. That is, it does not
-	 * wait for a proposal to be selected. This method is used by subclasses to
-	 * explicitly invoke the opening of the popup. If there are no proposals to
-	 * show, the popup will not open and a beep will be sounded.
+	 * Open the proposal popup and display the proposals provided by the proposal
+	 * provider. This method returns immediately. That is, it does not wait for a
+	 * proposal to be selected. This method is used to explicitly invoke the opening
+	 * of the popup. If there are no proposals to show, the popup will not open and
+	 * a beep will be sounded.
+	 *
+	 * @since 3.22
 	 */
-	protected void openProposalPopup() {
+	public void openProposalPopup() {
 		openProposalPopup(false);
 	}
 
 	/**
-	 * Close the proposal popup without accepting a proposal. This method
-	 * returns immediately, and has no effect if the proposal popup was not
-	 * open. This method is used by subclasses to explicitly close the popup
-	 * based on additional logic.
+	 * Close the proposal popup without accepting a proposal. This method returns
+	 * immediately, and has no effect if the proposal popup was not open. This
+	 * method is used by subclasses to explicitly close the popup based on
+	 * additional logic.
 	 *
-	 * @since 3.3
+	 * @since 3.22
 	 */
-	protected void closeProposalPopup() {
+	public void closeProposalPopup() {
 		if (popup != null) {
 			popup.close();
 		}
@@ -2020,9 +1998,8 @@ public class ContentProposalAdapter {
 		}
 		String contents = getControlContentAdapter().getControlContents(
 				getControl());
-		IContentProposal[] proposals = proposalProvider.getProposals(contents,
+		return proposalProvider.getProposals(contents,
 				position);
-		return proposals;
 	}
 
 	/**
@@ -2111,8 +2088,7 @@ public class ContentProposalAdapter {
 	 * Return whether the control content is empty
 	 */
 	private boolean isControlContentEmpty() {
-		return getControlContentAdapter().getControlContents(getControl())
-				.length() == 0;
+		return getControlContentAdapter().getControlContents(getControl()).isEmpty();
 	}
 
 	/*
@@ -2136,7 +2112,7 @@ public class ContentProposalAdapter {
 	 */
 	private boolean shouldPopupRemainOpen() {
 		// If we always autoactivate or never autoactivate, it should remain open
-		if (autoActivateString == null || autoActivateString.length() == 0)
+		if (autoActivateString == null || autoActivateString.isEmpty())
 			return true;
 		String content = getControlContentAdapter().getControlContents(getControl());
 		for (int i=0; i<autoActivateString.length(); i++) {
@@ -2152,7 +2128,7 @@ public class ContentProposalAdapter {
 	 */
 	private boolean allowsAutoActivate() {
 		return (autoActivateString != null && autoActivateString.length() > 0) // there are specific autoactivation chars supplied
-		  || (autoActivateString == null && triggerKeyStroke == null);    // we autoactivate on everything
+			|| (autoActivateString == null && triggerKeyStroke == null);    // we autoactivate on everything
 	}
 
 	/**
@@ -2181,4 +2157,16 @@ public class ContentProposalAdapter {
 		return false;
 	}
 
+	/**
+	 * Reloads the proposals from the content provider and fills them into the
+	 * proposal pop-up, if the pop-up is currently open.
+	 *
+	 * @since 3.15
+	 */
+	public void refresh() {
+		if (isProposalPopupOpen()) {
+			popup.refresh();
+		}
+	}
+
 }
