@@ -622,9 +622,9 @@ public class ControlDecoration {
 
 		// Listener for painting the decoration
 		paintListener = event -> {
-			Control control = (Control) event.widget;
-			Rectangle rect = getDecorationRectangle(control);
 			if (shouldShowDecoration()) {
+				Control control = (Control) event.widget;
+				Rectangle rect = getDecorationRectangle(control);
 				event.gc.drawImage(getImage(), rect.x, rect.y);
 			}
 		};
@@ -1077,7 +1077,7 @@ public class ControlDecoration {
 
 		// If there is no text, any existing hover should be hidden, and
 		// there is nothing more to do.
-		if (text == null || text.length() == 0) {
+		if (text == null || text.isEmpty()) {
 			hideHover();
 			return;
 		}
@@ -1254,7 +1254,7 @@ public class ControlDecoration {
 	 * @see #setShowOnlyOnFocus(boolean)
 	 * @see #hide()
 	 * @see #show()
-     *
+	 *
 	 * @since 3.6
 	 */
 	public boolean isVisible() {
