@@ -155,8 +155,7 @@ public abstract class FieldEditorPreferencePage extends PreferencePage
 		int numColumns = calcNumberOfColumns();
 		((GridLayout) fieldEditorParent.getLayout()).numColumns = numColumns;
 		if (fields != null) {
-			for (int i = 0; i < fields.size(); i++) {
-				FieldEditor fieldEditor = fields.get(i);
+			for (FieldEditor fieldEditor : fields) {
 				fieldEditor.adjustForNumColumns(numColumns);
 			}
 		}
@@ -305,7 +304,9 @@ public abstract class FieldEditorPreferencePage extends PreferencePage
 				FieldEditor pe = e.next();
 				pe.setPage(this);
 				pe.setPropertyChangeListener(this);
-				pe.setPreferenceStore(getPreferenceStore());
+				if (pe.getPreferenceStore() == null) {
+					pe.setPreferenceStore(getPreferenceStore());
+				}
 				pe.load();
 			}
 		}
