@@ -13,7 +13,10 @@
  *******************************************************************************/
 package org.eclipse.jface.resource;
 
+import java.net.MalformedURLException;
+import java.net.URI;
 import java.net.URL;
+import java.util.function.Supplier;
 
 import org.eclipse.swt.SWTException;
 import org.eclipse.swt.graphics.Device;
@@ -61,8 +64,7 @@ public abstract class ImageDescriptor extends DeviceResourceDescriptor {
 	/**
 	 * A small red square used to warn that an image cannot be created.
 	 */
-	protected static final ImageData DEFAULT_IMAGE_DATA = new ImageData(6, 6,
-			1, new PaletteData(new RGB[] { new RGB(255, 0, 0) }));
+	protected static final ImageData DEFAULT_IMAGE_DATA = new ImageData(6, 6, 1, new PaletteData(new RGB(255, 0, 0)));
 
 	/**
 	 * Constructs an image descriptor.
@@ -167,6 +169,9 @@ public abstract class ImageDescriptor extends DeviceResourceDescriptor {
 	/**
 	 * Creates and returns a new image descriptor from a URL.
 	 *
+	 * If the URL requires scanning IO to calculate, consider using
+	 * {@link #createFromURLSupplier(boolean,Supplier)} instead.
+	 *
 	 * @param url The URL of the image file.
 	 * @return a new image descriptor
 	 */
@@ -177,6 +182,46 @@ public abstract class ImageDescriptor extends DeviceResourceDescriptor {
 		return new URLImageDescriptor(url);
 	}
 
+	/**
+	 * Creates and returns a new image descriptor from a supplier of a URL.
+	 *
+	 * The URL will not be calculated until the image data is requested, at which
+	 * point, the URL supplier will be asked to provide the URL.
+	 *
+	 * If the URL supplier returns <code>null</code>, then an image from
+	 * {@link #getMissingImageDescriptor()} will be returned if
+	 * <code>useMissingImage</code> is <code>true</code>, and <code>null</code>
+	 * otherwise.
+	 * @param useMissingImage if the supplied URL is null, use missing image or null
+	 * @param supplier        the supplier of the image
+	 *
+	 * @return the image descriptor with a deferred lookup of the URL
+	 * @since 3.21
+	 */
+	public static ImageDescriptor createFromURLSupplier(boolean useMissingImage, Supplier<URL> supplier) {
+		return new DeferredImageDescriptor(useMissingImage, supplier);
+	}
+
+	/**
+	 * Convenient method to create an ImageDescriptor from an URI
+	 *
+	 * Delegates to ImageDescriptor createFromURL
+	 *
+	 * @param uriIconPath The URI of the image file.
+	 * @return a new image descriptor
+	 *
+	 * @since 3.19
+	 */
+	public ImageDescriptor imageDescriptorFromURI(URI uriIconPath) {
+		try {
+			return ImageDescriptor.createFromURL(new URL(uriIconPath.toString()));
+		} catch (MalformedURLException | NullPointerException e) {
+			// return the missing image placeholder to indicate
+			// the incorrect call without interfering with the user flow
+			return getMissingImageDescriptor();
+		}
+	}
+
 	@Override
 	public Object createResource(Device device) throws DeviceResourceException {
 		Image result = createImage(false, device);
