@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,6 +17,7 @@
  *     Bruce Sutton, bug 221768
  *     Matthew Hall, bug 221988
  *     Julien Desgats, bug 203950
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 548314
  *******************************************************************************/
 
 package org.eclipse.jface.viewers;
@@ -56,7 +57,7 @@ import org.eclipse.swt.widgets.Widget;
  * <p>
  * As of 3.2, AbstractTreeViewer supports multiple equal elements (each with a
  * different parent chain) in the tree. This support requires that clients
- * enable the element map by calling <code>setUseHashLookup(true)</code>.
+ * enable the element map by calling <code>setUseHashlookup(true)</code>.
  * </p>
  * <p>
  * Content providers for abstract tree viewers must implement one of the
@@ -102,6 +103,11 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 */
 	private boolean isExpandableCheckFilters = false;
 
+	/**
+	 * Indicates if the viewer's content provider is an instance of ITreePathContentProvider.
+	 */
+	private boolean isTreePathContentProvider = false;
+
 	/**
 	 * Safe runnable used to update an item.
 	 */
@@ -147,7 +153,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * @param childElements
 	 *            the child elements to add
 	 */
-	public void add(Object parentElementOrTreePath, Object[] childElements) {
+	public void add(Object parentElementOrTreePath, Object... childElements) {
 		Assert.isNotNull(parentElementOrTreePath);
 		assertElementsNotNull(childElements);
 		if (checkBusy())
@@ -307,7 +313,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	private Object[] filter(Object parentElementOrTreePath, Object[] elements) {
 		ViewerFilter[] filters = getFilters();
 		if (filters != null) {
-			ArrayList filtered = new ArrayList(elements.length);
+			List<Object> filtered = new ArrayList<>(elements.length);
 			for (Object element : elements) {
 				boolean add = true;
 				for (ViewerFilter filter : filters) {
@@ -721,8 +727,8 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	}
 
 	/**
-	 * Collapses all nodes of the viewer's tree, starting with the root. This
-	 * method is equivalent to <code>collapseToLevel(ALL_LEVELS)</code>.
+	 * Collapses all nodes of the viewer's tree, starting with the root. This method
+	 * is equivalent to <code>collapseToLevel(ALL_LEVELS)</code>.
 	 */
 	public void collapseAll() {
 		Object root = getRoot();
@@ -732,20 +738,28 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	}
 
 	/**
-	 * Collapses the subtree rooted at the given element or tree path to the
-	 * given level.
+	 * Collapses the subtree rooted at the given element or tree path to the given
+	 * level.
+	 * <p>
+	 * Note that the default implementation of this method does turn redraw off via
+	 * this operation via a call to <code>setRedraw</code>
+	 * </p>
 	 *
-	 * @param elementOrTreePath
-	 *            the element or tree path
-	 * @param level
-	 *            non-negative level, or <code>ALL_LEVELS</code> to collapse
-	 *            all levels of the tree
+	 * @param elementOrTreePath the element or tree path
+	 * @param level             non-negative level, or <code>ALL_LEVELS</code> to
+	 *                          collapse all levels of the tree
 	 */
 	public void collapseToLevel(Object elementOrTreePath, int level) {
 		Assert.isNotNull(elementOrTreePath);
-		Widget w = internalGetWidgetToSelect(elementOrTreePath);
-		if (w != null) {
-			internalCollapseToLevel(w, level);
+		Control control = getControl();
+		try {
+			control.setRedraw(false);
+			Widget w = internalGetWidgetToSelect(elementOrTreePath);
+			if (w != null) {
+				internalCollapseToLevel(w, level);
+			}
+		} finally {
+			control.setRedraw(true);
 		}
 	}
 
@@ -807,7 +821,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 			if (d != null) {
 				Object parentElement = d;
 				Object[] children;
-				if (isTreePathContentProvider() && widget instanceof Item) {
+				if (isTreePathContentProvider && widget instanceof Item) {
 					TreePath path = getTreePathFromItem((Item) widget);
 					children = getSortedChildren(path);
 				} else {
@@ -1032,7 +1046,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * method is equivalent to <code>expandToLevel(ALL_LEVELS)</code>.
 	 */
 	public void expandAll() {
-		expandToLevel(ALL_LEVELS, false);
+		expandToLevel(ALL_LEVELS, true);
 	}
 
 	/**
@@ -1056,18 +1070,18 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 *            levels of the tree
 	 */
 	public void expandToLevel(int level) {
-		expandToLevel(level, false);
+		expandToLevel(level, true);
 	}
 
 	/**
 	 * Expands the root of the viewer's tree to the given level.
 	 *
-	 * @param level
-	 *            non-negative level, or <code>ALL_LEVELS</code> to expand all
-	 *            levels of the tree
-	 * @param disableRedraw
-	 *            <code>true</code> when drawing operations should be disabled
-	 *            during expansion.
+	 * @param level         non-negative level, or <code>ALL_LEVELS</code> to expand
+	 *                      all levels of the tree
+	 * @param disableRedraw <code>true</code> when drawing operations should be
+	 *                      disabled during expansion. <code>true</code> when
+	 *                      drawing operations should be enabled during expansion.
+	 *                      Prefer using true as this results in a faster UI
 	 * @since 3.14
 	 */
 	public void expandToLevel(int level, boolean disableRedraw) {
@@ -1088,7 +1102,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 *            levels of the tree
 	 */
 	public void expandToLevel(Object elementOrTreePath, int level) {
-		expandToLevel(elementOrTreePath, level, false);
+		expandToLevel(elementOrTreePath, level, true);
 	}
 
 	/**
@@ -1096,14 +1110,14 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * element becomes visible in this viewer's tree control, and then expands the
 	 * subtree rooted at the given element to the given level.
 	 *
-	 * @param elementOrTreePath
-	 *            the element
-	 * @param level
-	 *            non-negative level, or <code>ALL_LEVELS</code> to expand all
-	 *            levels of the tree
-	 * @param disableRedraw
-	 *            <code>true</code> when drawing operations should be disabled
-	 *            during expansion.
+	 * @param elementOrTreePath the element
+	 * @param level             non-negative level, or <code>ALL_LEVELS</code> to
+	 *                          expand all levels of the tree
+	 * @param disableRedraw     <code>true</code> when drawing operations should be
+	 *                          disabled during expansion. <code>false</code> when
+	 *                          drawing operations should be enabled during
+	 *                          expansion. Prefer true as this results in a faster
+	 *                          UI.
 	 * @since 3.14
 	 */
 	public void expandToLevel(Object elementOrTreePath, int level, boolean disableRedraw) {
@@ -1473,10 +1487,11 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 */
 	protected abstract Item[] getSelection(Control control);
 
+	@SuppressWarnings("rawtypes")
 	@Override
 	protected List getSelectionFromWidget() {
 		Widget[] items = getSelection(getControl());
-		ArrayList list = new ArrayList(items.length);
+		List<Object> list = new ArrayList<>(items.length);
 		for (Widget item : items) {
 			Object e = item.getData();
 			if (e != null) {
@@ -1588,10 +1603,6 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	/**
 	 * Recursively collapses the subtree rooted at the given widget to the given
 	 * level.
-	 * <p>
-	 * Note that the default implementation of this method does not call
-	 * <code>setRedraw</code>.
-	 * </p>
 	 *
 	 * @param widget the widget
 	 * @param level  non-negative level, or <code>ALL_LEVELS</code> to collapse all
@@ -1679,21 +1690,23 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 					createChildren(pw);
 					Object element = internalToElement(elementOrPath);
 					w = internalFindChild(pw, element);
-					if (expand && pw instanceof Item) {
-						// expand parent items top-down
-						Item item = (Item) pw;
-						LinkedList<Item> toExpandList = new LinkedList<>();
-						while (item != null && !getExpanded(item)) {
-							toExpandList.addFirst(item);
-							item = getParentItem(item);
-						}
-						for (Item toExpand : toExpandList) {
-							setExpanded(toExpand, true);
-						}
-					}
 				}
 			}
 		}
+		if (expand && w instanceof Item) {
+			// expand parent items top-down
+			Item item = getParentItem((Item) w);
+			LinkedList<Item> toExpandList = new LinkedList<>();
+			while (item != null) {
+				if (!getExpanded(item)) {
+					toExpandList.addFirst(item);
+				}
+				item = getParentItem(item);
+			}
+			for (Item toExpand : toExpandList) {
+				setExpanded(toExpand, true);
+			}
+		}
 		return w;
 	}
 
@@ -1713,13 +1726,12 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	}
 
 	/**
-	 * This method takes a tree path or an element. If the argument is not a
-	 * tree path, returns the parent of the given element or <code>null</code>
-	 * if the parent is not known. If the argument is a tree path with more than
-	 * one segment, returns its parent tree path, otherwise returns
-	 * <code>null</code>.
+	 * This method takes a tree path or an element. If the argument is not a tree
+	 * path, returns the parent of the given element or <code>null</code> if the
+	 * parent is not known. If the argument is a tree path with more than one
+	 * segment, returns its parent tree path, otherwise returns <code>null</code>.
 	 *
-	 * @param elementOrTreePath
+	 * @param elementOrTreePath the element or path to find parent for
 	 * @return the parent element, or parent path, or <code>null</code>
 	 *
 	 * @since 3.2
@@ -1790,8 +1802,9 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 */
 	protected void internalExpandToLevel(Widget widget, int level) {
 		if (level == ALL_LEVELS || level > 0) {
-			if (widget instanceof Item && widget.getData() != null
-					&& !isExpandable((Item) widget, null, widget.getData())) {
+			Object data = widget.getData();
+			if (widget instanceof Item && data != null
+					&& !isExpandable((Item) widget, null, data)) {
 				return;
 			}
 			createChildren(widget, false);
@@ -2180,7 +2193,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 */
 	private boolean isExpandable(Item item, TreePath parentPath, Object element) {
 		Object elementOrTreePath = element;
-		if (isTreePathContentProvider()) {
+		if (isTreePathContentProvider) {
 			if (parentPath != null) {
 				elementOrTreePath = parentPath.createChildPath(element);
 			} else {
@@ -2223,10 +2236,9 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * reflect the model. This method only affects the viewer, not the model.
 	 * </p>
 	 *
-	 * @param elementsOrTreePaths
-	 *            the elements to remove
+	 * @param elementsOrTreePaths the elements to remove
 	 */
-	public void remove(final Object[] elementsOrTreePaths) {
+	public void remove(final Object... elementsOrTreePaths) {
 		assertElementsNotNull(elementsOrTreePaths);
 		if (elementsOrTreePaths.length == 0) {
 			return;
@@ -2254,7 +2266,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 *
 	 * @since 3.2
 	 */
-	public void remove(final Object parent, final Object[] elements) {
+	public void remove(final Object parent, final Object... elements) {
 		assertElementsNotNull(elements);
 		if (elements.length == 0) {
 			return;
@@ -2388,6 +2400,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	public void setContentProvider(IContentProvider provider) {
 		// the actual check is in assertContentProviderType
 		super.setContentProvider(provider);
+		isTreePathContentProvider = provider instanceof ITreePathContentProvider;
 	}
 
 	@Override
@@ -2421,7 +2434,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 *            the array of expanded elements
 	 * @see #getExpandedElements
 	 */
-	public void setExpandedElements(Object[] elements) {
+	public void setExpandedElements(Object... elements) {
 		assertElementsNotNull(elements);
 		if (checkBusy()) {
 			return;
@@ -2457,8 +2470,8 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 *
 	 * @since 3.2
 	 */
-	public void setExpandedTreePaths(TreePath[] treePaths) {
-		assertElementsNotNull(treePaths);
+	public void setExpandedTreePaths(TreePath... treePaths) {
+		assertElementsNotNull((Object[]) treePaths);
 		if (checkBusy())
 			return;
 		final IElementComparer comparer = getComparer();
@@ -2469,6 +2482,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 				return ((TreePath) a).equals(((TreePath) b), comparer);
 			}
 
+
 			@Override
 			public int hashCode(Object element) {
 				return ((TreePath) element).hashCode(comparer);
@@ -2529,7 +2543,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * a list of tree paths.
 	 */
 	@Override
-	protected void setSelectionToWidget(List v, boolean reveal) {
+	protected void setSelectionToWidget(@SuppressWarnings("rawtypes") List v, boolean reveal) {
 		if (v == null) {
 			setSelection(new ArrayList<>(0));
 			return;
@@ -2652,7 +2666,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 		// If the children weren't passed in, get them now since they're needed
 		// below.
 		if (elementChildren == null) {
-			if (isTreePathContentProvider() && widget instanceof Item) {
+			if (isTreePathContentProvider && widget instanceof Item) {
 				TreePath path = getTreePathFromItem((Item) widget);
 				elementChildren = getSortedChildren(path);
 			} else {
@@ -2846,8 +2860,8 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * Not to be called by clients. Return the items to be refreshed as part of
 	 * an update. elementChildren are the new elements.
 	 *
-	 * @param widget
-	 * @param elementChildren
+	 * @param widget widget to get children for
+	 * @param elementChildren unused
 	 * @since 3.4
 	 * @return Item[]
 	 *
@@ -2915,12 +2929,12 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	 * @since 2.0
 	 */
 	public Object[] getVisibleExpandedElements() {
-		ArrayList v = new ArrayList();
+		ArrayList<Object> v = new ArrayList<>();
 		internalCollectVisibleExpanded(v, getControl());
 		return v.toArray();
 	}
 
-	private void internalCollectVisibleExpanded(ArrayList result, Widget widget) {
+	private void internalCollectVisibleExpanded(ArrayList<Object> result, Widget widget) {
 		Item[] items = getChildren(widget);
 		for (Item item : items) {
 			if (getExpanded(item)) {
@@ -2937,13 +2951,14 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 
 	/**
 	 * Returns the tree path for the given item.
-	 * @param item
+	 *
+	 * @param item item to get path for
 	 * @return {@link TreePath}
 	 *
 	 * @since 3.2
 	 */
 	protected TreePath getTreePathFromItem(Item item) {
-		LinkedList segments = new LinkedList();
+		LinkedList<Object> segments = new LinkedList<>();
 		while (item != null) {
 			Object segment = item.getData();
 			Assert.isNotNull(segment);
@@ -3009,8 +3024,7 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 	protected void setSelectionToWidget(ISelection selection, boolean reveal) {
 		if (selection instanceof ITreeSelection) {
 			ITreeSelection treeSelection = (ITreeSelection) selection;
-			setSelectionToWidget(Arrays.asList(treeSelection.getPaths()),
-					reveal);
+			setSelectionToWidget(Arrays.asList(treeSelection.getPaths()), reveal);
 		} else {
 			super.setSelectionToWidget(selection, reveal);
 		}
@@ -3043,10 +3057,6 @@ public abstract class AbstractTreeViewer extends ColumnViewer {
 		return result.toArray(new TreePath[items.size()]);
 	}
 
-	private boolean isTreePathContentProvider() {
-		return getContentProvider() instanceof ITreePathContentProvider;
-	}
-
 	/**
 	 * Inserts the given element as a new child element of the given parent
 	 * element at the given position. If this viewer has a sorter, the position
