@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,7 @@
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 402439, 475689
  *     Thorsten Maack <tm@tmaack.de> - Bug 482163
  *     Jan-Ove Weichel <janove.weichel@vogella.com> - Bug 481490
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 548314
  *******************************************************************************/
 package org.eclipse.jface.viewers;
 
@@ -329,9 +330,9 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 		}
 
 		/**
-		 * Apply the fonts and colors to the control if
-		 * required.
-		 * @param control
+		 * Apply the fonts and colors to the control if required.
+		 *
+		 * @param control control to apply font and color on
 		 */
 		public void applyFontsAndColors(TableItem control) {
 
@@ -353,9 +354,9 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 		}
 
 		/**
-		 * Apply the fonts and colors to the control if
-		 * required.
-		 * @param control
+		 * Apply the fonts and colors to the control if required.
+		 *
+		 * @param control control to apply font and color on
 		 */
 		public void applyFontsAndColors(TreeItem control) {
 			if(usedDecorators){
@@ -377,21 +378,26 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 
 		/**
 		 * Set the background color.
-		 * @param background
+		 *
+		 * @param background color to set
 		 */
 		public void setBackground(Color background) {
 			this.background = background;
 		}
+
 		/**
 		 * Set the font.
-		 * @param font
+		 *
+		 * @param font font to set
 		 */
 		public void setFont(Font font) {
 			this.font = font;
 		}
+
 		/**
 		 * Set the foreground color.
-		 * @param foreground
+		 *
+		 * @param foreground color to set
 		 */
 		public void setForeground(Color foreground) {
 			this.foreground = foreground;
@@ -527,7 +533,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * @param elements
 	 *            the array to check
 	 */
-	protected void assertElementsNotNull(Object[] elements) {
+	protected void assertElementsNotNull(Object... elements) {
 		Assert.isNotNull(elements);
 		for (Object element : elements) {
 			Assert.isNotNull(element);
@@ -601,11 +607,11 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * Returns the widget in this viewer's control which represents the given
 	 * element if it is the viewer's input.
 	 * <p>
-	 * This method is internal to the framework; subclassers should not call
-	 * this method.
+	 * This method is internal to the framework; subclassers should not call this
+	 * method.
 	 * </p>
 	 *
-	 * @param element
+	 * @param element the element to find the representing widget for
 	 * @return the corresponding widget, or <code>null</code> if none
 	 */
 	protected abstract Widget doFindInputItem(Object element);
@@ -614,11 +620,11 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * Returns the widget in this viewer's control which represent the given
 	 * element. This method searches all the children of the input element.
 	 * <p>
-	 * This method is internal to the framework; subclassers should not call
-	 * this method.
+	 * This method is internal to the framework; subclassers should not call this
+	 * method.
 	 * </p>
 	 *
-	 * @param element
+	 * @param element the element to find the representing widget for
 	 * @return the corresponding widget, or <code>null</code> if none
 	 */
 	protected abstract Widget doFindItem(Object element);
@@ -636,8 +642,8 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * this method.
 	 * </p>
 	 *
-	 * @param item
-	 * @param element element
+	 * @param item widget item to update
+	 * @param element the element to represent
 	 * @param fullMap
 	 *            <code>true</code> if mappings are added and removed, and
 	 *            <code>false</code> if only the new map gets installed
@@ -671,12 +677,12 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 */
 	protected Object[] filter(Object[] elements) {
 		if (filters != null) {
-			ArrayList filtered = new ArrayList(elements.length);
+			List<Object> filtered = new ArrayList<>(elements.length);
 			Object root = getRoot();
 			for (Object element : elements) {
 				boolean add = true;
-				for (int j = 0; j < filters.size(); j++) {
-					add = filters.get(j).select(this, root, element);
+				for (ViewerFilter filter : filters) {
+					add = filter.select(this, root, element);
 					if (!add) {
 						break;
 					}
@@ -844,6 +850,9 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 */
 	protected Object[] getFilteredChildren(Object parent) {
 		Object[] result = getRawChildren(parent);
+		if (result.length == 0) {
+			return result;
+		}
 		if (filters != null) {
 			for (Object element : filters) {
 				ViewerFilter f = (ViewerFilter) element;
@@ -977,7 +986,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 		if (control == null || control.isDisposed()) {
 			return StructuredSelection.EMPTY;
 		}
-		List list = getSelectionFromWidget();
+		List<?> list = getSelectionFromWidget();
 		return new StructuredSelection(list, comparer);
 	}
 
@@ -1008,6 +1017,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 *
 	 * @return the list of selected elements
 	 */
+	@SuppressWarnings("rawtypes")
 	protected abstract List getSelectionFromWidget();
 
 	/**
@@ -1203,7 +1213,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 				handleDoubleSelect(e);
 			}
 		});
-		handler.addPostSelectionListener(widgetSelectedAdapter(e -> handlePostSelect(e)));
+		handler.addPostSelectionListener(widgetSelectedAdapter(this::handlePostSelect));
 		handler.addOpenListener(StructuredViewer.this::handleOpen);
 	}
 
@@ -1305,8 +1315,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 		}
 
 		if (filters != null) {
-			for (int i = 0, n = filters.size(); i < n; ++i) {
-				ViewerFilter filter = filters.get(i);
+			for (ViewerFilter filter : filters) {
 				if (filter.isFilterProperty(element, property)) {
 					return true;
 				}
@@ -1358,6 +1367,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * false, or to reveal the selection if <code>reveal</code> is true.
 	 * <p>
 	 * The default implementation of this method:
+	 * </p>
 	 * <ul>
 	 * <li>discovers the old selection (via <code>getSelection</code>)</li>
 	 * <li>runs the given runnable</li>
@@ -1367,7 +1377,6 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 * <li>calls <code>handleInvalidSelection</code> if the selection did not
 	 * take</li>
 	 * </ul>
-	 * </p>
 	 *
 	 * @param updateCode
 	 *            the code to run
@@ -1534,7 +1543,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 		if (filters != null) {
 			// Note: can't use List.remove(Object). Use identity comparison
 			// instead.
-			for (Iterator i = filters.iterator(); i.hasNext();) {
+			for (Iterator<ViewerFilter> i = filters.iterator(); i.hasNext();) {
 				Object o = i.next();
 				if (o == filter) {
 					i.remove();
@@ -1605,9 +1614,9 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	}
 
 	/**
-	 * Assert that the content provider is of one of the
-	 * supported types.
-	 * @param provider
+	 * Assert that the content provider is of one of the supported types.
+	 *
+	 * @param provider content provider to check
 	 */
 	protected void assertContentProviderType(IContentProvider provider) {
 		Assert.isTrue(provider instanceof IStructuredContentProvider);
@@ -1621,16 +1630,8 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 					"Need an underlying widget to be able to set the input." + //$NON-NLS-1$
 							"(Has the widget been disposed?)"); //$NON-NLS-1$
 		}
-		try {
-			//		fInChange= true;
-
-			unmapAllElements();
-
-			super.setInput(input);
-
-		} finally {
-			//		fInChange= false;
-		}
+		unmapAllElements();
+		super.setInput(input);
 	}
 
 	@Override
@@ -1681,7 +1682,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 	 *            <code>true</code> if the selection is to be made visible,
 	 *            and <code>false</code> otherwise
 	 */
-	protected abstract void setSelectionToWidget(List l, boolean reveal);
+	protected abstract void setSelectionToWidget(@SuppressWarnings("rawtypes") List l, boolean reveal);
 
 	/**
 	 * Converts the selection to a <code>List</code> and calls
@@ -1702,7 +1703,7 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 		if (selection instanceof IStructuredSelection) {
 			setSelectionToWidget(((IStructuredSelection) selection).toList(), reveal);
 		} else {
-			setSelectionToWidget((List) null, reveal);
+			setSelectionToWidget((List<?>) null, reveal);
 		}
 	}
 
@@ -1749,12 +1750,17 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 
 	/**
 	 * Configures whether this structured viewer uses an internal hash table to
-	 * speeds up the mapping between elements and SWT items. This must be called
+	 * speed up the mapping between elements and SWT items. This must be called
 	 * before the viewer is given an input (via <code>setInput</code>).
+	 * <p>
+	 * Note: enabling hash lookup requires from client code that elements managed by
+	 * the viewer properly implement {@link #hashCode()} and {@link #equals(Object)}
+	 * and that equal elements are not added to the same parent in the tree (each
+	 * equal element should have a different parent chain).
+	 * </p>
 	 *
-	 * @param enable
-	 *            <code>true</code> to enable hash lookup, and
-	 *            <code>false</code> to disable it
+	 * @param enable <code>true</code> to enable hash lookup, and <code>false</code>
+	 *               to disable it
 	 */
 	public void setUseHashlookup(boolean enable) {
 		Assert.isTrue(getInput() == null,
@@ -1821,8 +1827,9 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 
 	/**
 	 * Hook for testing.
-	 * @param element
-	 * @return Widget
+	 *
+	 * @param element the element
+	 * @return the corresponding widget, or <code>null</code> if none
 	 */
 	public Widget testFindItem(Object element) {
 		return findItem(element);
@@ -1830,8 +1837,9 @@ public abstract class StructuredViewer extends ContentViewer implements IPostSel
 
 	/**
 	 * Hook for testing.
-	 * @param element
-	 * @return Widget[]
+	 *
+	 * @param element the element
+	 * @return the corresponding widgets
 	 * @since 3.2
 	 */
 	public Widget[] testFindItems(Object element) {
