@@ -392,7 +392,8 @@ public class ApplicationWindow extends Window implements IRunnableContext {
 
 	/**
 	 * Create the status line if required.
-	 * @param shell
+	 *
+	 * @param shell the shell to create status line into
 	 */
 	protected void createStatusLine(Shell shell) {
 		if (statusLineManager != null) {
@@ -761,9 +762,7 @@ public class ApplicationWindow extends Window implements IRunnableContext {
 					try {
 						ModalContext.run(runnable, fork, mgr
 								.getProgressMonitor(), display);
-					} catch (InvocationTargetException ite) {
-						holder[0] = ite;
-					} catch (InterruptedException ie) {
+					} catch (InvocationTargetException | InterruptedException ie) {
 						holder[0] = ie;
 					}
 				});
