@@ -368,7 +368,7 @@ public class FormText extends Canvas {
 			model.dispose();
 			disposeResourceTable(true);
 		});
-		addPaintListener(e -> paint(e));
+		addPaintListener(this::paint);
 		addListener(SWT.KeyDown, e -> {
 			if (e.character == '\r') {
 				activateSelectedLink();
@@ -461,7 +461,7 @@ public class FormText extends Canvas {
 				handleMouseHover(e);
 			}
 		});
-		addMouseMoveListener(e -> handleMouseMove(e));
+		addMouseMoveListener(this::handleMouseMove);
 		initAccessible();
 		ensureBoldFontPresent(getFont());
 		createMenu();
@@ -519,13 +519,11 @@ public class FormText extends Canvas {
 	}
 
 	/**
-	 * If paragraphs are separated, spacing will be added between them.
-	 * Otherwise, new paragraphs will simply start on a new line with no
-	 * spacing.
+	 * If paragraphs are separated, spacing will be added between them. Otherwise,
+	 * new paragraphs will simply start on a new line with no spacing.
 	 *
-	 * @param value
-	 *            <samp>true </samp> if paragraphs are separated, </samp> false
-	 *            </samp> otherwise.
+	 * @param value <code>true</code> if paragraphs are separated, <code>false
+	 *              </code> otherwise.
 	 */
 	public void setParagraphsSeparated(boolean value) {
 		paragraphsSeparated = value;
@@ -848,23 +846,23 @@ public class FormText extends Canvas {
 	}
 
 	/**
-	 * Controls whether whitespace inside paragraph and list items is
-	 * normalized. Note that the new value will not affect the current text in
-	 * the control, only subsequent calls to <code>setText</code> or
-	 * <code>setContents</code>.
+	 * Controls whether whitespace inside paragraph and list items is normalized.
+	 * Note that the new value will not affect the current text in the control, only
+	 * subsequent calls to <code>setText</code> or <code>setContents</code>.
 	 * <p>
 	 * If normalized:
+	 * </p>
 	 * <ul>
 	 * <li>all white space characters will be condensed into at most one when
 	 * between words.</li>
-	 * <li>new line characters will be ignored and replaced with one white
-	 * space character</li>
-	 * <li>white space characters after the opening tags and before the closing
-	 * tags will be trimmed</li>
+	 * <li>new line characters will be ignored and replaced with one white space
+	 * character</li>
+	 * <li>white space characters after the opening tags and before the closing tags
+	 * will be trimmed</li>
+	 * </ul>
 	 *
-	 * @param value
-	 *            <code>true</code> if whitespace is normalized,
-	 *            <code>false</code> otherwise.
+	 * @param value <code>true</code> if whitespace is normalized,
+	 *              <code>false</code> otherwise.
 	 */
 	public void setWhitespaceNormalized(boolean value) {
 		model.setWhitespaceNormalized(value);
@@ -1190,7 +1188,7 @@ public class FormText extends Canvas {
 			@Override
 			public void getDefaultAction (AccessibleControlEvent e) {
 				if (model.getHyperlinkCount() > 0) {
-				    e.result = SWT.getMessage ("SWT_Press"); //$NON-NLS-1$
+					e.result = SWT.getMessage ("SWT_Press"); //$NON-NLS-1$
 				}
 			}
 
@@ -1206,7 +1204,7 @@ public class FormText extends Canvas {
 				int linkCount = model.getHyperlinkCount();
 				if (childID == ACC.CHILDID_SELF) {
 					if (linkCount > 0) {
-					    role = ACC.ROLE_LINK;
+						role = ACC.ROLE_LINK;
 					} else {
 						role = ACC.ROLE_TEXT;
 					}
@@ -1290,8 +1288,7 @@ public class FormText extends Canvas {
 		IHyperlinkSegment selectedLink = getSelectedLink();
 		if (getDisplay().getFocusControl() != this)
 			selectedLink = null;
-		for (int i = 0; i < paragraphs.length; i++) {
-			Paragraph p = paragraphs[i];
+		for (Paragraph p : paragraphs) {
 			p.computeSelection(gc, resourceTable, selectedLink, selData);
 		}
 		gc.dispose();
@@ -1313,7 +1310,7 @@ public class FormText extends Canvas {
 		notifyListeners(SWT.Selection, event);
 		// A listener could have caused the widget to be disposed
 		if (!isDisposed()) {
-		    getAccessible().selectionChanged();
+			getAccessible().selectionChanged();
 		}
 	}
 
@@ -1692,8 +1689,8 @@ public class FormText extends Canvas {
 				}
 			}
 		}
-		for (int i = 0; i < imagesToRemove.size(); i++) {
-			resourceTable.remove(imagesToRemove.get(i));
+		for (String element : imagesToRemove) {
+			resourceTable.remove(element);
 		}
 	}
 
