@@ -413,8 +413,7 @@ public class MessageManager implements IMessageManager {
 	 * Finds the message with the provided key in the provided list.
 	 */
 	private Message findMessage(Object key, ArrayList<Message> list) {
-		for (int i = 0; i < list.size(); i++) {
-			Message message = list.get(i);
+		for (Message message : list) {
 			if (message.getKey().equals(key))
 				return message;
 		}
@@ -449,7 +448,7 @@ public class MessageManager implements IMessageManager {
 		if (form.isDisposed()) {
 			return;
 		}
-		if (form.getHead().getBounds().height == 0 || mergedList.isEmpty() || mergedList == null) {
+		if (form.getHead().getBounds().height == 0 || mergedList == null || mergedList.isEmpty()) {
 			form.setMessage(null, IMessageProvider.NONE);
 			return;
 		}
@@ -468,7 +467,7 @@ public class MessageManager implements IMessageManager {
 			if (peers.size() > 1)
 				messageText = NLS.bind(
 						MULTIPLE_MESSAGE_SUMMARY_KEYS[maxType],
-						new String[] { peers.size() + "" }); //$NON-NLS-1$
+						new String[] { Integer.toString(peers.size()) });
 			else
 				messageText = SINGLE_MESSAGE_SUMMARY_KEYS[maxType];
 			form.setMessage(messageText, maxType, array);
