@@ -73,8 +73,7 @@ public class FormImages {
 			int hash = 0;
 			for (RGB fRGB : fRGBs)
 				hash = hash * 7 + fRGB.hashCode();
-			hash = hash * 7 + fLength;
-			return hash;
+			return hash * 7 + fLength;
 		}
 	}
 
@@ -104,8 +103,7 @@ public class FormImages {
 		public int hashCode() {
 			int hash = super.hashCode();
 			hash = hash * 7 + Integer.valueOf(fTheight).hashCode();
-			hash = hash * 7 + Integer.valueOf(fMarginHeight).hashCode();
-			return hash;
+			return hash * 7 + Integer.valueOf(fMarginHeight).hashCode();
 		}
 
 		@Override
@@ -126,8 +124,6 @@ public class FormImages {
 			gc.setBackground(color1);
 			gc.fillGradientRectangle(0, fMarginHeight + 2, 1, fTheight - 2, true);
 			gc.dispose();
-			color1.dispose();
-			color2.dispose();
 			return image;
 		}
 	}
@@ -194,10 +190,6 @@ public class FormImages {
 			Color bg = fBgRGB == null ? null : new Color(device, fBgRGB);
 			drawTextGradient(gc, width, height, colors, fPercents, fVertical, bg);
 			gc.dispose();
-			for (Color color : colors)
-				color.dispose();
-			if (bg != null)
-				bg.dispose();
 			return gradient;
 		}
 
@@ -273,8 +265,7 @@ public class FormImages {
 		public int hashCode() {
 			int hash = super.hashCode();
 			hash = hash * 7 + Integer.hashCode(fTheight);
-			hash = hash * 7 + Integer.hashCode(fMarginHeight);
-			return hash;
+			return hash * 7 + Integer.hashCode(fMarginHeight);
 		}
 
 		@Override
@@ -294,8 +285,6 @@ public class FormImages {
 			gc.setBackground(originalBgColor);
 			gc.fillRectangle(0, fTheight - fMarginHeight - 4, 1, 4);
 			gc.dispose();
-			color1.dispose();
-			originalBgColor.dispose();
 			return image;
 		}
 	}
@@ -321,8 +310,6 @@ public class FormImages {
 			gc.setBackground(color1);
 			gc.fillGradientRectangle(0, fMarginHeight + 2, 1, fTheight - 2, true);
 			gc.dispose();
-			color1.dispose();
-			color2.dispose();
 
 			return image;
 		}
