@@ -17,6 +17,7 @@ import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.osgi.service.environment.Constants;
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.custom.StyledText;
 import org.eclipse.swt.dnd.DragSource;
 import org.eclipse.swt.dnd.DragSourceEffect;
 import org.eclipse.swt.dnd.DragSourceEvent;
@@ -42,7 +43,6 @@ import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Layout;
 import org.eclipse.swt.widgets.Menu;
-import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.forms.IFormColors;
 import org.eclipse.ui.forms.widgets.ILayoutExtension;
 import org.eclipse.ui.forms.widgets.SizeCache;
@@ -66,7 +66,7 @@ public class TitleRegion extends Canvas {
 	private BusyIndicator busyLabel;
 	private Control currentTitleControl;
 	private Label titleLabel;
-	private Text titleText;
+	private StyledText titleText;
 	private SizeCache titleCache;
 	private int fontHeight = -1;
 	private int fontBaselineHeight = -1;
@@ -77,7 +77,6 @@ public class TitleRegion extends Canvas {
 	private Transfer[] dragTransferTypes;
 	private DragSourceListener dragListener;
 	private DragSource dragSource;
-	private Image dragImage;
 
 	private class HoverListener implements MouseTrackListener,
 			MouseMoveListener {
@@ -247,7 +246,7 @@ public class TitleRegion extends Canvas {
 		super(parent, SWT.NULL);
 		titleLabel = new Label(this, SWT.WRAP);
 		titleLabel.setVisible(false);
-		titleText = new Text(this, SWT.WRAP);
+		titleText = new StyledText(this, SWT.WRAP);
 		titleText.setCursor(getDisplay().getSystemCursor(SWT.CURSOR_IBEAM));
 		titleText.setEditable(false);
 		titleText.addFocusListener(FocusListener.focusLostAdapter(e -> titleText.setSelection(0)));
@@ -256,12 +255,6 @@ public class TitleRegion extends Canvas {
 		titleCache = new SizeCache();
 		super.setLayout(new TitleRegionLayout());
 		hookHoverListeners();
-		addListener(SWT.Dispose, e -> {
-			if (dragImage != null) {
-				dragImage.dispose();
-				dragImage = null;
-			}
-		});
 	}
 
 	@Override
@@ -279,7 +272,7 @@ public class TitleRegion extends Canvas {
 		addMouseMoveListener(listener);
 		titleLabel.addMouseTrackListener(listener);
 		titleLabel.addMouseMoveListener(listener);
-		addPaintListener(e -> onPaint(e));
+		addPaintListener(this::onPaint);
 	}
 
 	private void onPaint(PaintEvent e) {
