@@ -16,9 +16,9 @@
  *******************************************************************************/
 package org.eclipse.ui.actions;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 
@@ -50,8 +50,6 @@ import org.eclipse.ui.internal.ide.IDEWorkbenchMessages;
 import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 import org.eclipse.ui.part.FileEditorInput;
 
-import com.ibm.icu.text.Collator;
-
 /**
  * A menu for opening files in the workbench.
  * <p>
@@ -86,7 +84,7 @@ public class OpenWithMenu extends ContributionItem {
 	/**
 	 * Compares the labels from two IEditorDescriptor objects
 	 */
-	private static final Comparator<IEditorDescriptor> comparer = new Comparator<IEditorDescriptor>() {
+	private static final Comparator<IEditorDescriptor> comparer = new Comparator<>() {
 		private Collator collator = Collator.getInstance();
 
 		@Override
@@ -239,7 +237,7 @@ public class OpenWithMenu extends ContributionItem {
 
 		editors = IDE.overrideEditorAssociations(editorInput, contentType, editors);
 
-		Collections.sort(Arrays.asList(editors), comparer);
+		Arrays.asList(editors).sort(comparer);
 
 		boolean defaultFound = false;
 
@@ -324,8 +322,6 @@ public class OpenWithMenu extends ContributionItem {
 						: editorDescriptor.getId();
 
 				page.openEditor(new FileEditorInput(file), editorId, true, MATCH_BOTH);
-				// only remember the default editor if the open succeeds
-				IDE.setDefaultEditor(file, editorId);
 			}
 		} catch (PartInitException e) {
 			DialogUtil.openError(page.getWorkbenchWindow().getShell(),
