@@ -14,6 +14,7 @@
  *******************************************************************************/
 package org.eclipse.ui.actions;
 
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -25,12 +26,15 @@ import org.eclipse.core.resources.ResourceAttributes;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.Status;
+import org.eclipse.core.runtime.preferences.IPreferencesService;
 import org.eclipse.jface.dialogs.IInputValidator;
 import org.eclipse.jface.dialogs.InputDialog;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.viewers.IStructuredSelection;
+import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.window.IShellProvider;
 import org.eclipse.jface.window.Window;
 import org.eclipse.swt.SWT;
@@ -44,6 +48,7 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.TreeItem;
+import org.eclipse.ui.IWorkbenchPreferenceConstants;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.ide.undo.MoveResourcesOperation;
 import org.eclipse.ui.ide.undo.WorkspaceUndoUtil;
@@ -52,8 +57,6 @@ import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 import org.eclipse.ui.internal.ide.IIDEHelpContextIds;
 import org.eclipse.ui.internal.ide.actions.LTKLauncher;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * Standard action for renaming the selected resources.
  * <p>
@@ -63,6 +66,8 @@ import com.ibm.icu.text.MessageFormat;
  */
 public class RenameResourceAction extends WorkspaceAction {
 
+	private static final String WORKBENCH_PLUGIN_ID = "org.eclipse.ui.workbench"; //$NON-NLS-1$
+
 	/*
 	 * The tree editing widgets. If treeEditor is null then edit using the
 	 * dialog. We keep the editorText around so that we can close it if a new
@@ -175,11 +180,11 @@ public class RenameResourceAction extends WorkspaceAction {
 	/**
 	 * Check if the user wishes to overwrite the supplied resource
 	 *
-	 * @returns true if there is no collision or delete was successful
 	 * @param shell
 	 *            the shell to create the dialog in
 	 * @param destination -
 	 *            the resource to be overwritten
+	 * @return true if there is no collision or delete was successful
 	 */
 	private boolean checkOverwrite(final Shell shell,
 			final IResource destination) {
@@ -364,7 +369,7 @@ public class RenameResourceAction extends WorkspaceAction {
 	/**
 	 * Get the Tree being edited.
 	 *
-	 * @returnTree
+	 * @return Tree
 	 */
 	private Tree getTree() {
 		return this.navigatorTree;
@@ -407,10 +412,9 @@ public class RenameResourceAction extends WorkspaceAction {
 	}
 
 	/**
-	 * Return the new name to be given to the target resource or
-	 * <code>null<code>
-	 * if the query was canceled. Rename the currently selected resource using the table editor.
-	 * Continue the action when the user is done.
+	 * Return the new name to be given to the target resource or <code>null</code>
+	 * if the query was canceled. Rename the currently selected resource using the
+	 * table editor. Continue the action when the user is done.
 	 *
 	 * @param resource the resource to rename
 	 */
@@ -431,7 +435,12 @@ public class RenameResourceAction extends WorkspaceAction {
 		textEditor.setBounds(2, inset, Math.min(textSize.x, parentSize.x - 4),
 				parentSize.y - 2 * inset);
 		textEditorParent.redraw();
-		textEditor.selectAll();
+		int startOfFileExtension = resource.getName().lastIndexOf('.'); // $NON-NLS-1$
+		if (startOfFileExtension == -1) {
+			textEditor.selectAll();
+		} else {
+			textEditor.setSelection(0, startOfFileExtension);
+		}
 		textEditor.setFocus();
 	}
 
@@ -441,21 +450,27 @@ public class RenameResourceAction extends WorkspaceAction {
 		if (currentResource == null || !currentResource.exists()) {
 			return;
 		}
-		if (LTKLauncher.openRenameWizard(getStructuredSelection())) {
-			return;
-		}
-		if (this.navigatorTree == null) {
-			// Do a quick read only and null check
-			if (!checkReadOnlyAndNull(currentResource)) {
-				return;
+
+		String defaultValue = ""; //$NON-NLS-1$
+		IPreferencesService preferences = Platform.getPreferencesService();
+		String renameMode = preferences.getString(WORKBENCH_PLUGIN_ID,
+				IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE, defaultValue,
+				null);
+		boolean dialogMode = IWorkbenchPreferenceConstants.RESOURCE_RENAME_MODE_DIALOG.equals(renameMode);
+
+		if (this.navigatorTree == null || dialogMode || LTKLauncher.isCompositeRename(getStructuredSelection())) {
+			if (!LTKLauncher.openRenameWizard(getStructuredSelection())) {
+				// LTK Launcher couldn't rename the resource
+				if (!checkReadOnlyAndNull(currentResource)) {
+					return;
+				}
+				String newName = queryNewResourceName(currentResource);
+				if (newName == null || newName.isEmpty()) {
+					return;
+				}
+				newPath = currentResource.getFullPath().removeLastSegments(1).append(newName);
+				super.run();
 			}
-			String newName = queryNewResourceName(currentResource);
-			if (newName == null || newName.isEmpty()) {
-				return;
-			}
-			newPath = currentResource.getFullPath().removeLastSegments(1)
-					.append(newName);
-			super.run();
 		} else {
 			runWithInlineEditor();
 		}
@@ -531,9 +546,11 @@ public class RenameResourceAction extends WorkspaceAction {
 					if (!status.isOK()) {
 						displayError(status.getMessage());
 					} else {
-						IPath newPath = inlinedResource.getFullPath()
-								.removeLastSegments(1).append(newName);
-						runWithNewPath(newPath, inlinedResource);
+						if (!LTKLauncher.renameResource(newName, new StructuredSelection(inlinedResource))) {
+							// LTK Launcher couldn't rename the resource
+							IPath newPath = inlinedResource.getFullPath().removeLastSegments(1).append(newName);
+							runWithNewPath(newPath, inlinedResource);
+						}
 					}
 				}
 				inlinedResource = null;
@@ -650,6 +667,7 @@ public class RenameResourceAction extends WorkspaceAction {
 										WorkspaceUndoUtil
 												.getUIInfoAdapter(getShell()));
 					} catch (ExecutionException e) {
+						IDEWorkbenchPlugin.log(e.toString());
 						if (e.getCause() instanceof CoreException) {
 							errorStatus[0] = ((CoreException) e.getCause())
 									.getStatus();
