@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -21,6 +21,7 @@ package org.eclipse.ui.dialogs;
 import java.io.IOException;
 import java.io.StringReader;
 import java.io.StringWriter;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
@@ -87,8 +88,6 @@ import org.eclipse.ui.internal.ide.model.ResourceFactory;
 import org.eclipse.ui.model.WorkbenchLabelProvider;
 import org.eclipse.ui.statushandlers.StatusManager;
 
-import com.ibm.icu.text.Collator;
-
 /**
  * Shows a list of resources to the user with a text entry field for a string
  * pattern used to filter the list of resources.
@@ -219,7 +218,7 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 	 * @param text the new subtitle
 	 */
 	private void setSubtitle(String text) {
-		if (text == null || text.length() == 0) {
+		if (text == null || text.isEmpty()) {
 			getShell().setText(title);
 		} else {
 			getShell().setText(title + " - " + text); //$NON-NLS-1$
@@ -663,7 +662,7 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		}
 
 		private StyledString styleResourceExtensionMatch(IResource resource, String matchingString, Styler styler) {
-			StyledString str = new StyledString(resource.getName().trim());
+			StyledString str = new StyledString(resource.getName());
 			String resourceExtension = resource.getFileExtension();
 			int lastDotIndex = matchingString.lastIndexOf('.');
 			if (lastDotIndex == -1 || resourceExtension == null) {
@@ -681,7 +680,7 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		private List<Position> getMatchPositions(String string, String matching) {
 			final String originalMatching = matching;
 			List<Position> positions = new ArrayList<>();
-			if (matching.length() == 0 || string.length() == 0) {
+			if (matching.isEmpty() || string.isEmpty()) {
 				return positions;
 			}
 
@@ -940,9 +939,9 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		/**
 		 * Creates new ResourceFilter instance
 		 *
-		 * @param container
+		 * @param container   filtered container
 		 * @param showDerived flag which determine showing derived elements
-		 * @param typeMask
+		 * @param typeMask    filter type mask. See {@link IResource#getType()} types.
 		 */
 		public ResourceFilter(IContainer container, boolean showDerived, int typeMask) {
 			super();
@@ -974,7 +973,7 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 					filenamePattern = "**"; //$NON-NLS-1$
 
 				if (sep > 0) {
-					if (filenamePattern.length() == 0) // relative patterns don't need a file name
+					if (filenamePattern.isEmpty()) // relative patterns don't need a file name
 						filenamePattern = "**"; //$NON-NLS-1$
 
 					String containerPattern = stringPattern.substring(0, sep);
@@ -986,8 +985,12 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 								.setPattern(searchContainer.getFullPath().append(containerPattern).toString());
 					}
 
-					if (!containerPattern.startsWith("" + IPath.SEPARATOR)) //$NON-NLS-1$
-						containerPattern = IPath.SEPARATOR + containerPattern;
+					if (!containerPattern.startsWith(Character.toString('*'))) {
+						if (!containerPattern.startsWith(Character.toString(IPath.SEPARATOR))) {
+							containerPattern = IPath.SEPARATOR + containerPattern;
+						}
+						containerPattern = '*' + containerPattern;
+					}
 					this.containerPattern = new SearchPattern(SearchPattern.RULE_EXACT_MATCH
 							| SearchPattern.RULE_PREFIX_MATCH | SearchPattern.RULE_PATTERN_MATCH);
 					this.containerPattern.setPattern(containerPattern);
@@ -1074,11 +1077,12 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 					// match path relative to current selection:
 					if (relativeContainerPattern != null)
 						return relativeContainerPattern.matches(containerPath);
+				// match direct parency
+
 					return false;
 				}
 				return true;
 			}
-
 			return false;
 		}
 
@@ -1187,8 +1191,7 @@ public class FilteredResourcesSelectionDialog extends FilteredItemsSelectionDial
 		@Override
 		protected Object restoreItemFromMemento(IMemento element) {
 			ResourceFactory resourceFactory = new ResourceFactory();
-			IResource resource = (IResource) resourceFactory.createElement(element);
-			return resource;
+			return resourceFactory.createElement(element);
 		}
 
 		@Override
