@@ -15,13 +15,14 @@
  *******************************************************************************/
 package org.eclipse.ui.dialogs;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collections;
 
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.text.StringMatcher;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.swt.SWT;
@@ -43,11 +44,8 @@ import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 import org.eclipse.ui.internal.ide.IDEWorkbenchMessages;
 import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
-import org.eclipse.ui.internal.ide.StringMatcher;
 import org.eclipse.ui.model.WorkbenchLabelProvider;
 
-import com.ibm.icu.text.Collator;
-
 /**
  * Shows a list of resources to the user with a text entry field for a string
  * pattern used to filter the list of resources.
@@ -864,13 +862,13 @@ public class ResourceListSelectionDialog extends SelectionDialog {
 	 * A new resource has been selected. Change the contents of the folder names
 	 * list.
 	 *
-	 * @desc resource descriptor of the selected resource
+	 * @param desc resource descriptor of the selected resource
 	 */
 	private void updateFolders(final ResourceDescriptor desc) {
 		BusyIndicator.showWhile(getShell().getDisplay(), () -> {
 			if (!desc.resourcesSorted) {
 				// sort the folder names
-				Collections.sort(desc.resources, (o1, o2) -> {
+				desc.resources.sort((o1, o2) -> {
 					String s1 = getParentLabel((IResource) o1);
 					String s2 = getParentLabel((IResource) o2);
 					return collator.compare(s1, s2);
@@ -878,9 +876,9 @@ public class ResourceListSelectionDialog extends SelectionDialog {
 				desc.resourcesSorted = true;
 			}
 			folderNames.removeAll();
-			for (int i = 0; i < desc.resources.size(); i++) {
+			for (Object element : desc.resources) {
 				TableItem newItem = new TableItem(folderNames, SWT.NONE);
-				IResource r = (IResource) desc.resources.get(i);
+				IResource r = (IResource) element;
 				newItem.setText(getParentLabel(r));
 				newItem.setImage(getParentImage(r));
 				newItem.setData(r);
