@@ -568,9 +568,7 @@ public class LinkedResourceEditor {
 			try {
 				new ProgressMonitorDialog(fRemoveButton.getShell()).run(true,
 						true, op);
-			} catch (InvocationTargetException e) {
-				IDEWorkbenchPlugin.log(null, e);
-			} catch (InterruptedException e) {
+			} catch (InvocationTargetException | InterruptedException e) {
 				IDEWorkbenchPlugin.log(null, e);
 			}
 			fTree.refresh();
@@ -655,7 +653,7 @@ public class LinkedResourceEditor {
 
 				Text text = new Text(parent, SWT.BORDER | SWT.MULTI
 						| SWT.V_SCROLL | SWT.H_SCROLL);
-				text.setText(resultMessage.toString());
+				text.setText(resultMessage);
 				GridData data = new GridData(640, 300);
 				text.setLayoutData(data);
 				return parent;
