@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -162,7 +162,7 @@ public class ResourceWorkingSetPage extends WizardPage implements IWorkingSetPag
 		data.widthHint = SIZING_SELECTION_WIDGET_WIDTH;
 		tree.getControl().setLayoutData(data);
 
-		tree.addCheckStateListener(event -> handleCheckStateChange(event));
+		tree.addCheckStateListener(this::handleCheckStateChange);
 
 		tree.addTreeListener(new ITreeViewerListener() {
 			@Override
@@ -489,9 +489,8 @@ public class ResourceWorkingSetPage extends WizardPage implements IWorkingSetPag
 				setPageComplete(false);
 				firstCheck = false;
 				return;
-			} else {
-				errorMessage = IDEWorkbenchMessages.ResourceWorkingSetPage_warning_nameMustNotBeEmpty;
 			}
+			errorMessage = IDEWorkbenchMessages.ResourceWorkingSetPage_warning_nameMustNotBeEmpty;
 		}
 		firstCheck = false;
 		if (errorMessage == null && (workingSet == null || newText.equals(workingSet.getName()) == false)) {
