@@ -15,10 +15,10 @@
 package org.eclipse.ui.internal.views.markers;
 
 import java.lang.reflect.InvocationTargetException;
+import java.util.Arrays;
 import java.util.Iterator;
 
 import org.eclipse.core.resources.ResourcesPlugin;
-import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
@@ -260,10 +260,8 @@ public class CachedMarkerBuilder {
 				SortingJob job = new SortingJob(CachedMarkerBuilder.this);
 				job.run(monitor);
 			});
-		} catch (InvocationTargetException e) {
-			StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, e.getLocalizedMessage(), e));
-		} catch (InterruptedException e) {
-			StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, e.getLocalizedMessage(), e));
+		} catch (InvocationTargetException | InterruptedException e) {
+			StatusManager.getManager().handle(StatusUtil.newError(e));
 		}
 	}
 
@@ -432,7 +430,7 @@ public class CachedMarkerBuilder {
 	 *
 	 * schedules marker update job
 	 */
-	 MarkerUpdateJob scheduleUpdateJob(long delay, boolean clean) {
+	MarkerUpdateJob scheduleUpdateJob(long delay, boolean clean) {
 		return scheduleUpdateJob(delay, clean, new boolean[] { true, false, false });
 	}
 
@@ -592,10 +590,10 @@ public class CachedMarkerBuilder {
 	 * @see CachedMarkerBuilder#getClonedMarkers()
 	 * and {@link #getMarkers()}
 	 */
-	 Markers createMarkersClone() {
-		 if(markers.isInChange()){
-			 return null;
-		 }
+	Markers createMarkersClone() {
+		if(markers.isInChange()){
+			return null;
+		}
 		markersClone =markers.getClone();
 		return markersClone;
 	}
@@ -622,9 +620,7 @@ public class CachedMarkerBuilder {
 	 */
 	boolean[] readChangeFlags() {
 		boolean [] changes=new boolean[changeFlags.length];
-		for (int i = 0; i < changes.length; i++) {
-			changes[i]=changeFlags[i];
-		}
+		System.arraycopy(changeFlags, 0, changes, 0, changes.length);
 		return changes;
 	}
 
@@ -632,9 +628,7 @@ public class CachedMarkerBuilder {
 	 * Reset change flags to false
 	 */
 	void resetChangeFlags() {
-		for (int i = 0; i < changeFlags.length; i++) {
-			this.changeFlags[i] = false;
-		}
+		Arrays.fill(this.changeFlags, false);
 	}
 
 	/**
