@@ -16,6 +16,8 @@
 
 package org.eclipse.ui.internal.views.markers;
 
+import java.text.CollationKey;
+import java.text.Collator;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Objects;
@@ -35,9 +37,6 @@ import org.eclipse.ui.views.markers.MarkerViewUtil;
 import org.eclipse.ui.views.markers.internal.MarkerMessages;
 import org.eclipse.ui.views.markers.internal.MarkerTypesModel;
 
-import com.ibm.icu.text.CollationKey;
-import com.ibm.icu.text.Collator;
-
 /**
  * The MarkerEntry is the class that wrappers an {@link IMarker} for display in
  * an {@link ExtendedMarkersView}.
@@ -217,7 +216,7 @@ class MarkerEntry extends MarkerSupportItem implements IAdaptable {
 			attributeValue = getAttributeValue(attribute, defaultValue);
 		}
 
-		if (attributeValue.length() == 0) {
+		if (attributeValue.isEmpty()) {
 			return MarkerSupportInternalUtilities.EMPTY_COLLATION_KEY;
 		}
 		CollationKey key = Collator.getInstance().getCollationKey(attributeValue);
@@ -264,7 +263,7 @@ class MarkerEntry extends MarkerSupportItem implements IAdaptable {
 
 
 		// Is the location override set?
-		String locationString = getAttributeValue(IMarker.LOCATION, MarkerSupportInternalUtilities.EMPTY_STRING);
+		String locationString = getAttributeValue(IMarker.LOCATION, MarkerItemDefaults.LOCATION_DEFAULT);
 		if (locationString.length() > 0) {
 			getCache().put(LOCATION_STRING, locationString);
 			return locationString;
