@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2017 IBM Corporation and others.
+ * Copyright (c) 2004, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -238,12 +238,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 					}
 
 				}
-			} catch (CoreException e) {
-				// project definition file could not be parsed
-				this.projectName = DataTransferMessages.WizardProjectsImportPage_invalidProjectName;
-				this.isInvalid = true;
-
-			} catch (IOException e) {
+			} catch (CoreException | IOException e) {
 				this.projectName = DataTransferMessages.WizardProjectsImportPage_invalidProjectName;
 				this.isInvalid = true;
 			}
@@ -323,12 +318,17 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 
 	// dialog store id constants
 	private static final String STORE_DIRECTORIES = "WizardProjectsImportPage.STORE_DIRECTORIES";//$NON-NLS-1$
+
 	private static final String STORE_ARCHIVES = "WizardProjectsImportPage.STORE_ARCHIVES";//$NON-NLS-1$
 
 	private static final String STORE_NESTED_PROJECTS = "WizardProjectsImportPage.STORE_NESTED_PROJECTS"; //$NON-NLS-1$
 
 	private static final String STORE_COPY_PROJECT_ID = "WizardProjectsImportPage.STORE_COPY_PROJECT_ID"; //$NON-NLS-1$
 
+	private static final String STORE_CLOSE_CREATED_PROJECTS_ID = "WizardProjectsImportPage.STORE_CLOSE_CREATED_PROJECTS_ID"; //$NON-NLS-1$
+
+	private static final String STORE_HIDE_CONFLICTING_PROJECTS_ID = "WizardProjectsImportPage.STORE_HIDE_CONFLICTING_PROJECTS_ID"; //$NON-NLS-1$
+
 	private static final String STORE_ARCHIVE_SELECTED = "WizardProjectsImportPage.STORE_ARCHIVE_SELECTED"; //$NON-NLS-1$
 
 	private Combo directoryPathField;
@@ -343,8 +343,14 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 
 	private boolean copyFiles = false;
 
+	private Button closeProjectsCheckbox;
+
 	private boolean closeProjectsAfterImport = false;
 
+	private Button hideConflictingProjectsCheckbox;
+
+	private boolean hideConflictingProjects = false;
+
 	private ProjectRecord[] selectedProjects = new ProjectRecord[0];
 
 	// Keep track of the directory that we browsed to last time
@@ -379,10 +385,15 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 
 	private IStructuredSelection currentSelection;
 
-	private Button hideConflictingProjects;
 
 	private ConflictingProjectFilter conflictingProjectsFilter = new ConflictingProjectFilter();
 
+	/**
+	 * Prevent handling focus lost events during other events which trigger
+	 * directory searches. See bug 549966.
+	 */
+	private boolean isUpdatingProjectsList;
+
 	/**
 	 * Creates a new project creation wizard page.
 	 *
@@ -473,9 +484,9 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			public void widgetSelected(SelectionEvent e) {
 				nestedProjects = nestedProjectsCheckbox.getSelection();
 				if (projectFromDirectoryRadio.getSelection()) {
-					updateProjectsList(directoryPathField.getText().trim(), true);
+					updateProjectsListAndPreventFocusLostHandling(directoryPathField.getText().trim(), true);
 				} else {
-					updateProjectsList(archivePathField.getText().trim(), true);
+					updateProjectsListAndPreventFocusLostHandling(archivePathField.getText().trim(), true);
 				}
 			}
 		});
@@ -495,28 +506,26 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			}
 		});
 
-		Button closeProjectsCheckbox = new Button(optionsGroup, SWT.CHECK);
+		closeProjectsCheckbox = new Button(optionsGroup, SWT.CHECK);
 		closeProjectsCheckbox.setText(DataTransferMessages.WizardProjectsImportPage_closeProjectsAfterImport);
 		closeProjectsCheckbox.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		closeProjectsCheckbox.setSelection(closeProjectsAfterImport);
 		closeProjectsCheckbox.addSelectionListener(
 				SelectionListener.widgetSelectedAdapter(e -> closeProjectsAfterImport = closeProjectsCheckbox.getSelection()));
 
-		hideConflictingProjects = new Button(optionsGroup, SWT.CHECK);
-		hideConflictingProjects
+		hideConflictingProjectsCheckbox = new Button(optionsGroup, SWT.CHECK);
+		hideConflictingProjectsCheckbox
 				.setText(DataTransferMessages.WizardProjectsImportPage_hideExistingProjects);
-		hideConflictingProjects.setLayoutData(new GridData(
+		hideConflictingProjectsCheckbox.setLayoutData(new GridData(
 				GridData.FILL_HORIZONTAL));
-		hideConflictingProjects.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				projectsList.removeFilter(conflictingProjectsFilter);
-				if (hideConflictingProjects.getSelection()) {
-					projectsList.addFilter(conflictingProjectsFilter);
-				}
+		hideConflictingProjectsCheckbox.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+			hideConflictingProjects = hideConflictingProjectsCheckbox.getSelection();
+			projectsList.removeFilter(conflictingProjectsFilter);
+			if (hideConflictingProjectsCheckbox.getSelection()) {
+				projectsList.addFilter(conflictingProjectsFilter);
 			}
-		});
-		Dialog.applyDialogFont(hideConflictingProjects);
+		}));
+		Dialog.applyDialogFont(hideConflictingProjectsCheckbox);
 	}
 
 	/**
@@ -541,6 +550,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 				| GridData.GRAB_VERTICAL | GridData.FILL_BOTH));
 
 		projectsList = new CheckboxTreeViewer(listComposite, SWT.BORDER);
+		projectsList.setUseHashlookup(true);
 		GridData gridData = new GridData(SWT.FILL, SWT.FILL, true, true);
 		gridData.widthHint = new PixelConverter(projectsList.getControl()).convertWidthInCharsToPixels(25);
 		gridData.heightHint = new PixelConverter(projectsList.getControl()).convertHeightInCharsToPixels(10);
@@ -646,9 +656,9 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				if (projectFromDirectoryRadio.getSelection()) {
-					updateProjectsList(directoryPathField.getText().trim(), true);
+					updateProjectsListAndPreventFocusLostHandling(directoryPathField.getText().trim(), true);
 				} else {
-					updateProjectsList(archivePathField.getText().trim(), true);
+					updateProjectsListAndPreventFocusLostHandling(archivePathField.getText().trim(), true);
 				}
 			}
 		});
@@ -736,7 +746,9 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 		directoryPathField.addFocusListener(new FocusAdapter() {
 			@Override
 			public void focusLost(org.eclipse.swt.events.FocusEvent e) {
-				updateProjectsList(directoryPathField.getText().trim());
+				if (!isUpdatingProjectsList) {
+					updateProjectsList(directoryPathField.getText().trim());
+				}
 			}
 
 		});
@@ -758,7 +770,9 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 		archivePathField.addFocusListener(new FocusAdapter() {
 			@Override
 			public void focusLost(org.eclipse.swt.events.FocusEvent e) {
-				updateProjectsList(archivePathField.getText().trim());
+				if (!isUpdatingProjectsList) {
+					updateProjectsList(archivePathField.getText().trim());
+				}
 			}
 		});
 
@@ -790,12 +804,20 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			browseDirectoriesButton.setEnabled(false);
 			archivePathField.setEnabled(true);
 			browseArchivesButton.setEnabled(true);
+
+			// if there are available selections in the combo-box, select latest entry
+			if (archivePathField.getItemCount() > 0 && archivePathField.getText().isEmpty()) {
+				archivePathField.setText(archivePathField.getItem(0));
+			}
+
 			updateProjectsList(archivePathField.getText());
 			archivePathField.setFocus();
 			nestedProjectsCheckbox.setSelection(true);
 			nestedProjectsCheckbox.setEnabled(false);
 			copyCheckbox.setSelection(true);
 			copyCheckbox.setEnabled(false);
+			closeProjectsCheckbox.setSelection(closeProjectsAfterImport);
+			hideConflictingProjectsCheckbox.setSelection(hideConflictingProjects);
 		}
 	}
 
@@ -805,12 +827,19 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			browseDirectoriesButton.setEnabled(true);
 			archivePathField.setEnabled(false);
 			browseArchivesButton.setEnabled(false);
+
+			if (directoryPathField.getItemCount() > 0 && directoryPathField.getText().isEmpty()) {
+				directoryPathField.setText(directoryPathField.getItem(0));
+			}
+
 			updateProjectsList(directoryPathField.getText());
 			directoryPathField.setFocus();
 			nestedProjectsCheckbox.setEnabled(true);
 			nestedProjectsCheckbox.setSelection(nestedProjects);
 			copyCheckbox.setEnabled(true);
 			copyCheckbox.setSelection(copyFiles);
+			closeProjectsCheckbox.setSelection(closeProjectsAfterImport);
+			hideConflictingProjectsCheckbox.setSelection(hideConflictingProjects);
 		}
 	}
 
@@ -832,12 +861,27 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	 * @param path
 	 */
 	public void updateProjectsList(final String path) {
-		updateProjectsList(path, false);
+		updateProjectsListAndPreventFocusLostHandling(path, false);
+	}
+
+	/**
+	 * Calling {@link #updateProjectsList(String, boolean)} will cause a focus lost
+	 * event, if the directory or archive field is active. Handling that focus lost
+	 * event causes nested execution of the update method, leading to broken
+	 * behavior. See bug 549966.
+	 */
+	private void updateProjectsListAndPreventFocusLostHandling(final String path, boolean forceUpdate) {
+		isUpdatingProjectsList = true;
+		try {
+			updateProjectsList(path, forceUpdate);
+		} finally {
+			isUpdatingProjectsList = false;
+		}
 	}
 
 	private void updateProjectsList(final String path, boolean forceUpdate) {
 		// on an empty path empty selectedProjects
-		if (path == null || path.length() == 0) {
+		if (path == null || path.isEmpty()) {
 			setMessage(DataTransferMessages.WizardProjectsImportPage_ImportProjectsDescription);
 			selectedProjects = new ProjectRecord[0];
 			projectsList.refresh(true);
@@ -855,8 +899,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 
 		// We can't access the radio button from the inner class so get the
 		// status beforehand
-		final boolean dirSelected = this.projectFromDirectoryRadio
-				.getSelection();
+		final boolean dirSelected = this.projectFromDirectoryRadio.getSelection();
 		try {
 			getContainer().run(true, true, monitor -> {
 
@@ -865,7 +908,6 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 								DataTransferMessages.WizardProjectsImportPage_SearchingMessage,
 								100);
 				selectedProjects = new ProjectRecord[0];
-				Collection files = new ArrayList();
 				monitor.worked(10);
 				if (!dirSelected
 						&& ArchiveFileManipulations.isTarFile(path)) {
@@ -878,18 +920,19 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 							sourceTarFile);
 					Object child1 = structureProvider.getRoot();
 
+					Collection<ProjectRecord> files = new ArrayList<>();
 					if (!collectProjectFilesFromProvider(files, child1, 0,
 							monitor)) {
 						return;
 					}
-					Iterator filesIterator1 = files.iterator();
+					Iterator<ProjectRecord> filesIterator1 = files.iterator();
 					selectedProjects = new ProjectRecord[files.size()];
 					int index1 = 0;
 					monitor.worked(50);
 					monitor
 							.subTask(DataTransferMessages.WizardProjectsImportPage_ProcessingMessage);
 					while (filesIterator1.hasNext()) {
-						selectedProjects[index1++] = (ProjectRecord) filesIterator1
+						selectedProjects[index1++] = filesIterator1
 								.next();
 					}
 				} else if (!dirSelected
@@ -902,36 +945,39 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 							sourceFile);
 					Object child2 = structureProvider.getRoot();
 
+					Collection<ProjectRecord> files = new ArrayList<>();
 					if (!collectProjectFilesFromProvider(files, child2, 0,
 							monitor)) {
 						return;
 					}
-					Iterator filesIterator2 = files.iterator();
+
+					Iterator<ProjectRecord> filesIterator2 = files.iterator();
 					selectedProjects = new ProjectRecord[files.size()];
 					int index2 = 0;
 					monitor.worked(50);
 					monitor
 							.subTask(DataTransferMessages.WizardProjectsImportPage_ProcessingMessage);
 					while (filesIterator2.hasNext()) {
-						selectedProjects[index2++] = (ProjectRecord) filesIterator2
+						selectedProjects[index2++] = filesIterator2
 								.next();
 					}
 				}
 
 				else if (dirSelected && directory.isDirectory()) {
 
+					Collection<File> files = new ArrayList<>();
 					if (!collectProjectFilesFromDirectory(files, directory,
 							null, nestedProjects, monitor)) {
 						return;
 					}
-					Iterator filesIterator3 = files.iterator();
+					Iterator<File> filesIterator3 = files.iterator();
 					selectedProjects = new ProjectRecord[files.size()];
 					int index3 = 0;
 					monitor.worked(50);
 					monitor
 							.subTask(DataTransferMessages.WizardProjectsImportPage_ProcessingMessage);
 					while (filesIterator3.hasNext()) {
-						File file = (File) filesIterator3.next();
+						File file = filesIterator3.next();
 						selectedProjects[index3] = new ProjectRecord(file);
 						index3++;
 					}
@@ -989,7 +1035,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	 * Return null if this file does not exist or is not of valid format.
 	 */
 	private ZipFile getSpecifiedZipSourceFile(String fileName) {
-		if (fileName.length() == 0) {
+		if (fileName.isEmpty()) {
 			return null;
 		}
 
@@ -1010,7 +1056,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	 * Return null if this file does not exist or is not of valid format.
 	 */
 	private TarFile getSpecifiedTarSourceFile(String fileName) {
-		if (fileName.length() == 0) {
+		if (fileName.isEmpty()) {
 			return null;
 		}
 
@@ -1116,11 +1162,11 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 		monitor.subTask(NLS.bind(
 				DataTransferMessages.WizardProjectsImportPage_CheckingMessage,
 				structureProvider.getLabel(entry)));
-		List children = structureProvider.getChildren(entry);
+		List<?> children = structureProvider.getChildren(entry);
 		if (children == null) {
-			children = new ArrayList(1);
+			children = new ArrayList<>(1);
 		}
-		Iterator childrenEnum = children.iterator();
+		Iterator<?> childrenEnum = children.iterator();
 		while (childrenEnum.hasNext()) {
 			Object child = childrenEnum.next();
 			if (structureProvider.isFolder(child)) {
@@ -1146,11 +1192,11 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 				.setMessage(DataTransferMessages.WizardProjectsImportPage_SelectDialogTitle);
 
 		String dirName = directoryPathField.getText().trim();
-		if (dirName.length() == 0) {
+		if (dirName.isEmpty()) {
 			dirName = previouslyBrowsedDirectory;
 		}
 
-		if (dirName.length() == 0) {
+		if (dirName.isEmpty()) {
 			dialog.setFilterPath(IDEWorkbenchPlugin.getPluginWorkspace()
 					.getRoot().getLocation().toOSString());
 		} else {
@@ -1180,11 +1226,11 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 				.setText(DataTransferMessages.WizardProjectsImportPage_SelectArchiveDialogTitle);
 
 		String fileName = archivePathField.getText().trim();
-		if (fileName.length() == 0) {
+		if (fileName.isEmpty()) {
 			fileName = previouslyBrowsedArchive;
 		}
 
-		if (fileName.length() == 0) {
+		if (fileName.isEmpty()) {
 			dialog.setFilterPath(IDEWorkbenchPlugin.getPluginWorkspace()
 					.getRoot().getLocation().toOSString());
 		} else {
@@ -1221,7 +1267,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 				// Import as many projects as we can; accumulate errors to
 				// report to the user
 				MultiStatus status = new MultiStatus(IDEWorkbenchPlugin.IDE_WORKBENCH, 1,
-						DataTransferMessages.WizardProjectsImportPage_projectsInWorkspaceAndInvalid, null);
+						DataTransferMessages.WizardProjectsImportPage_projectsInWorkspaceAndInvalid);
 				for (Object element : selected) {
 					status.add(createExistingProject((ProjectRecord) element, subMonitor.split(1)));
 				}
@@ -1314,7 +1360,7 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 		}
 		if (record.projectArchiveFile != null) {
 			// import from archive
-			List fileSystemObjects = structureProvider
+			List<?> fileSystemObjects = structureProvider
 					.getChildren(record.parent);
 			structureProvider.setStrip(record.level);
 			ImportOperation operation = new ImportOperation(project
@@ -1330,6 +1376,13 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 				return new Status(IStatus.ERROR, IDEWorkbenchPlugin.IDE_WORKBENCH, 2,
 						e.getCause().getLocalizedMessage(), e);
 			}
+			if (closeProjectsAfterImport) {
+				try {
+					project.close(subMonitor.split(1));
+				} catch (CoreException e) {
+					return e.getStatus();
+				}
+			}
 			return operation.getStatus();
 		}
 
@@ -1521,6 +1574,17 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			// checkbox
 			copyFiles = settings.getBoolean(STORE_COPY_PROJECT_ID);
 			copyCheckbox.setSelection(copyFiles);
+
+			// checkbox
+			closeProjectsAfterImport = settings.getBoolean(STORE_CLOSE_CREATED_PROJECTS_ID);
+			closeProjectsCheckbox.setSelection(closeProjectsAfterImport);
+
+			// checkbox
+			hideConflictingProjects = settings.getBoolean(STORE_HIDE_CONFLICTING_PROJECTS_ID);
+			hideConflictingProjectsCheckbox.setSelection(hideConflictingProjects);
+			// trigger a selection event for the button to make sure the filter is set
+			// properly at page creation
+			hideConflictingProjectsCheckbox.notifyListeners(SWT.Selection, new Event());
 		}
 
 		// Second, check to see if we don't have an initial path,
@@ -1586,12 +1650,20 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 			saveInHistory(settings, STORE_DIRECTORIES, directoryPathField.getText());
 			saveInHistory(settings, STORE_ARCHIVES, archivePathField.getText());
 
-			settings.put(STORE_NESTED_PROJECTS, nestedProjectsCheckbox.getSelection());
+			if (nestedProjectsCheckbox.isEnabled()) { // only store selection if it was users choice and not enforced
+				settings.put(STORE_NESTED_PROJECTS, nestedProjectsCheckbox.getSelection());
+			}
 
-			settings.put(STORE_COPY_PROJECT_ID, copyCheckbox.getSelection());
+			if (copyCheckbox.isEnabled()) { // only store selection if it was users choice and not enforced
+				settings.put(STORE_COPY_PROJECT_ID, copyCheckbox.getSelection());
+			}
 
 			settings.put(STORE_ARCHIVE_SELECTED, projectFromArchiveRadio
 					.getSelection());
+
+			settings.put(STORE_CLOSE_CREATED_PROJECTS_ID, closeProjectsCheckbox.getSelection());
+
+			settings.put(STORE_HIDE_CONFLICTING_PROJECTS_ID, hideConflictingProjectsCheckbox.getSelection());
 		}
 	}
 
@@ -1630,5 +1702,4 @@ public class WizardProjectsImportPage extends WizardDataTransferPage {
 	protected boolean allowNewContainerName() {
 		return true;
 	}
-
 }
