@@ -104,6 +104,13 @@ import org.eclipse.ui.views.framelist.TreeFrame;
 /**
  * Implements the Resource Navigator view.
  *
+ * @noextend This class is not intended to be subclassed by clients.
+ * @noinstantiate This class is not intended to be instantiated by clients.
+ * @noreference This class is not intended to be referenced by clients.
+ *
+ *              Planned to be deleted, please see Bug
+ *              https://bugs.eclipse.org/bugs/show_bug.cgi?id=549953
+ *
  * @deprecated as of 3.5, use the Common Navigator Framework classes instead
  */
 @Deprecated
@@ -275,8 +282,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 		ArrayList<IResource> list = new ArrayList<>();
 		if (selection instanceof IStructuredSelection) {
 			IStructuredSelection ssel = (IStructuredSelection) selection;
-			for (Iterator<?> i = ssel.iterator(); i.hasNext();) {
-				Object o = i.next();
+			for (Object o : ssel) {
 				IResource resource = Adapters.adapt(o, IResource.class);
 				if (resource != null) {
 					list.add(resource);
@@ -324,7 +330,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 
 		getSite().setSelectionProvider(viewer);
 		getSite().getPage().addPartListener(partListener);
-		IWorkingSetManager workingSetManager = getPlugin().getWorkbench().getWorkingSetManager();
+		IWorkingSetManager workingSetManager =  PlatformUI.getWorkbench().getWorkingSetManager();
 		workingSetManager.addPropertyChangeListener(propertyChangeListener);
 
 		if (memento != null) {
@@ -353,7 +359,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 	protected void initContextMenu() {
 		MenuManager menuMgr = new MenuManager("#PopupMenu"); //$NON-NLS-1$
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(manager -> ResourceNavigator.this.fillContextMenu(manager));
+		menuMgr.addMenuListener(ResourceNavigator.this::fillContextMenu);
 		TreeViewer viewer = getTreeViewer();
 		Menu menu = menuMgr.createContextMenu(viewer.getTree());
 		viewer.getTree().setMenu(menu);
@@ -395,7 +401,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 	 */
 	protected void initLabelProvider(TreeViewer viewer) {
 		viewer.setLabelProvider(new DecoratingLabelProvider(new WorkbenchLabelProvider(),
-				getPlugin().getWorkbench().getDecoratorManager().getLabelDecorator()));
+				PlatformUI.getWorkbench().getDecoratorManager().getLabelDecorator()));
 	}
 
 	/**
@@ -433,8 +439,8 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 	 * @since 2.0
 	 */
 	protected void initListeners(final TreeViewer viewer) {
-		viewer.addSelectionChangedListener(event -> handleSelectionChanged(event));
-		viewer.addDoubleClickListener(event -> handleDoubleClick(event));
+		viewer.addSelectionChangedListener(this::handleSelectionChanged);
+		viewer.addDoubleClickListener(this::handleDoubleClick);
 
 		openAndLinkWithEditorHelper = new OpenAndLinkWithEditorHelper(viewer) {
 			@Override
@@ -502,7 +508,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 	public void dispose() {
 		getSite().getPage().removePartListener(partListener);
 
-		IWorkingSetManager workingSetManager = getPlugin().getWorkbench().getWorkingSetManager();
+		IWorkingSetManager workingSetManager = PlatformUI.getWorkbench().getWorkingSetManager();
 		workingSetManager.removePropertyChangeListener(propertyChangeListener);
 
 		if (collapseAllHandler != null) {
@@ -922,7 +928,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 		IWorkingSet workingSet = null;
 
 		if (workingSetName != null && workingSetName.isEmpty() == false) {
-			IWorkingSetManager workingSetManager = getPlugin().getWorkbench().getWorkingSetManager();
+			IWorkingSetManager workingSetManager = PlatformUI.getWorkbench().getWorkingSetManager();
 			workingSet = workingSetManager.getWorkingSet(workingSetName);
 		} else if (PlatformUI.getPreferenceStore()
 				.getBoolean(IWorkbenchPreferenceConstants.USE_WINDOW_WORKING_SET_BY_DEFAULT)) {
@@ -1452,8 +1458,7 @@ public class ResourceNavigator extends ViewPart implements ISetSelectionTarget,
 			ISelection sel = context.getSelection();
 			if (sel instanceof IStructuredSelection) {
 				IStructuredSelection ssel = (IStructuredSelection) sel;
-				for (Iterator<?> i = ssel.iterator(); i.hasNext();) {
-					Object o1 = i.next();
+				for (Object o1 : ssel) {
 
 					IResource resource = Adapters.adapt(o1, IResource.class);
 					if (resource != null) {
