@@ -19,6 +19,7 @@ import java.util.StringTokenizer;
 
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.Adapters;
+import org.eclipse.core.text.StringMatcher;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.jface.viewers.ViewerFilter;
@@ -29,6 +30,13 @@ import org.eclipse.ui.internal.util.PrefUtil;
  * Filter used to determine whether resources are to be shown or not.
  *
  * @since 2.0
+ *
+ * @noextend This class is not intended to be subclassed by clients.
+ * @noinstantiate This class is not intended to be instantiated by clients.
+ * @noreference This class is not intended to be referenced by clients.
+ *
+ *              Planned to be deleted, please see Bug
+ *              https://bugs.eclipse.org/bugs/show_bug.cgi?id=549953
  * @deprecated as of 3.5, use the Common Navigator Framework classes instead
  */
 @Deprecated
@@ -83,7 +91,7 @@ public class ResourcePatternFilter extends ViewerFilter {
 		IPreferenceStore viewsPrefs = IDEWorkbenchPlugin.getDefault().getPreferenceStore();
 		String storedPatterns = viewsPrefs.getString(FILTERS_TAG);
 
-		if (storedPatterns.length() == 0) {
+		if (storedPatterns.isEmpty()) {
 			// try to migrate patterns from old workbench preference store location
 			IPreferenceStore workbenchPrefs = PrefUtil.getInternalPreferenceStore();
 			storedPatterns = workbenchPrefs.getString(FILTERS_TAG);
@@ -93,7 +101,7 @@ public class ResourcePatternFilter extends ViewerFilter {
 			}
 		}
 
-		if (storedPatterns.length() == 0) {
+		if (storedPatterns.isEmpty()) {
 			// revert to all filter extensions with selected == "true"
 			// if there are no filters in the preference store
 			List<String> defaultFilters = FiltersContentProvider.getDefaultFilters();
