@@ -14,7 +14,6 @@
 package org.eclipse.ui.views.navigator;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.core.resources.IResource;
@@ -32,6 +31,11 @@ import org.eclipse.jface.viewers.StructuredSelection;
  *        </p>
  * @noinstantiate This class is not intended to be instantiated by clients.
  * @noextend This class is not intended to be subclassed by clients.
+ * @noreference This class is not intended to be referenced by clients.
+ *
+ *              Planned to be deleted, please see Bug
+ *              https://bugs.eclipse.org/bugs/show_bug.cgi?id=549953
+ *
  * @deprecated as of 3.5, use {@link org.eclipse.ui.ide.ResourceSelectionUtil}
  *             instead.
  */
@@ -53,9 +57,7 @@ public class ResourceSelectionUtil {
 	 * @see IResource#getType()
 	 */
 	public static boolean allResourcesAreOfType(IStructuredSelection selection, int resourceMask) {
-		Iterator<?> resources = selection.iterator();
-		while (resources.hasNext()) {
-			Object next = resources.next();
+		for (Object next : selection) {
 			if (!(next instanceof IResource)) {
 				return false;
 			}
@@ -77,10 +79,8 @@ public class ResourceSelectionUtil {
 	 * @see IResource#getType()
 	 */
 	public static IStructuredSelection allResources(IStructuredSelection selection, int resourceMask) {
-		Iterator<?> adaptables = selection.iterator();
 		List<IResource> result = new ArrayList<>();
-		while (adaptables.hasNext()) {
-			Object next = adaptables.next();
+		for (Object next : selection) {
 
 			IResource resource = Adapters.adapt(next, IResource.class);
 			if (resource == null) {
