@@ -102,7 +102,7 @@ import org.eclipse.ui.statushandlers.StatusManager;
  * name is created, the dialog closes, and the call to <code>open</code>
  * returns.
  * </p>
- * 
+ *
  * @noextend This class is not intended to be subclassed by clients.
  */
 public class BasicNewProjectResourceWizard extends BasicNewResourceWizard
@@ -556,7 +556,7 @@ try {
 		}
 		String desc = finalPersp.getDescription();
 		String message;
-		if (desc == null || desc.length() == 0)
+		if (desc == null || desc.isEmpty())
 			message = NLS.bind(ResourceMessages.NewProject_perspSwitchMessage,
 					finalPersp.getLabel());
 		else
