@@ -37,6 +37,7 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Listener;
 import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.monitoring.IUiFreezeEventLogger;
 import org.eclipse.ui.monitoring.PreferenceConstants;
 import org.eclipse.ui.monitoring.StackSample;
@@ -185,7 +186,7 @@ public class EventLoopMonitorThread extends Thread {
 				if (eventHistory != null) {
 					eventHistory.recordEvent(event.type, event.detail, nestingLevel);
 				}
-				 // Log a long interval, start the timer if inside another event.
+				// Log a long interval, start the timer if inside another event.
 				handleEventTransition(true, nestingLevel > 0);
 				break;
 			case SWT.PreExternalEventDispatch:
@@ -340,11 +341,11 @@ public class EventLoopMonitorThread extends Thread {
 	private final int longEventWarningThreshold;
 	private final AtomicBoolean cancelled = new AtomicBoolean(false);
 	private final AtomicReference<LongEventInfo> eventToPublish =
-			new AtomicReference<LongEventInfo>(null);
+			new AtomicReference<>(null);
 
 	// Accessed only by the monitoring thread.
 	private final List<IUiFreezeEventLogger> externalLoggers =
-			new ArrayList<IUiFreezeEventLogger>();
+			new ArrayList<>();
 	private DefaultUiFreezeEventLogger defaultLogger;
 	private final Display display;
 	private final FilterHandler uiThreadFilter;
@@ -489,7 +490,7 @@ public class EventLoopMonitorThread extends Thread {
 		boolean dumpAllThreads = false;
 
 		// Register for events
-		display.asyncExec(() -> registerDisplayListeners());
+		display.asyncExec(this::registerDisplayListeners);
 
 		long currTime = getTimestamp();
 
@@ -651,16 +652,16 @@ public class EventLoopMonitorThread extends Thread {
 					threadMXBean.dumpAllThreads(dumpLockedMonitors, dumpLockedSynchronizers);
 			// Remove the info for the monitoring thread.
 			int index = 0;
-			for (int i = 0; i < threadStacks.length; i++) {
-				ThreadInfo thread = threadStacks[i];
+			for (ThreadInfo thread : threadStacks) {
 				long threadId = thread.getThreadId();
 				// Skip the stack trace of the event loop monitoring thread.
 				if (threadId != monitoringThreadId) {
 					if (threadId == uiThreadId) {
 						// Swap the UI thread to first slot in the array if it is not there already.
 						if (index != 0) {
+							ThreadInfo uiThread = thread;
 							thread = threadStacks[0];
-							threadStacks[0] = threadStacks[i];
+							threadStacks[0] = uiThread;
 						}
 					} else if (!isInteresting(thread)) {
 						continue; // Skip the non-interesting thread.
@@ -688,7 +689,7 @@ public class EventLoopMonitorThread extends Thread {
 	}
 
 	private static Display getDisplay() throws IllegalStateException {
-		IWorkbench workbench = MonitoringPlugin.getDefault().getWorkbench();
+		IWorkbench workbench = PlatformUI.getWorkbench();
 		if (workbench == null) {
 			throw new IllegalStateException(Messages.EventLoopMonitorThread_workbench_was_null);
 		}
