@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2014, 2018 Red Hat Inc.
+ * Copyright (c) 2014, 2020 Red Hat Inc. and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,7 @@
  ******************************************************************************/
 package org.eclipse.ui.internal.navigator.resources.nested;
 
+import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.Set;
 
@@ -35,11 +36,16 @@ import org.eclipse.ui.commands.ICommandService;
 import org.eclipse.ui.handlers.HandlerUtil;
 import org.eclipse.ui.internal.navigator.resources.plugin.WorkbenchNavigatorPlugin;
 import org.eclipse.ui.navigator.CommonViewer;
+import org.eclipse.ui.navigator.ICommonFilterDescriptor;
+import org.eclipse.ui.navigator.INavigatorFilterService;
 
 public class NestedProjectsContentProvider implements ITreeContentProvider, IResourceChangeListener {
 
 	public static final String EXTENSION_ID = "org.eclipse.ui.navigator.resources.nested.nestedProjectContentProvider"; //$NON-NLS-1$
 
+	private static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];
+	private static final IProject[] EMPTY_PROJECT_ARRAY = new IProject[0];
+
 	private Command projectPresetionCommand;
 	private CommonViewer viewer;
 
@@ -56,7 +62,6 @@ public class NestedProjectsContentProvider implements ITreeContentProvider, IRes
 
 	@Override
 	public void dispose() {
-		NestedProjectsLabelProvider.viewersToUpdate.remove(this.viewer);
 		try {
 			HandlerUtil.updateRadioState(this.projectPresetionCommand, Boolean.FALSE.toString());
 		} catch (ExecutionException ex) {
@@ -68,18 +73,34 @@ public class NestedProjectsContentProvider implements ITreeContentProvider, IRes
 	@Override
 	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
 		this.viewer = (CommonViewer)viewer;
-		NestedProjectsLabelProvider.viewersToUpdate.add(this.viewer);
+		ensureFiltersActivated();
+	}
+
+	private void ensureFiltersActivated() {
+		INavigatorFilterService filterService = this.viewer.getNavigatorContentService().getFilterService();
+		Set<String> filters = new HashSet<>();
+		for (ICommonFilterDescriptor desc : filterService.getVisibleFilterDescriptors()) {
+			if (filterService.isActive(desc.getId())) {
+				filters.add(desc.getId());
+			}
+		}
+		if (!filters.contains(HideTopLevelProjectIfNested.EXTENSION_ID)
+				|| !filters.contains(HideFolderWhenProjectIsShownAsNested.EXTENTSION_ID)) {
+			filters.add(HideTopLevelProjectIfNested.EXTENSION_ID);
+			filters.add(HideFolderWhenProjectIsShownAsNested.EXTENTSION_ID);
+			filterService.activateFilterIdsAndUpdateViewer(filters.toArray(new String[filters.size()]));
+		}
 	}
 
 	@Override
 	public Object[] getElements(Object inputElement) {
-		return null;
+		return EMPTY_OBJECT_ARRAY;
 	}
 
 	@Override
 	public IProject[] getChildren(Object parentElement) {
 		if (! (parentElement instanceof IContainer)) {
-			return null;
+			return EMPTY_PROJECT_ARRAY;
 		}
 		IContainer container = (IContainer)parentElement;
 		return NestedProjectManager.getInstance().getDirectChildrenProjects(container);
