@@ -18,6 +18,8 @@
  *******************************************************************************/
 package org.eclipse.ui.dialogs;
 
+import static org.eclipse.jface.viewers.LabelProvider.createTextImageProvider;
+
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -34,10 +36,8 @@ import org.eclipse.jface.resource.LocalResourceManager;
 import org.eclipse.jface.resource.ResourceManager;
 import org.eclipse.jface.util.Util;
 import org.eclipse.jface.viewers.ITreeContentProvider;
-import org.eclipse.jface.viewers.LabelProvider;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TreeViewer;
-import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.osgi.util.TextProcessor;
 import org.eclipse.swt.SWT;
@@ -83,16 +83,6 @@ public class EditorSelectionDialog extends Dialog {
 
 		private static final Object[] EMPTY = new Object[0];
 
-		@Override
-		public void dispose() {
-			//
-		}
-
-		@Override
-		public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
-			//
-		}
-
 		@Override
 		public Object[] getElements(Object inputElement) {
 			if (inputElement == null || !inputElement.getClass().isArray()) {
@@ -283,19 +273,13 @@ public class EditorSelectionDialog extends Dialog {
 		editorTable.setFont(font);
 		data.heightHint = tree.getItemHeight() * 12;
 		editorTableViewer.setContentProvider(new TreeArrayContentProvider());
-		editorTableViewer.setLabelProvider(new LabelProvider() {
-			@Override
-			public String getText(Object element) {
-				IEditorDescriptor d = (IEditorDescriptor) element;
-				return TextProcessor.process(d.getLabel(), "."); //$NON-NLS-1$
-			}
-
-			@Override
-			public Image getImage(Object element) {
-				IEditorDescriptor d = (IEditorDescriptor) element;
-				return (Image) resourceManager.get(d.getImageDescriptor());
-			}
-		});
+		editorTableViewer.setLabelProvider(createTextImageProvider(element-> {
+			IEditorDescriptor d = (IEditorDescriptor) element;
+			return TextProcessor.process(d.getLabel(), "."); //$NON-NLS-1$
+		}, element -> {
+			IEditorDescriptor d = (IEditorDescriptor) element;
+			return (Image) resourceManager.get(d.getImageDescriptor());
+		}));
 
 		browseExternalEditorsButton = new Button(contents, SWT.PUSH);
 		browseExternalEditorsButton.setText(WorkbenchMessages.EditorSelection_browse);
@@ -355,6 +339,9 @@ public class EditorSelectionDialog extends Dialog {
 		return fileName.substring(lastDot + 1, fileName.length());
 	}
 
+	/**
+	 * Fills the editor table.
+	 */
 	protected void fillEditorTable() {
 		IEditorDescriptor newSelection = selectedEditor;
 
@@ -505,6 +492,9 @@ public class EditorSelectionDialog extends Dialog {
 		return selectedEditor;
 	}
 
+	/**
+	 * Opens the prompt to select an external editor.
+	 */
 	protected void promptForExternalEditor() {
 		FileDialog dialog = new FileDialog(getShell(), SWT.OPEN | SWT.PRIMARY_MODAL | SWT.SHEET);
 		dialog.setFilterExtensions(Executable_Filters);
