@@ -14,11 +14,11 @@
  *******************************************************************************/
 package org.eclipse.ui.dialogs;
 
+import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Set;
-import java.util.Vector;
-
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
@@ -36,7 +36,7 @@ import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.ui.internal.WorkbenchMessages;
-import org.eclipse.ui.internal.misc.StringMatcher;
+import org.eclipse.ui.internal.misc.TextMatcher;
 import org.eclipse.ui.internal.util.Util;
 import org.eclipse.ui.progress.WorkbenchJob;
 
@@ -73,11 +73,11 @@ public class FilteredList extends Composite {
 	}
 
 	private class DefaultFilterMatcher implements FilterMatcher {
-		private StringMatcher fMatcher;
+		private TextMatcher fMatcher;
 
 		@Override
 		public void setFilter(String pattern, boolean ignoreCase, boolean ignoreWildCards) {
-			fMatcher = new StringMatcher(pattern + '*', ignoreCase, ignoreWildCards);
+			fMatcher = new TextMatcher(pattern + '*', ignoreCase, ignoreWildCards);
 		}
 
 		@Override
@@ -104,7 +104,7 @@ public class FilteredList extends Composite {
 
 	Label[] fLabels;
 
-	Vector fImages = new Vector();
+	List<Image> fImages = new ArrayList<>();
 
 	int[] fFoldedIndices;
 
@@ -137,8 +137,8 @@ public class FilteredList extends Composite {
 		/**
 		 * Create a new instance of label.
 		 *
-		 * @param newString
-		 * @param image
+		 * @param newString the label
+		 * @param image     the image
 		 */
 		public Label(String newString, Image image) {
 			if (newString == null) {
@@ -152,8 +152,8 @@ public class FilteredList extends Composite {
 		/**
 		 * Return whether or not the receiver is the same as label.
 		 *
-		 * @param label
-		 * @return boolean
+		 * @param label the {@link Label} to compare
+		 * @return boolean true if the receiver is the same as the passed label
 		 */
 		public boolean equals(Label label) {
 			if (label == null) {
@@ -257,7 +257,7 @@ public class FilteredList extends Composite {
 		int length = fElements.length;
 		// fill labels
 		fLabels = new Label[length];
-		Set imageSet = new HashSet();
+		Set<Image> imageSet = new HashSet<>();
 		for (int i = 0; i != length; i++) {
 			String text = fLabelProvider.getText(fElements[i]);
 			Image image = fLabelProvider.getImage(fElements[i]);
@@ -286,7 +286,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Sets the filter matcher.
 	 *
-	 * @param filterMatcher
+	 * @param filterMatcher the {@link FilterMatcher} to set.
 	 */
 	public void setFilterMatcher(FilterMatcher filterMatcher) {
 		Assert.isNotNull(filterMatcher);
@@ -296,7 +296,7 @@ public class FilteredList extends Composite {
 	/**
 	 * Sets a custom comparator for sorting the list.
 	 *
-	 * @param comparator
+	 * @param comparator the {@link Comparator} to set.
 	 */
 	public void setComparator(Comparator comparator) {
 		Assert.isNotNull(comparator);
@@ -500,7 +500,7 @@ public class FilteredList extends Composite {
 	 * elements after filtering.
 	 */
 	private int filter() {
-		if (((fFilter == null) || (fFilter.length() == 0)) && !fMatchEmptyString) {
+		if (((fFilter == null) || (fFilter.isEmpty())) && !fMatchEmptyString) {
 			return 0;
 		}
 		fFilterMatcher.setFilter(fFilter.trim(), fIgnoreCase, false);
@@ -530,7 +530,7 @@ public class FilteredList extends Composite {
 		/**
 		 * Create a new instance of a job used to update the table.
 		 *
-		 * @param table
+		 * @param table the table to update.
 		 * @param count The number of items to update per running.
 		 */
 		public TableUpdateJob(Table table, int count) {
