@@ -14,7 +14,7 @@
 package org.eclipse.ui.dialogs;
 
 import org.eclipse.jface.util.Util;
-import org.eclipse.ui.internal.misc.StringMatcher;
+import org.eclipse.ui.internal.misc.TextMatcher;
 
 /**
  * A search pattern defines how search results are found.
@@ -95,7 +95,7 @@ public class SearchPattern {
 
 	private String initialPattern;
 
-	private StringMatcher stringMatcher;
+	private TextMatcher stringMatcher;
 
 	private static final char END_SYMBOL = '<';
 
@@ -158,14 +158,14 @@ public class SearchPattern {
 		initializePatternAndMatchRule(stringPattern);
 		matchRule = matchRule & this.allowedRules;
 		if (matchRule == RULE_PATTERN_MATCH) {
-			stringMatcher = new StringMatcher(this.stringPattern, true, false);
+			stringMatcher = new TextMatcher(this.stringPattern, true, false);
 		}
 	}
 
 	/**
 	 * Matches text with pattern. matching is determine by matchKind.
 	 *
-	 * @param text
+	 * @param text the text to match
 	 * @return true if search pattern was matched with text false in other way
 	 */
 	public boolean matches(String text) {
@@ -515,7 +515,7 @@ public class SearchPattern {
 	 * Checks pattern's character is allowed for specified set. It could be override
 	 * if you want change logic of camelCaseMatch methods.
 	 *
-	 * @param patternChar
+	 * @param patternChar the char to check
 	 * @return true if patternChar is in set of allowed characters for pattern
 	 */
 	protected boolean isPatternCharAllowed(char patternChar) {
