@@ -45,7 +45,7 @@ class ExtensionEventHandler implements IRegistryChangeListener {
 
 	private Workbench workbench;
 
-	private List changeList = new ArrayList(10);
+	private List<?> changeList = new ArrayList<>(10);
 
 	public ExtensionEventHandler(Workbench workbench) {
 		this.workbench = workbench;
@@ -65,8 +65,8 @@ class ExtensionEventHandler implements IRegistryChangeListener {
 			if (display == null) {
 				return;
 			}
-			ArrayList appearList = new ArrayList(5);
-			ArrayList revokeList = new ArrayList(5);
+			ArrayList<IExtensionDelta> appearList = new ArrayList<>(5);
+			ArrayList<IExtensionDelta> revokeList = new ArrayList<>(5);
 			String id = null;
 			int numPerspectives = 0;
 			int numActionSetPartAssoc = 0;
@@ -86,21 +86,25 @@ class ExtensionEventHandler implements IRegistryChangeListener {
 					}
 				} else {
 					if (extensionDelta.getKind() == IExtensionDelta.REMOVED) {
-						if (id.equals(IWorkbenchRegistryConstants.PL_ACTION_SET_PART_ASSOCIATIONS)) {
+						switch (id) {
+						case IWorkbenchRegistryConstants.PL_ACTION_SET_PART_ASSOCIATIONS:
 							revokeList.add(0, extensionDelta);
 							numActionSetPartAssoc++;
-						} else if (id.equals(IWorkbenchRegistryConstants.PL_PERSPECTIVES)) {
+							break;
+						case IWorkbenchRegistryConstants.PL_PERSPECTIVES:
 							revokeList.add(numActionSetPartAssoc, extensionDelta);
-						} else {
+							break;
+						default:
 							revokeList.add(extensionDelta);
+							break;
 						}
 					}
 				}
 			}
-			Iterator iter = appearList.iterator();
+			Iterator<IExtensionDelta> iter = appearList.iterator();
 			IExtensionDelta extDelta = null;
 			while (iter.hasNext()) {
-				extDelta = (IExtensionDelta) iter.next();
+				extDelta = iter.next();
 				extPt = extDelta.getExtensionPoint();
 				ext = extDelta.getExtension();
 				asyncAppear(display, extPt, ext);
@@ -149,8 +153,8 @@ class ExtensionEventHandler implements IRegistryChangeListener {
 			reader.readElement(configElement);
 		}
 
-		Collection fonts = reader.getFontDefinitions();
-		FontDefinition[] fontDefs = (FontDefinition[]) fonts.toArray(new FontDefinition[fonts.size()]);
+		Collection<FontDefinition> fonts = reader.getFontDefinitions();
+		FontDefinition[] fontDefs = fonts.toArray(new FontDefinition[fonts.size()]);
 		ThemeElementHelper.populateRegistry(workbench.getThemeManager().getTheme(IThemeManager.DEFAULT_THEME), fontDefs,
 				PrefUtil.getInternalPreferenceStore());
 	}
@@ -164,17 +168,17 @@ class ExtensionEventHandler implements IRegistryChangeListener {
 			reader.readElement(configElement);
 		}
 
-		Collection colors = reader.getColorDefinitions();
-		ColorDefinition[] colorDefs = (ColorDefinition[]) colors.toArray(new ColorDefinition[colors.size()]);
+		Collection<ColorDefinition> colors = reader.getColorDefinitions();
+		ColorDefinition[] colorDefs = colors.toArray(new ColorDefinition[colors.size()]);
 
 		ITheme theme = workbench.getThemeManager().getTheme(IThemeManager.DEFAULT_THEME);
 		ThemeElementHelper.populateRegistry(theme, colorDefs, PrefUtil.getInternalPreferenceStore());
 
-		Collection fonts = reader.getFontDefinitions();
-		FontDefinition[] fontDefs = (FontDefinition[]) fonts.toArray(new FontDefinition[fonts.size()]);
+		Collection<FontDefinition> fonts = reader.getFontDefinitions();
+		FontDefinition[] fontDefs = fonts.toArray(new FontDefinition[fonts.size()]);
 		ThemeElementHelper.populateRegistry(theme, fontDefs, PrefUtil.getInternalPreferenceStore());
 
-		Map data = reader.getData();
+		Map<String, String> data = reader.getData();
 		registry.addData(data);
 	}
 
@@ -186,8 +190,8 @@ class ExtensionEventHandler implements IRegistryChangeListener {
 		final StringBuilder message = new StringBuilder(
 				ExtensionEventHandlerMessages.ExtensionEventHandler_following_changes);
 
-		for (Iterator i = changeList.iterator(); i.hasNext();) {
-			message.append(i.next());
+		for (Object element : changeList) {
+			message.append(element);
 		}
 
 		message.append(ExtensionEventHandlerMessages.ExtensionEventHandler_need_to_reset);
