@@ -42,15 +42,19 @@ import org.eclipse.ui.PlatformUI;
  * <code>IObjectContributorManager</code>. It provides fast merging of
  * contributions with the following semantics:
  * <ul>
- * <li>All of the matching contributors will be invoked per property lookup
+ * <li>All of the matching contributors will be invoked per property lookup</li>
  * <li>The search order from a class with the definition<br>
  * <code>class X extends Y implements A, B</code><br>
- * is as follows: <il>
- * <li>the target's class: X
- * <li>X's superclasses in order to <code>Object</code>
- * <li>a depth-first traversal of the target class's interaces in the order
+ * is as follows:</li>
+ * <li>
+ * <ul>
+ * <li>the target's class: X</li>
+ * <li>X's superclasses in order to <code>Object</code></li>
+ * <li>a depth-first traversal of the target class's interfaces in the order
  * returned by <code>getInterfaces()</code> (in the example, A and its
- * superinterfaces then B and its superinterfaces) </il>
+ * superinterfaces then B and its superinterfaces)</li>
+ * </ul>
+ * </li>
  * </ul>
  *
  * @see IObjectContributor
@@ -129,8 +133,8 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	 * Adds contributors for the given types to the result list.
 	 */
 	private void addContributorsFor(List types, List result) {
-		for (Iterator classes = types.iterator(); classes.hasNext();) {
-			Class clazz = (Class) classes.next();
+		for (Iterator<Class> classes = types.iterator(); classes.hasNext();) {
+			Class clazz = classes.next();
 			List contributorList = (List) contributors.get(clazz.getName());
 			if (contributorList != null) {
 				result.addAll(contributorList);
@@ -274,9 +278,8 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	 * @return whether it is applicable
 	 */
 	public boolean isApplicableTo(IStructuredSelection selection, IObjectContributor contributor) {
-		Iterator elements = selection.iterator();
-		while (elements.hasNext()) {
-			if (contributor.isApplicableTo(elements.next()) == false) {
+		for (Object element : selection) {
+			if (contributor.isApplicableTo(element) == false) {
 				return false;
 			}
 		}
@@ -293,9 +296,8 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	 */
 
 	public boolean isApplicableTo(List list, IObjectContributor contributor) {
-		Iterator elements = list.iterator();
-		while (elements.hasNext()) {
-			if (contributor.isApplicableTo(elements.next()) == false) {
+		for (Object element : list) {
+			if (contributor.isApplicableTo(element) == false) {
 				return false;
 			}
 		}
@@ -491,7 +493,7 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	/**
 	 * Prunes from the list of adapters type names that are in the class search
 	 * order of every class in <code>results</code>.
-	 * 
+	 *
 	 * @param adapters
 	 * @param results
 	 * @since 3.1
@@ -519,9 +521,7 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 			result.add(clazz);
 			// add all the interfaces it implements
 			Class[] interfaces = clazz.getInterfaces();
-			for (Class currentInterface : interfaces) {
-				result.add(currentInterface);
-			}
+			result.addAll(Arrays.asList(interfaces));
 			// get the superclass
 			clazz = clazz.getSuperclass();
 		}
@@ -567,7 +567,7 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	/**
 	 * Returns the list of contributors that are interested in the given list of
 	 * model elements.
-	 * 
+	 *
 	 * @param elements a list of model elements (<code>Object</code>)
 	 * @return the list of interested contributors (<code>IObjectContributor</code>)
 	 */
@@ -592,8 +592,8 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 			addAll(contributors, getResourceContributors(resourceClass));
 		}
 		if (commonClasses != null && !commonClasses.isEmpty()) {
-			for (int i = 0; i < commonClasses.size(); i++) {
-				List results = getObjectContributors((Class) commonClasses.get(i));
+			for (Object commonClass : commonClasses) {
+				List results = getObjectContributors((Class) commonClass);
 				addAll(contributors, results);
 			}
 		}
@@ -629,8 +629,8 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	 * this class.
 	 */
 	private static void addAll(Collection collection, List toAdd) {
-		for (int i = 0, size = toAdd.size(); i < size; ++i) {
-			collection.add(toAdd.get(i));
+		for (Object element : toAdd) {
+			collection.add(element);
 		}
 	}
 
@@ -757,9 +757,9 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 		ArrayList results = new ArrayList(4);
 		ArrayList superClasses = new ArrayList(4);
 		if (!classesEmpty) {
-			for (int j = 0; j < classes.size(); j++) {
-				if (classes.get(j) != null) {
-					superClasses.add(classes.get(j));
+			for (Object clazz : classes) {
+				if (clazz != null) {
+					superClasses.add(clazz);
 				}
 			}
 			// Just keep the first super class
@@ -914,9 +914,7 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 			return null;
 		}
 
-		for (int i = 0; i < objects.size(); i++) {
-			Object object = objects.get(i);
-
+		for (Object object : objects) {
 			if (object instanceof IAdaptable) {
 				if (resourceMappingClass.isInstance(object)) {
 					continue;
@@ -973,10 +971,10 @@ public abstract class ObjectContributorManager implements IExtensionChangeHandle
 	private Class getCommonClass(Class class1, Class class2) {
 		List list1 = computeCombinedOrder(class1);
 		List list2 = computeCombinedOrder(class2);
-		for (int i = 0; i < list1.size(); i++) {
-			for (int j = 0; j < list2.size(); j++) {
-				Class candidate1 = (Class) list1.get(i);
-				Class candidate2 = (Class) list2.get(j);
+		for (Object element1 : list1) {
+			for (Object element2 : list2) {
+				Class candidate1 = (Class) element1;
+				Class candidate2 = (Class) element2;
 				if (candidate1.equals(candidate2)) {
 					return candidate1;
 				}
