@@ -53,7 +53,7 @@ public class ReopenEditorMenu extends ContributionItem {
 
 	/**
 	 * Create a new instance.
-	 * 
+	 *
 	 * @param window        the window on which the menu is to be created
 	 * @param id            menu's id
 	 * @param showSeparator whether or not to show a separator
@@ -98,7 +98,7 @@ public class ReopenEditorMenu extends ContributionItem {
 		StringBuilder nm = new StringBuilder();
 		nm.append(mnemonic);
 		if (mnemonic <= MAX_MNEMONIC_SIZE) {
-			nm.insert(nm.length() - (mnemonic + "").length(), '&'); //$NON-NLS-1$
+			nm.insert(nm.length() - (Integer.toString(mnemonic)).length(), '&');
 		}
 //        sb.append(" "); //$NON-NLS-1$
 
@@ -248,9 +248,7 @@ public class ReopenEditorMenu extends ContributionItem {
 		new MenuItem(menu, SWT.SEPARATOR);
 		MenuItem miClear = new MenuItem(menu, SWT.PUSH);
 		miClear.setText(WorkbenchMessages.OpenRecentDocumentsClear_text);
-		miClear.addSelectionListener(widgetSelectedAdapter(e -> Arrays.stream(history.getItems()).forEach(item -> {
-			history.remove(item);
-		})));
+		miClear.addSelectionListener(widgetSelectedAdapter(e -> Arrays.stream(history.getItems()).forEach(history::remove)));
 		miClear.setEnabled(nItems > 0);
 	}
 
