@@ -228,7 +228,7 @@ public class SaveablesList implements ISaveablesLifecycleListener {
 	 * use his previously "equal" colleagues to retrieve the expected reference
 	 * count
 	 *
-	 * @key object to find known, previously equal one
+	 * @param key object to find known, previously equal one
 	 * @return fixed key or given key
 	 */
 	private Saveable fixKeyIfKnown(Saveable key) {
@@ -771,9 +771,9 @@ public class SaveablesList implements ISaveablesLifecycleListener {
 				case ISaveablePart2.CANCEL: // cancel
 					return true;
 				}
-			} else {
+			} else if (!modelsToSave.isEmpty()) {
 				MyListSelectionDialog dlg = new MyListSelectionDialog(shellProvider.getShell(), modelsToSave,
-						new ArrayContentProvider(), new WorkbenchPartLabelProvider(),
+						ArrayContentProvider.getInstance(), new WorkbenchPartLabelProvider(),
 						stillOpenElsewhere ? WorkbenchMessages.EditorManager_saveResourcesOptionallyMessage
 								: WorkbenchMessages.EditorManager_saveResourcesMessage,
 						canCancel, stillOpenElsewhere);
