@@ -15,10 +15,9 @@
 
 package org.eclipse.ui.internal;
 
-import com.ibm.icu.text.Collator;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -80,25 +79,23 @@ public class ShowViewMenu extends ContributionItem {
 
 	private static final String NO_TARGETS_MSG = WorkbenchMessages.Workbench_showInNoTargets;
 
-	private Comparator actionComparator = (o1, o2) -> {
+	private Comparator<CommandContributionItemParameter> actionComparator = (o1, o2) -> {
 		if (collator == null) {
 			collator = Collator.getInstance();
 		}
-		CommandContributionItemParameter a1 = (CommandContributionItemParameter) o1;
-		CommandContributionItemParameter a2 = (CommandContributionItemParameter) o2;
-		return collator.compare(a1.label, a2.label);
+		return collator.compare(o1.label, o2.label);
 	};
 
 	private Action showDlgAction;
 
-	private Map actions = new HashMap(21);
+	private Map<String, ?> actions = new HashMap<>(21);
 
 	// Maps pages to a list of opened views
-	private Map openedViews = new HashMap();
+	private Map<IWorkbenchPage, ArrayList<String>> openedViews = new HashMap<>();
 
 	private MenuManager menuManager;
 
-	private IMenuListener menuListener = manager -> manager.markDirty();
+	private IMenuListener menuListener = IMenuManager::markDirty;
 	private boolean makeFast;
 
 	private static Collator collator;
@@ -133,13 +130,7 @@ public class ShowViewMenu extends ContributionItem {
 			public void run() {
 				try {
 					handlerService.executeCommand(cmd, null);
-				} catch (final ExecutionException e) {
-					// Do nothing.
-				} catch (NotDefinedException e) {
-					// Do nothing.
-				} catch (NotEnabledException e) {
-					// Do nothing.
-				} catch (NotHandledException e) {
+				} catch (ExecutionException | NotDefinedException | NotEnabledException | NotHandledException e) {
 					// Do nothing.
 				}
 			}
@@ -182,14 +173,14 @@ public class ShowViewMenu extends ContributionItem {
 		}
 
 		// Get visible actions.
-		List viewIds = Arrays.asList(page.getShowViewShortcuts());
+		List<String> viewIds = Arrays.asList(page.getShowViewShortcuts());
 
 		// add all open views
 		viewIds = addOpenedViews(page, viewIds);
 
-		List actions = new ArrayList(viewIds.size());
-		for (Iterator i = viewIds.iterator(); i.hasNext();) {
-			String id = (String) i.next();
+		List<CommandContributionItemParameter> actions = new ArrayList<>(viewIds.size());
+		for (Iterator<String> i = viewIds.iterator(); i.hasNext();) {
+			String id = i.next();
 			if (id.equals(IIntroConstants.INTRO_VIEW_ID)) {
 				continue;
 			}
@@ -198,9 +189,9 @@ public class ShowViewMenu extends ContributionItem {
 				actions.add(item);
 			}
 		}
-		Collections.sort(actions, actionComparator);
-		for (Iterator i = actions.iterator(); i.hasNext();) {
-			CommandContributionItemParameter ccip = (CommandContributionItemParameter) i.next();
+		actions.sort(actionComparator);
+		for (Iterator<CommandContributionItemParameter> i = actions.iterator(); i.hasNext();) {
+			CommandContributionItemParameter ccip = i.next();
 			if (WorkbenchActivityHelper.filterItem(ccip)) {
 				continue;
 			}
@@ -242,6 +233,7 @@ public class ShowViewMenu extends ContributionItem {
 
 	}
 
+	@SuppressWarnings("unchecked")
 	private CommandContributionItemParameter getItem(String viewId) {
 		IViewRegistry reg = WorkbenchPlugin.getDefault().getViewRegistry();
 		IViewDescriptor desc = reg.find(viewId);
@@ -254,7 +246,7 @@ public class ShowViewMenu extends ContributionItem {
 				IWorkbenchCommandConstants.VIEWS_SHOW_VIEW, CommandContributionItem.STYLE_PUSH);
 		parms.label = label;
 		parms.icon = desc.getImageDescriptor();
-		parms.parameters = new HashMap();
+		parms.parameters = new HashMap<String, String>();
 
 		parms.parameters.put(VIEW_ID_PARM, viewId);
 		if (makeFast) {
@@ -263,18 +255,17 @@ public class ShowViewMenu extends ContributionItem {
 		return parms;
 	}
 
-	private List addOpenedViews(IWorkbenchPage page, List actions) {
-		ArrayList views = getParts(page);
-		ArrayList result = new ArrayList(views.size() + actions.size());
+	private List<String> addOpenedViews(IWorkbenchPage page, List<String> actions) {
+		ArrayList<String> views = getParts(page);
+		ArrayList<String> result = new ArrayList<>(views.size() + actions.size());
 
-		for (int i = 0; i < actions.size(); i++) {
-			Object element = actions.get(i);
+		for (String element : actions) {
 			if (result.indexOf(element) < 0) {
 				result.add(element);
 			}
 		}
 		for (int i = 0; i < views.size(); i++) {
-			Object element = views.get(i);
+			String element = views.get(i);
 			if (result.indexOf(element) < 0) {
 				result.add(element);
 			}
@@ -282,10 +273,10 @@ public class ShowViewMenu extends ContributionItem {
 		return result;
 	}
 
-	private ArrayList getParts(IWorkbenchPage page) {
-		ArrayList parts = (ArrayList) openedViews.get(page);
+	private ArrayList<String> getParts(IWorkbenchPage page) {
+		ArrayList<String> parts = openedViews.get(page);
 		if (parts == null) {
-			parts = new ArrayList();
+			parts = new ArrayList<>();
 			openedViews.put(page, parts);
 		}
 		return parts;
