@@ -55,7 +55,7 @@ public class WorkbenchLayoutSettingsTransfer extends WorkbenchSettingsTransfer {
 			if (deltas.exists()) {
 				byte[] bytes = new byte[8192];
 				try (FileInputStream inputStream = new FileInputStream(deltas);
-						FileOutputStream outputStream = new FileOutputStream(new File(workspaceFile, "deltas.xml")); //$NON-NLS-1$
+						FileOutputStream outputStream = new FileOutputStream(new File(workspaceFile, "deltas.xml")) //$NON-NLS-1$
 				) {
 					int read = inputStream.read(bytes, 0, 8192);
 					while (read != -1) {
@@ -69,7 +69,7 @@ public class WorkbenchLayoutSettingsTransfer extends WorkbenchSettingsTransfer {
 			if (workbenchModel.exists()) {
 				byte[] bytes = new byte[8192];
 				try (FileInputStream inputStream = new FileInputStream(workbenchModel);
-						FileOutputStream outputStream = new FileOutputStream(new File(workspaceFile, "workbench.xmi")); //$NON-NLS-1$
+						FileOutputStream outputStream = new FileOutputStream(new File(workspaceFile, "workbench.xmi")) //$NON-NLS-1$
 				) {
 					int read = inputStream.read(bytes, 0, 8192);
 					while (read != -1) {
