@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2018 IBM Corporation and others.
+ * Copyright (c) 2005, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -352,10 +352,6 @@ public class WorkbenchMessages extends NLS {
 
 	public static String AboutSystemPage_RetrievingSystemInfo;
 
-	// --- Shortcutbar ---
-	public static String PerspectiveBarContributionItem_toolTip;
-	public static String PerspectiveBarNewContributionItem_toolTip;
-
 	// --- Coolbar ---
 	public static String WorkbenchWindow_FileToolbar;
 	public static String WorkbenchWindow_EditToolbar;
@@ -459,9 +455,8 @@ public class WorkbenchMessages extends NLS {
 	// --- Appearance ---
 	public static String ViewsPreferencePage_Theme;
 	public static String ViewsPreference_currentTheme;
-	public static String ViewsPreference_currentThemeDescription;
 	public static String ViewsPreference_currentThemeFormat;
-	public static String ViewsPreference_enableAnimations;
+	public static String ViewsPreference_useRoundTabs;
 	public static String ViewsPreference_visibleTabs_description;
 	public static String ViewsPreference_enableMRU;
 	public static String ViewsPreference_useColoredLabels;
@@ -536,6 +531,7 @@ public class WorkbenchMessages extends NLS {
 	public static String WorkbenchPreference_noEffectOnAllViews;
 	public static String WorkbenchPreference_HeapStatusButton;
 	public static String WorkbenchPreference_HeapStatusButtonToolTip;
+	public static String WorkbenchPreference_inlineRename;
 
 	// --- Globalization -----
 	public static String GlobalizationPreference_nlExtensions;
@@ -568,6 +564,7 @@ public class WorkbenchMessages extends NLS {
 	public static String PropertyDialog_toolTip;
 	public static String PropertyDialog_messageTitle;
 	public static String PropertyDialog_noPropertyMessage;
+	public static String PropertyDialog_noPropertyMessageForUnknown;
 	public static String PropertyDialog_propertyMessage;
 	public static String PropertyPageNode_errorMessage;
 
@@ -663,7 +660,6 @@ public class WorkbenchMessages extends NLS {
 	// ==============================================================================
 	public static String Startup_Loading;
 	public static String Startup_Loading_Workbench;
-	public static String Startup_Done;
 
 	public static String WorkbenchPage_UnknownLabel;
 
@@ -709,13 +705,14 @@ public class WorkbenchMessages extends NLS {
 	public static String Workbench_problemsRestoring;
 	public static String Workbench_problemsSaving;
 
+	public static String Workbench_problemsRestartErrorTitle;
+	public static String Workbench_problemsRestartErrorMessage;
+
 	public static String PageLayout_missingRefPart;
 
 	// ==============================================================================
 	// Keys used in the reuse editor which is released as experimental.
 	// ==============================================================================
-	public static String EditorManager_openNewEditorLabel;
-	public static String EditorManager_reuseEditorDialogTitle;
 	public static String PinEditorAction_toolTip;
 	public static String WorkbenchPreference_reuseEditors;
 	public static String WorkbenchPreference_reuseEditorsThreshold;
@@ -793,12 +790,6 @@ public class WorkbenchMessages extends NLS {
 	public static String SystemSummary_sectionTitle;
 	public static String SystemSummary_sectionError;
 
-	// paramter 0 is the feature name, parameter 1 is the version and parameter 2 is
-	// the Id
-	public static String SystemSummary_featureVersion;
-
-	public static String SystemSummary_descriptorIdVersionState;
-
 	// =================================================================
 	// Editor List
 	// =================================================================
@@ -818,12 +809,10 @@ public class WorkbenchMessages extends NLS {
 
 	public static String EventLoopProgressMonitor_OpenDialogJobName;
 	public static String DecorationReference_EmptyReference;
-	public static String RectangleAnimation_Animating_Rectangle;
 	public static String FilteredList_UpdateJobName;
 	public static String FilteredTree_ClearToolTip;
 	public static String FilteredTree_FilterMessage;
 	public static String FilteredTree_FilteredDialogTitle;
-	public static String FilteredTree_AccessibleListenerClearButton;
 	public static String FilteredTree_AccessibleListenerFiltered;
 	public static String Workbench_startingPlugins;
 	public static String ScopedPreferenceStore_DefaultAddedError;
@@ -924,20 +913,6 @@ public class WorkbenchMessages extends NLS {
 	public static String LegacyActionPersistence_AutogeneratedCommandName;
 
 	// ==============================================================================
-	// Trim Common UI
-	// ==============================================================================
-
-	// Trim Menu item labels
-	public static String TrimCommon_DockOn;
-	public static String TrimCommon_Left;
-	public static String TrimCommon_Right;
-	public static String TrimCommon_Bottom;
-	public static String TrimCommon_Top;
-	public static String TrimCommon_Close;
-
-	// Trim area Display Names
-	public static String TrimCommon_Progress_TrimName;
-
 	// FilteredItemsSelectionDialog
 	public static String FilteredItemsSelectionDialog_cacheSearchJob_taskName;
 	public static String FilteredItemsSelectionDialog_menu;
@@ -1012,7 +987,6 @@ public class WorkbenchMessages extends NLS {
 
 	// Util
 	public static String Util_List;
-	public static String Util_listNull;
 
 	// Zoom change messages
 	public static String Workbench_zoomChangedTitle;
