@@ -16,9 +16,9 @@
 
 package org.eclipse.ui.internal;
 
-import com.ibm.icu.text.MessageFormat;
 import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
+import java.text.Bidi;
+import java.text.MessageFormat;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
@@ -51,7 +51,6 @@ import org.eclipse.ui.IEditorRegistry;
 import org.eclipse.ui.IElementFactory;
 import org.eclipse.ui.IPerspectiveRegistry;
 import org.eclipse.ui.ISharedImages;
-import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkingSetManager;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.decorators.DecoratorManager;
@@ -91,7 +90,7 @@ import org.osgi.util.tracker.ServiceTracker;
 
 /**
  * This class represents the TOP of the workbench UI world A plugin class is
- * effectively an application wrapper for a plugin & its classes. This class
+ * effectively an application wrapper for a plugin &amp; its classes. This class
  * should be thought of as the workbench UI's application class.
  *
  * This class is responsible for tracking various registries font, preference,
@@ -115,7 +114,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 	/**
 	 * The OSGi splash property.
 	 *
-	 * @sicne 3.4
+	 * @since 3.4
 	 */
 	private static final String PROP_SPLASH_HANDLE = "org.eclipse.equinox.launcher.splash.handle"; //$NON-NLS-1$
 
@@ -330,7 +329,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 	/**
 	 * Checks to see if the provided element has the syntax for an executable
 	 * extension with a given name that resides in a bundle that is already active.
-	 * Determining the bundle happens in one of two ways:<br/>
+	 * Determining the bundle happens in one of two ways:<br>
 	 * <ul>
 	 * <li>The element has an attribute with the specified name or element text in
 	 * the form <code>bundle.id/class.name[:optional attributes]</code></li>
@@ -355,7 +354,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 
 	/**
 	 * Returns the bundle that contains the class referenced by an executable
-	 * extension. Determining the bundle happens in one of two ways:<br/>
+	 * extension. Determining the bundle happens in one of two ways:<br>
 	 * <ul>
 	 * <li>The element has an attribute with the specified name or element text in
 	 * the form <code>bundle.id/class.name[:optional attributes]</code></li>
@@ -466,7 +465,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 	}
 
 	/**
-	 * Answer the element factory for an id, or <code>null</code. if not found.
+	 * Answer the element factory for an id, or <code>null</code>. if not found.
 	 *
 	 * @param targetID
 	 * @return IElementFactory
@@ -609,17 +608,6 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 		return e4Context.get(IViewRegistry.class);
 	}
 
-	/**
-	 * Answer the workbench.
-	 *
-	 * @deprecated Use <code>PlatformUI.getWorkbench()</code> instead.
-	 */
-	@Deprecated
-	@Override
-	public IWorkbench getWorkbench() {
-		return PlatformUI.getWorkbench();
-	}
-
 	/**
 	 * Set default preference values. This method must be called whenever the
 	 * preference store is initially loaded because the default values are not
@@ -687,7 +675,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 			errorCode = ce.getStatus().getCode();
 		}
 
-		return new Status(IStatus.ERROR, pluginId, errorCode, message, StatusUtil.getCause(t));
+		return new Status(IStatus.ERROR, pluginId, errorCode, message, t);
 	}
 
 	/**
@@ -894,7 +882,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 		try {
 			// use qualified class name to avoid import statement
 			// and premature attempt to resolve class reference
-			boolean isBidi = com.ibm.icu.text.Bidi.requiresBidi(message.toCharArray(), 0, message.length());
+			boolean isBidi = Bidi.requiresBidi(message.toCharArray(), 0, message.length());
 			return Boolean.valueOf(isBidi);
 		} catch (NoClassDefFoundError e) {
 			// the ICU Base bundle used in place of ICU?
@@ -1142,7 +1130,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 	 */
 	private BundleListener getBundleListener() {
 		if (bundleListener == null) {
-			bundleListener = event -> WorkbenchPlugin.this.bundleChanged(event);
+			bundleListener = WorkbenchPlugin.this::bundleChanged;
 		}
 		return bundleListener;
 	}
@@ -1210,23 +1198,7 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 			return null;
 		}
 
-		// look for the 32 bit internal_new shell method
-		try {
-			Method method = Shell.class.getMethod("internal_new", Display.class, int.class); //$NON-NLS-1$
-			// we're on a 32 bit platform so invoke it with splash
-			// handle as an int
-			splashShell = (Shell) method.invoke(null, display, Integer.valueOf(splashHandle));
-		} catch (NoSuchMethodException e) {
-			// look for the 64 bit internal_new shell method
-			try {
-				Method method = Shell.class.getMethod("internal_new", Display.class, long.class); //$NON-NLS-1$
-
-				// we're on a 64 bit platform so invoke it with a long
-				splashShell = (Shell) method.invoke(null, display, Long.valueOf(splashHandle));
-			} catch (NoSuchMethodException e2) {
-				// cant find either method - don't do anything.
-			}
-		}
+		splashShell = Shell.internal_new(display, Long.parseLong(splashHandle));
 
 		display.setData(DATA_SPLASH_SHELL, splashShell);
 		return splashShell;
@@ -1337,7 +1309,8 @@ public class WorkbenchPlugin extends AbstractUIPlugin {
 					preferenceManager = new WorkbenchPreferenceManager(PREFERENCE_PAGE_CATEGORY_SEPARATOR);
 
 					// Get the pages from the registry
-					PreferencePageRegistryReader registryReader = new PreferencePageRegistryReader(getWorkbench());
+					PreferencePageRegistryReader registryReader = new PreferencePageRegistryReader(
+							PlatformUI.getWorkbench());
 					registryReader.loadFromRegistry(Platform.getExtensionRegistry());
 					preferenceManager.addPages(registryReader.getTopLevelNodes());
 
