@@ -14,7 +14,6 @@
 package org.eclipse.ui.internal.about;
 
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.FileReader;
 import java.io.FileWriter;
 import java.io.IOException;
@@ -48,17 +47,17 @@ public class AboutUtils {
 	/**
 	 * Scan the contents of the about text
 	 *
-	 * @param s
-	 * @return
+	 * @param aboutText
+	 * @return AboutItem
 	 */
-	public static AboutItem scan(String s) {
+	public static AboutItem scan(String aboutText) {
 		ArrayList<int[]> linkRanges = new ArrayList<>();
 		ArrayList<String> links = new ArrayList<>();
 
 		// slightly modified version of jface url detection
 		// see org.eclipse.jface.text.hyperlink.URLHyperlinkDetector
 
-		int urlSeparatorOffset = s.indexOf("://"); //$NON-NLS-1$
+		int urlSeparatorOffset = aboutText.indexOf("://"); //$NON-NLS-1$
 		while (urlSeparatorOffset >= 0) {
 
 			boolean startDoubleQuote = false;
@@ -70,13 +69,13 @@ public class AboutUtils {
 				urlOffset--;
 				ch = ' ';
 				if (urlOffset > -1)
-					ch = s.charAt(urlOffset);
+					ch = aboutText.charAt(urlOffset);
 				startDoubleQuote = ch == '"';
 			} while (Character.isUnicodeIdentifierStart(ch));
 			urlOffset++;
 
 			// Right to "://"
-			StringTokenizer tokenizer = new StringTokenizer(s.substring(urlSeparatorOffset + 3), " \t\n\r\f<>", false); //$NON-NLS-1$
+			StringTokenizer tokenizer = new StringTokenizer(aboutText.substring(urlSeparatorOffset + 3), " \t\n\r\f<>", false); //$NON-NLS-1$
 			if (!tokenizer.hasMoreTokens())
 				return null;
 
@@ -84,8 +83,8 @@ public class AboutUtils {
 
 			if (startDoubleQuote) {
 				int endOffset = -1;
-				int nextDoubleQuote = s.indexOf('"', urlOffset);
-				int nextWhitespace = s.indexOf(' ', urlOffset);
+				int nextDoubleQuote = aboutText.indexOf('"', urlOffset);
+				int nextWhitespace = aboutText.indexOf(' ', urlOffset);
 				if (nextDoubleQuote != -1 && nextWhitespace != -1)
 					endOffset = Math.min(nextDoubleQuote, nextWhitespace);
 				else if (nextDoubleQuote != -1)
@@ -97,11 +96,11 @@ public class AboutUtils {
 			}
 
 			linkRanges.add(new int[] { urlOffset, urlLength });
-			links.add(s.substring(urlOffset, urlOffset + urlLength));
+			links.add(aboutText.substring(urlOffset, urlOffset + urlLength));
 
-			urlSeparatorOffset = s.indexOf("://", urlOffset + urlLength + 1); //$NON-NLS-1$
+			urlSeparatorOffset = aboutText.indexOf("://", urlOffset + urlLength + 1); //$NON-NLS-1$
 		}
-		return new AboutItem(s, linkRanges.toArray(new int[linkRanges.size()][2]),
+		return new AboutItem(aboutText, linkRanges.toArray(new int[linkRanges.size()][2]),
 				links.toArray(new String[links.size()]));
 	}
 
@@ -110,7 +109,8 @@ public class AboutUtils {
 	 * to a resource within a bundle, then a temp copy of the file will be extracted
 	 * and opened.
 	 *
-	 * @see <code>Platform.asLocalUrl</code>
+	 * @see Platform#asLocalURL(URL)
+	 *
 	 * @param url The target url to be displayed, null will be safely ignored
 	 * @return true if the url was successfully displayed and false otherwise
 	 */
@@ -146,9 +146,7 @@ public class AboutUtils {
 		try {
 			IWebBrowser browser = support.getExternalBrowser();
 			browser.openURL(new URL(urlEncodeForSpaces(href.toCharArray())));
-		} catch (MalformedURLException e) {
-			openWebBrowserError(shell, href, e);
-		} catch (PartInitException e) {
+		} catch (MalformedURLException | PartInitException e) {
 			openWebBrowserError(shell, href, e);
 		}
 	}
@@ -237,8 +235,6 @@ public class AboutUtils {
 			while ((count = in.read(buffer, 0, buffer.length)) > 0) {
 				out.write(buffer, 0, count);
 			}
-		} catch (FileNotFoundException e) {
-			return null;
 		} catch (IOException e) {
 			return null;
 		} finally {
