@@ -35,7 +35,7 @@ import org.eclipse.ui.internal.WorkbenchMessages;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 
 /**
- * This class is used to prompt the user for a file name & extension.
+ * This class is used to prompt the user for a file name &amp; extension.
  */
 public class ContentTypeFilenameAssociationDialog extends TitleAreaDialog {
 
@@ -144,7 +144,7 @@ public class ContentTypeFilenameAssociationDialog extends TitleAreaDialog {
 		// We need kernel api to validate the extension or a filename
 
 		// check for empty name and extension
-		if (filename.length() == 0) {
+		if (filename.isEmpty()) {
 			setErrorMessage(null);
 			return false;
 		}
