@@ -13,9 +13,8 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.dialogs;
 
-import com.ibm.icu.text.Collator;
+import java.text.Collator;
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.Comparator;
 import org.eclipse.jface.preference.IPreferencePage;
 import org.eclipse.jface.preference.PreferencePage;
@@ -146,7 +145,7 @@ public class DecoratorsPreferencePage extends PreferencePage implements IWorkben
 				Object[] elements = (Object[]) inputElement;
 				Object[] results = new Object[elements.length];
 				System.arraycopy(elements, 0, results, 0, elements.length);
-				Collections.sort(Arrays.asList(results), comparer);
+				Arrays.asList(results).sort(comparer);
 				return results;
 			}
 
@@ -212,7 +211,7 @@ public class DecoratorsPreferencePage extends PreferencePage implements IWorkben
 			return;
 		}
 		String text = definition.getDescription();
-		if (text == null || text.length() == 0) {
+		if (text == null || text.isEmpty()) {
 			descriptionText.setText(WorkbenchMessages.PreferencePage_noDescription);
 		} else {
 			descriptionText.setText(text);
