@@ -17,7 +17,6 @@ package org.eclipse.ui.internal.dialogs;
 
 import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import org.eclipse.core.runtime.Assert;
@@ -90,9 +89,9 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 
 	protected IWorkbench workbench;
 
-	protected List imagesToDispose;
+	protected List<Image> imagesToDispose;
 
-	protected Map editorsToImages;
+	protected Map<IEditorDescriptor, Image> editorsToImages;
 
 	/**
 	 * Add a new resource type to the collection shown in the top of the page. This
@@ -115,7 +114,7 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 		}
 
 		// Find the index at which to insert the new entry.
-		String newFilename = (newName + (newExtension == null || newExtension.length() == 0 ? "" : "." + newExtension)) //$NON-NLS-1$ //$NON-NLS-2$
+		String newFilename = (newName + (newExtension == null || newExtension.isEmpty() ? "" : "." + newExtension)) //$NON-NLS-1$ //$NON-NLS-2$
 				.toUpperCase();
 		IFileEditorMapping resourceType;
 		TableItem[] items = resourceTypeTable.getItems();
@@ -153,8 +152,8 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 	 */
 	@Override
 	protected Control createContents(Composite parent) {
-		imagesToDispose = new ArrayList();
-		editorsToImages = new HashMap(50);
+		imagesToDispose = new ArrayList<>();
+		editorsToImages = new HashMap<>(50);
 
 		// define container & its gridding
 		Composite pageComponent = new Composite(parent, SWT.NULL);
@@ -286,14 +285,14 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 	public void dispose() {
 		super.dispose();
 		if (imagesToDispose != null) {
-			for (Iterator e = imagesToDispose.iterator(); e.hasNext();) {
-				((Image) e.next()).dispose();
+			for (Image image : imagesToDispose) {
+				image.dispose();
 			}
 			imagesToDispose = null;
 		}
 		if (editorsToImages != null) {
-			for (Iterator e = editorsToImages.values().iterator(); e.hasNext();) {
-				((Image) e.next()).dispose();
+			for (Image image : editorsToImages.values()) {
+				image.dispose();
 			}
 			editorsToImages = null;
 		}
@@ -388,7 +387,7 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 	 * Returns the image associated with the given editor.
 	 */
 	protected Image getImage(IEditorDescriptor editor) {
-		Image image = (Image) editorsToImages.get(editor);
+		Image image = editorsToImages.get(editor);
 		if (image == null) {
 			image = editor.getImageDescriptor().createImage();
 			editorsToImages.put(editor, image);
@@ -409,12 +408,12 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 			return null;
 		}
 		if (editorTable.getItemCount() > 0) {
-			ArrayList editorList = new ArrayList();
+			ArrayList<IEditorDescriptor> editorList = new ArrayList<>();
 			for (int i = 0; i < editorTable.getItemCount(); i++) {
-				editorList.add(editorTable.getItem(i).getData(DATA_EDITOR));
+				editorList.add((IEditorDescriptor) editorTable.getItem(i).getData(DATA_EDITOR));
 			}
 
-			return (IEditorDescriptor[]) editorList.toArray(new IEditorDescriptor[editorList.size()]);
+			return editorList.toArray(new IEditorDescriptor[editorList.size()]);
 		}
 		return null;
 	}
@@ -635,8 +634,8 @@ public class FileEditorsPreferencePage extends PreferencePage implements IWorkbe
 			return false;
 		}
 
-		for (int i = 0; i < items.length; i++) {
-			if (!isEditorRemovable(items[i])) {
+		for (TableItem item : items) {
+			if (!isEditorRemovable(item)) {
 				return false;
 			}
 		}
