@@ -19,9 +19,8 @@ package org.eclipse.ui.internal.dialogs;
 
 import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
-import com.ibm.icu.text.Collator;
+import java.text.Collator;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.Comparator;
 import java.util.Objects;
 import org.eclipse.e4.ui.model.application.MApplication;
@@ -105,13 +104,11 @@ public class PerspectivesPreferencePage extends PreferencePage implements IWorkb
 	/**
 	 * <code>Comparator</code> to compare two perspective descriptors
 	 */
-	private Comparator<IPerspectiveDescriptor> comparator = new Comparator<IPerspectiveDescriptor>() {
+	private Comparator<IPerspectiveDescriptor> comparator = new Comparator<>() {
 		private Collator collator = Collator.getInstance();
 
 		@Override
-		public int compare(IPerspectiveDescriptor ob1, IPerspectiveDescriptor ob2) {
-			IPerspectiveDescriptor d1 = ob1;
-			IPerspectiveDescriptor d2 = ob2;
+		public int compare(IPerspectiveDescriptor d1, IPerspectiveDescriptor d2) {
 			return collator.compare(d1.getLabel(), d2.getLabel());
 		}
 	};
@@ -234,7 +231,7 @@ public class PerspectivesPreferencePage extends PreferencePage implements IWorkb
 		for (int i = 0; i < persps.length; i++) {
 			perspectives.add(i, persps[i]);
 		}
-		Collections.sort(perspectives, comparator);
+		perspectives.sort(comparator);
 		defaultPerspectiveId = perspectiveRegistry.getDefaultPerspective();
 		updatePerspectivesTable();
 
@@ -375,7 +372,7 @@ public class PerspectivesPreferencePage extends PreferencePage implements IWorkb
 
 	/**
 	 * Look up the index of the perpective with the given if.
-	 * 
+	 *
 	 * @param perspectiveId or <code>null</code>
 	 * @return int -1 if it cannot be found
 	 */
