@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,6 +18,8 @@
 
 package org.eclipse.ui.internal.dialogs;
 
+import static org.eclipse.jface.viewers.LabelProvider.createTextProvider;
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 import static org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants.ATT_COLOR_AND_FONT_ID;
 import static org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants.ATT_OS_VERSION;
 import static org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants.ATT_THEME_ASSOCIATION;
@@ -41,11 +43,12 @@ import org.eclipse.e4.ui.css.swt.theme.IThemeEngine;
 import org.eclipse.e4.ui.internal.workbench.swt.E4Application;
 import org.eclipse.e4.ui.internal.workbench.swt.PartRenderingEngine;
 import org.eclipse.e4.ui.model.application.MApplication;
+import org.eclipse.e4.ui.workbench.renderers.swt.CTabRendering;
 import org.eclipse.e4.ui.workbench.renderers.swt.StackRenderer;
 import org.eclipse.jface.dialogs.Dialog;
-import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.fieldassist.ControlDecoration;
 import org.eclipse.jface.fieldassist.FieldDecorationRegistry;
+import org.eclipse.jface.notifications.AbstractNotificationPopup;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.preference.PreferencePage;
 import org.eclipse.jface.util.Util;
@@ -56,16 +59,16 @@ import org.eclipse.jface.viewers.LabelProvider;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.SWTException;
-import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.layout.RowLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Label;
-import org.eclipse.swt.widgets.Text;
+import org.eclipse.swt.widgets.Link;
 import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkbenchPreferenceConstants;
 import org.eclipse.ui.IWorkbenchPreferencePage;
@@ -73,8 +76,6 @@ import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.WorkbenchMessages;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.themes.IThemeDescriptor;
-import org.eclipse.ui.internal.tweaklets.PreferencePageEnhancer;
-import org.eclipse.ui.internal.tweaklets.Tweaklets;
 import org.eclipse.ui.internal.util.PrefUtil;
 import org.eclipse.ui.themes.IThemeManager;
 import org.osgi.service.prefs.BackingStoreException;
@@ -93,11 +94,10 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 	private ControlDecoration themeComboDecorator;
 	private ITheme currentTheme;
 	private String defaultTheme;
-	private Button enableAnimations;
+	private Button useRoundTabs;
 	private Button enableMru;
 	private Button useColoredLabels;
 
-	private Text colorsAndFontsThemeDescriptionText;
 	private ComboViewer colorsAndFontsThemeCombo;
 	private ControlDecoration colorFontsDecorator;
 	private ColorsAndFontsTheme currentColorsAndFontsTheme;
@@ -106,6 +106,8 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 
 	private Button themingEnabled;
 
+	private NotificationPopUp notificationPopUp;
+
 	@Override
 	protected Control createContents(Composite parent) {
 		initializeDialogUnits(parent);
@@ -132,13 +134,8 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		highContrastMode = parent.getDisplay().getHighContrast();
 
 		themeIdCombo = new ComboViewer(comp, SWT.READ_ONLY);
-		themeIdCombo.setLabelProvider(new LabelProvider() {
-			@Override
-			public String getText(Object element) {
-				return ((ITheme) element).getLabel();
-			}
-		});
-		themeIdCombo.setContentProvider(new ArrayContentProvider());
+		themeIdCombo.setLabelProvider(createTextProvider(element -> ((ITheme) element).getLabel()));
+		themeIdCombo.setContentProvider(ArrayContentProvider.getInstance());
 		themeIdCombo.setInput(getCSSThemes(highContrastMode));
 		themeIdCombo.getCombo().setEnabled(!highContrastMode);
 		themeIdCombo.getControl().setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
@@ -158,23 +155,14 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 			} else {
 				themeComboDecorator.hide();
 			}
-			try {
-				((PreferencePageEnhancer) Tweaklets.get(PreferencePageEnhancer.KEY)).setSelection(selection);
-			} catch (SWTException e) {
-				WorkbenchPlugin.log("Failed to set CSS preferences", e); //$NON-NLS-1$
-			}
 			selectColorsAndFontsTheme(getColorAndFontThemeIdByThemeId(selection.getId()));
 		});
 
 		currentColorsAndFontsTheme = getCurrentColorsAndFontsTheme();
 		createColorsAndFontsThemeCombo(comp);
-		createColorsAndFontsThemeDescriptionText(comp);
 
 		createThemeIndependentComposits(comp);
 
-		((PreferencePageEnhancer) Tweaklets.get(PreferencePageEnhancer.KEY)).setSelection(currentTheme);
-		((PreferencePageEnhancer) Tweaklets.get(PreferencePageEnhancer.KEY)).createContents(comp);
-
 		if (currentTheme != null) {
 			String colorsAndFontsThemeId = getColorAndFontThemeIdByThemeId(currentTheme.getId());
 			if (colorsAndFontsThemeId != null && !currentColorsAndFontsTheme.getId().equals(colorsAndFontsThemeId)) {
@@ -188,7 +176,7 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 	}
 
 	private void createThemeIndependentComposits(Composite comp) {
-		createEnableAnimationsPref(comp);
+		createUseRoundTabs(comp);
 		createColoredLabelsPref(comp);
 		createEnableMruPref(comp);
 	}
@@ -239,27 +227,21 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		return label;
 	}
 
+	protected void createUseRoundTabs(Composite composite) {
+		IEclipsePreferences prefs = getSwtRendererPreferences();
+		boolean enabled = prefs.getBoolean(CTabRendering.USE_ROUND_TABS, CTabRendering.USE_ROUND_TABS_DEFAULT);
+		useRoundTabs = createCheckButton(composite, WorkbenchMessages.ViewsPreference_useRoundTabs, enabled);
+	}
+
 	protected void createEnableMruPref(Composite composite) {
 		createLabel(composite, ""); //$NON-NLS-1$
 		createLabel(composite, WorkbenchMessages.ViewsPreference_visibleTabs_description);
 		IEclipsePreferences prefs = getSwtRendererPreferences();
-		if (engine != null) {
-			boolean mruControlledByCSS = prefs.getBoolean(StackRenderer.MRU_CONTROLLED_BY_CSS_KEY, false);
-			if (mruControlledByCSS) {
-				return;
-			}
-		}
 		boolean defaultValue = getDefaultMRUValue();
 		boolean actualValue = prefs.getBoolean(StackRenderer.MRU_KEY, defaultValue);
 		enableMru = createCheckButton(composite, WorkbenchMessages.ViewsPreference_enableMRU, actualValue);
 	}
 
-	protected void createEnableAnimationsPref(Composite composite) {
-		IPreferenceStore apiStore = PrefUtil.getAPIPreferenceStore();
-
-		enableAnimations = createCheckButton(composite, WorkbenchMessages.ViewsPreference_enableAnimations,
-				apiStore.getBoolean(IWorkbenchPreferenceConstants.ENABLE_ANIMATIONS));
-	}
 
 	/** @return the currently selected theme or null if there are no themes */
 	private ITheme getSelectedTheme() {
@@ -284,20 +266,53 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		}
 
 		IPreferenceStore apiStore = PrefUtil.getAPIPreferenceStore();
-		apiStore.setValue(IWorkbenchPreferenceConstants.ENABLE_ANIMATIONS, enableAnimations.getSelection());
 		apiStore.setValue(IWorkbenchPreferenceConstants.USE_COLORED_LABELS, useColoredLabels.getSelection());
-		((PreferencePageEnhancer) Tweaklets.get(PreferencePageEnhancer.KEY)).performOK();
 
 		IEclipsePreferences prefs = getSwtRendererPreferences();
-		if (enableMru != null) {
-			prefs.putBoolean(StackRenderer.MRU_KEY, enableMru.getSelection());
-		}
+		prefs.putBoolean(StackRenderer.MRU_KEY, enableMru.getSelection());
+		boolean themingEnabledChanged = prefs.getBoolean(PartRenderingEngine.ENABLED_THEME_KEY, true) != themingEnabled
+				.getSelection();
 		prefs.putBoolean(PartRenderingEngine.ENABLED_THEME_KEY, themingEnabled.getSelection());
+
+		prefs.putBoolean(CTabRendering.USE_ROUND_TABS, useRoundTabs.getSelection());
 		try {
 			prefs.flush();
 		} catch (BackingStoreException e) {
 			WorkbenchPlugin.log("Failed to set SWT renderer preferences", e); //$NON-NLS-1$
 		}
+
+		if (engine != null) {
+			ITheme theme = getSelectedTheme();
+			boolean themeChanged = theme != null && !theme.equals(currentTheme);
+			boolean colorsAndFontsThemeChanged = !PlatformUI.getWorkbench().getThemeManager().getCurrentTheme().getId()
+					.equals(currentColorsAndFontsTheme.getId());
+
+			if (theme != null) {
+				currentTheme = theme;
+			}
+
+			ColorsAndFontsTheme colorsAndFontsTheme = getSelectedColorsAndFontsTheme();
+			if (colorsAndFontsTheme != null) {
+				currentColorsAndFontsTheme = colorsAndFontsTheme;
+			}
+
+			themeComboDecorator.hide();
+			colorFontsDecorator.hide();
+
+			if (themeChanged || colorsAndFontsThemeChanged) {
+				if (notificationPopUp == null) {
+					notificationPopUp = new NotificationPopUp(getShell().getDisplay());
+					notificationPopUp.open();
+				}
+			}
+		}
+		if (themingEnabledChanged) {
+			if (notificationPopUp == null) {
+				notificationPopUp = new NotificationPopUp(getShell().getDisplay());
+				notificationPopUp.open();
+			}
+		}
+
 		return super.performOk();
 	}
 
@@ -321,18 +336,16 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		if (engine != null) {
 			setColorsAndFontsTheme(currentColorsAndFontsTheme);
 
-			((PreferencePageEnhancer) Tweaklets.get(PreferencePageEnhancer.KEY)).performDefaults();
 			engine.setTheme(defaultTheme, true);
 			if (engine.getActiveTheme() != null) {
 				themeIdCombo.setSelection(new StructuredSelection(engine.getActiveTheme()));
 			}
 		}
 		IPreferenceStore apiStore = PrefUtil.getAPIPreferenceStore();
-		enableAnimations.setSelection(apiStore.getDefaultBoolean(IWorkbenchPreferenceConstants.ENABLE_ANIMATIONS));
 		useColoredLabels.setSelection(apiStore.getDefaultBoolean(IWorkbenchPreferenceConstants.USE_COLORED_LABELS));
-		if (enableMru != null) {
-			enableMru.setSelection(getDefaultMRUValue());
-		}
+
+		useRoundTabs.setSelection(CTabRendering.USE_ROUND_TABS_DEFAULT);
+		enableMru.setSelection(getDefaultMRUValue());
 		super.performDefaults();
 	}
 
@@ -349,35 +362,6 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		return super.performCancel();
 	}
 
-	@Override
-	protected void performApply() {
-		super.performApply();
-		if (engine != null) {
-			ITheme theme = getSelectedTheme();
-			boolean themeChanged = theme != null && !theme.equals(currentTheme);
-			boolean colorsAndFontsThemeChanged = !PlatformUI.getWorkbench().getThemeManager().getCurrentTheme().getId()
-					.equals(currentColorsAndFontsTheme.getId());
-
-			if (theme != null) {
-				currentTheme = theme;
-			}
-
-			ColorsAndFontsTheme colorsAndFontsTheme = getSelectedColorsAndFontsTheme();
-			if (colorsAndFontsTheme != null) {
-				currentColorsAndFontsTheme = colorsAndFontsTheme;
-			}
-
-			themeComboDecorator.hide();
-			colorFontsDecorator.hide();
-
-			if (themeChanged || colorsAndFontsThemeChanged) {
-				MessageDialog.openWarning(getShell(), WorkbenchMessages.ThemeChangeWarningTitle,
-						WorkbenchMessages.ThemeChangeWarningText);
-			}
-		}
-
-	}
-
 	private void createColorsAndFontsThemeCombo(Composite composite) {
 		new Label(composite, SWT.NONE).setText(WorkbenchMessages.ViewsPreference_currentTheme);
 		colorsAndFontsThemeCombo = new ComboViewer(composite, SWT.READ_ONLY);
@@ -389,7 +373,7 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 			}
 		});
 		colorFontsDecorator = new ControlDecoration(colorsAndFontsThemeCombo.getCombo(), SWT.TOP | SWT.LEFT);
-		colorsAndFontsThemeCombo.setContentProvider(new ArrayContentProvider());
+		colorsAndFontsThemeCombo.setContentProvider(ArrayContentProvider.getInstance());
 		colorsAndFontsThemeCombo.setInput(getColorsAndFontsThemes());
 		colorsAndFontsThemeCombo.getControl().setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		colorsAndFontsThemeCombo.addSelectionChangedListener(event -> {
@@ -402,43 +386,19 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 				colorFontsDecorator.show();
 			} else
 				colorFontsDecorator.hide();
-			refreshColorsAndFontsThemeDescriptionText(colorsAndFontsTheme);
 			setColorsAndFontsTheme(colorsAndFontsTheme);
 		});
 	}
 
-	/**
-	 * Create the text box that will contain the current theme description text (if
-	 * any).
-	 *
-	 * @param parent the parent <code>Composite</code>.
-	 */
-	private void createColorsAndFontsThemeDescriptionText(Composite parent) {
-		new Label(parent, SWT.NONE).setText(WorkbenchMessages.ViewsPreference_currentThemeDescription);
-
-		colorsAndFontsThemeDescriptionText = new Text(parent,
-				SWT.H_SCROLL | SWT.V_SCROLL | SWT.READ_ONLY | SWT.BORDER | SWT.WRAP);
-		GridData layoutData = new GridData(SWT.FILL, SWT.FILL, true, true);
-		// give a height hint that'll show at least two lines (and let the
-		// scroll bars draw nicely if necessary)
-		GC gc = new GC(parent);
-		layoutData.heightHint = Dialog.convertHeightInCharsToPixels(gc.getFontMetrics(), 2);
-		gc.dispose();
-		colorsAndFontsThemeDescriptionText.setLayoutData(layoutData);
-	}
-
 	@SuppressWarnings("unchecked")
 	private void selectColorsAndFontsTheme(String colorAndFontThemeId) {
 		if (colorAndFontThemeId == null) {
 			colorAndFontThemeId = currentColorsAndFontsTheme.getId();
 		}
 
-		List<ColorsAndFontsTheme> colorsAndFontsThemes = (List<ColorsAndFontsTheme>) colorsAndFontsThemeCombo
-				.getInput();
-
-		for (int i = 0; i < colorsAndFontsThemes.size(); i++) {
-			if (colorsAndFontsThemes.get(i).getId().equals(colorAndFontThemeId)) {
-				ISelection selection = new StructuredSelection(colorsAndFontsThemes.get(i));
+		for (ColorsAndFontsTheme theme : (List<ColorsAndFontsTheme>) colorsAndFontsThemeCombo.getInput()) {
+			if (theme.getId().equals(colorAndFontThemeId)) {
+				ISelection selection = new StructuredSelection(theme);
 				colorsAndFontsThemeCombo.setSelection(selection);
 				break;
 			}
@@ -507,20 +467,6 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		return result;
 	}
 
-	private void refreshColorsAndFontsThemeDescriptionText(ColorsAndFontsTheme theme) {
-		String description = ""; //$NON-NLS-1$
-		if (theme != null) {
-			IThemeDescriptor[] descs = WorkbenchPlugin.getDefault().getThemeRegistry().getThemes();
-			for (int i = 0; i < descs.length; i++) {
-				if (descs[i].getId().equals(theme.getId()) && descs[i].getDescription() != null) {
-					description = descs[i].getDescription();
-					break;
-				}
-			}
-		}
-		colorsAndFontsThemeDescriptionText.setText(description);
-	}
-
 	private ColorsAndFontsTheme getSelectedColorsAndFontsTheme() {
 		return (ColorsAndFontsTheme) colorsAndFontsThemeCombo.getStructuredSelection().getFirstElement();
 	}
@@ -566,4 +512,29 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 		}
 
 	}
+
+	private class NotificationPopUp extends AbstractNotificationPopup {
+
+		public NotificationPopUp(Display display) {
+			super(display);
+			setDelayClose(0);
+			setParentShell(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell());
+		}
+
+		@Override
+		protected String getPopupShellTitle() {
+			return WorkbenchMessages.ThemeChangeWarningTitle;
+		}
+
+
+		@Override
+		protected void createContentArea(Composite parent) {
+			parent.setLayout(new RowLayout());
+
+			Link link = new Link(parent, SWT.WRAP);
+			link.setText(WorkbenchMessages.ThemeChangeWarningText);
+			link.addSelectionListener(widgetSelectedAdapter(e -> PlatformUI.getWorkbench().restart(true)));
+		}
+	}
+
 }
