@@ -55,7 +55,7 @@ public class WizardCollectionElement extends AdaptableList implements IPluginCon
 
 	/**
 	 * Creates a new <code>WizardCollectionElement</code>. Parent can be null.
-	 * 
+	 *
 	 * @param id       the id
 	 * @param pluginId the plugin
 	 * @param name     the name
@@ -86,9 +86,7 @@ public class WizardCollectionElement extends AdaptableList implements IPluginCon
 		this.configElement = input.configElement;
 		this.wizards = wizards;
 
-		for (Object child : input.children) {
-			children.add(child);
-		}
+		children.addAll(input.children);
 	}
 
 	/**
@@ -181,8 +179,8 @@ public class WizardCollectionElement extends AdaptableList implements IPluginCon
 		if (!recursive) {
 			return null;
 		}
-		for (Iterator iterator = children.iterator(); iterator.hasNext();) {
-			WizardCollectionElement child = (WizardCollectionElement) iterator.next();
+		for (Iterator<WizardCollectionElement> iterator = children.iterator(); iterator.hasNext();) {
+			WizardCollectionElement child = iterator.next();
 			WorkbenchWizardElement result = child.findWizard(searchId, true);
 			if (result != null) {
 				return result;
@@ -250,12 +248,12 @@ public class WizardCollectionElement extends AdaptableList implements IPluginCon
 	 */
 	private IWizardDescriptor[] getWizardsExpression(IWizardDescriptor[] wizardDescriptors) {
 		int size = wizardDescriptors.length;
-		List result = new ArrayList(size);
+		List<IWizardDescriptor> result = new ArrayList<>(size);
 		for (int i = 0; i < size; i++) {
 			if (!WorkbenchActivityHelper.restrictUseOf(wizardDescriptors[i]))
 				result.add(wizardDescriptors[i]);
 		}
-		return (IWizardDescriptor[]) result.toArray(new IWizardDescriptor[result.size()]);
+		return result.toArray(new IWizardDescriptor[result.size()]);
 	}
 
 	/**
@@ -279,13 +277,13 @@ public class WizardCollectionElement extends AdaptableList implements IPluginCon
 	private WorkbenchWizardElement[] getWorkbenchWizardElementsExpression(
 			WorkbenchWizardElement[] workbenchWizardElements) {
 		int size = workbenchWizardElements.length;
-		List result = new ArrayList(size);
+		List<WorkbenchWizardElement> result = new ArrayList<>(size);
 		for (int i = 0; i < size; i++) {
 			WorkbenchWizardElement element = workbenchWizardElements[i];
 			if (!WorkbenchActivityHelper.restrictUseOf(element))
 				result.add(element);
 		}
-		return (WorkbenchWizardElement[]) result.toArray(new WorkbenchWizardElement[result.size()]);
+		return result.toArray(new WorkbenchWizardElement[result.size()]);
 	}
 
 	/**
