@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,10 +13,10 @@
  *     Tom Hochstein (Freescale) - Bug 407522 - Perspective reset not working correctly
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 422040, 431992, 472654
  *     Andrey Loskutov <loskutov@gmx.de> - Bug 456729, 404348, 421178, 420956, 424638, 460503
+ *     Rolf Theunissen <rolf.theunissen@gmail.com> - Bug 558765
  *******************************************************************************/
 package org.eclipse.ui.internal.dialogs.cpd;
 
-import java.net.URL;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -29,11 +29,15 @@ import org.eclipse.e4.core.commands.ECommandService;
 import org.eclipse.e4.core.contexts.IEclipseContext;
 import org.eclipse.e4.ui.bindings.EBindingService;
 import org.eclipse.e4.ui.internal.workbench.OpaqueElementUtil;
+import org.eclipse.e4.ui.internal.workbench.RenderedElementUtil;
 import org.eclipse.e4.ui.model.application.MApplication;
 import org.eclipse.e4.ui.model.application.commands.MParameter;
 import org.eclipse.e4.ui.model.application.ui.MUIElement;
+import org.eclipse.e4.ui.model.application.ui.MUILabel;
 import org.eclipse.e4.ui.model.application.ui.basic.MTrimBar;
 import org.eclipse.e4.ui.model.application.ui.basic.MTrimElement;
+import org.eclipse.e4.ui.model.application.ui.menu.MDirectMenuItem;
+import org.eclipse.e4.ui.model.application.ui.menu.MDynamicMenuContribution;
 import org.eclipse.e4.ui.model.application.ui.menu.MHandledItem;
 import org.eclipse.e4.ui.model.application.ui.menu.MHandledMenuItem;
 import org.eclipse.e4.ui.model.application.ui.menu.MItem;
@@ -53,8 +57,11 @@ import org.eclipse.jface.action.ContributionItem;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.action.IContributionItem;
 import org.eclipse.jface.action.IContributionManager;
+import org.eclipse.jface.action.IMenuManager;
+import org.eclipse.jface.action.LegacyActionTools;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.SubContributionItem;
+import org.eclipse.jface.action.SubMenuManager;
 import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.bindings.TriggerSequence;
 import org.eclipse.jface.dialogs.IDialogConstants;
@@ -120,7 +127,6 @@ import org.eclipse.ui.internal.WorkbenchPage;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.WorkbenchWindow;
 import org.eclipse.ui.internal.actions.NewWizardShortcutAction;
-import org.eclipse.ui.internal.dialogs.DialogUtil;
 import org.eclipse.ui.internal.dialogs.WorkbenchWizardElement;
 import org.eclipse.ui.internal.dialogs.cpd.TreeManager.TreeItem;
 import org.eclipse.ui.internal.e4.compatibility.ModeledPageLayout;
@@ -128,8 +134,10 @@ import org.eclipse.ui.internal.intro.IIntroConstants;
 import org.eclipse.ui.internal.registry.ActionSetDescriptor;
 import org.eclipse.ui.internal.registry.ActionSetRegistry;
 import org.eclipse.ui.internal.registry.IActionSetDescriptor;
+import org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants;
 import org.eclipse.ui.internal.util.BundleUtility;
 import org.eclipse.ui.menus.CommandContributionItem;
+import org.eclipse.ui.menus.CommandContributionItemParameter;
 import org.eclipse.ui.model.WorkbenchViewerComparator;
 import org.eclipse.ui.part.PageBook;
 import org.eclipse.ui.views.IViewCategory;
@@ -146,6 +154,10 @@ import org.eclipse.ui.wizards.IWizardDescriptor;
  */
 public class CustomizePerspectiveDialog extends TrayDialog {
 
+	/**
+	 * Flag showing that we have initialized all legacy action sets for given window
+	 */
+	private static final String ALL_SETS_INITIALIZED = "ALL_SETS_INITIALIZED"; //$NON-NLS-1$
 	private static final String TOOLBAR_ICON = "$nl$/icons/full/obj16/toolbar.png"; //$NON-NLS-1$
 	private static final String SUBMENU_ICON = "$nl$/icons/full/obj16/submenu.png"; //$NON-NLS-1$
 	private static final String MENU_ICON = "$nl$/icons/full/obj16/menu.png"; //$NON-NLS-1$
@@ -156,7 +168,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 
 	static final String KEYS_PREFERENCE_PAGE_ID = "org.eclipse.ui.preferencePages.Keys"; //$NON-NLS-1$
 
-	static final String NEW_LINE = System.getProperty("line.separator"); //$NON-NLS-1$
+	static final String NEW_LINE = System.lineSeparator();
 
 	static final int MIN_TOOLTIP_WIDTH = 160;
 
@@ -230,7 +242,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	private IEclipseContext context;
 
 	/**
-	 * Represents a menu item or a tool bar item.
+	 * Represents a menu item or a toolbar item.
 	 *
 	 * @since 3.5
 	 */
@@ -242,7 +254,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		ActionSet actionSet;
 
 		public DisplayItem(String label, IContributionItem item) {
-			treeManager.super(label == null ? null : DialogUtil.removeAccel(removeShortcut(label)));
+			treeManager.super(label == null ? null : LegacyActionTools.removeMnemonics(removeShortcut(label)));
 			this.item = item;
 		}
 
@@ -276,6 +288,11 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	class DynamicContributionItem extends DisplayItem {
 		private List<MenuItem> preview;
 
+		public DynamicContributionItem(String label, IContributionItem item) {
+			super(WorkbenchMessages.HideItems_dynamicItemName + " - " + label, item); //$NON-NLS-1$
+			preview = new ArrayList<>();
+		}
+
 		public DynamicContributionItem(IContributionItem item) {
 			super(WorkbenchMessages.HideItems_dynamicItemName, item);
 			preview = new ArrayList<>();
@@ -384,7 +401,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		private List<ShortcutItem> contributionItems;
 
 		public Category(String label) {
-			treeManager.super(label == null ? null : DialogUtil.removeAccel(removeShortcut(label)));
+			treeManager.super(label == null ? null : LegacyActionTools.removeMnemonics(removeShortcut(label)));
 			this.contributionItems = new ArrayList<>();
 		}
 
@@ -442,7 +459,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	/**
 	 * Represents an action set, under which ContributionItems exist. There is no
 	 * inherent hierarchy in action sets - they exist independent of one another,
-	 * simply contribution menu items and tool bar items.
+	 * simply contribution menu items and toolbar items.
 	 *
 	 * @since 3.5
 	 */
@@ -554,7 +571,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		gd.heightHint = convertVerticalDLUsToPixels(TAB_HEIGHT_IN_DLUS);
 		tabFolder.setLayoutData(gd);
 
-		// Tool Bar Item Hiding Page
+		// Toolbar Item Hiding Page
 		TabItem tab = new TabItem(tabFolder, SWT.NONE);
 		tab.setText(WorkbenchMessages.HideToolBarItems_toolBarItemsTab);
 		tab.setControl(createToolBarVisibilityPage(tabFolder));
@@ -756,7 +773,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 				SWT.BORDER | SWT.H_SCROLL | SWT.V_SCROLL);
 		actionSetAvailabilityTable = actionSetsViewer;
 		actionSetsViewer.getTable().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
-		actionSetsViewer.setContentProvider(new ArrayContentProvider());
+		actionSetsViewer.setContentProvider(ArrayContentProvider.getInstance());
 		actionSetsViewer.setComparator(new WorkbenchViewerComparator());
 		actionSetsViewer.setCheckStateProvider(new ICheckStateProvider() {
 			@Override
@@ -848,6 +865,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		actionSetToolbarViewer = new TreeViewer(toolbarGroup);
 		actionSetToolbarViewer.setAutoExpandLevel(AbstractTreeViewer.ALL_LEVELS);
 		actionSetToolbarViewer.getControl().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
+		actionSetToolbarViewer.setUseHashlookup(true);
 		actionSetToolbarViewer.setContentProvider(TreeManager.getTreeContentProvider());
 		actionSetToolbarViewer.setLabelProvider(new GrayOutUnavailableLabelProvider(null));
 		actionSetToolbarViewer.addFilter(setFilter);
@@ -1147,7 +1165,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		actionSetViewer.getTable().setLayoutData(new GridData(GridData.FILL_BOTH));
 		actionSetViewer.setLabelProvider(new GrayOutUnavailableLabelProvider(null));
 		actionSetViewer.setComparator(new WorkbenchViewerComparator());
-		actionSetViewer.setContentProvider(new ArrayContentProvider());
+		actionSetViewer.setContentProvider(ArrayContentProvider.getInstance());
 
 		// Tooltip on tree items
 		Table table = actionSetViewer.getTable();
@@ -1281,7 +1299,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 
 	/**
 	 * @param item
-	 * @return true iff the item will show up in a menu or tool bar structure - i.e.
+	 * @return true iff the item will show up in a menu or toolbar structure - i.e.
 	 *         it is available, or has a child which is available thus must be
 	 *         displayed in order to display the child
 	 */
@@ -1329,10 +1347,22 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	}
 
 	private void initializeActionSetInput() {
-		// Just get the action sets at this point. Do not load the action set
-		// until it is actually selected in the dialog.
+		// Just get the action sets at this point.
 		ActionSetRegistry reg = WorkbenchPlugin.getDefault().getActionSetRegistry();
 		IActionSetDescriptor[] sets = reg.getActionSets();
+
+		// Populate all legacy actionsets into the model, see bug 549898
+		// Note: all (also invisible) actions sets will be loaded here and
+		// respective actions will be created. This is not good ("invisible"
+		// actions will live from this moment on till shutdown) and we need
+		// a better solution.
+		Object initDone = context.get(ALL_SETS_INITIALIZED);
+		if (initDone == null) {
+			context.set(ALL_SETS_INITIALIZED, Boolean.TRUE);
+			window.getActionPresentation().setActionSets(sets);
+			window.updateActionSets();
+		}
+
 		IActionSetDescriptor[] actionSetDescriptors = ((WorkbenchPage) window.getActivePage()).getActionSets();
 		List<IActionSetDescriptor> initiallyAvailableActionSets = Arrays.asList(actionSetDescriptors);
 
@@ -1365,21 +1395,14 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	}
 
 	private void initializeIcons() {
-		String iconPath = MENU_ICON;
-		URL url = BundleUtility.find(PlatformUI.PLUGIN_ID, iconPath);
-		menuImageDescriptor = ImageDescriptor.createFromURL(url);
-
-		iconPath = SUBMENU_ICON;
-		url = BundleUtility.find(PlatformUI.PLUGIN_ID, iconPath);
-		submenuImageDescriptor = ImageDescriptor.createFromURL(url);
-
-		iconPath = TOOLBAR_ICON;
-		url = BundleUtility.find(PlatformUI.PLUGIN_ID, iconPath);
-		toolbarImageDescriptor = ImageDescriptor.createFromURL(url);
-
-		iconPath = WARNING_ICON;
-		url = BundleUtility.find(PlatformUI.PLUGIN_ID, iconPath);
-		warningImageDescriptor = ImageDescriptor.createFromURL(url);
+		menuImageDescriptor = ImageDescriptor
+				.createFromURLSupplier(true, () -> BundleUtility.find(PlatformUI.PLUGIN_ID, MENU_ICON));
+		submenuImageDescriptor = ImageDescriptor
+				.createFromURLSupplier(true, () -> BundleUtility.find(PlatformUI.PLUGIN_ID, SUBMENU_ICON));
+		toolbarImageDescriptor = ImageDescriptor
+				.createFromURLSupplier(true, () -> BundleUtility.find(PlatformUI.PLUGIN_ID, TOOLBAR_ICON));
+		warningImageDescriptor = ImageDescriptor
+				.createFromURLSupplier(true, () -> BundleUtility.find(PlatformUI.PLUGIN_ID, WARNING_ICON));
 	}
 
 	private void initializeNewWizardsMenu(DisplayItem menu, Category parentCategory, IWizardCategory element,
@@ -1498,8 +1521,6 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		window.fillActionBars(customizeActionBars,
 				ActionBarAdvisor.FILL_PROXY | ActionBarAdvisor.FILL_MENU_BAR | ActionBarAdvisor.FILL_COOL_BAR);
 
-		window.fill(customizeActionBars.menuRenderer, customizeActionBars.mainMenu, customizeActionBars.menuManager);
-
 		// Populate the action bars with the action sets' data
 		for (ActionSet actionSet : actionSets) {
 			ActionSetDescriptor descriptor = actionSet.descriptor;
@@ -1532,20 +1553,8 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		engine.createGui(customizeActionBars.mainMenu, customizeActionBars.windowModel.getWidget(),
 				customizeActionBars.windowModel.getContext());
 
-		MTrimBar topTrim = customizeActionBars.coolBarManager.getTopTrim();
-		topTrim.setToBeRendered(true);
-
-		// Get the menu from the action bars
-		engine.createGui(topTrim, customizeActionBars.windowModel.getWidget(),
-				customizeActionBars.windowModel.getContext());
-
-		// Ensure the menu is completely built by updating the menu manager.
-		// (This method call requires a menu already be created)
-		customizeActionBars.menuManager.updateAll(true);
-		customizeActionBars.coolBarManager.update(true);
-
 		shortcuts = new Category(""); //$NON-NLS-1$
-		toolBarItems = createTrimBarEntries(topTrim);
+		toolBarItems = createTrimBarEntries(window.getTopTrim());
 		menuItems = createMenuStructure(customizeActionBars.mainMenu);
 	}
 
@@ -1706,7 +1715,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	}
 
 	private static String getActionSetID(MUIElement item) {
-		String id = (String) item.getTransientData().get("ActionSet"); //$NON-NLS-1$
+		String id = (String) item.getTransientData().get(IWorkbenchRegistryConstants.TAG_ACTION_SET);
 		if (id != null) {
 			return id;
 		}
@@ -1756,156 +1765,195 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 	}
 
 	private void createMenuEntries(MMenu menu, DisplayItem parent) {
-		Map<IContributionItem, IContributionItem> findDynamics = new HashMap<>();
 		DynamicContributionItem dynamicEntry = null;
 
-		if (menu.getParent() != null) {
-			// Search for any dynamic menu entries which will be handled later
-			IContributionManager manager = menuMngrRenderer.getManager(menu);
-			if (manager != null) {
-				IContributionItem[] items = manager.getItems();
-				for (int i = 0; i < items.length; i++) {
-					IContributionItem ci = items[i];
-					if (ci.isDynamic()) {
-						findDynamics.put(i > 0 ? items[i - 1] : null, ci);
-					}
-				}
-				// If there is an item with no preceding item, set it up to be
-				// added first.
-				if (findDynamics.containsKey(null)) {
-					IContributionItem item = findDynamics.get(null);
-					dynamicEntry = new DynamicContributionItem(item);
-					dynamicEntry.setCheckState(getMenuItemIsVisible(dynamicEntry));
-					dynamicEntry.setActionSet(idToActionSet.get(getActionSetID(item)));
-					parent.addChild(dynamicEntry);
-				}
-			}
-		}
-
+		Map<IContributionItem, DisplayItem> processedOpaqueItems = new HashMap<>();
 		for (MMenuElement menuItem : menu.getChildren()) {
-			dynamicEntry = createMenuEntry(parent, findDynamics, dynamicEntry, menuItem);
+			dynamicEntry = createMenuEntry(parent, dynamicEntry, menuItem, processedOpaqueItems);
 		}
 	}
 
-	private DynamicContributionItem createMenuEntry(DisplayItem parent,
-			Map<IContributionItem, IContributionItem> findDynamics, DynamicContributionItem dynamicEntry,
-			MMenuElement menuItem) {
-		String text = menuItem.getLocalizedLabel();
-		if (text == null || text.length() == 0) {
-			text = menuItem.getLabel();
+	private DynamicContributionItem createMenuEntry(DisplayItem parent, DynamicContributionItem dynamicEntry,
+			MMenuElement menuItem, Map<IContributionItem, DisplayItem> processedOpaqueItems) {
+		if (!menuItem.isToBeRendered()) {
+			return null;
 		}
-		if ((text != null && text.length() != 0) || (menuItem instanceof MHandledMenuItem)
-				|| menuItem.getWidget() != null) {
-			IContributionItem contributionItem;
-			if (menuItem instanceof MMenu) {
-				contributionItem = menuMngrRenderer.getManager((MMenu) menuItem);
-			} else {
-				contributionItem = menuMngrRenderer.getContribution(menuItem);
-			}
-			if (contributionItem == null) {
-				return dynamicEntry;
-			}
-			if (dynamicEntry != null && contributionItem.equals(dynamicEntry.getIContributionItem())) {
-				// If the last item added is the item meant to go before the
-				// given dynamic entry, add the dynamic entry so it is in
-				// the correct order.
-				dynamicEntry.addCurrentItem((MenuItem) menuItem.getWidget());
-				// TODO: might not work
-			} else {
-				ImageDescriptor iconDescriptor = null;
-				String iconURI = menuItem.getIconURI();
-				if (iconURI != null && iconURI.length() > 0) {
-					iconDescriptor = resUtils.imageDescriptorFromURI(URI.createURI(iconURI));
-				}
 
-				if (menuItem.getWidget() instanceof MenuItem) {
-					MenuItem item = (MenuItem) menuItem.getWidget();
-					if (text == null) {
-						if ("".equals(item.getText())) { //$NON-NLS-1$
-							return dynamicEntry;
-						}
-						text = item.getText();
-					}
-					if (iconDescriptor == null) {
-						Image image = item.getImage();
-						if (image != null) {
-							iconDescriptor = ImageDescriptor.createFromImage(image);
-						}
-					}
-				} else if (menuItem instanceof MHandledMenuItem) {
-					MHandledMenuItem hmi = (MHandledMenuItem) menuItem;
-					final String i18nLabel = hmi.getLocalizedLabel();
-					if (i18nLabel != null) {
-						text = i18nLabel;
-					} else if (hmi.getWbCommand() != null) {
-						try {
-							text = hmi.getWbCommand().getName();
-						} catch (NotDefinedException e) {
-							// we'll just ignore a failure
-						}
-					}
-				}
-				DisplayItem menuEntry = new DisplayItem(text, contributionItem);
+		if (menuItem instanceof MMenu) {
+			MenuManager manager = menuMngrRenderer.getManager((MMenu) menuItem);
 
-				if (iconDescriptor != null) {
-					menuEntry.setImageDescriptor(iconDescriptor);
-				}
-				menuEntry.setActionSet(idToActionSet.get(getActionSetID(menuItem)));
-				parent.addChild(menuEntry);
-
-				if (ActionFactory.NEW.getId().equals(contributionItem.getId())) {
-					initializeNewWizardsMenu(menuEntry);
-					wizards = menuEntry;
-				} else if (SHORTCUT_CONTRIBUTION_ITEM_ID_OPEN_PERSPECTIVE.equals(contributionItem.getId())) {
-					initializePerspectivesMenu(menuEntry);
-					perspectives = menuEntry;
-				} else if (SHORTCUT_CONTRIBUTION_ITEM_ID_SHOW_VIEW.equals(contributionItem.getId())) {
-					initializeViewsMenu(menuEntry);
-					views = menuEntry;
+			ImageDescriptor iconDescriptor;
+			DisplayItem menuEntry;
+			if (OpaqueElementUtil.isOpaqueMenu(menuItem)) {
+				if (processedOpaqueItems.containsKey(manager)) {
+					// Manager already processed as wrapped item, which determines the position
+					// Still the child entries must be added
+					menuEntry = processedOpaqueItems.get(manager);
 				} else {
-					if (menuItem instanceof MMenu) {// TODO:menuItem any
-													// other instance
-						createMenuEntries((MMenu) menuItem, menuEntry);
-					}
+					menuEntry = new DisplayItem(manager.getMenuText(), manager);
+					parent.addChild(menuEntry);
 				}
-
-				if (menuEntry.getChildren().isEmpty()) {
-					menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
-				}
-
-				if (iconDescriptor == null) {
-					if (parent.getParent() == null) {
-						menuEntry.setImageDescriptor(menuImageDescriptor);
-					} else if (menuEntry.getChildrenCount() > 0) {
-						menuEntry.setImageDescriptor(submenuImageDescriptor);
-					}
-				}
-			}
-			if (findDynamics.containsKey(contributionItem)) {
-				IContributionItem item = findDynamics.get(contributionItem);
-				dynamicEntry = new DynamicContributionItem(item);
-				dynamicEntry.setCheckState(getMenuItemIsVisible(dynamicEntry));
-				dynamicEntry.setActionSet(idToActionSet.get(getActionSetID(contributionItem)));
-				parent.addChild(dynamicEntry);
+				iconDescriptor = manager.getImageDescriptor();
 			} else {
-				return dynamicEntry;
+				menuEntry = new DisplayItem(menuItem.getLocalizedLabel(), manager);
+				iconDescriptor = getIconDescriptor(menuItem);
+				parent.addChild(menuEntry);
 			}
+
+			if (iconDescriptor != null) {
+				menuEntry.setImageDescriptor(iconDescriptor);
+			} else if (parent.getParent() == null) {
+				menuEntry.setImageDescriptor(menuImageDescriptor);
+			} else {
+				menuEntry.setImageDescriptor(submenuImageDescriptor);
+			}
+
+			menuEntry.setActionSet(idToActionSet.get(getActionSetID(menuItem)));
+
+			// Compatibility sub-menus for some opaque menus
+			String managerId = manager != null ? manager.getId() : null;
+			if (ActionFactory.NEW.getId().equals(managerId)) {
+				initializeNewWizardsMenu(menuEntry);
+				wizards = menuEntry;
+			} else if (SHORTCUT_CONTRIBUTION_ITEM_ID_OPEN_PERSPECTIVE.equals(managerId)) {
+				initializePerspectivesMenu(menuEntry);
+				perspectives = menuEntry;
+			} else if (SHORTCUT_CONTRIBUTION_ITEM_ID_SHOW_VIEW.equals(managerId)) {
+				initializeViewsMenu(menuEntry);
+				views = menuEntry;
+			} else {
+				createMenuEntries((MMenu) menuItem, menuEntry);
+			}
+
+			if (menuEntry.getChildren().isEmpty()) {
+				menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
+			}
+		} else if (RenderedElementUtil.isRenderedMenuItem(menuItem)) {
+			IContributionItem contributionItem = menuMngrRenderer.getContribution(menuItem);
+
+			if (dynamicEntry == null || !contributionItem.equals(dynamicEntry.getIContributionItem())) {
+				// Only create one dynamic item for multiple (successive) dynamic contribution
+				// items
+				dynamicEntry = new DynamicContributionItem(contributionItem);
+				dynamicEntry.setActionSet(idToActionSet.get(getActionSetID(menuItem)));
+				dynamicEntry.setCheckState(getMenuItemIsVisible(dynamicEntry));
+				parent.addChild(dynamicEntry);
+			}
+
+			if (menuItem.getWidget() != null) {
+				// TODO See Bug 558766: add children; widgets are no longer available
+				dynamicEntry.addCurrentItem((MenuItem) menuItem.getWidget());
+			}
+
+			return dynamicEntry;
 		} else if (OpaqueElementUtil.isOpaqueMenuItem(menuItem)) {
 			IContributionItem contributionItem = menuMngrRenderer.getContribution(menuItem);
-			if (contributionItem instanceof ActionContributionItem) {
+
+			if (contributionItem instanceof SubContributionItem) {
+				// get the wrapped contribution item
+				contributionItem = ((SubContributionItem) contributionItem).getInnerItem();
+			}
+			if (contributionItem instanceof SubMenuManager) {
+				// get the wrapped contribution item
+				contributionItem = (IMenuManager) ((SubMenuManager) contributionItem).getParent();
+			}
+
+			if (processedOpaqueItems.containsKey(contributionItem)) {
+				// Only the first occurrence of an item will be shown
+				return null;
+			}
+
+			if (contributionItem.isDynamic()) {
+				if (dynamicEntry == null || !contributionItem.equals(dynamicEntry.getIContributionItem())) {
+					// Only create one dynamic item for multiple (successive) dynamic contribution
+					// items
+					dynamicEntry = new DynamicContributionItem(contributionItem);
+					dynamicEntry.setActionSet(idToActionSet.get(getActionSetID(contributionItem)));
+					dynamicEntry.setCheckState(getMenuItemIsVisible(dynamicEntry));
+					parent.addChild(dynamicEntry);
+					processedOpaqueItems.put(contributionItem, dynamicEntry);
+				}
+
+				if (menuItem.getWidget() != null) {
+					// TODO See Bug 558766: add children; widgets are no longer available
+					dynamicEntry.addCurrentItem((MenuItem) menuItem.getWidget());
+				}
+
+				return dynamicEntry;
+			} else if (contributionItem instanceof CommandContributionItem) {
+				CommandContributionItem cci = (CommandContributionItem) contributionItem;
+				CommandContributionItemParameter data = cci.getData();
+				DisplayItem menuEntry = new DisplayItem(data.label, contributionItem);
+				menuEntry.setImageDescriptor(data.icon);
+				menuEntry.setActionSet(idToActionSet.get(getActionSetID(contributionItem)));
+				menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
+				parent.addChild(menuEntry);
+				processedOpaqueItems.put(contributionItem, menuEntry);
+			} else if (contributionItem instanceof ActionContributionItem) {
 				final IAction action = ((ActionContributionItem) contributionItem).getAction();
 				DisplayItem menuEntry = new DisplayItem(action.getText(), contributionItem);
 				menuEntry.setImageDescriptor(action.getImageDescriptor());
 				menuEntry.setActionSet(idToActionSet.get(getActionSetID(contributionItem)));
+				menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
 				parent.addChild(menuEntry);
-				if (menuEntry.getChildren().isEmpty()) {
-					menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
+				processedOpaqueItems.put(contributionItem, menuEntry);
+			} else if (contributionItem instanceof MenuManager) {
+				MenuManager manager = (MenuManager) contributionItem;
+				DisplayItem menuEntry = new DisplayItem(manager.getMenuText(), contributionItem);
+				menuEntry.setImageDescriptor(manager.getImageDescriptor());
+				menuEntry.setActionSet(idToActionSet.get(getActionSetID(contributionItem)));
+				menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
+				parent.addChild(menuEntry);
+
+				// The child entries will be processes when the not-wrapped item is processed,
+				// see MMenu case
+				processedOpaqueItems.put(contributionItem, menuEntry);
+			}
+		} else if (menuItem instanceof MDynamicMenuContribution) {
+			IContributionItem contributionItem = menuMngrRenderer.getContribution(menuItem);
+			dynamicEntry = new DynamicContributionItem(menuItem.getLocalizedLabel(), contributionItem);
+			dynamicEntry.setImageDescriptor(getIconDescriptor(menuItem));
+			dynamicEntry.setActionSet(idToActionSet.get(getActionSetID(menuItem)));
+			dynamicEntry.setCheckState(getMenuItemIsVisible(dynamicEntry));
+
+			// TODO See Bug 558766: add children
+
+			parent.addChild(dynamicEntry);
+		} else if (menuItem instanceof MDirectMenuItem) {
+			IContributionItem contributionItem = menuMngrRenderer.getContribution(menuItem);
+			DisplayItem menuEntry = new DisplayItem(menuItem.getLocalizedLabel(), contributionItem);
+			menuEntry.setImageDescriptor(getIconDescriptor(menuItem));
+			menuEntry.setActionSet(idToActionSet.get(getActionSetID(menuItem)));
+			menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
+			parent.addChild(menuEntry);
+		} else if (menuItem instanceof MHandledMenuItem) {
+			IContributionItem contributionItem = menuMngrRenderer.getContribution(menuItem);
+
+			MHandledMenuItem hmi = (MHandledMenuItem) menuItem;
+			String text = hmi.getLocalizedLabel();
+			if (text == null && hmi.getWbCommand() != null) {
+				try {
+					text = hmi.getWbCommand().getName();
+				} catch (NotDefinedException e) {
+					// we'll just ignore a failure
 				}
 			}
-		} else {
-			return dynamicEntry;
+
+			DisplayItem menuEntry = new DisplayItem(text, contributionItem);
+			menuEntry.setImageDescriptor(getIconDescriptor(menuItem));
+			menuEntry.setActionSet(idToActionSet.get(getActionSetID(menuItem)));
+			menuEntry.setCheckState(getMenuItemIsVisible(menuEntry));
+			parent.addChild(menuEntry);
 		}
-		return dynamicEntry;
+		return null;
+	}
+
+	private ImageDescriptor getIconDescriptor(MUILabel item) {
+		String iconURI = item.getIconURI();
+		if (iconURI != null && iconURI.length() > 0) {
+			return resUtils.imageDescriptorFromURI(URI.createURI(iconURI));
+		}
+		return null;
 	}
 
 	private boolean getMenuItemIsVisible(DisplayItem item) {
@@ -1960,7 +2008,6 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 			MToolBar toolBar = (MToolBar) trimElement;
 			ToolBarManager manager = toolbarMngrRenderer.getManager(toolBar);
 			if (manager != null) {
-				toolbarMngrRenderer.reconcileManagerToModel(manager, toolBar);
 				IContributionItem contributionItem = (IContributionItem) toolBar.getTransientData()
 						.get(CoolBarToTrimManager.OBJECT);
 				String text = getToolbarLabel(toolBar);
@@ -2013,11 +2060,7 @@ public class CustomizePerspectiveDialog extends TrayDialog {
 		if (element instanceof MItem) {
 			text = getToolTipText((MItem) element);
 		}
-		ImageDescriptor iconDescriptor = null;
-		String iconURI = element instanceof MItem ? ((MItem) element).getIconURI() : null;
-		if (iconURI != null && iconURI.length() > 0) {
-			iconDescriptor = resUtils.imageDescriptorFromURI(URI.createURI(iconURI));
-		}
+		ImageDescriptor iconDescriptor = element instanceof MItem ? getIconDescriptor((MItem) element) : null;
 		if (element.getWidget() instanceof ToolItem) {
 			ToolItem item = (ToolItem) element.getWidget();
 			if (text == null) {
