@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2018 IBM Corporation and others.
+ * Copyright (c) 2005, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,6 +15,7 @@
  *     		Bug 226342 - [KeyBindings] Keys preference page conflict table is hard to read
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 440810, 491393
  *     Cornel Izbasa <cizbasa@info.uvt.ro> - Bug 442215
+ *     Christian Georgi (SAP SE) - Bug 540440
  *******************************************************************************/
 
 package org.eclipse.ui.internal.keys;
@@ -31,6 +32,7 @@ import org.eclipse.core.commands.ParameterizedCommand;
 import org.eclipse.core.commands.util.Tracing;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
+import org.eclipse.jface.action.LegacyActionTools;
 import org.eclipse.jface.bindings.Binding;
 import org.eclipse.jface.bindings.TriggerSequence;
 import org.eclipse.jface.bindings.keys.KeySequence;
@@ -39,6 +41,7 @@ import org.eclipse.jface.bindings.keys.KeyStroke;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.dialogs.MessageDialog;
+import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.preference.PreferencePage;
 import org.eclipse.jface.resource.DeviceResourceException;
 import org.eclipse.jface.resource.ImageDescriptor;
@@ -66,6 +69,7 @@ import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.FontMetrics;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
@@ -75,6 +79,7 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.MenuItem;
@@ -90,6 +95,7 @@ import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.commands.ICommandImageService;
 import org.eclipse.ui.commands.ICommandService;
 import org.eclipse.ui.dialogs.FilteredTree;
+import org.eclipse.ui.internal.IPreferenceConstants;
 import org.eclipse.ui.internal.IWorkbenchHelpContextIds;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.keys.model.BindingElement;
@@ -102,6 +108,8 @@ import org.eclipse.ui.internal.keys.model.KeyController;
 import org.eclipse.ui.internal.keys.model.ModelElement;
 import org.eclipse.ui.internal.keys.model.SchemeElement;
 import org.eclipse.ui.internal.keys.model.SchemeModel;
+import org.eclipse.ui.internal.keys.show.ShowKeysToggleHandler;
+import org.eclipse.ui.internal.keys.show.ShowKeysUI;
 import org.eclipse.ui.internal.misc.Policy;
 import org.eclipse.ui.internal.util.Util;
 import org.eclipse.ui.keys.IBindingService;
@@ -184,10 +192,15 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 
 	private TableViewer conflictViewer;
 
+	private Button fShowCommandKey;
+	private Button fShowCommandKeyForMouseEvents;
+
 	private ICommandImageService commandImageService;
 
 	private ICommandService commandService;
 
+	private IWorkbench fWorkbench;
+
 	/**
 	 * A FilteredTree that provides a combo which is used to organize and display
 	 * elements in the tree according to the selected criteria.
@@ -287,8 +300,7 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 		private int sortUser(final Object a, final Object b) {
 			int typeA = ((BindingElement) a).getUserDelta().intValue();
 			int typeB = ((BindingElement) b).getUserDelta().intValue();
-			int result = typeA - typeB;
-			return result;
+			return typeA - typeB;
 		}
 
 	}
@@ -366,7 +378,7 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 			BindingElement bindingElement = ((BindingElement) element);
 			switch (index) {
 			case COMMAND_NAME_COLUMN: // name
-				return bindingElement.getName();
+				return LegacyActionTools.removeMnemonics(bindingElement.getName());
 			case KEY_SEQUENCE_COLUMN: // keys
 				TriggerSequence seq = bindingElement.getTrigger();
 				return seq == null ? Util.ZERO_LENGTH_STRING : seq.format();
@@ -468,6 +480,7 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 		createTree(page);
 		createTreeControls(page);
 		createDataControls(page);
+		createShowKeysControls(page);
 
 		fill();
 
@@ -665,9 +678,9 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 
 		// Construct the menu to attach to the above button.
 		final Menu addKeyMenu = new Menu(addKeyButton);
-		final Iterator trappedKeyItr = KeySequenceText.TRAPPED_KEYS.iterator();
+		final Iterator<KeyStroke> trappedKeyItr = KeySequenceText.TRAPPED_KEYS.iterator();
 		while (trappedKeyItr.hasNext()) {
-			final KeyStroke trappedKey = (KeyStroke) trappedKeyItr.next();
+			final KeyStroke trappedKey = trappedKeyItr.next();
 			final MenuItem menuItem = new MenuItem(addKeyMenu, SWT.PUSH);
 			menuItem.setText(trappedKey.format());
 			menuItem.addSelectionListener(widgetSelectedAdapter(e -> {
@@ -751,8 +764,8 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 		tableLayout.addColumnData(new ColumnWeightData(40));
 		table.setLayout(tableLayout);
 		conflictViewer.setContentProvider((IStructuredContentProvider) inputElement -> {
-			if (inputElement instanceof Collection) {
-				return ((Collection) inputElement).toArray();
+			if (inputElement instanceof Collection<?>) {
+				return ((Collection<?>) inputElement).toArray(new Object[0]);
 			}
 			return new Object[0];
 		});
@@ -1038,8 +1051,38 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 		keyController.addPropertyChangeListener(listener);
 	}
 
+	private void createShowKeysControls(Composite parent) {
+		ShowKeysUI showKeysUI = new ShowKeysUI(fWorkbench, getPreferenceStore());
+
+		final Group group = new Group(parent, SWT.NONE);
+		group.setText(NewKeysPreferenceMessages.ShowCommandKeysGroup_Title);
+		group.setLayout(new GridLayout(1, false));
+		group.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 1, 1));
+
+		fShowCommandKey = new Button(group, SWT.CHECK);
+		fShowCommandKey.setText(NewKeysPreferenceMessages.ShowCommandKeysForKeyboard_Text);
+		fShowCommandKey.setSelection(getPreferenceStore().getBoolean(IPreferenceConstants.SHOW_KEYS_ENABLED_FOR_KEYBOARD));
+		fShowCommandKey.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+			// show a preview of the shortcut popup
+			if (fShowCommandKey.getSelection()) {
+				showKeysUI.openForPreview(ShowKeysToggleHandler.COMMAND_ID, null);
+			}
+		}));
+		fShowCommandKeyForMouseEvents = new Button(group, SWT.CHECK);
+		fShowCommandKeyForMouseEvents.setText(NewKeysPreferenceMessages.ShowCommandKeysForMouse_Text);
+		fShowCommandKeyForMouseEvents
+				.setSelection(getPreferenceStore().getBoolean(IPreferenceConstants.SHOW_KEYS_ENABLED_FOR_MOUSE_EVENTS));
+		fShowCommandKeyForMouseEvents.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+			// show a preview of the shortcut popup
+			if (fShowCommandKeyForMouseEvents.getSelection()) {
+				showKeysUI.openForPreview(ShowKeysToggleHandler.COMMAND_ID, null);
+			}
+		}));
+	}
+
 	@Override
 	public void init(IWorkbench workbench) {
+		fWorkbench = workbench;
 		keyController = new KeyController();
 		keyController.init(workbench);
 
@@ -1056,13 +1099,13 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 			keyController.getBindingModel().setSelectedElement((ModelElement) data);
 		}
 		if (data instanceof Binding && fFilteredTree != null) {
-			BindingElement be = (BindingElement) keyController.getBindingModel().getBindingToElement().get(data);
+			BindingElement be = keyController.getBindingModel().getBindingToElement().get(data);
 			fFilteredTree.getViewer().setSelection(new StructuredSelection(be), true);
 		}
 		if (data instanceof ParameterizedCommand) {
-			Map commandToElement = keyController.getBindingModel().getCommandToElement();
+			Map<ParameterizedCommand, BindingElement> commandToElement = keyController.getBindingModel().getCommandToElement();
 
-			BindingElement be = (BindingElement) commandToElement.get(data);
+			BindingElement be = commandToElement.get(data);
 			if (be != null) {
 				fFilteredTree.getViewer().setSelection(new StructuredSelection(be), true);
 			}
@@ -1072,10 +1115,20 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 	@Override
 	public boolean performOk() {
 		keyController.saveBindings(fBindingService);
+		IPreferenceStore preferenceStore = getPreferenceStore();
+		preferenceStore.setValue(IPreferenceConstants.SHOW_KEYS_ENABLED_FOR_KEYBOARD, fShowCommandKey.getSelection());
+		preferenceStore.setValue(IPreferenceConstants.SHOW_KEYS_ENABLED_FOR_MOUSE_EVENTS,
+				fShowCommandKeyForMouseEvents.getSelection());
+
 		saveState(getDialogSettings());
 		return super.performOk();
 	}
 
+	@Override
+	protected IPreferenceStore doGetPreferenceStore() {
+		return WorkbenchPlugin.getDefault().getPreferenceStore();
+	}
+
 	/**
 	 * Save the state of the receiver.
 	 *
@@ -1124,6 +1177,11 @@ public class NewKeysPreferencePage extends PreferencePage implements IWorkbenchP
 				Tracing.printTrace(TRACING_COMPONENT, "performDefaults:model in " + elapsedTime + "ms"); //$NON-NLS-1$ //$NON-NLS-2$
 
 			}
+
+			fShowCommandKey
+					.setSelection(getPreferenceStore().getDefaultBoolean(IPreferenceConstants.SHOW_KEYS_ENABLED_FOR_KEYBOARD));
+			fShowCommandKeyForMouseEvents.setSelection(
+					getPreferenceStore().getDefaultBoolean(IPreferenceConstants.SHOW_KEYS_ENABLED_FOR_MOUSE_EVENTS));
 		}
 
 		super.performDefaults();
