@@ -13,8 +13,6 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.misc;
 
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -38,13 +36,13 @@ public class StatusUtil {
 	/**
 	 * Answer a flat collection of the passed status and its recursive children
 	 */
-	protected static List flatten(IStatus aStatus) {
-		List result = new ArrayList();
+	protected static List<IStatus> flatten(IStatus aStatus) {
+		List<IStatus> result = new ArrayList<>();
 
 		if (aStatus.isMultiStatus()) {
 			for (IStatus status : aStatus.getChildren()) {
 				if (status.isMultiStatus()) {
-					Iterator childStatiiEnum = flatten(status).iterator();
+					Iterator<IStatus> childStatiiEnum = flatten(status).iterator();
 					while (childStatiiEnum.hasNext()) {
 						result.add(childStatiiEnum.next());
 					}
@@ -116,51 +114,7 @@ public class StatusUtil {
 	}
 
 	public static IStatus newStatus(String pluginId, String message, Throwable exception) {
-		return new Status(IStatus.ERROR, pluginId, IStatus.OK, message, getCause(exception));
-	}
-
-	public static Throwable getCause(Throwable exception) {
-		// Figure out which exception should actually be logged -- if the given
-		// exception is
-		// a wrapper, unwrap it
-		Throwable cause = null;
-		if (exception != null) {
-			if (exception instanceof CoreException) {
-				// Workaround: CoreException contains a cause, but does not actually implement
-				// getCause().
-				// If we get a CoreException, we need to manually unpack the cause. Otherwise,
-				// use
-				// the general-purpose mechanism. Remove this branch if CoreException ever
-				// implements
-				// a correct getCause() method.
-				CoreException ce = (CoreException) exception;
-				cause = ce.getStatus().getException();
-			} else {
-				// use reflect instead of a direct call to getCause(), to allow compilation
-				// against JCL Foundation (bug 80053)
-				try {
-					Method causeMethod = exception.getClass().getMethod("getCause"); //$NON-NLS-1$
-					Object o = causeMethod.invoke(exception);
-					if (o instanceof Throwable) {
-						cause = (Throwable) o;
-					}
-				} catch (NoSuchMethodException e) {
-					// ignore
-				} catch (IllegalArgumentException e) {
-					// ignore
-				} catch (IllegalAccessException e) {
-					// ignore
-				} catch (InvocationTargetException e) {
-					// ignore
-				}
-			}
-
-			if (cause == null) {
-				cause = exception;
-			}
-		}
-
-		return cause;
+		return new Status(IStatus.ERROR, pluginId, IStatus.OK, message, exception);
 	}
 
 	/**
@@ -171,7 +125,7 @@ public class StatusUtil {
 	public static IStatus newStatus(int severity, String message, Throwable exception) {
 
 		String statusMessage = message;
-		if (message == null || message.trim().length() == 0) {
+		if (message == null || message.trim().isEmpty()) {
 			if (exception.getMessage() == null) {
 				statusMessage = exception.toString();
 			} else {
@@ -179,7 +133,7 @@ public class StatusUtil {
 			}
 		}
 
-		return new Status(severity, WorkbenchPlugin.PI_WORKBENCH, severity, statusMessage, getCause(exception));
+		return new Status(severity, WorkbenchPlugin.PI_WORKBENCH, severity, statusMessage, exception);
 	}
 
 	/**
@@ -187,13 +141,13 @@ public class StatusUtil {
 	 *
 	 * Utility method for creating status.
 	 */
-	public static IStatus newStatus(List children, String message, Throwable exception) {
+	public static IStatus newStatus(List<IStatus> children, String message, Throwable exception) {
 
-		List flatStatusCollection = new ArrayList();
-		Iterator iter = children.iterator();
+		List<IStatus> flatStatusCollection = new ArrayList<>();
+		Iterator<IStatus> iter = children.iterator();
 		while (iter.hasNext()) {
-			IStatus currentStatus = (IStatus) iter.next();
-			Iterator childrenIter = flatten(currentStatus).iterator();
+			IStatus currentStatus = iter.next();
+			Iterator<IStatus> childrenIter = flatten(currentStatus).iterator();
 			while (childrenIter.hasNext()) {
 				flatStatusCollection.add(childrenIter.next());
 			}
