@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2016 IBM Corporation and others.
+ * Copyright (c) 2005, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -39,7 +39,6 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.WorkbenchMessages;
 import org.eclipse.ui.internal.WorkbenchPlugin;
-import org.eclipse.ui.internal.misc.StatusUtil;
 
 /**
  * <p>
@@ -84,7 +83,7 @@ public class AdvancedValidationUserApprover implements IOperationApprover, IOper
 
 		IAdaptable uiInfo;
 
-		StatusReportingRunnable(IUndoableOperation operation, IOperationHistory history, IAdaptable uiInfo, int doing) {
+		StatusReportingRunnable(IUndoableOperation operation, IAdaptable uiInfo, int doing) {
 			super();
 			this.operation = operation;
 			this.doing = doing;
@@ -175,7 +174,7 @@ public class AdvancedValidationUserApprover implements IOperationApprover, IOper
 		final IStatus[] status = new IStatus[1];
 		PlatformUI.getWorkbench().getDisplay().syncExec(() -> {
 			// Compute the undoable or redoable status
-			status[0] = computeOperationStatus(operation, history, uiInfo, doing);
+			status[0] = computeOperationStatus(operation, uiInfo, doing);
 
 			// Report non-OK statuses to the user. In some cases, the user
 			// may choose to proceed, and the returned status will be
@@ -197,21 +196,19 @@ public class AdvancedValidationUserApprover implements IOperationApprover, IOper
 		return status[0];
 	}
 
-	private IStatus computeOperationStatus(IUndoableOperation operation, IOperationHistory history, IAdaptable uiInfo,
+	private IStatus computeOperationStatus(IUndoableOperation operation, IAdaptable uiInfo,
 			int doing) {
 		try {
-			StatusReportingRunnable runnable = new StatusReportingRunnable(operation, history, uiInfo, doing);
+			StatusReportingRunnable runnable = new StatusReportingRunnable(operation, uiInfo, doing);
 			TimeTriggeredProgressMonitorDialog progressDialog = new TimeTriggeredProgressMonitorDialog(getShell(uiInfo),
 					PlatformUI.getWorkbench().getProgressService().getLongOperationTime());
 
 			progressDialog.run(false, true, runnable);
 			return runnable.getStatus();
-		} catch (OperationCanceledException e) {
-			return Status.CANCEL_STATUS;
 		} catch (InvocationTargetException e) {
 			reportException(e, uiInfo);
 			return IOperationHistory.OPERATION_INVALID_STATUS;
-		} catch (InterruptedException e) {
+		} catch (OperationCanceledException | InterruptedException e) {
 			// Operation was cancelled and acknowledged by runnable with this
 			// exception. Do nothing.
 			return Status.CANCEL_STATUS;
@@ -222,15 +219,13 @@ public class AdvancedValidationUserApprover implements IOperationApprover, IOper
 	 * Report the specified execution exception to the log and to the user.
 	 */
 	private void reportException(Exception e, IAdaptable uiInfo) {
-		Throwable nestedException = StatusUtil.getCause(e);
-		Throwable exception = (nestedException == null) ? e : nestedException;
 		String title = WorkbenchMessages.Error;
 		String message = WorkbenchMessages.WorkbenchWindow_exceptionMessage;
-		String exceptionMessage = exception.getMessage();
+		String exceptionMessage = e.getMessage();
 		if (exceptionMessage == null) {
 			exceptionMessage = message;
 		}
-		IStatus status = new Status(IStatus.ERROR, WorkbenchPlugin.PI_WORKBENCH, 0, exceptionMessage, exception);
+		IStatus status = new Status(IStatus.ERROR, WorkbenchPlugin.PI_WORKBENCH, 0, exceptionMessage, e);
 		WorkbenchPlugin.log(message, status);
 
 		boolean createdShell = false;
