@@ -33,7 +33,7 @@ public abstract class WorkbenchSettingsTransfer extends SettingsTransfer {
 
 	/**
 	 * Return a status message for missing workspace settings.
-	 * 
+	 *
 	 * @return IStatus
 	 */
 	protected IStatus noWorkingSettingsStatus() {
@@ -43,7 +43,7 @@ public abstract class WorkbenchSettingsTransfer extends SettingsTransfer {
 
 	/**
 	 * Return the workbench settings location for the new root
-	 * 
+	 *
 	 * @param newWorkspaceRoot
 	 * @return IPath or <code>null</code> if it can't be determined.
 	 */
@@ -58,9 +58,7 @@ public abstract class WorkbenchSettingsTransfer extends SettingsTransfer {
 
 		// Strip it down to the extension
 		dataLocation = dataLocation.removeFirstSegments(segmentsToRemove);
-		// Now add in the
-		dataLocation = newWorkspaceRoot.append(dataLocation);
-		return dataLocation;
+		return newWorkspaceRoot.append(dataLocation);
 	}
 
 }
