@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2015 IBM Corporation and others.
+ * Copyright (c) 2003, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,6 +15,7 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.progress;
 
+import java.util.Optional;
 import java.util.Queue;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import org.eclipse.core.runtime.IProgressMonitor;
@@ -38,24 +39,31 @@ public class JobInfo extends JobTreeElement {
 
 	private GroupInfo parent;
 
-	private TaskInfo taskInfo;
+	private volatile Optional<TaskInfo> taskInfo;
 
-	// Default to no progress.
+	private ProgressManager progressManager;
+
+	private FinishedJobs finishedJobs;
+
+	// Default to no progress
 	private int ticks = -1;
 
 	/**
 	 * Creates a top level JobInfo.
 	 *
-	 * @param enclosingJob
+	 * @param enclosingJob the job to represent by this info
 	 */
 	protected JobInfo(Job enclosingJob) {
 		this.job = enclosingJob;
+		this.progressManager = ProgressManager.getInstance();
+		this.finishedJobs = FinishedJobs.getInstance();
+		this.taskInfo = Optional.empty();
 	}
 
 	/**
 	 * Adds the subtask to the receiver.
 	 *
-	 * @param subTaskName
+	 * @param subTaskName name for the sub task
 	 */
 	void addSubTask(String subTaskName) {
 		children.add(new SubTaskInfo(this, subTaskName));
@@ -67,9 +75,11 @@ public class JobInfo extends JobTreeElement {
 	 * @param workIncrement
 	 */
 	void addWork(double workIncrement) {
-		if (taskInfo == null) {
+		Optional<TaskInfo> optionalInfo = getTaskInfo();
+		if (!optionalInfo.isPresent()) {
 			return;
 		}
+		TaskInfo taskInfo = optionalInfo.get();
 		if (parent == null || ticks < 1) {
 			taskInfo.addWork(workIncrement);
 		} else {
@@ -84,15 +94,15 @@ public class JobInfo extends JobTreeElement {
 	 * @param work
 	 */
 	void beginTask(String taskName, int work) {
-		taskInfo = new TaskInfo(this, taskName, work);
+		taskInfo = Optional.of(new TaskInfo(this, taskName, work));
 	}
 
 	@Override
 	public void cancel() {
 		this.canceled = true;
 		this.job.cancel();
-		// Call the refresh so that this is updated immediately.
-		ProgressManager.getInstance().refreshJobInfo(this);
+		// Call the refresh so that this is updated immediately
+		progressManager.refreshJobInfo(this);
 	}
 
 	/**
@@ -103,8 +113,8 @@ public class JobInfo extends JobTreeElement {
 	}
 
 	void clearTaskInfo() {
-		FinishedJobs.getInstance().remove(taskInfo);
-		taskInfo = null;
+		taskInfo.ifPresent(finishedJobs::remove);
+		taskInfo = Optional.empty();
 	}
 
 	/**
@@ -117,7 +127,7 @@ public class JobInfo extends JobTreeElement {
 	private int compareJobs(JobInfo jobInfo) {
 		Job job2 = jobInfo.getJob();
 
-		// User jobs have top priority.
+		// User jobs have top priority
 		if (job.isUser()) {
 			if (!job2.isUser()) {
 				return -1;
@@ -141,13 +151,13 @@ public class JobInfo extends JobTreeElement {
 
 		int thisPriority = job.getPriority();
 		int otherPriority = job2.getPriority();
-		// If equal priority, order by names.
+		// If equal priority, order by names
 		if (thisPriority == otherPriority) {
 			return job.getName().compareTo(job2.getName());
 		}
 
-		// Order by priority.
-		if (thisPriority > otherPriority) {
+		// order by priority (lower value is higher priority)
+		if (thisPriority < otherPriority) {
 			return -1;
 		}
 		return 1;
@@ -163,7 +173,7 @@ public class JobInfo extends JobTreeElement {
 		boolean thisCanceled = isCanceled();
 		boolean anotherCanceled = element.isCanceled();
 		if (thisCanceled && !anotherCanceled) {
-			// If the receiver is cancelled then it is lowest priority.
+			// If the receiver is cancelled then it is lowest priority
 			return 1;
 		} else if (!thisCanceled && anotherCanceled) {
 			return -1;
@@ -172,17 +182,17 @@ public class JobInfo extends JobTreeElement {
 		int thisState = getJob().getState();
 		int anotherState = element.getJob().getState();
 
-		// If equal job state, compare other job attributes.
+		// if equal job state, compare other job attributes
 		if (thisState == anotherState) {
 			return compareJobs(element);
 		}
 
-		// Ordering by job states, Job.RUNNING should be ordered first.
+		// ordering by job states, Job.RUNNING should be ordered first
 		return Integer.compare(anotherState, thisState);
 	}
 
 	/**
-	 * Disposes of the receiver.
+	 * Dispose of the receiver.
 	 */
 	void dispose() {
 		if (parent != null) {
@@ -191,7 +201,7 @@ public class JobInfo extends JobTreeElement {
 	}
 
 	/**
-	 * Returns the blocked status or <code>null</code> if there isn't one.
+	 * Return the blocked status or <code>null</code> if there isn't one.
 	 *
 	 * @return the blockedStatus.
 	 */
@@ -206,9 +216,9 @@ public class JobInfo extends JobTreeElement {
 
 	@Override
 	String getCondensedDisplayString() {
-		TaskInfo info = getTaskInfo();
-		if (info != null) {
-			return info.getDisplayStringWithoutTask(true);
+		Optional<TaskInfo> optionalInfo = getTaskInfo();
+		if (optionalInfo.isPresent()) {
+			return optionalInfo.get().getDisplayStringWithoutTask(true);
 		}
 		return getJob().getName();
 	}
@@ -260,16 +270,17 @@ public class JobInfo extends JobTreeElement {
 		if (isCanceled()) {
 			return NLS.bind(ProgressMessages.JobInfo_Cancelled, (new Object[] { getJob().getName() }));
 		}
-		if (isBlocked()) {
+		IStatus blockedStatusLocal = getBlockedStatus();
+		if (blockedStatusLocal != null) {
 			return NLS.bind(ProgressMessages.JobInfo_Blocked,
-					(new Object[] { getJob().getName(), blockedStatus.getMessage() }));
+					(new Object[] { getJob().getName(), blockedStatusLocal.getMessage() }));
 		}
 		if (getJob().getState() == Job.RUNNING) {
-			TaskInfo info = getTaskInfo();
-			if (info == null) {
+			Optional<TaskInfo> optionalInfo = getTaskInfo();
+			if (!optionalInfo.isPresent()) {
 				return getJob().getName();
 			}
-			return info.getDisplayString(showProgress);
+			return optionalInfo.get().getDisplayString(showProgress);
 		}
 		if (getJob().getState() == Job.SLEEPING) {
 			return NLS.bind(ProgressMessages.JobInfo_Sleeping, (new Object[] { getJob().getName() }));
@@ -311,8 +322,9 @@ public class JobInfo extends JobTreeElement {
 	 * @return int
 	 */
 	int getPercentDone() {
-		TaskInfo info = getTaskInfo();
-		if (info != null) {
+		Optional<TaskInfo> optionalInfo = getTaskInfo();
+		if (optionalInfo.isPresent()) {
+			TaskInfo info = optionalInfo.get();
 			if (info.totalWork == IProgressMonitor.UNKNOWN) {
 				return IProgressMonitor.UNKNOWN;
 			}
@@ -325,9 +337,9 @@ public class JobInfo extends JobTreeElement {
 	}
 
 	/**
-	 * Returns the taskInfo.
+	 * @return the taskInfo, never null
 	 */
-	TaskInfo getTaskInfo() {
+	Optional<TaskInfo> getTaskInfo() {
 		return taskInfo;
 	}
 
@@ -336,15 +348,6 @@ public class JobInfo extends JobTreeElement {
 		return !children.isEmpty();
 	}
 
-	/**
-	 * Returns whether or not there is a task.
-	 *
-	 * @return boolean
-	 */
-	boolean hasTaskInfo() {
-		return taskInfo != null;
-	}
-
 	@Override
 	boolean isActive() {
 		return getJob().getState() != Job.NONE;
@@ -403,7 +406,7 @@ public class JobInfo extends JobTreeElement {
 	 * @param name
 	 */
 	void setTaskName(String name) {
-		taskInfo.setTaskName(name);
+		taskInfo.ifPresent(info -> info.setTaskName(name));
 	}
 
 	/**
