@@ -164,13 +164,7 @@ public class ProgressAnimationItem extends AnimationItem implements FinishedJobs
 			try {
 				service.executeCommand(command, null);
 				removeTopElement(ji);
-			} catch (ExecutionException e) {
-				exception = e;
-			} catch (NotDefinedException e) {
-				exception = e;
-			} catch (NotEnabledException e) {
-				exception = e;
-			} catch (NotHandledException e) {
+			} catch (ExecutionException | NotDefinedException | NotEnabledException | NotHandledException e) {
 				exception = e;
 			}
 
@@ -230,7 +224,7 @@ public class ProgressAnimationItem extends AnimationItem implements FinishedJobs
 					if (action != null && action.isEnabled()) {
 						// green arrow with exclamation mark
 						String tt = action.getToolTipText();
-						if (tt == null || tt.trim().length() == 0) {
+						if (tt == null || tt.trim().isEmpty()) {
 							tt = NLS.bind(ProgressMessages.ProgressAnimationItem_ok, job.getName());
 						}
 						initButton(okImage, tt);
