@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2016 IBM Corporation and others.
+ * Copyright (c) 2003, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -26,6 +26,7 @@ import java.time.Duration;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Enumeration;
+import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
@@ -33,12 +34,12 @@ import java.util.LinkedHashSet;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
+import java.util.function.Predicate;
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.IProgressMonitor;
-import org.eclipse.core.runtime.IProgressMonitorWithBlocking;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.ListenerList;
 import org.eclipse.core.runtime.NullProgressMonitor;
@@ -86,8 +87,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	 * A property to determine if the job was run in the dialog. Kept for backwards
 	 * compatibility.
 	 *
-	 * @deprecated
-	 * @see IProgressConstants#PROPERTY_IN_DIALOG
+	 * @deprecated use IProgressConstants#PROPERTY_IN_DIALOG instead
 	 */
 	@Deprecated
 	public static final QualifiedName PROPERTY_IN_DIALOG = IProgressConstants.PROPERTY_IN_DIALOG;
@@ -133,7 +133,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	 */
 	public static final String BLOCKED_JOB_KEY = "LOCKED_JOB"; //$NON-NLS-1$
 
-	final ConcurrentMap<Job, JobMonitor> runnableMonitors = new ConcurrentHashMap<>();
+	final Map<Job, JobMonitor> runnableMonitors = new HashMap<>();
 
 	// A table that maps families to keys in the Jface image table
 	private Hashtable<Object, String> imageKeyTable = new Hashtable<>();
@@ -200,22 +200,28 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	 * The JobMonitor is the inner class that handles the IProgressMonitor
 	 * integration with the ProgressMonitor.
 	 */
-	public class JobMonitor implements IProgressMonitorWithBlocking {
+	public class JobMonitor implements IProgressMonitor {
 		Job job;
 		JobInfo info;
 		String currentTaskName;
-		Set<IProgressMonitorWithBlocking> monitors = Collections.emptySet();
+		Set<IProgressMonitor> monitors = Collections.emptySet();
 
 		/**
 		 * Creates a monitor on the supplied job.
 		 *
-		 * @param newJob
+		 * @param newJob  the job this monitor is created for
+		 * @param jobInfo the info object for the job
 		 */
 		JobMonitor(Job newJob, JobInfo jobInfo) {
 			job = newJob;
 			info = jobInfo;
 		}
 
+		/**
+		 * Get the monitored job's information.
+		 *
+		 * @return job info
+		 */
 		public JobInfo getJobInfo() {
 			return info;
 		}
@@ -223,22 +229,28 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 		/**
 		 * Adds monitor as another monitor that
 		 *
-		 * @param monitor
+		 * @param monitor the listening monitor to add
 		 */
-		public void addProgressListener(IProgressMonitorWithBlocking monitor) {
+		public void addProgressListener(IProgressMonitor monitor) {
 			Assert.isNotNull(monitor);
-			Set<IProgressMonitorWithBlocking> newSet = new LinkedHashSet<>(monitors);
+			Set<IProgressMonitor> newSet = new LinkedHashSet<>(monitors);
 			newSet.add(monitor);
 			this.monitors = Collections.unmodifiableSet(newSet);
-			TaskInfo currentTask = info.getTaskInfo();
-			if (currentTask != null) {
+			Optional<TaskInfo> optionalInfo = info.getTaskInfo();
+			if (optionalInfo.isPresent()) {
+				TaskInfo currentTask = optionalInfo.get();
 				monitor.beginTask(currentTaskName, currentTask.totalWork);
 				monitor.internalWorked(currentTask.preWork);
 			}
 		}
 
-		public void removeProgresListener(IProgressMonitorWithBlocking monitor) {
-			Set<IProgressMonitorWithBlocking> newSet = new LinkedHashSet<>(monitors);
+		/**
+		 * Removes progress listener.
+		 *
+		 * @param monitor the listening monitor to remove
+		 */
+		public void removeProgresListener(IProgressMonitor monitor) {
+			Set<IProgressMonitor> newSet = new LinkedHashSet<>(monitors);
 			newSet.remove(monitor);
 			this.monitors = Collections.unmodifiableSet(newSet);
 		}
@@ -255,12 +267,12 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 		public void done() {
 			info.clearTaskInfo();
 			info.clearChildren();
-			monitors.forEach(IProgressMonitorWithBlocking::done);
+			monitors.forEach(t -> t.done());
 		}
 
 		@Override
 		public void internalWorked(double work) {
-			if (info.hasTaskInfo()) {
+			if (info.getTaskInfo().isPresent()) {
 				info.addWork(work);
 				refreshJobInfo(info);
 			}
@@ -284,7 +296,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 
 		@Override
 		public void setTaskName(String taskName) {
-			if (info.hasTaskInfo()) {
+			if (info.getTaskInfo().isPresent()) {
 				info.setTaskName(taskName);
 			} else {
 				beginTask(taskName, 100);
@@ -316,7 +328,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 		public void clearBlocked() {
 			info.setBlockedStatus(null);
 			refreshJobInfo(info);
-			monitors.forEach(IProgressMonitorWithBlocking::clearBlocked);
+			monitors.forEach(IProgressMonitor::clearBlocked);
 		}
 
 		@Override
@@ -342,6 +354,9 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 		Job.getJobManager().addJobChangeListener(this.changeListener);
 	}
 
+	/**
+	 * Send pending notifications to listeners.
+	 */
 	/* Visible for testing */ public void notifyListeners() {
 		Set<GroupInfo> localPendingGroupUpdates, localPendingGroupRemoval;
 		Map<JobInfo, Set<IJobProgressManagerListener>> localPendingJobUpdates, localPendingJobAddition,
@@ -424,8 +439,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 					next.decrementBusy(event.getJob());
 				}
 
-				final JobInfo info = progressFor(event.getJob()).getJobInfo();
-				removeJobInfo(info);
+				final JobInfo info = removeJob(event.getJob());
 
 				/*
 				 * Only report severe errors to the StatusManager if the error is not part of a
@@ -504,7 +518,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	 * The job in JobInfo is now sleeping. Refreshes it if we are showing it,
 	 * removes it if not.
 	 *
-	 * @param info
+	 * @param info the job going to sleep
 	 */
 	protected void sleepJobInfo(JobInfo info) {
 		GroupInfo group = info.getGroupInfo();
@@ -577,11 +591,13 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	 * Returns a monitor for the job. Checks if we cached a monitor for this job
 	 * previously for a long operation timeout check.
 	 *
-	 * @param job
-	 * @return IProgressMonitor
+	 * @param job the job to (progress) monitor
+	 * @return a monitor for the job. Might be an existing monitor for this job.
 	 */
 	public JobMonitor progressFor(Job job) {
-		return runnableMonitors.computeIfAbsent(job, j -> new JobMonitor(j, new JobInfo(j)));
+		synchronized (runnableMonitors) {
+			return runnableMonitors.computeIfAbsent(job, j -> new JobMonitor(j, new JobInfo(j)));
+		}
 	}
 
 	/**
@@ -605,11 +621,12 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	/**
 	 * Refreshes the IJobProgressManagerListeners as a result of a change in info.
 	 *
-	 * @param info
+	 * @param info the updated job info
 	 */
 	public void refreshJobInfo(JobInfo info) {
 		synchronized (pendingUpdatesMutex) {
-			rememberListenersForJob(info, pendingJobUpdates);
+			Predicate<IJobProgressManagerListener> predicate = listener -> !isNeverDisplaying(info.getJob(), listener.showsDebug());
+			rememberListenersForJob(info, pendingJobUpdates, predicate);
 		}
 		uiRefreshThrottler.throttledExec();
 	}
@@ -617,7 +634,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	/**
 	 * Refreshes the IJobProgressManagerListeners as a result of a change in info.
 	 *
-	 * @param info
+	 * @param info the updated job group
 	 */
 	public void refreshGroup(GroupInfo info) {
 		synchronized (pendingUpdatesMutex) {
@@ -626,19 +643,37 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 		uiRefreshThrottler.throttledExec();
 	}
 
+	/**
+	 * Refreshes the content providers as a result of a deletion of job.
+	 *
+	 * @param job the job to remove information about
+	 * @return the removed job info
+	 */
+	public JobInfo removeJob(Job job) {
+		JobInfo info;
+		synchronized (runnableMonitors) {
+			info = progressFor(job).getJobInfo();
+			managedJobs.remove(job);
+			synchronized (pendingUpdatesMutex) {
+				Predicate<IJobProgressManagerListener> predicate = listener -> !isNeverDisplaying(info.getJob(), listener.showsDebug());
+				rememberListenersForJob(info, pendingJobRemoval, predicate);
+			}
+			runnableMonitors.remove(job);
+		}
+		uiRefreshThrottler.throttledExec();
+		return info;
+	}
+
 	/**
 	 * Refreshes the content providers as a result of a deletion of info.
 	 *
 	 * @param info the info to remove
+	 * @deprecated use the more thread safe {@link #removeJob(Job)} instead. See bug
+	 *             558655.
 	 */
+	@Deprecated
 	public void removeJobInfo(JobInfo info) {
-		Job job = info.getJob();
-		managedJobs.remove(job);
-		synchronized (pendingUpdatesMutex) {
-			rememberListenersForJob(info, pendingJobRemoval);
-		}
-		runnableMonitors.remove(job);
-		uiRefreshThrottler.throttledExec();
+		removeJob(info.getJob());
 	}
 
 	/**
@@ -656,7 +691,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	/**
 	 * Refreshes the content providers as a result of an addition of info.
 	 *
-	 * @param info
+	 * @param info the added job info
 	 */
 	public void addJobInfo(JobInfo info) {
 		GroupInfo group = info.getGroupInfo();
@@ -666,16 +701,16 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 
 		managedJobs.add(info.getJob());
 		synchronized (pendingUpdatesMutex) {
-			rememberListenersForJob(info, pendingJobAddition);
+			Predicate<IJobProgressManagerListener> predicate = listener -> !isCurrentDisplaying(info.getJob(), listener.showsDebug());
+			rememberListenersForJob(info, pendingJobAddition, predicate);
 		}
 		uiRefreshThrottler.throttledExec();
 	}
 
-	private void rememberListenersForJob(JobInfo info, Map<JobInfo, Set<IJobProgressManagerListener>> listenersMap) {
+	private void rememberListenersForJob(JobInfo info, Map<JobInfo, Set<IJobProgressManagerListener>> listenersMap, Predicate<IJobProgressManagerListener> predicate) {
 		Set<IJobProgressManagerListener> localListeners = listenersMap.computeIfAbsent(info,
 				k -> new LinkedHashSet<>());
-		listeners.stream().filter(listener -> !isCurrentDisplaying(info.getJob(), listener.showsDebug()))
-				.forEach(localListeners::add);
+		listeners.stream().filter(predicate).forEach(localListeners::add);
 	}
 
 	/**
@@ -706,7 +741,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	/**
 	 * Returns the current job infos filtered on debug mode.
 	 *
-	 * @param debug
+	 * @param debug if the listener is in debug mode
 	 * @return JobInfo[]
 	 */
 	public JobInfo[] getJobInfos(boolean debug) {
@@ -717,7 +752,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	/**
 	 * Returns the current root elements filtered on the debug mode.
 	 *
-	 * @param debug
+	 * @param debug if the listener is in debug mode
 	 * @return JobTreeElement[]
 	 */
 	public JobTreeElement[] getRootElements(boolean debug) {
@@ -980,7 +1015,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 
 	@Override
 	public void registerIconForFamily(ImageDescriptor icon, Object family) {
-		String key = IMAGE_KEY + String.valueOf(imageKeyTable.size());
+		String key = IMAGE_KEY + imageKeyTable.size();
 		imageKeyTable.put(family, key);
 		ImageRegistry registry = JFaceResources.getImageRegistry();
 
@@ -1013,9 +1048,9 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 		IWorkbench workbench = PlatformUI.getWorkbench();
 		Shell[] shells = workbench.getDisplay().getShells();
 		if (active) {
-			for (int i = 0; i < shells.length; i++) {
-				if (!shells[i].isDisposed()) {
-					shells[i].setEnabled(active);
+			for (Shell shell : shells) {
+				if (!shell.isDisposed()) {
+					shell.setEnabled(active);
 				}
 			}
 		} else {
@@ -1036,7 +1071,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	 */
 	boolean checkForStaleness(Job job) {
 		if (job.getState() == Job.NONE) {
-			removeJobInfo(progressFor(job).getJobInfo());
+			removeJob(job);
 			return true;
 		}
 		return false;
@@ -1054,7 +1089,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 	/**
 	 * Sets whether or not the ProgressViewUpdater should show system jobs.
 	 *
-	 * @param showSystem
+	 * @param showSystem <code>true</code> to show system jobs
 	 */
 	public void setShowSystemJobs(boolean showSystem) {
 		ProgressViewUpdater updater = ProgressViewUpdater.getSingleton();
@@ -1080,11 +1115,7 @@ public class ProgressManager extends ProgressProvider implements IProgressServic
 			try {
 				manager.beginRule(rule, getEventLoopMonitor());
 				context.run(false, false, runnable);
-			} catch (InvocationTargetException e) {
-				status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, e.getMessage(), e);
-			} catch (InterruptedException e) {
-				status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, e.getMessage(), e);
-			} catch (OperationCanceledException e) {
+			} catch (InvocationTargetException | InterruptedException | OperationCanceledException e) {
 				status = new Status(IStatus.ERROR, PlatformUI.PLUGIN_ID, e.getMessage(), e);
 			} finally {
 				manager.endRule(rule);
