@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2017 IBM Corporation and others.
+ * Copyright (c) 2003, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -28,17 +28,13 @@ import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.jface.window.IShellProvider;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.GC;
-import org.eclipse.swt.graphics.Point;
-import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.PlatformUI;
-import org.eclipse.ui.internal.AnimationEngine;
 import org.eclipse.ui.internal.WorkbenchPlugin;
-import org.eclipse.ui.internal.WorkbenchWindow;
 import org.eclipse.ui.internal.misc.StatusUtil;
 import org.eclipse.ui.internal.util.BundleUtility;
 import org.eclipse.ui.progress.IProgressConstants;
@@ -63,14 +59,14 @@ public class ProgressManagerUtil {
 			/*
 			 * https://bugs.eclipse.org/371354
 			 *
-			 * This ordering is inherently unstable, since it relies on
-			 * modifiable properties of the elements: E.g. the default
-			 * implementation in JobTreeElement compares getDisplayString(),
-			 * many of whose implementations use getPercentDone().
+			 * This ordering is inherently unstable, since it relies on modifiable
+			 * properties of the elements: E.g. the default implementation in JobTreeElement
+			 * compares getDisplayString(), many of whose implementations use
+			 * getPercentDone().
 			 *
-			 * JavaSE 7+'s TimSort introduced a breaking change: It now throws a
-			 * new IllegalArgumentException for bad comparators. Workaround is
-			 * to retry a few times.
+			 * JavaSE 7+'s TimSort introduced a breaking change: It now throws a new
+			 * IllegalArgumentException for bad comparators. Workaround is to retry a few
+			 * times.
 			 */
 			for (int retries = 3; retries > 0; retries--) {
 				try {
@@ -87,8 +83,8 @@ public class ProgressManagerUtil {
 	}
 
 	/**
-	 * A constant used by the progress support to determine if an operation is
-	 * too short to show progress.
+	 * A constant used by the progress support to determine if an operation is too
+	 * short to show progress.
 	 */
 	public static long SHORT_OPERATION_TIME = 250;
 
@@ -107,8 +103,7 @@ public class ProgressManagerUtil {
 	 * @return IStatus
 	 */
 	static IStatus exceptionStatus(Throwable exception) {
-		return StatusUtil.newStatus(IStatus.ERROR,
-				exception.getMessage() == null ? "" : exception.getMessage(), //$NON-NLS-1$
+		return StatusUtil.newStatus(IStatus.ERROR, exception.getMessage() == null ? "" : exception.getMessage(), //$NON-NLS-1$
 				exception);
 	}
 
@@ -149,8 +144,7 @@ public class ProgressManagerUtil {
 			return;
 		}
 		try {
-			IViewDescriptor reference = WorkbenchPlugin.getDefault()
-					.getViewRegistry()
+			IViewDescriptor reference = WorkbenchPlugin.getDefault().getViewRegistry()
 					.find(IProgressConstants.PROGRESS_VIEW_ID);
 
 			if (reference == null) {
@@ -163,10 +157,10 @@ public class ProgressManagerUtil {
 	}
 
 	/**
-	 * Shorten the given text <code>t</code> so that its length doesn't exceed
-	 * the given width. The default implementation replaces characters in the
-	 * center of the original string with an ellipsis ("..."). Override if you
-	 * need a different strategy.
+	 * Shorten the given text <code>t</code> so that its length doesn't exceed the
+	 * given width. The default implementation replaces characters in the center of
+	 * the original string with an ellipsis ("..."). Override if you need a
+	 * different strategy.
 	 *
 	 * @param textValue
 	 * @param control
@@ -187,7 +181,7 @@ public class ProgressManagerUtil {
 	}
 
 	private static String clipToSize(GC gc, String textValue, String ellipsisString, int maxWidth) {
-		int averageCharWidth = gc.getFontMetrics().getAverageCharWidth();
+		int averageCharWidth = (int) gc.getFontMetrics().getAverageCharacterWidth();
 		int length = textValue.length();
 
 		int secondWord = findSecondWhitespace(textValue, gc, maxWidth);
@@ -210,8 +204,7 @@ public class ProgressManagerUtil {
 			if (maxExtent <= maxWidth) {
 				return textValue;
 			}
-			currentLength = Math.max(0,
-					Math.round(length * ((float) maxWidth / maxExtent)) - ellipsisString.length());
+			currentLength = Math.max(0, Math.round(length * ((float) maxWidth / maxExtent)) - ellipsisString.length());
 			upperBoundWidth = maxExtent;
 			upperBoundLength = length;
 		} else {
@@ -293,8 +286,7 @@ public class ProgressManagerUtil {
 			}
 		}
 
-		s = clipToLength(textValue, ellipsisString, pivot, currentLength);
-		return s;
+		return clipToLength(textValue, ellipsisString, pivot, currentLength);
 	}
 
 	private static String clipToLength(String textValue, String ellipsisString, int pivot, int newLength) {
@@ -309,7 +301,6 @@ public class ProgressManagerUtil {
 		if (charsToClip >= length) {
 			return ""; //$NON-NLS-1$
 		}
-		String s;
 		int start = pivot - charsToClip / 2;
 		int end = pivot + (charsToClip + 1) / 2;
 
@@ -329,23 +320,19 @@ public class ProgressManagerUtil {
 		} else {
 			s2 = ""; //$NON-NLS-1$
 		}
-		s = s1 + ellipsisString + s2;
-		return s;
+		return s1 + ellipsisString + s2;
 	}
 
 	/**
-	 * Find the second index of a whitespace. Return the first index if there
-	 * isn't one or 0 if there is no space at all.
+	 * Find the second index of a whitespace. Return the first index if there isn't
+	 * one or 0 if there is no space at all.
 	 *
 	 * @param textValue
-	 * @param gc
-	 *            The GC to test max length
-	 * @param maxWidth
-	 *            The maximim extent
+	 * @param gc        The GC to test max length
+	 * @param maxWidth  The maximim extent
 	 * @return int
 	 */
-	private static int findSecondWhitespace(String textValue, GC gc,
-			int maxWidth) {
+	private static int findSecondWhitespace(String textValue, GC gc, int maxWidth) {
 		int firstCharacter = 0;
 		char[] chars = textValue.toCharArray();
 		// Find the first whitespace
@@ -380,11 +367,10 @@ public class ProgressManagerUtil {
 	}
 
 	/**
-	 * If there are any modal shells open reschedule openJob to wait until they
-	 * are closed. Return true if it rescheduled, false if there is nothing
-	 * blocking it.
+	 * If there are any modal shells open reschedule openJob to wait until they are
+	 * closed. Return true if it rescheduled, false if there is nothing blocking it.
 	 *
-	 * @param openJob
+	 * @param openJob the job to reschedule (with delay) when modal dialog is open
 	 * @return boolean. true if the job was rescheduled due to modal dialogs.
 	 */
 	public static boolean rescheduleIfModalShellOpen(Job openJob) {
@@ -394,8 +380,7 @@ public class ProgressManagerUtil {
 		}
 
 		// try again in a few seconds
-		openJob.schedule(PlatformUI.getWorkbench().getProgressService()
-				.getLongOperationTime());
+		openJob.schedule(PlatformUI.getWorkbench().getProgressService().getLongOperationTime());
 		return true;
 	}
 
@@ -404,15 +389,12 @@ public class ProgressManagerUtil {
 	 * <code>true</code>. If not then set it to open itself when it has had
 	 * ProgressManager#longOperationTime worth of ticks.
 	 *
-	 * @param dialog
-	 *            ProgressMonitorJobsDialog that will be opening
-	 * @param excludedShell
-	 *            The shell
-	 * @return boolean. <code>true</code> if it can open. Otherwise return
-	 *         false and set the dialog to tick.
+	 * @param dialog        ProgressMonitorJobsDialog that will be opening
+	 * @param excludedShell The shell
+	 * @return boolean. <code>true</code> if it can open. Otherwise return false and
+	 *         set the dialog to tick.
 	 */
-	public static boolean safeToOpen(ProgressMonitorJobsDialog dialog,
-			Shell excludedShell) {
+	public static boolean safeToOpen(ProgressMonitorJobsDialog dialog, Shell excludedShell) {
 		Shell modal = getModalShellExcluding(excludedShell);
 		if (modal == null) {
 			return true;
@@ -423,11 +405,10 @@ public class ProgressManagerUtil {
 	}
 
 	/**
-	 * Return the modal shell that is currently open. If there isn't one then
-	 * return null. If there are stacked modal shells, return the top one.
+	 * Return the modal shell that is currently open. If there isn't one then return
+	 * null. If there are stacked modal shells, return the top one.
 	 *
-	 * @param shell
-	 *            A shell to exclude from the search. May be <code>null</code>.
+	 * @param shell A shell to exclude from the search. May be <code>null</code>.
 	 *
 	 * @return Shell or <code>null</code>.
 	 */
@@ -436,8 +417,7 @@ public class ProgressManagerUtil {
 
 		// If shell is null or disposed, then look through all shells
 		if (shell == null || shell.isDisposed()) {
-			return getModalChildExcluding(PlatformUI.getWorkbench()
-					.getDisplay().getShells(), shell);
+			return getModalChildExcluding(PlatformUI.getWorkbench().getDisplay().getShells(), shell);
 		}
 
 		// Start with the shell to exclude and check it's shells
@@ -445,16 +425,15 @@ public class ProgressManagerUtil {
 	}
 
 	/**
-	 * Return the modal shell that is currently open. If there isn't one then
-	 * return null.
+	 * Return the modal shell that is currently open. If there isn't one then return
+	 * null.
 	 *
-	 * @param toSearch shells to search for modal children
+	 * @param toSearch  shells to search for modal children
 	 * @param toExclude shell to ignore
 	 * @return the most specific modal child, or null if none
 	 */
 	private static Shell getModalChildExcluding(Shell[] toSearch, Shell toExclude) {
-		int modal = SWT.APPLICATION_MODAL | SWT.SYSTEM_MODAL
-				| SWT.PRIMARY_MODAL;
+		int modal = SWT.APPLICATION_MODAL | SWT.SYSTEM_MODAL | SWT.PRIMARY_MODAL;
 
 		// Make sure we don't pick a parent that has a modal child (this can
 		// lock the app)
@@ -462,7 +441,7 @@ public class ProgressManagerUtil {
 
 		for (int i = toSearch.length - 1; i >= 0; i--) {
 			Shell shell = toSearch[i];
-			if(shell.equals(toExclude)) {
+			if (shell.equals(toExclude) || shell.isDisposed()) {
 				continue;
 			}
 
@@ -483,11 +462,11 @@ public class ProgressManagerUtil {
 	}
 
 	/**
-	 * Utility method to get the best parenting possible for a dialog. If there
-	 * is a modal shell return it so as to avoid two modal dialogs. If not then
-	 * return the shell of the active workbench window. If that shell is
-	 * <code>null</code> or not visible, then return the splash shell if still
-	 * visible. Otherwise return the shell of the active workbench window.
+	 * Utility method to get the best parenting possible for a dialog. If there is a
+	 * modal shell return it so as to avoid two modal dialogs. If not then return
+	 * the shell of the active workbench window. If that shell is <code>null</code>
+	 * or not visible, then return the splash shell if still visible. Otherwise
+	 * return the shell of the active workbench window.
 	 *
 	 * @return the best parent shell or <code>null</code>
 	 */
@@ -506,9 +485,7 @@ public class ProgressManagerUtil {
 			if (splashShell != null && splashShell.isVisible()) {
 				return splashShell;
 			}
-		} catch (IllegalAccessException e) {
-			// Use non-modal shell
-		} catch (InvocationTargetException e) {
+		} catch (IllegalAccessException | InvocationTargetException e) {
 			// Use non-modal shell
 		}
 
@@ -542,72 +519,16 @@ public class ProgressManagerUtil {
 		return null;
 	}
 
-	/**
-	 * Animate the closing of a window given the start position down to the
-	 * progress region.
-	 *
-	 * @param startPosition
-	 *            Rectangle. The position to start drawing from.
-	 */
-	public static void animateDown(Rectangle startPosition) {
-		IWorkbenchWindow currentWindow = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow();
-		if (currentWindow == null) {
-			return;
-		}
-		WorkbenchWindow internalWindow = (WorkbenchWindow) currentWindow;
-
-		ProgressRegion progressRegion = internalWindow.getProgressRegion();
-		if (progressRegion == null) {
-			return;
-		}
-		Rectangle endPosition = progressRegion.getControl().getBounds();
-
-		Point windowLocation = internalWindow.getShell().getLocation();
-		endPosition.x += windowLocation.x;
-		endPosition.y += windowLocation.y;
-
-		// animate the progress dialog's removal
-		AnimationEngine.createTweakedAnimation(internalWindow.getShell(), 400, startPosition, endPosition);
-	}
 
 	/**
-	 * Animate the opening of a window given the start position down to the
-	 * progress region.
-	 *
-	 * @param endPosition
-	 *            Rectangle. The position to end drawing at.
-	 */
-	public static void animateUp(Rectangle endPosition) {
-		IWorkbenchWindow currentWindow = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow();
-		if (currentWindow == null) {
-			return;
-		}
-		WorkbenchWindow internalWindow = (WorkbenchWindow) currentWindow;
-		Point windowLocation = internalWindow.getShell().getLocation();
-
-		ProgressRegion progressRegion = internalWindow.getProgressRegion();
-		if (progressRegion == null) {
-			return;
-		}
-		Rectangle startPosition = progressRegion.getControl().getBounds();
-		startPosition.x += windowLocation.x;
-		startPosition.y += windowLocation.y;
-
-		// animate the progress dialog's arrival
-		AnimationEngine.createTweakedAnimation(internalWindow.getShell(), 400, startPosition, endPosition);
-	}
-
-	/**
-	 * Get the shell provider to use in the progress support dialogs. This
-	 * provider will try to always parent off of an existing modal shell. If
-	 * there isn't one it will use the current workbench window.
+	 * Get the shell provider to use in the progress support dialogs. This provider
+	 * will try to always parent off of an existing modal shell. If there isn't one
+	 * it will use the current workbench window.
 	 *
 	 * @return IShellProvider
 	 */
 	static IShellProvider getShellProvider() {
-		return () -> getDefaultParent();
+		return ProgressManagerUtil::getDefaultParent;
 	}
 
 	/**
@@ -616,8 +537,7 @@ public class ProgressManagerUtil {
 	 * @return URL
 	 */
 	public static URL getIconsRoot() {
-		return BundleUtility.find(PlatformUI.PLUGIN_ID,
-				ProgressManager.PROGRESS_FOLDER);
+		return BundleUtility.find(PlatformUI.PLUGIN_ID, ProgressManager.PROGRESS_FOLDER);
 	}
 
 	/**
