@@ -17,14 +17,19 @@
 package org.eclipse.ui.internal.quickaccess;
 
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
-import java.util.LinkedList;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
+import java.util.function.Function;
+import java.util.stream.Collectors;
 import org.eclipse.core.commands.Command;
 import org.eclipse.core.runtime.Adapters;
 import org.eclipse.core.runtime.Assert;
-import org.eclipse.e4.core.commands.ExpressionContext;
 import org.eclipse.e4.ui.model.application.MApplication;
 import org.eclipse.e4.ui.model.application.ui.basic.MWindow;
 import org.eclipse.jface.bindings.TriggerSequence;
@@ -42,6 +47,7 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.BusyIndicator;
 import org.eclipse.swt.events.KeyAdapter;
 import org.eclipse.swt.events.KeyEvent;
+import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.graphics.FontMetrics;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Point;
@@ -61,6 +67,7 @@ import org.eclipse.ui.internal.progress.ProgressManagerUtil;
 import org.eclipse.ui.internal.quickaccess.providers.ActionProvider;
 import org.eclipse.ui.internal.quickaccess.providers.CommandProvider;
 import org.eclipse.ui.internal.quickaccess.providers.EditorProvider;
+import org.eclipse.ui.internal.quickaccess.providers.HelpSearchProvider;
 import org.eclipse.ui.internal.quickaccess.providers.PerspectiveProvider;
 import org.eclipse.ui.internal.quickaccess.providers.PreferenceProvider;
 import org.eclipse.ui.internal.quickaccess.providers.PropertiesProvider;
@@ -81,10 +88,10 @@ public class QuickAccessDialog extends PopupDialog {
 	private Command invokingCommand;
 	private QuickAccessContents contents;
 	private KeyAdapter keyAdapter;
+	private Set<ModifyListener> toRemoveTextListeners;
 	private Text filterText;
 	private IWorkbenchWindow window;
-	private LinkedList<QuickAccessElement> previousPicksList = new LinkedList<>();
-	private static final String TEXT_ARRAY = "textArray"; //$NON-NLS-1$
+	private static final String USER_INPUT_TEXTS = "textArray"; //$NON-NLS-1$
 	private static final String TEXT_ENTRIES = "textEntries"; //$NON-NLS-1$
 	private static final String ORDERED_PROVIDERS = "orderedProviders"; //$NON-NLS-1$
 	private static final String ORDERED_ELEMENTS = "orderedElements"; //$NON-NLS-1$
@@ -92,13 +99,13 @@ public class QuickAccessDialog extends PopupDialog {
 	static final int MAXIMUM_NUMBER_OF_TEXT_ENTRIES_PER_ELEMENT = 3;
 	protected Map<QuickAccessElement, ArrayList<String>> textMap = new HashMap<>();
 	protected Map<String, QuickAccessElement> elementMap = new HashMap<>();
-	protected Map<String, QuickAccessProvider> providerMap;
 	private final Display display;
 	private String lastSelectionFilter = ""; //$NON-NLS-1$
+	private PreviousPicksProvider previousPicksProvider;
 
-	public QuickAccessDialog(final IWorkbenchWindow window, final Command invokingCommand) {
+	public QuickAccessDialog(IWorkbenchWindow window, Command invokingCommand) {
 		super(ProgressManagerUtil.getDefaultParent(), SWT.RESIZE, true, true, // persist
-																				// size
+				// size
 				false, // but not location
 				true, true, QuickAccessMessages.QuickAccessContents_QuickAccess,
 				QuickAccessMessages.QuickAccess_StartTypingToFindMatches);
@@ -109,9 +116,11 @@ public class QuickAccessDialog extends PopupDialog {
 
 		BusyIndicator.showWhile(window.getShell() == null ? null : window.getShell().getDisplay(), () -> {
 			final CommandProvider commandProvider = new CommandProvider();
-			commandProvider.setSnapshot(new ExpressionContext(model.getContext().getActiveLeaf()));
+			commandProvider.setContext(model.getContext().getActiveLeaf());
 			List<QuickAccessProvider> providers = new ArrayList<>();
-			providers.add(new PreviousPicksProvider(previousPicksList));
+			previousPicksProvider = new PreviousPicksProvider(MAXIMUM_NUMBER_OF_ELEMENTS);
+			previousPicksProvider.setElementsInitializer(() -> restorePreviousEntries(providers));
+			providers.add(previousPicksProvider);
 			providers.add(new EditorProvider());
 			providers.add(new ViewProvider(model.getContext().get(MApplication.class), model));
 			providers.add(new PerspectiveProvider());
@@ -129,10 +138,12 @@ public class QuickAccessDialog extends PopupDialog {
 					});
 				}
 			}));
-			providerMap = new HashMap<>();
-			for (QuickAccessProvider provider : providers) {
-				providerMap.put(provider.getId(), provider);
-			}
+			providers.add(new HelpSearchProvider());
+
+			Collection<String> previousPickProviderIds = getPreviousPickProviderIds(getDialogSettings());
+			previousPicksProvider.setInvolvedProviders(
+					providers.stream().filter(provider -> previousPickProviderIds.contains(provider.getId()))
+							.collect(Collectors.toSet()));
 			QuickAccessDialog.this.contents = new QuickAccessContents(
 					providers.toArray(new QuickAccessProvider[providers.size()])) {
 				@Override
@@ -155,63 +166,27 @@ public class QuickAccessDialog extends PopupDialog {
 				 * @param element
 				 */
 				void addPreviousPick(String text, QuickAccessElement element) {
-					// previousPicksList:
-					// Remove element from previousPicksList so
-					// there are no duplicates
-					// If list is max size, remove last(oldest)
-					// element
-					// Remove entries for removed element from
-					// elementMap and textMap
-					// Add element to front of previousPicksList
-					previousPicksList.remove(element);
-					if (previousPicksList.size() == MAXIMUM_NUMBER_OF_ELEMENTS) {
-						QuickAccessElement removedElement = previousPicksList.removeLast();
+					previousPicksProvider.addPreviousPick(element, removedElement -> {
 						ArrayList<String> removedList = textMap.remove(removedElement);
-						for (int i = 0; i < removedList.size(); i++) {
-							elementMap.remove(removedList.get(i));
-						}
-					}
-					previousPicksList.addFirst(element);
-
-					// textMap:
-					// Get list of strings for element from textMap
-					// Create new list for element if there isn't
-					// one and put
-					// element->textList in textMap
-					// Remove rememberedText from list
-					// If list is max size, remove first(oldest)
-					// string
-					// Remove text from elementMap
-					// Add rememberedText to list of strings for
-					// element in textMap
-					ArrayList<String> textList = textMap.get(element);
-					if (textList == null) {
-						textList = new ArrayList<>();
-						textMap.put(element, textList);
-					}
-
+						removedList.forEach(elementMap::remove);
+					});
+					ArrayList<String> textList = textMap.computeIfAbsent(element, key -> new ArrayList<>());
 					textList.remove(text);
 					if (textList.size() == MAXIMUM_NUMBER_OF_TEXT_ENTRIES_PER_ELEMENT) {
-						Object removedText = textList.remove(0);
+						String removedText = textList.remove(0);
 						elementMap.remove(removedText);
 					}
 
-					if (text.length() > 0) {
+					if (!text.isEmpty()) {
 						textList.add(text);
-
-						// elementMap:
-						// Put rememberedText->element in elementMap
-						// If it replaced a different element update
-						// textMap and
-						// PreviousPicksList
-						Object replacedElement = elementMap.put(text, element);
+						QuickAccessElement replacedElement = elementMap.put(text, element);
 						if (replacedElement != null && !replacedElement.equals(element)) {
 							textList = textMap.get(replacedElement);
 							if (textList != null) {
 								textList.remove(text);
 								if (textList.isEmpty()) {
 									textMap.remove(replacedElement);
-									previousPicksList.remove(replacedElement);
+									previousPicksProvider.removeElement(replacedElement);
 								}
 							}
 						}
@@ -220,8 +195,7 @@ public class QuickAccessDialog extends PopupDialog {
 
 				@Override
 				protected QuickAccessElement getPerfectMatch(String filter) {
-					QuickAccessElement perfectMatch = elementMap.get(filter);
-					return perfectMatch;
+					return elementMap.get(filter);
 				}
 
 				@Override
@@ -236,36 +210,32 @@ public class QuickAccessDialog extends PopupDialog {
 						 * EclipseContext is in place.
 						 */
 						final QuickAccessElement element = (QuickAccessElement) selectedElement;
-						window.getShell().getDisplay().asyncExec(() -> element.execute());
+						window.getShell().getDisplay().asyncExec(element::execute);
 					}
 				}
 			};
-			restoreDialog();
 			QuickAccessDialog.this.invokingCommand = invokingCommand;
 			if (QuickAccessDialog.this.invokingCommand != null && !QuickAccessDialog.this.invokingCommand.isDefined()) {
 				QuickAccessDialog.this.invokingCommand = null;
 			} else {
-				// Pre-fetch key sequence - do not change because
-				// scope will
-				// change later.
+// Pre-fetch key sequence - do not change because
+// scope will
+// change later.
 				getInvokingCommandKeySequences();
 			}
-			// create early
+// create early
 			create();
 		});
-		QuickAccessDialog.this.contents.refresh(""); //$NON-NLS-1$
+		QuickAccessDialog.this.contents.updateProposals(""); //$NON-NLS-1$
 	}
 
 	@Override
 	protected Control createTitleControl(Composite parent) {
 		parent.getShell().setText(QuickAccessMessages.QuickAccessContents_QuickAccess);
 		filterText = new Text(parent, SWT.NONE);
-
 		GridDataFactory.fillDefaults().align(SWT.FILL, SWT.CENTER).grab(true, false).applyTo(filterText);
-
 		contents.hookFilterText(filterText);
 		filterText.addKeyListener(getKeyAdapter());
-
 		return filterText;
 	}
 
@@ -286,7 +256,7 @@ public class QuickAccessDialog extends PopupDialog {
 		return composite;
 	}
 
-	final protected TriggerSequence[] getInvokingCommandKeySequences() {
+	private TriggerSequence[] getInvokingCommandKeySequences() {
 		if (invokingCommandKeySequences == null) {
 			if (invokingCommand != null) {
 				IBindingService bindingService = Adapters.adapt(window.getWorkbench(), IBindingService.class);
@@ -327,6 +297,14 @@ public class QuickAccessDialog extends PopupDialog {
 
 	@Override
 	public boolean close() {
+		if (!filterText.isDisposed()) {
+			filterText.removeKeyListener(getKeyAdapter());
+			if (toRemoveTextListeners != null) {
+				for (ModifyListener listener : toRemoveTextListeners) {
+					filterText.removeModifyListener(listener);
+				}
+			}
+		}
 		storeDialog(getDialogSettings());
 		return super.close();
 	}
@@ -366,68 +344,102 @@ public class QuickAccessDialog extends PopupDialog {
 		return result;
 	}
 
-	protected String getId() {
+	protected static String getId() {
 		return "org.eclipse.ui.internal.QuickAccess"; //$NON-NLS-1$
 	}
 
 	private void storeDialog(IDialogSettings dialogSettings) {
-		String[] orderedElements = new String[previousPicksList.size()];
-		String[] orderedProviders = new String[previousPicksList.size()];
-		String[] textEntries = new String[previousPicksList.size()];
-		ArrayList<String> arrayList = new ArrayList<>();
-		for (int i = 0; i < orderedElements.length; i++) {
-			QuickAccessElement quickAccessElement = previousPicksList.get(i);
-			ArrayList<String> elementText = textMap.get(quickAccessElement);
-			Assert.isNotNull(elementText);
-			orderedElements[i] = quickAccessElement.getId();
-			orderedProviders[i] = contents.getProviderFor(quickAccessElement).getId();
-			arrayList.addAll(elementText);
-			textEntries[i] = elementText.size() + ""; //$NON-NLS-1$
+		if (previousPicksProvider.elements != null) {
+			String[] orderedElements = new String[previousPicksProvider.elements.size()];
+			String[] orderedProviders = new String[previousPicksProvider.elements.size()];
+			String[] textEntries = new String[previousPicksProvider.elements.size()];
+			ArrayList<String> arrayList = new ArrayList<>();
+			for (int i = 0; i < orderedElements.length; i++) {
+				QuickAccessElement quickAccessElement = previousPicksProvider.elements.get(i);
+				ArrayList<String> elementText = textMap.get(quickAccessElement);
+				Assert.isNotNull(elementText);
+				orderedElements[i] = quickAccessElement.getId();
+				orderedProviders[i] = contents.getProviderFor(quickAccessElement).getId();
+				arrayList.addAll(elementText);
+				textEntries[i] = Integer.toString(elementText.size());
+			}
+			String[] textArray = arrayList.toArray(new String[arrayList.size()]);
+			dialogSettings.put(ORDERED_ELEMENTS, orderedElements);
+			dialogSettings.put(ORDERED_PROVIDERS, orderedProviders);
+			dialogSettings.put(TEXT_ENTRIES, textEntries);
+			dialogSettings.put(USER_INPUT_TEXTS, textArray);
 		}
-		String[] textArray = arrayList.toArray(new String[arrayList.size()]);
-		dialogSettings.put(ORDERED_ELEMENTS, orderedElements);
-		dialogSettings.put(ORDERED_PROVIDERS, orderedProviders);
-		dialogSettings.put(TEXT_ENTRIES, textEntries);
-		dialogSettings.put(TEXT_ARRAY, textArray);
 	}
 
-	private void restoreDialog() {
+	private List<QuickAccessElement> restorePreviousEntries(Collection<QuickAccessProvider> providers) {
 		IDialogSettings dialogSettings = getDialogSettings();
-		if (dialogSettings != null) {
-			String[] orderedElements = dialogSettings.getArray(ORDERED_ELEMENTS);
-			String[] orderedProviders = dialogSettings.getArray(ORDERED_PROVIDERS);
-			String[] textEntries = dialogSettings.getArray(TEXT_ENTRIES);
-			String[] textArray = dialogSettings.getArray(TEXT_ARRAY);
-			elementMap = new HashMap<>();
-			textMap = new HashMap<>();
-			previousPicksList = new LinkedList<>();
-			if (orderedElements != null && orderedProviders != null && textEntries != null && textArray != null) {
-				int arrayIndex = 0;
-				for (int i = 0; i < orderedElements.length; i++) {
-					QuickAccessProvider quickAccessProvider = providerMap.get(orderedProviders[i]);
-					int numTexts = Integer.parseInt(textEntries[i]);
-					if (quickAccessProvider != null) {
-						QuickAccessElement quickAccessElement = quickAccessProvider.getElementForId(orderedElements[i]);
-						if (quickAccessElement != null) {
-							contents.registerProviderFor(quickAccessElement, quickAccessProvider);
-							ArrayList<String> arrayList = new ArrayList<>();
-							for (int j = arrayIndex; j < arrayIndex + numTexts; j++) {
-								String text = textArray[j];
-								// text length can be zero for old workspaces,
-								// see bug 190006
-								if (text.length() > 0) {
-									arrayList.add(text);
-									elementMap.put(text, quickAccessElement);
-								}
+		if (dialogSettings == null) {
+			return Collections.emptyList();
+		}
+		List<QuickAccessElement> res = new ArrayList<>();
+		String[] orderedElements = dialogSettings.getArray(ORDERED_ELEMENTS);
+		String[] orderedProviders = dialogSettings.getArray(ORDERED_PROVIDERS);
+		String[] rawTextEntriesCountByElement = dialogSettings.getArray(TEXT_ENTRIES);
+		String[] userInputTexts = dialogSettings.getArray(USER_INPUT_TEXTS);
+		elementMap = new HashMap<>();
+		textMap = new HashMap<>();
+		if (orderedElements != null && orderedProviders != null && rawTextEntriesCountByElement != null
+				&& userInputTexts != null) {
+			Map<String, QuickAccessProvider> providerMap = providers.stream()
+					.collect(Collectors.toMap(QuickAccessProvider::getId, Function.identity()));
+			Integer[] textEntriesCountByElement = Arrays.stream(rawTextEntriesCountByElement).map(Integer::parseInt)
+					.toArray(Integer[]::new);
+			int inputTextIndex = 0;
+			for (int i = 0; i < orderedElements.length; i++) {
+				int numberOfMatchingTextsForCurrentElement = textEntriesCountByElement[i].intValue();
+				QuickAccessProvider quickAccessProvider = providerMap.get(orderedProviders[i]);
+				if (quickAccessProvider != null) {
+					String firstText = null;
+					if (inputTextIndex < userInputTexts.length && numberOfMatchingTextsForCurrentElement >= 1) {
+						firstText = userInputTexts[inputTextIndex];
+					}
+					QuickAccessElement quickAccessElement = quickAccessProvider.findElement(orderedElements[i],
+							firstText);
+					if (quickAccessElement != null) {
+						contents.registerProviderFor(quickAccessElement, quickAccessProvider);
+						ArrayList<String> matchingTextsForElement = new ArrayList<>();
+						for (int j = inputTextIndex; j < inputTextIndex
+								+ numberOfMatchingTextsForCurrentElement; j++) {
+							String text = userInputTexts[j];
+							// text length can be zero for old workspaces,
+							// see bug 190006
+							if (!text.isEmpty()) {
+								matchingTextsForElement.add(text);
+								elementMap.put(text, quickAccessElement);
 							}
-							textMap.put(quickAccessElement, arrayList);
-							previousPicksList.add(quickAccessElement);
 						}
+						textMap.put(quickAccessElement, matchingTextsForElement);
+						res.add(quickAccessElement);
 					}
-					arrayIndex += numTexts;
 				}
+				inputTextIndex += numberOfMatchingTextsForCurrentElement;
 			}
 		}
+		return res;
+	}
+
+	/**
+	 * @param dialogSettings
+	 * @return
+	 */
+	private Collection<String> getPreviousPickProviderIds(IDialogSettings dialogSettings) {
+		if (dialogSettings == null) {
+			return Collections.emptySet();
+		}
+		String[] orderedProviders = dialogSettings.getArray(ORDERED_PROVIDERS);
+		if (orderedProviders == null) {
+			return Collections.emptySet();
+		}
+		return new HashSet<>(Arrays.asList(orderedProviders));
+	}
+
+	public QuickAccessContents getQuickAccessContents() {
+		return this.contents;
 	}
 
 }
