@@ -18,7 +18,6 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.registry;
 
-import com.ibm.icu.text.Collator;
 import java.io.BufferedReader;
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -28,10 +27,10 @@ import java.io.StringReader;
 import java.io.StringWriter;
 import java.io.Writer;
 import java.nio.charset.StandardCharsets;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -155,7 +154,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 	/*
 	 * Compares the labels from two IEditorDescriptor objects
 	 */
-	private static final Comparator<IEditorDescriptor> comparer = new Comparator<IEditorDescriptor>() {
+	private static final Comparator<IEditorDescriptor> comparer = new Comparator<>() {
 		private Collator collator = Collator.getInstance();
 
 		@Override
@@ -496,7 +495,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 	public IEditorDescriptor[] getSortedEditorsFromPlugins() {
 		// see #comparer
 		Collection<IEditorDescriptor> descs = WorkbenchActivityHelper.restrictCollection(sortedEditorsFromPlugins,
-				new ArrayList<IEditorDescriptor>());
+				new ArrayList<>());
 		return descs.toArray(new IEditorDescriptor[descs.size()]);
 	}
 
@@ -589,7 +588,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 	 * @param defaultEditors the default editors to set
 	 */
 	private void setProductDefaults(String defaultEditors) {
-		if (defaultEditors == null || defaultEditors.length() == 0) {
+		if (defaultEditors == null || defaultEditors.isEmpty()) {
 			return;
 		}
 
@@ -638,7 +637,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 		try {
 			// Get the editors defined in the preferences store
 			String xmlString = store.getString(IPreferenceConstants.EDITORS);
-			if (xmlString == null || xmlString.length() == 0) {
+			if (xmlString == null || xmlString.isEmpty()) {
 				stream = new FileInputStream(
 						workbenchStatePath.append(IWorkbenchConstants.EDITOR_FILE_NAME).toOSString());
 				reader = new BufferedReader(new InputStreamReader(stream, StandardCharsets.UTF_8));
@@ -738,8 +737,6 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 	 */
 	public void readResources(Map<String, IEditorDescriptor> editorTable, Reader reader) throws WorkbenchException {
 		XMLMemento memento = XMLMemento.createReadRoot(reader);
-		String versionString = memento.getString(IWorkbenchConstants.TAG_VERSION);
-		boolean versionIs31 = "3.1".equals(versionString); //$NON-NLS-1$
 
 		for (IMemento childMemento : memento.getChildren(IWorkbenchConstants.TAG_INFO)) {
 			List<IEditorDescriptor> editors = getEditorDescriptors(
@@ -774,18 +771,8 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 						childMemento.getChildren(IWorkbenchConstants.TAG_DELETED_EDITOR), editorTable);
 
 				List<IEditorDescriptor> defaultEditors = null;
-				if (versionIs31) { // parse the new format
-					defaultEditors = getEditorDescriptors(
-							childMemento.getChildren(IWorkbenchConstants.TAG_DEFAULT_EDITOR), editorTable);
-				} else { // guess at pre 3.1 format defaults
-					defaultEditors = new ArrayList<>(
-							(editors.isEmpty() ? 0 : 1) + mapping.getDeclaredDefaultEditors().length);
-					if (!editors.isEmpty()) {
-						IEditorDescriptor editor = editors.get(0);
-						defaultEditors.add(editor);
-					}
-					defaultEditors.addAll(Arrays.asList(mapping.getDeclaredDefaultEditors()));
-				}
+				defaultEditors = getEditorDescriptors(childMemento.getChildren(IWorkbenchConstants.TAG_DEFAULT_EDITOR),
+						editorTable);
 
 				// Add any new editors that have already been read from the registry
 				// which were not deleted.
@@ -859,7 +846,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 		try {
 			// Get the resource types
 			String xmlString = store.getString(IPreferenceConstants.RESOURCES);
-			if (xmlString == null || xmlString.length() == 0) {
+			if (xmlString == null || xmlString.isEmpty()) {
 				stream = new FileInputStream(
 						workbenchStatePath.append(IWorkbenchConstants.RESOURCE_TYPE_FILE_NAME).toOSString());
 				reader = new BufferedReader(new InputStreamReader(stream, StandardCharsets.UTF_8));
@@ -919,7 +906,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 	 */
 	private String mappingKeyFor(FileEditorMapping mapping) {
 		return mappingKeyFor(
-				mapping.getName() + (mapping.getExtension().length() == 0 ? "" : "." + mapping.getExtension())); //$NON-NLS-1$ //$NON-NLS-2$
+				mapping.getName() + (mapping.getExtension().isEmpty() ? "" : "." + mapping.getExtension())); //$NON-NLS-1$ //$NON-NLS-2$
 	}
 
 	/**
@@ -1078,7 +1065,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 		IEditorDescriptor[] array = new IEditorDescriptor[unsortedList.size()];
 		unsortedList.toArray(array);
 
-		Collections.sort(Arrays.asList(array), comparer);
+		Arrays.asList(array).sort(comparer);
 		return array;
 	}
 
@@ -1090,9 +1077,7 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 	private void sortInternalEditors() {
 		IEditorDescriptor[] array = sortEditors(sortedEditorsFromPlugins);
 		sortedEditorsFromPlugins = new ArrayList<>();
-		for (IEditorDescriptor element : array) {
-			sortedEditorsFromPlugins.add(element);
-		}
+		sortedEditorsFromPlugins.addAll(Arrays.asList(array));
 	}
 
 	/**
@@ -1454,12 +1439,12 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 		if (type != null) {
 			// now add any objects directly related to the content type
 			IEditorDescriptor[] related = registry.getRelatedObjects(type);
-			for (int i = 0; i < related.length; i++) {
+			for (IEditorDescriptor r : related) {
 				// we don't want to return duplicates
-				if (!allRelated.contains(related[i])) {
+				if (!allRelated.contains(r)) {
 					// if it's not filtered, add it to the list
-					if (!WorkbenchActivityHelper.filterItem(related[i])) {
-						allRelated.add(related[i]);
+					if (!WorkbenchActivityHelper.filterItem(r)) {
+						allRelated.add(r);
 					}
 				}
 			}
@@ -1470,12 +1455,12 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 			// now add any indirectly related objects, walking up the content type hierarchy
 			while ((type = type.getBaseType()) != null) {
 				IEditorDescriptor[] related = registry.getRelatedObjects(type);
-				for (int i = 0; i < related.length; i++) {
+				for (IEditorDescriptor r : related) {
 					// we don't want to return duplicates
-					if (!allRelated.contains(related[i])) {
+					if (!allRelated.contains(r)) {
 						// if it's not filtered, add it to the list
-						if (!WorkbenchActivityHelper.filterItem(related[i])) {
-							allRelated.add(related[i]);
+						if (!WorkbenchActivityHelper.filterItem(r)) {
+							allRelated.add(r);
 						}
 					}
 				}
@@ -1508,26 +1493,25 @@ public class EditorRegistry extends EventManager implements IEditorRegistry, IEx
 		}
 
 		IEditorDescriptor[] related = relatedRegistry.getRelatedObjects(type);
-		for (int i = 0; i < related.length; i++) {
+		for (IEditorDescriptor r : related) {
 			// we don't want to return duplicates
-			if (!allRelated.contains(related[i])) {
+			if (!allRelated.contains(r)) {
 				// if it's not filtered, add it to the list
-				if (!WorkbenchActivityHelper.filterItem(related[i])) {
-					allRelated.add(related[i]);
+				if (!WorkbenchActivityHelper.filterItem(r)) {
+					allRelated.add(r);
 				}
-
 			}
 		}
 
 		// now add any indirectly related objects, walking up the content type hierarchy
 		while ((type = type.getBaseType()) != null) {
 			related = relatedRegistry.getRelatedObjects(type);
-			for (int i = 0; i < related.length; i++) {
+			for (IEditorDescriptor r : related) {
 				// we don't want to return duplicates
-				if (!allRelated.contains(related[i])) {
+				if (!allRelated.contains(r)) {
 					// if it's not filtered, add it to the list
-					if (!WorkbenchActivityHelper.filterItem(related[i])) {
-						allRelated.add(related[i]);
+					if (!WorkbenchActivityHelper.filterItem(r)) {
+						allRelated.add(r);
 					}
 				}
 			}
