@@ -110,7 +110,7 @@ public class InternalDialog extends TrayDialog {
 	 */
 	private TableViewer statusListViewer;
 	/**
-	 * Composite on the left bottom corner. Allows for opening support tray & Error
+	 * Composite on the left bottom corner. Allows for opening support tray &amp; Error
 	 * Log.
 	 */
 	private Composite linkComposite;
@@ -142,13 +142,13 @@ public class InternalDialog extends TrayDialog {
 
 	private DetailsAreaManager detailsManager;
 
-	private Map dialogState;
+	private Map<Object, Object> dialogState;
 
 	/**
 	 * @param dialogState
 	 * @param modal
 	 */
-	public InternalDialog(final Map dialogState, boolean modal) {
+	public InternalDialog(final Map<Object, Object> dialogState, boolean modal) {
 		super(ProgressManagerUtil.getDefaultParent());
 		this.dialogState = dialogState;
 		supportTray = new SupportTray(dialogState, event -> {
@@ -307,11 +307,6 @@ public class InternalDialog extends TrayDialog {
 			if (getBooleanValue(IStatusDialogConstants.TRAY_OPENED)) {
 				openTray();
 			}
-		} else {
-			if (getBooleanValue(IStatusDialogConstants.ANIMATION)) {
-				Rectangle shellPosition = getShell().getBounds();
-				ProgressManagerUtil.animateUp(shellPosition);
-			}
 		}
 		return result;
 	}
@@ -654,9 +649,6 @@ public class InternalDialog extends TrayDialog {
 		dialogState.put(IStatusDialogConstants.SHELL_BOUNDS, getShell().getBounds());
 		statusListViewer = null;
 		boolean result = super.close();
-		if (!modalitySwitch && getBooleanValue(IStatusDialogConstants.ANIMATION)) {
-			ProgressManagerUtil.animateDown(getShellBounds());
-		}
 		return result;
 	}
 
@@ -725,7 +717,7 @@ public class InternalDialog extends TrayDialog {
 		}
 		/* check handling hint and display link if it is expected */
 		boolean shouldDisplay = false;
-		Iterator it = ((Collection) dialogState.get(IStatusDialogConstants.STATUS_ADAPTERS)).iterator();
+		Iterator<?> it = ((Collection<?>) dialogState.get(IStatusDialogConstants.STATUS_ADAPTERS)).iterator();
 		while (it.hasNext()) {
 			StatusAdapter adapter = (StatusAdapter) it.next();
 			Integer hint = (Integer) adapter.getProperty(WorkbenchStatusDialogManagerImpl.HINT);
@@ -794,7 +786,7 @@ public class InternalDialog extends TrayDialog {
 
 			@Override
 			public Object[] getElements(Object inputElement) {
-				return ((Collection) dialogState.get(IStatusDialogConstants.STATUS_ADAPTERS)).toArray();
+				return ((Collection<?>) dialogState.get(IStatusDialogConstants.STATUS_ADAPTERS)).toArray();
 			}
 
 			@Override
@@ -974,6 +966,6 @@ public class InternalDialog extends TrayDialog {
 	}
 
 	private boolean isMulti() {
-		return ((Collection) dialogState.get(IStatusDialogConstants.STATUS_ADAPTERS)).size() > 1;
+		return ((Collection<?>) dialogState.get(IStatusDialogConstants.STATUS_ADAPTERS)).size() > 1;
 	}
 }
