@@ -521,6 +521,8 @@ public class CommandContributionItem extends ContributionItem {
 			}
 		}
 
+		item.setToolTipText(tooltip);
+
 		if (item.getSelection() != checkedState) {
 			item.setSelection(checkedState);
 		}
@@ -544,7 +546,7 @@ public class CommandContributionItem extends ContributionItem {
 				try {
 					text = command.getCommand().getName();
 					tooltip = command.getCommand().getDescription();
-					if (tooltip == null || tooltip.trim().length() == 0) {
+					if (tooltip == null || tooltip.trim().isEmpty()) {
 						tooltip = text;
 					}
 				} catch (NotDefinedException e) {
@@ -781,16 +783,7 @@ public class CommandContributionItem extends ContributionItem {
 
 		try {
 			handlerService.executeCommand(command, event);
-		} catch (ExecutionException e) {
-			StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, "Failed to execute item " //$NON-NLS-1$
-					+ getId(), e));
-		} catch (NotDefinedException e) {
-			StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, "Failed to execute item " //$NON-NLS-1$
-					+ getId(), e));
-		} catch (NotEnabledException e) {
-			StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, "Failed to execute item " //$NON-NLS-1$
-					+ getId(), e));
-		} catch (NotHandledException e) {
+		} catch (ExecutionException | NotDefinedException | NotEnabledException | NotHandledException e) {
 			StatusManager.getManager().handle(StatusUtil.newStatus(IStatus.ERROR, "Failed to execute item " //$NON-NLS-1$
 					+ getId(), e));
 		}
