@@ -16,7 +16,6 @@ import java.util.Collection;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import org.eclipse.urischeme.IOperatingSystemRegistration;
@@ -31,10 +30,15 @@ public class RegistrationMacOsX implements IOperatingSystemRegistration {
 	private static final String UNREGISTER = "-u"; //$NON-NLS-1$
 	private static final String RECURSIVE = "-r"; //$NON-NLS-1$
 	private static final String DUMP = "-dump"; //$NON-NLS-1$
+	private static final String ANY_LINES = "(?:.*\\n)*"; //$NON-NLS-1$
+	private static final String TRAILING_HEX_VALUE_WITH_BRACKETS = "\\s\\(0x\\w*\\)"; //$NON-NLS-1$
+	private static final String PATH_WITH_CAPTURING_GROUP = "path:\\s*(.*)"; //$NON-NLS-1$
 
 	private IFileProvider fileProvider;
 	private IProcessExecutor processExecutor;
 
+	private String lsRegisterOutput = null;
+
 	public RegistrationMacOsX() {
 		this(new FileProvider(), new ProcessExecutor());
 	}
@@ -45,8 +49,7 @@ public class RegistrationMacOsX implements IOperatingSystemRegistration {
 	}
 
 	@Override
-	public void handleSchemes(Collection<IScheme> toAdd, Collection<IScheme> toRemove)
-			throws Exception {
+	public void handleSchemes(Collection<IScheme> toAdd, Collection<IScheme> toRemove) throws Exception {
 		String pathToEclipseApp = getPathToEclipseApp();
 
 		changePlistFile(toAdd, toRemove, pathToEclipseApp);
@@ -58,17 +61,13 @@ public class RegistrationMacOsX implements IOperatingSystemRegistration {
 	public List<ISchemeInformation> getSchemesInformation(Collection<IScheme> schemes) throws Exception {
 		List<ISchemeInformation> returnList = new ArrayList<>();
 
-		String lsRegisterOutput = processExecutor.execute(LSREGISTER, DUMP);
-
-		String[] lsRegisterEntries = lsRegisterOutput.split("-{80}\n"); //$NON-NLS-1$
-
+		String eclipseLauncher = getEclipseLauncher();
 		for (IScheme scheme : schemes) {
 
-			SchemeInformation schemeInfo = new SchemeInformation(scheme.getName(),
-					scheme.getDescription());
+			SchemeInformation schemeInfo = new SchemeInformation(scheme.getName(), scheme.getDescription());
 
-			String location = determineHandlerLocation(lsRegisterEntries, scheme.getName());
-			if (location != "" && getEclipseLauncher().startsWith(location)) { //$NON-NLS-1$
+			String location = determineHandlerLocation(getLsRegisterOutput(), scheme.getName());
+			if (!location.isEmpty() && eclipseLauncher.startsWith(location)) {
 				schemeInfo.setHandled(true);
 			}
 			schemeInfo.setHandlerLocation(location);
@@ -78,26 +77,48 @@ public class RegistrationMacOsX implements IOperatingSystemRegistration {
 		return returnList;
 	}
 
-	private String determineHandlerLocation(String[] lsRegisterEntries, String scheme) throws Exception {
+	private String getLsRegisterOutput() throws Exception {
+		if (this.lsRegisterOutput != null) {
+			return this.lsRegisterOutput;
+		}
+		this.lsRegisterOutput = processExecutor.execute(LSREGISTER, DUMP);
+		return this.lsRegisterOutput;
+	}
 
-		List<String> splitList = Stream.of(lsRegisterEntries). //
-				parallel().//
-				filter(s -> s.startsWith("BundleClass")).// //$NON-NLS-1$
-				filter(s -> s.contains(scheme + ":")).// //$NON-NLS-1$
-				collect(Collectors.toList());
+	private String determineHandlerLocation(String lsRegisterDump, String scheme) throws Exception {
+
+		String[] lsRegisterEntries = lsRegisterDump.split("-{80}\n"); //$NON-NLS-1$
+		String keyOfFirstLine;
+		String keyOfSchemeList;
+
+		if (Stream.of(lsRegisterEntries).parallel().anyMatch(s -> s.startsWith("BundleClass:"))) { //$NON-NLS-1$
+			// pre macOS 10.15.3
+			keyOfFirstLine = "BundleClass"; //$NON-NLS-1$
+			keyOfSchemeList = "bindings:"; //$NON-NLS-1$
+		} else {
+			// starting with macOS 10.15.3
+			keyOfFirstLine = "bundle id"; //$NON-NLS-1$
+			keyOfSchemeList = "claimed schemes:"; //$NON-NLS-1$
+
+		}
 
-		String lines = "(?:.*\\n)*"; //$NON-NLS-1$
 		Pattern pattern = Pattern.compile(
-				"^" + lines + "\\spath:\\s*(.*)\\n" + lines + "\\s*bindings:.*" + scheme + ":", //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
+				"^" + ANY_LINES + "\\s*" + PATH_WITH_CAPTURING_GROUP + "\\n" + ANY_LINES + "\\s*" //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
+						+ keyOfSchemeList
+						+ ".*" //$NON-NLS-1$
+						+ Pattern.quote(scheme) + ":", //$NON-NLS-1$
 				Pattern.MULTILINE);
 
-		for (String entry : splitList) {
-			Matcher matcher = pattern.matcher(entry);
-			if (matcher.find()) {
-				return matcher.group(1);
-			}
-		}
-		return ""; //$NON-NLS-1$
+		String path = Stream.of(lsRegisterEntries). //
+				parallel().//
+				filter(s -> s.startsWith(keyOfFirstLine)).//
+				filter(s -> s.contains(scheme + ":")).// //$NON-NLS-1$
+				map(pattern::matcher).//
+				filter(Matcher::find).//
+				map(m -> m.group(1)).findFirst().map(s -> s.replaceFirst(TRAILING_HEX_VALUE_WITH_BRACKETS, "")) //$NON-NLS-1$
+				.orElse(""); //$NON-NLS-1$
+
+		return path;
 	}
 
 	private PlistFileWriter getPlistFileWriter(String plistPath) throws IOException {
@@ -114,8 +135,8 @@ public class RegistrationMacOsX implements IOperatingSystemRegistration {
 		processExecutor.execute(LSREGISTER, RECURSIVE, pathToEclipseApp);
 	}
 
-	private void changePlistFile(Collection<IScheme> toAdd, Collection<IScheme> toRemove,
-			String pathToEclipseApp) throws IOException {
+	private void changePlistFile(Collection<IScheme> toAdd, Collection<IScheme> toRemove, String pathToEclipseApp)
+			throws IOException {
 		String plistPath = pathToEclipseApp + PLIST_PATH_SUFFIX;
 
 		PlistFileWriter writer = getPlistFileWriter(plistPath);
@@ -131,9 +152,30 @@ public class RegistrationMacOsX implements IOperatingSystemRegistration {
 		writer.writeTo(fileProvider.newWriter(plistPath));
 	}
 
+	/**
+	 * Depending if Eclipse is running stand alone (productive use-case) or started
+	 * from another Eclipse ("Run as Eclipse Application" use-case) the
+	 * "eclipse.home.location" property looks differently. The
+	 * "eclipse.home.location" property is also dependent on the how the target
+	 * platform is defined.<br>
+	 *
+	 * <ol>
+	 * <li>Productive Use:
+	 * <code>file:/path/to/Eclipse.app/Contents/Eclipse/</code></li>
+	 * <li>As Eclipse Application (running Platform):
+	 * <code>file:/path/to/Eclipse.app/Contents/Eclipse/</code></li>
+	 * <li>As Eclipse Application :
+	 * <code>file:/path/to/FolderwithoutDotApp/Contents/Eclipse/</code></li>
+	 * <li>As Eclipse Application :
+	 * <code>file:/path/to/FolderwithoutDotApp/Contents/Eclipse/plugins/</code></li>
+	 * </ol>
+	 *
+	 * @return The path the app
+	 */
 	private String getPathToEclipseApp() {
 		String homeLocationProperty = System.getProperty("eclipse.home.location"); //$NON-NLS-1$
-		return homeLocationProperty.replaceAll("file:(.*.app).*", "$1"); //$NON-NLS-1$ //$NON-NLS-2$
+		// remove the "file:" prefix and everything starting at "/Contents/Eclipse"
+		return homeLocationProperty.replaceAll("file:(.*)\\/Contents\\/Eclipse.*", "$1"); //$NON-NLS-1$ //$NON-NLS-2$
 	}
 
 	/**
