@@ -57,11 +57,14 @@ public class RegistrationWindows implements IOperatingSystemRegistration {
 	@Override
 	public void handleSchemes(Collection<IScheme> toAdd, Collection<IScheme> toRemove)
 			throws Exception {
-		for (IScheme scheme : toAdd) {
-			registryWriter.addScheme(scheme.getName(), getEclipseLauncher());
-		}
-		for (IScheme scheme : toRemove) {
-			registryWriter.removeScheme(scheme.getName());
+		String eclipseLauncher = getEclipseLauncher();
+		if (eclipseLauncher != null) {
+			for (IScheme scheme : toAdd) {
+				registryWriter.addScheme(scheme.getName(), eclipseLauncher);
+			}
+			for (IScheme scheme : toRemove) {
+				registryWriter.removeScheme(scheme.getName());
+			}
 		}
 	}
 
@@ -69,7 +72,7 @@ public class RegistrationWindows implements IOperatingSystemRegistration {
 	 * Takes the given schemes,converts them to schemeInformation type by adding all
 	 * the properties like schemeName,schemeDescription, handled(is handled by
 	 * current instance) and handlerPath. If there is no handlerPath defined it is
-	 * set to "<none>"
+	 * set to empty string
 	 *
 	 * @param schemes The schemes that should be checked for registrations.
 	 * @return the registered schemes.
