@@ -33,60 +33,69 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Widget;
 
-/**
- * @since 3.2
- *
- */
 public class Snippet012CompositeUpdater {
 
 	public static void main(String[] args) {
 		final Display display = new Display();
+
 		Realm.runWithDefault(DisplayRealm.getRealm(display), () -> {
-			Shell shell = new Shell(display);
+			Shell shell = createShell();
 
-			final WritableList<Counter> list = new WritableList<>();
-
-			Button button = new Button(shell, SWT.PUSH);
-			button.setText("add");
-			button.addSelectionListener(new SelectionAdapter() {
-				@Override
-				public void widgetSelected(org.eclipse.swt.events.SelectionEvent e) {
-					list.add(0, new Counter());
-				}
-			});
-
-			final Composite composite = new Composite(shell, SWT.None);
-
-			// TODO: This class is marked as "NON-API", why is it used in a snippet?
-			new CompositeUpdater<Counter>(composite, list) {
-				@Override
-				protected Widget createWidget(int index) {
-					Label label = new Label(composite, SWT.BORDER);
-					// requestLayout(label);
-					return label;
-				}
-
-				@Override
-				protected void updateWidget(Widget widget, Counter element) {
-					((Label) widget).setText(element.getValue() + "");
-					requestLayout((Label) widget);
-				}
-			};
-			GridLayoutFactory.fillDefaults().numColumns(10).generateLayout(composite);
-
-			GridDataFactory.fillDefaults().grab(true, true).applyTo(composite);
-
-			GridLayoutFactory.fillDefaults().generateLayout(shell);
-			shell.pack();
-			shell.open();
 			while (!shell.isDisposed()) {
-				if (!display.readAndDispatch())
+				if (!display.readAndDispatch()) {
 					display.sleep();
+				}
 			}
 		});
+
 		display.dispose();
 	}
 
+	/**
+	 * @param display
+	 * @return
+	 */
+	private static Shell createShell() {
+		Shell shell = new Shell();
+
+		final WritableList<Counter> list = new WritableList<>();
+
+		Button button = new Button(shell, SWT.PUSH);
+		button.setText("add");
+		button.addSelectionListener(new SelectionAdapter() {
+			@Override
+			public void widgetSelected(org.eclipse.swt.events.SelectionEvent e) {
+				list.add(0, new Counter());
+			}
+		});
+
+		final Composite composite = new Composite(shell, SWT.None);
+
+		// TODO: This class is marked as "NON-API", why is it used in a snippet?
+		new CompositeUpdater<Counter>(composite, list) {
+			@Override
+			protected Widget createWidget(int index) {
+				Label label = new Label(composite, SWT.BORDER);
+				// requestLayout(label);
+				return label;
+			}
+
+			@Override
+			protected void updateWidget(Widget widget, Counter element) {
+				((Label) widget).setText(element.getValue() + "");
+				requestLayout((Label) widget);
+			}
+		};
+		GridLayoutFactory.fillDefaults().numColumns(10).generateLayout(composite);
+
+		GridDataFactory.fillDefaults().grab(true, true).applyTo(composite);
+
+		GridLayoutFactory.fillDefaults().generateLayout(shell);
+		shell.pack();
+		shell.open();
+		return shell;
+	}
+
 	static Timer timer = new Timer(true);
 
 	static class Counter extends WritableValue<Integer> {
@@ -99,8 +108,7 @@ public class Snippet012CompositeUpdater {
 			timer.schedule(new TimerTask() {
 				@Override
 				public void run() {
-					// we have to get onto the realm (UI thread) to perform the
-					// increment
+					// We have to get onto the realm (UI thread) to perform the increment
 					getRealm().asyncExec(() -> setValue(getValue() + 1));
 					scheduleIncrementTask();
 				}
