@@ -32,8 +32,8 @@ import org.eclipse.core.databinding.observable.value.ComputedValue;
 import org.eclipse.core.databinding.observable.value.IObservableValue;
 import org.eclipse.jface.databinding.swt.DisplayRealm;
 import org.eclipse.jface.databinding.swt.typed.WidgetProperties;
-import org.eclipse.jface.databinding.viewers.typed.ViewerProperties;
 import org.eclipse.jface.databinding.viewers.ViewerSupport;
+import org.eclipse.jface.databinding.viewers.typed.ViewerProperties;
 import org.eclipse.jface.dialogs.InputDialog;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.layout.GridDataFactory;
@@ -62,17 +62,17 @@ import org.eclipse.swt.widgets.Text;
  */
 public class Snippet018CheckboxTableViewerCheckedSelection {
 	public static void main(String[] args) {
-		// The SWT event loop
 		final Display display = Display.getDefault();
 		Realm.runWithDefault(DisplayRealm.getRealm(display), () -> {
-			ViewModel viewModel = createSampleModel();
+			Shell shell = new View(createSampleModel()).createShell();
 
-			Shell shell = new View(viewModel).createShell();
-			shell.open();
-			while (!shell.isDisposed())
-				if (!display.readAndDispatch())
+			while (!shell.isDisposed()) {
+				if (!display.readAndDispatch()) {
 					display.sleep();
+				}
+			}
 		});
+
 		display.dispose();
 	}
 
@@ -86,16 +86,14 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 		Person wendy = createPerson("Wendy");
 		Person butters = createPerson("Butters");
 
-		setFriends(stan, new Person[] { kyle, eric, kenny, wendy });
-		setFriends(kyle, new Person[] { stan, eric, kenny });
-		setFriends(eric, new Person[] { eric });
-		setFriends(kenny, new Person[] { stan, kyle, eric });
-		setFriends(wendy, new Person[] { stan });
-		setFriends(butters, new Person[0]);
+		stan.setFriends(kyle, eric, kenny, wendy);
+		kyle.setFriends(stan, eric, kenny);
+		eric.setFriends(eric);
+		kenny.setFriends(stan, kyle, eric);
+		wendy.setFriends(stan);
+		butters.setFriends();
 
-		Person[] people = new Person[] { stan, kyle, eric, kenny, wendy,
-				butters };
-		viewModel.setPeople(Arrays.asList(people));
+		viewModel.setPeople(Arrays.asList(stan, kyle, eric, kenny, wendy, butters));
 		return viewModel;
 	}
 
@@ -105,43 +103,37 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 		return person;
 	}
 
-	private static void setFriends(Person person, Person[] friends) {
-		person.setFriends(new HashSet<>(Arrays.asList(friends)));
-	}
-
-	// Minimal JavaBeans support
+	/** Helper class for implementing JavaBeans support. */
 	public static abstract class AbstractModelObject {
-		private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(
-				this);
+		private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
 
 		public void addPropertyChangeListener(PropertyChangeListener listener) {
 			propertyChangeSupport.addPropertyChangeListener(listener);
 		}
 
-		public void addPropertyChangeListener(String propertyName,
-				PropertyChangeListener listener) {
-			propertyChangeSupport.addPropertyChangeListener(propertyName,
-					listener);
+		public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener) {
+			propertyChangeSupport.addPropertyChangeListener(propertyName, listener);
 		}
 
 		public void removePropertyChangeListener(PropertyChangeListener listener) {
 			propertyChangeSupport.removePropertyChangeListener(listener);
 		}
 
-		public void removePropertyChangeListener(String propertyName,
-				PropertyChangeListener listener) {
-			propertyChangeSupport.removePropertyChangeListener(propertyName,
-					listener);
+		public void removePropertyChangeListener(String propertyName, PropertyChangeListener listener) {
+			propertyChangeSupport.removePropertyChangeListener(propertyName, listener);
 		}
 
-		protected void firePropertyChange(String propertyName, Object oldValue,
-				Object newValue) {
-			propertyChangeSupport.firePropertyChange(propertyName, oldValue,
-					newValue);
+		protected void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
+			propertyChangeSupport.firePropertyChange(propertyName, oldValue, newValue);
 		}
 	}
 
-	// The data model class.
+	/**
+	 * The data model class.
+	 * <p>
+	 * This example implements full JavaBeans bound properties so that changes to
+	 * instances of this class will automatically be propagated to the UI.
+	 */
 	static class Person extends AbstractModelObject {
 		private String name;
 		private Set<Person> friends = new HashSet<>();
@@ -158,24 +150,24 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 			return new HashSet<>(friends);
 		}
 
+		public void setFriends(Person... friends) {
+			setFriends(new HashSet<>(Arrays.asList(friends)));
+		}
+
 		public void setFriends(Set<Person> friends) {
-			firePropertyChange("friends", this.friends,
-					this.friends = new HashSet<>(friends));
+			firePropertyChange("friends", this.friends, this.friends = new HashSet<>(friends));
 		}
 
 		@Override
 		public String toString() {
 			return name;
 		}
+
 	}
 
-	// The View's model--the root of our Model graph for this particular GUI.
-	//
-	// Typically each View class has a corresponding ViewModel class.
-	//
-	// The ViewModel is responsible for getting the objects to edit from the
-	// data access tier. Since this snippet doesn't have any persistent objects
-	// to retrieve, this ViewModel just instantiates a model object to edit.
+	/**
+	 * The View's model--the root of our Model graph for this particular GUI.
+	 */
 	static class ViewModel extends AbstractModelObject {
 		private List<Person> people = new ArrayList<>();
 
@@ -184,12 +176,11 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 		}
 
 		public void setPeople(List<Person> people) {
-			firePropertyChange("people", this.people,
-					this.people = new ArrayList<>(people));
+			firePropertyChange("people", this.people, this.people = new ArrayList<>(people));
 		}
 	}
 
-	// The GUI view
+	/** The GUI view. */
 	static class View {
 		private ViewModel viewModel;
 
@@ -207,17 +198,16 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 
 		public Shell createShell() {
 			// Build a UI
-			final Display display = Display.getCurrent();
-			shell = new Shell(display);
+			shell = new Shell();
 
 			createUI(shell);
 
 			// Bind UI
 			bindUI();
 
-			// Open and return the Shell
 			shell.setSize(shell.computeSize(400, SWT.DEFAULT));
 			shell.open();
+
 			return shell;
 		}
 
@@ -228,10 +218,8 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 			new Label(shell, SWT.NONE).setText("People");
 
 			Composite buttons = new Composite(shell, SWT.NONE);
-			GridDataFactory.swtDefaults().align(SWT.RIGHT, SWT.CENTER).applyTo(
-					buttons);
-			GridLayoutFactory.fillDefaults().numColumns(2).equalWidth(true)
-					.applyTo(buttons);
+			GridDataFactory.swtDefaults().align(SWT.RIGHT, SWT.CENTER).applyTo(buttons);
+			GridLayoutFactory.fillDefaults().numColumns(2).equalWidth(true).applyTo(buttons);
 			addPersonButton = new Button(buttons, SWT.PUSH);
 			addPersonButton.setText("Add");
 			GridDataFactory.fillDefaults().applyTo(addPersonButton);
@@ -240,13 +228,11 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 			GridDataFactory.fillDefaults().applyTo(removePersonButton);
 
 			Composite peopleComposite = new Composite(shell, SWT.NONE);
-			GridDataFactory.fillDefaults().grab(true, true).span(2, 1).applyTo(
-					peopleComposite);
+			GridDataFactory.fillDefaults().grab(true, true).span(2, 1).applyTo(peopleComposite);
 			TableColumnLayout peopleColumnLayout = new TableColumnLayout();
 			peopleComposite.setLayout(peopleColumnLayout);
 
-			peopleViewer = new TableViewer(peopleComposite, SWT.SINGLE
-					| SWT.BORDER | SWT.FULL_SELECTION);
+			peopleViewer = new TableViewer(peopleComposite, SWT.SINGLE | SWT.BORDER | SWT.FULL_SELECTION);
 
 			Table peopleTable = peopleViewer.getTable();
 			peopleTable.setHeaderVisible(true);
@@ -254,25 +240,21 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 
 			TableColumn nameColumn = new TableColumn(peopleTable, SWT.NONE);
 			nameColumn.setText("Name");
-			peopleColumnLayout.setColumnData(nameColumn,
-					new ColumnWeightData(1));
+			peopleColumnLayout.setColumnData(nameColumn, new ColumnWeightData(1));
 
 			TableColumn friendsColumn = new TableColumn(peopleTable, SWT.NONE);
 			friendsColumn.setText("Friends");
-			peopleColumnLayout.setColumnData(friendsColumn,
-					new ColumnWeightData(3));
+			peopleColumnLayout.setColumnData(friendsColumn, new ColumnWeightData(3));
 
 			new Label(shell, SWT.NONE).setText("Name");
 
 			personName = new Text(shell, SWT.BORDER);
-			GridDataFactory.fillDefaults().grab(true, false)
-					.applyTo(personName);
+			GridDataFactory.fillDefaults().grab(true, false).applyTo(personName);
 
 			new Label(shell, SWT.NONE).setText("Friends");
 
 			Composite friendsComposite = new Composite(shell, SWT.NONE);
-			GridDataFactory.fillDefaults().grab(true, true).applyTo(
-					friendsComposite);
+			GridDataFactory.fillDefaults().grab(true, true).applyTo(friendsComposite);
 			TableColumnLayout friendsColumnLayout = new TableColumnLayout();
 			friendsComposite.setLayout(friendsColumnLayout);
 
@@ -282,26 +264,24 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 			Table friendsTable = friendsViewer.getTable();
 			friendsTable.setHeaderVisible(true);
 			friendsTable.setLinesVisible(true);
-			TableColumn friendNameColumn = new TableColumn(friendsTable,
-					SWT.NONE);
+			TableColumn friendNameColumn = new TableColumn(friendsTable, SWT.NONE);
 			friendNameColumn.setText("Name");
-			friendsColumnLayout.setColumnData(friendNameColumn,
-					new ColumnWeightData(1));
+			friendsColumnLayout.setColumnData(friendNameColumn, new ColumnWeightData(1));
 
-			GridDataFactory.fillDefaults().grab(true, true).applyTo(
-					friendsViewer.getTable());
+			GridDataFactory.fillDefaults().grab(true, true).applyTo(friendsViewer.getTable());
 		}
 
 		private void bindUI() {
-			DataBindingContext dbc = new DataBindingContext();
+			DataBindingContext bindingContext = new DataBindingContext();
 
 			final IObservableList<Person> people = BeanProperties.list(ViewModel.class, "people", Person.class)
 					.observe(viewModel);
 
 			addPersonButton.addListener(SWT.Selection, event -> {
 				InputDialog dlg = new InputDialog(shell, "Add Person", "Enter name:", "<Name>", newText -> {
-					if (newText == null || newText.length() == 0)
+					if (newText == null || newText.length() == 0) {
 						return "Name cannot be empty";
+					}
 					return null;
 				});
 				if (dlg.open() == Window.OK) {
@@ -314,11 +294,13 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 
 			removePersonButton.addListener(SWT.Selection, event -> {
 				IStructuredSelection selected = peopleViewer.getStructuredSelection();
-				if (selected.isEmpty())
+				if (selected.isEmpty()) {
 					return;
+				}
 				Person person = (Person) selected.getFirstElement();
-				if (MessageDialog.openConfirm(shell, "Remove person", "Remove " + person.getName() + "?"))
+				if (MessageDialog.openConfirm(shell, "Remove person", "Remove " + person.getName() + "?")) {
 					people.remove(person);
+				}
 			});
 
 			ViewerSupport.bind(peopleViewer, people, BeanProperties.values(Person.class, "name", "friends"));
@@ -326,16 +308,16 @@ public class Snippet018CheckboxTableViewerCheckedSelection {
 			final IObservableValue<Person> selectedPerson = ViewerProperties.singleSelection(Person.class)
 					.observe(peopleViewer);
 
-			IObservableValue<Boolean> personSelected =  ComputedValue.create(() -> selectedPerson.getValue() != null);
-			dbc.bindValue(WidgetProperties.enabled().observe(removePersonButton), personSelected);
-			dbc.bindValue(WidgetProperties.enabled().observe(friendsViewer.getTable()), personSelected);
+			IObservableValue<Boolean> personSelected = ComputedValue.create(() -> selectedPerson.getValue() != null);
+			bindingContext.bindValue(WidgetProperties.enabled().observe(removePersonButton), personSelected);
+			bindingContext.bindValue(WidgetProperties.enabled().observe(friendsViewer.getTable()), personSelected);
 
-			dbc.bindValue(WidgetProperties.text(SWT.Modify).observe(personName),
+			bindingContext.bindValue(WidgetProperties.text(SWT.Modify).observe(personName),
 					BeanProperties.value(Person.class, "name", String.class).observeDetail(selectedPerson));
 
 			ViewerSupport.bind(friendsViewer, people, BeanProperties.value(Person.class, "name"));
 
-			dbc.bindSet(ViewerProperties.checkedElements(Person.class).observe((Viewer) friendsViewer),
+			bindingContext.bindSet(ViewerProperties.checkedElements(Person.class).observe((Viewer) friendsViewer),
 					BeanProperties.set(Person.class, "friends", Person.class).observeDetail(selectedPerson));
 		}
 	}
