@@ -43,7 +43,7 @@ import org.eclipse.swt.widgets.TableColumn;
  * Example how to fill a {@link TableViewer} from the background without
  * blocking the UI
  *
- * @author Tom Schindl <tom.schindl@bestsolution.at>
+ * @author Tom Schindl &lt;tom.schindl@bestsolution.at&gt;
  *
  */
 public class Snippet045TableViewerFillFromBackgroundThread {
@@ -77,7 +77,7 @@ public class Snippet045TableViewerFillFromBackgroundThread {
 			if (m.counter == 0) {
 				return "Column " + columnIndex + " => " + "Initial input";
 			}
-			return "Column " + columnIndex + " => thread added " + element.toString();
+			return "Column " + columnIndex + " => thread added " + element;
 		}
 
 		@Override
