@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2018 IBM Corporation and others.
+ * Copyright (c) 2004, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,8 @@
 package org.eclipse.ui.examples.jobs.views;
 
 import java.lang.reflect.InvocationTargetException;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import org.eclipse.core.resources.IWorkspaceRunnable;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
@@ -88,7 +90,7 @@ public class JobsView extends ViewPart {
 		boolean unknown = unknownField.getSelection();
 		boolean user = userField.getSelection();
 		boolean reschedule = rescheduleField.getSelection();
-		final long rescheduleWait = Long.parseLong(rescheduleDelay.getText());
+		final long rescheduleWait = parseDuration(rescheduleDelay.getText(), 1000);
 		boolean keep = keepField.getSelection();
 		boolean keepOne = keepOneField.getSelection();
 		boolean gotoAction = gotoActionField.getSelection();
@@ -108,7 +110,7 @@ public class JobsView extends ViewPart {
 			group.beginTask("Group", total); //$NON-NLS-1$
 		}
 
-		long delay = Integer.parseInt(delayField.getText());
+		long delay = parseDuration(delayField.getText(), 0);
 		for (int i = 0; i < jobCount; i++) {
 			Job result;
 			if (ui)
@@ -177,8 +179,7 @@ public class JobsView extends ViewPart {
 		// create jobs
 		Button create = new Button(group, SWT.PUSH);
 		create.setText("Create jobs"); //$NON-NLS-1$
-		create
-				.setToolTipText("Creates and schedules jobs according to above parameters"); //$NON-NLS-1$
+		create.setToolTipText("Creates and schedules jobs according to above parameters"); //$NON-NLS-1$
 		create.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		create.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> createJobs()));
 
@@ -218,8 +219,7 @@ public class JobsView extends ViewPart {
 		// join the running test jobs
 		Button window = new Button(group, SWT.PUSH);
 		window.setText("Runnable in Window"); //$NON-NLS-1$
-		window
-				.setToolTipText("Using a runnable context in the workbench window"); //$NON-NLS-1$
+		window.setToolTipText("Using a runnable context in the workbench window"); //$NON-NLS-1$
 		window.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		window.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> runnableInWindow()));
 
@@ -240,7 +240,8 @@ public class JobsView extends ViewPart {
 		// show in dialog
 		Button showInDialog = new Button(group, SWT.PUSH);
 		showInDialog.setText("showInDialog"); //$NON-NLS-1$
-		showInDialog.setToolTipText("Uses IProgressService.showInDialog"); //$NON-NLS-1$
+		showInDialog.setToolTipText(
+				"Uses IProgressService.showInDialog. Does nothing if IPreferenceConstants.RUN_IN_BACKGROUND is enabled"); //$NON-NLS-1$
 		showInDialog.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		showInDialog.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> showInDialog()));
 
@@ -299,7 +300,7 @@ public class JobsView extends ViewPart {
 		// duration
 		Label label = new Label(body, SWT.NONE);
 		label.setText("Duration:"); //$NON-NLS-1$
-		durationField = new Combo(body, SWT.DROP_DOWN | SWT.READ_ONLY);
+		durationField = new Combo(body, SWT.DROP_DOWN);
 		GridData data = new GridData(GridData.FILL_HORIZONTAL);
 		data.widthHint = IDialogConstants.ENTRY_FIELD_WIDTH;
 		durationField.setLayoutData(data);
@@ -328,6 +329,7 @@ public class JobsView extends ViewPart {
 		data.widthHint = IDialogConstants.ENTRY_FIELD_WIDTH;
 		quantityField.setLayoutData(data);
 		quantityField.setText("1"); //$NON-NLS-1$
+		quantityField.setToolTipText("Number of jobs to create at once"); //$NON-NLS-1$
 
 		// reschedule delay
 		label = new Label(body, SWT.NONE);
@@ -358,6 +360,7 @@ public class JobsView extends ViewPart {
 		// system
 		systemField = new Button(group, SWT.CHECK);
 		systemField.setText("System job"); //$NON-NLS-1$
+		systemField.setToolTipText("Set system flag when creating jobs"); //$NON-NLS-1$
 		data = new GridData(GridData.FILL_HORIZONTAL);
 		systemField.setLayoutData(data);
 
@@ -376,18 +379,21 @@ public class JobsView extends ViewPart {
 		// reschedule
 		rescheduleField = new Button(group, SWT.CHECK);
 		rescheduleField.setText("Reschedule"); //$NON-NLS-1$
+		rescheduleField.setToolTipText("Reschedule job on finish until job is canceled"); //$NON-NLS-1$
 		data = new GridData(GridData.FILL_HORIZONTAL);
 		rescheduleField.setLayoutData(data);
 
 		// keep
 		keepField = new Button(group, SWT.CHECK);
 		keepField.setText("Keep"); //$NON-NLS-1$
+		keepField.setToolTipText("Set the IProgressConstants.KEEP_PROPERTY to true"); //$NON-NLS-1$
 		data = new GridData(GridData.FILL_HORIZONTAL);
 		keepField.setLayoutData(data);
 
 		// keep one
 		keepOneField = new Button(group, SWT.CHECK);
 		keepOneField.setText("KeepOne"); //$NON-NLS-1$
+		keepOneField.setToolTipText("Set the IProgressConstants.KEEPONE_PROPERTY to true"); //$NON-NLS-1$
 		data = new GridData(GridData.FILL_HORIZONTAL);
 		keepOneField.setLayoutData(data);
 
@@ -400,31 +406,32 @@ public class JobsView extends ViewPart {
 		// whether the job is a user job
 		userField = new Button(group, SWT.CHECK);
 		userField.setText("User job"); //$NON-NLS-1$
+		userField.setToolTipText("Set user flag when creating jobs"); //$NON-NLS-1$
 		data = new GridData(GridData.FILL_HORIZONTAL);
 		userField.setLayoutData(data);
 
 		// whether the job has a goto action
 		gotoActionField = new Button(group, SWT.CHECK);
 		gotoActionField.setText("Goto action"); //$NON-NLS-1$
+		gotoActionField.setToolTipText("Create job with a clickable link to invoke a test action"); //$NON-NLS-1$
 		data = new GridData(GridData.FILL_HORIZONTAL);
 		gotoActionField.setLayoutData(data);
 
 		// whether the job should use a scheduling rule
 		schedulingRuleField = new Button(group, SWT.CHECK);
 		schedulingRuleField.setText("Schedule sequentially"); //$NON-NLS-1$
-		schedulingRuleField
-				.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+		schedulingRuleField.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 
 		// failure
 		failureField = new Button(group, SWT.CHECK);
 		failureField.setText("Fail"); //$NON-NLS-1$
+		failureField.setToolTipText("Immediately end new job with error status"); //$NON-NLS-1$
 		failureField.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 
 		// failure
 		noPromptField = new Button(group, SWT.CHECK);
 		noPromptField.setText("No Prompt"); //$NON-NLS-1$
-		noPromptField
-				.setToolTipText("Set the IProgressConstants.NO_IMMEDIATE_ERROR_PROMPT_PROPERTY to true"); //$NON-NLS-1$
+		noPromptField.setToolTipText("Set the IProgressConstants.NO_IMMEDIATE_ERROR_PROMPT_PROPERTY to true"); //$NON-NLS-1$
 		noPromptField.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 	}
 
@@ -457,21 +464,59 @@ public class JobsView extends ViewPart {
 	}
 
 	protected long getDuration() {
-		switch (durationField.getSelectionIndex()) {
-		case 0:
-			return 0;
-		case 1:
-			return 1;
-		case 2:
-			return 1000;
-		case 3:
-			return 10000;
-		case 4:
-			return 60000;
-		case 5:
-		default:
-			return 600000;
+		return parseDuration(durationField.getText(), 3000);
+	}
+
+	/**
+	 * Parse a time duration string with optional time unit to milliseconds. Only
+	 * supports integer values without sign. No negative value possible.
+	 * <p>
+	 * Supported units are (case insensitive) milliseconds, seconds, minutes, hours,
+	 * days. Duration value and unit are optional separated by whitespace. The unit
+	 * part can be shortened to a prefix of the full unit name. If the prefix is not
+	 * unique one unit will be preferred.
+	 * </p>
+	 *
+	 * @param durationStr duration string to parse
+	 * @return parsed duration in milliseconds or <code>-1</code> if string was
+	 *         invalid
+	 */
+	protected long parseDuration(String durationStr) {
+		if (durationStr == null || durationStr.isEmpty()) {
+			return -1;
 		}
+		String[] unitPrefix = new String[] { "seconds", "minutes", "hours", "days", "milliseconds" }; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
+		long[] prefixMultiplicator = new long[] { 1000, 60_000, 3_600_000, 1_314_000_000, 1 };
+		assert unitPrefix.length == prefixMultiplicator.length;
+
+		Pattern p = Pattern.compile("(\\d+)\\s*([a-z]*)", Pattern.CASE_INSENSITIVE); //$NON-NLS-1$
+		Matcher m = p.matcher(durationStr.trim());
+		if (m.matches()) {
+			long value = Long.parseLong(m.group(1));
+			String unit = m.group(2);
+			if (unit.isEmpty()) {
+				return value;
+			}
+			for (int i = 0; i < unitPrefix.length; i++) {
+				if (unitPrefix[i].startsWith(unit)) {
+					return value * prefixMultiplicator[i];
+				}
+			}
+		}
+		return -1;
+	}
+
+	/**
+	 * Parse duration or return default if string is invalid.
+	 *
+	 * @param durationStr     duration string to parse
+	 * @param defaultDuration default duration to return if string is invalid
+	 * @return the parsed or the default duration
+	 * @see #parseDuration(String)
+	 */
+	protected long parseDuration(String durationStr, long defaultDuration) {
+		long duration = parseDuration(durationStr);
+		return duration >= 0 ? duration : defaultDuration;
 	}
 
 	protected void jobWithRuntimeException() {
@@ -494,14 +539,7 @@ public class JobsView extends ViewPart {
 			// that reports progress in a modal dialog with details area
 			PlatformUI.getWorkbench().getProgressService().busyCursorWhile(
 					monitor -> Job.getJobManager().join(TestJob.FAMILY_TEST_JOB, monitor));
-		} catch (InterruptedException e) {
-			// thrown if the user interrupts the join by canceling the progress
-			// monitor
-			// A UI component should swallow the exception and finish the action
-			// or operation. A lower level component should just propagate the
-			// exception
-			e.printStackTrace();
-		} catch (InvocationTargetException e) {
+		} catch (InterruptedException | InvocationTargetException e) {
 			// Thrown when the operation running within busyCursorWhile throws
 			// an
 			// exception. This should either be propagated or displayed to the
@@ -523,9 +561,7 @@ public class JobsView extends ViewPart {
 						else
 							doRun(duration, monitor);
 					}, ResourcesPlugin.getWorkspace().getRoot());
-		} catch (InvocationTargetException e) {
-			e.printStackTrace();
-		} catch (InterruptedException e) {
+		} catch (InvocationTargetException | InterruptedException e) {
 			e.printStackTrace();
 		}
 	}
@@ -562,7 +598,6 @@ public class JobsView extends ViewPart {
 	 * Run a workspace runnable in the application window.
 	 *
 	 */
-
 	public void runnableInWindow() {
 
 		final long time = getDuration();
