@@ -857,12 +857,7 @@ public class ESelectionServiceTest extends UITest {
 		// assertEquals(selection2, partThreeImpl.input); // incorrect
 
 		ESelectionService selectionService = partContextA.get(ESelectionService.class);
-		selectionService.addSelectionListener(partC.getElementId(), new ISelectionListener() {
-			@Override
-			public void selectionChanged(MPart part, Object selection) {
-				partOneImpl.setOtherSelection(selection);
-			}
-		});
+		selectionService.addSelectionListener(partC.getElementId(), (part, selection1) -> partOneImpl.setOtherSelection(selection1));
 
 		partThreeImpl.setSelection(selection3);
 
