@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2016 EclipseSource Muenchen GmbH and others.
+ * Copyright (c) 2016, 2020 EclipseSource Muenchen GmbH and others.
  *
  *
  * This program and the accompanying materials
@@ -11,6 +11,7 @@
  *
  * Contributors:
  * Alexandra Buzila - initial API and implementation
+ * Gerhard Kreuzer  - Bug 561324
  ******************************************************************************/
 
 package org.eclipse.e4.ui.tests.workbench;
@@ -53,7 +54,6 @@ import org.eclipse.e4.ui.model.fragment.MFragmentFactory;
 import org.eclipse.e4.ui.model.fragment.MModelFragment;
 import org.eclipse.e4.ui.model.fragment.MModelFragments;
 import org.eclipse.e4.ui.model.fragment.MStringModelFragment;
-import org.eclipse.e4.ui.workbench.Selector;
 import org.eclipse.e4.ui.workbench.modeling.EModelService;
 import org.eclipse.emf.common.util.URI;
 import org.eclipse.emf.ecore.EObject;
@@ -114,13 +114,8 @@ public class ModelAssemblerTests {
 		assertTrue(elements.isEmpty());
 
 		List<MApplicationElement> modelElements = modelService.findElements(application, MApplicationElement.class,
-				EModelService.ANYWHERE, new Selector() {
-					@Override
-					public boolean select(MApplicationElement element) {
-						return element.getContributorURI() != null
-								&& element.getContributorURI().equals(contributorURI);
-					}
-				});
+				EModelService.ANYWHERE, element -> element.getContributorURI() != null
+						&& element.getContributorURI().equals(contributorURI));
 		assertTrue(modelElements.isEmpty());
 
 		verifyZeroInteractions(logger);
@@ -256,8 +251,8 @@ public class ModelAssemblerTests {
 	/** Tests that correctly configured imports are correctly handled. */
 	@Test
 	public void testImports() {
-		List<MApplicationElement> imports = new ArrayList<MApplicationElement>();
-		List<MApplicationElement> addedElements = new ArrayList<MApplicationElement>();
+		List<MApplicationElement> imports = new ArrayList<>();
+		List<MApplicationElement> addedElements = new ArrayList<>();
 
 		final String windowElementId = "testImports_emptyList_window1";
 		MTrimmedWindow importWindow1 = modelService.createModelElement(MTrimmedWindow.class);
@@ -282,8 +277,8 @@ public class ModelAssemblerTests {
 	/** Tests the processing of an import with a null/incorrect element id. */
 	@Test
 	public void testImports_noImportElementId() {
-		List<MApplicationElement> imports = new ArrayList<MApplicationElement>();
-		List<MApplicationElement> addedElements = new ArrayList<MApplicationElement>();
+		List<MApplicationElement> imports = new ArrayList<>();
+		List<MApplicationElement> addedElements = new ArrayList<>();
 
 		MTrimmedWindow importWindow1 = modelService.createModelElement(MTrimmedWindow.class);
 		importWindow1.setElementId(null);
@@ -300,7 +295,6 @@ public class ModelAssemblerTests {
 
 		assembler.resolveImports(imports, addedElements);
 		assertEquals(null, placeholder.getRef());
-		verify(logger).warn("Could not resolve an import element for 'null'");
 		verify(logger).warn("Could not resolve import for null");
 		verifyZeroInteractions(logger);
 	}
