@@ -26,6 +26,7 @@ import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TableItem;
@@ -80,7 +81,7 @@ public class UriSchemeHandlerPreferencePageTest {
 	@Test
 	public void schemesShown() throws Exception {
 		this.page.createContents(this.page.getShell());
-
+		waitForJob();
 		assertScheme(getTableItem(0), false, noAppSchemeInfo);
 		assertScheme(getTableItem(1), true, thisAppSchemeInfo);
 		assertScheme(getTableItem(2), false, otherAppSchemeInfo);
@@ -89,15 +90,16 @@ public class UriSchemeHandlerPreferencePageTest {
 	@Test
 	public void handlerTextShown() throws Exception {
 		this.page.createContents(this.page.getShell());
-
+		waitForJob();
 		assertHandlerTextForSelection(page, 0, NO_APPLICATION);
 		assertHandlerTextForSelection(page, 1, THIS_ECLIPSE_HANDLER_LOCATION);
 		assertHandlerTextForSelection(page, 2, OTHER_ECLIPSE_HANDLER_LOCATION);
 	}
 
 	@Test
-	public void checkNoAppScheme() {
+	public void checkNoAppScheme() throws Exception {
 		this.page.createContents(this.page.getShell());
+		waitForJob();
 
 		clickTableViewerCheckbox(0, true);
 
@@ -105,8 +107,9 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void uncheckThisAppScheme() {
+	public void uncheckThisAppScheme() throws Exception {
 		this.page.createContents(this.page.getShell());
+		waitForJob();
 
 		clickTableViewerCheckbox(1, false);
 
@@ -114,8 +117,9 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void checkOtherAppSchemeGivesWarningAndRevertsClick() {
+	public void checkOtherAppSchemeGivesWarningAndRevertsClick() throws Exception {
 		this.page.createContents(this.page.getShell());
+		waitForJob();
 
 		clickTableViewerCheckbox(2, true);
 
@@ -132,8 +136,10 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void checkOtherAppSchemeOnWindowsIsAllowed() {
+	public void checkOtherAppSchemeOnWindowsIsAllowed() throws Exception {
 		this.page.createContents(this.page.getShell());
+		waitForJob();
+
 		operatingSystemRegistration.canOverwriteOtherApplicationsRegistration = true;
 		messageDialogSpy.actualAnswer = true;
 
@@ -152,8 +158,10 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void checkOtherAppSchemeOnWindowsIsAllowedButNothingChangesWhenUserSaysNo() {
+	public void checkOtherAppSchemeOnWindowsIsAllowedButNothingChangesWhenUserSaysNo() throws Exception {
 		this.page.createContents(this.page.getShell());
+		waitForJob();
+
 		operatingSystemRegistration.canOverwriteOtherApplicationsRegistration = true;
 		messageDialogSpy.actualAnswer = false;
 
@@ -172,9 +180,9 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void registersSchemesInOperatingSystemOnApply() {
+	public void registersSchemesInOperatingSystemOnApply() throws Exception {
 		this.page.createContents(this.page.getShell());
-
+		waitForJob();
 		clickTableViewerCheckbox(0, true);
 		clickTableViewerCheckbox(1, false);
 		page.performOk();
@@ -188,8 +196,9 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void doesNotRegistersSchemesInOperatingSystemOnCancel() {
+	public void doesNotRegistersSchemesInOperatingSystemOnCancel() throws Exception {
 		this.page.createContents(this.page.getShell());
+		waitForJob();
 
 		clickTableViewerCheckbox(0, true);
 		clickTableViewerCheckbox(1, false);
@@ -202,21 +211,38 @@ public class UriSchemeHandlerPreferencePageTest {
 	}
 
 	@Test
-	public void showsErrorOnOperatingSystemRegistrationReadError() {
+	public void doesNotRegistersSchemesInOperatingSystemOnApplyWhenLoading() throws Exception {
+		this.page.createContents(this.page.getShell());
+
+		// tableItem[1] (hello1 scheme) is true (refer to members), but page is still
+		// loading
+		page.performOk();
+
+		OperatingSystemRegistrationMock mock = (OperatingSystemRegistrationMock) page.operatingSystemRegistration;
+		assertEquals(0, mock.addedSchemes.size());
+
+		assertEquals(0, mock.removedSchemes.size());
+		waitForJob();
+	}
+
+	@Test
+	public void showsErrorOnOperatingSystemRegistrationReadError() throws Exception {
 		OperatingSystemRegistrationMock mock = (OperatingSystemRegistrationMock) page.operatingSystemRegistration;
 		mock.schemeInformationReadException = new IOExceptionWithoutStackTrace("Error reading from OS");
 
 		this.page.createContents(this.page.getShell());
+		waitForJob();
 
 		assertErrorStatusRaised(IDEWorkbenchMessages.UrlHandlerPreferencePage_Error_Reading_Scheme);
 	}
 
 	@Test
-	public void showsErrorOnOperatingSystemRegistrationWriteError() {
+	public void showsErrorOnOperatingSystemRegistrationWriteError() throws Exception {
 		OperatingSystemRegistrationMock mock = (OperatingSystemRegistrationMock) page.operatingSystemRegistration;
 		mock.schemeInformationRegisterException = new IOExceptionWithoutStackTrace("Error writing into OS");
 
 		this.page.createContents(this.page.getShell());
+		waitForJob();
 
 		page.performOk();
 
@@ -251,6 +277,23 @@ public class UriSchemeHandlerPreferencePageTest {
 		assertTrue(page.performOk());
 	}
 
+	@Test
+	public void loadingSchemesShownAfterPageOpened() throws Exception {
+		this.page.createContents(this.page.getShell());
+		assertLoadingScheme(getTableItem(0), noAppSchemeInfo);
+		assertLoadingScheme(getTableItem(1), thisAppSchemeInfo);
+		assertLoadingScheme(getTableItem(2), otherAppSchemeInfo);
+		waitForJob();
+	}
+
+	private void waitForJob() throws InterruptedException {
+		this.page.osRegistrationReadingJob.join();
+		// jobs sets data asynchronously in TableViewer
+		Display display = Display.getCurrent();
+		while (display.readAndDispatch()) {
+		}
+	}
+
 	private void clickTableViewerCheckbox(int itemIndex, boolean checked) {
 		TableItem item = page.tableViewer.getTable().getItem(itemIndex);
 
@@ -285,7 +328,22 @@ public class UriSchemeHandlerPreferencePageTest {
 		} else {
 			assertEquals("", tableItem.getText(2));
 		}
+	}
 
+	private void assertLoadingScheme(TableItem tableItem, ISchemeInformation information) {
+		// check pojo
+		UiSchemeInformation uiInformation = (UiSchemeInformation) tableItem.getData();
+		assertFalse(uiInformation.checked);
+		assertEquals(information.getName(), uiInformation.getName());
+		assertEquals(information.getDescription(), uiInformation.getDescription());
+		assertEquals(IDEWorkbenchMessages.UrlHandlerPreferencePage_LoadingText,
+				uiInformation.getHandlerInstanceLocation());
+
+		// check UI
+		assertFalse(tableItem.getChecked());
+		assertEquals(information.getName(), tableItem.getText(0));
+		assertEquals(information.getDescription(), tableItem.getText(1));
+		assertEquals(IDEWorkbenchMessages.UrlHandlerPreferencePage_LoadingText, tableItem.getText(2));
 	}
 
 	private void assertHandlerTextForSelection(UriSchemeHandlerPreferencePage page, int selection, String text) {
@@ -311,7 +369,7 @@ public class UriSchemeHandlerPreferencePageTest {
 			@Override
 			public Shell getShell() {
 				return new Shell();
-			};
+			}
 		};
 
 		page.extensionReader = createExtensionReaderStub();
