@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -28,11 +28,13 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.jobs.Job;
+import org.eclipse.jface.preference.IPreferenceStore;
+import org.eclipse.jface.preference.PreferenceMemento;
+import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ShellEvent;
 import org.eclipse.swt.events.ShellListener;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
-import org.eclipse.ui.IWindowListener;
 import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchWindow;
@@ -66,41 +68,16 @@ public abstract class UITestCase extends TestCase {
 		return ResourcesPlugin.getWorkspace().getRoot();
 	}
 
-	class TestWindowListener implements IWindowListener {
-		private boolean enabled = true;
-
-		public void setEnabled(boolean enabled) {
-			this.enabled = enabled;
-		}
-
-		@Override
-		public void windowActivated(IWorkbenchWindow window) {
-			// do nothing
-		}
-
-		@Override
-		public void windowDeactivated(IWorkbenchWindow window) {
-			// do nothing
-		}
-
-		@Override
-		public void windowClosed(IWorkbenchWindow window) {
-			if (enabled)
-				testWindows.remove(window);
-		}
-
-		@Override
-		public void windowOpened(IWorkbenchWindow window) {
-			if (enabled)
-				testWindows.add(window);
-		}
-	}
+	/**
+	 * Rule to close windows opened during the test case, manually called to remain
+	 * compatible with JUnit3
+	 */
+	private CloseTestWindowsRule closeTestWindows = new CloseTestWindowsRule();
 
 	protected IWorkbench fWorkbench;
 
-	private List<IWorkbenchWindow> testWindows;
-
-	private TestWindowListener windowListener;
+	/** Preference helper to restore changed preference values after test run. */
+	private PreferenceMemento prefMemento = new PreferenceMemento();
 
 	/**
 	 * Required to preserve the existing logging output when running tests with
@@ -125,8 +102,6 @@ public abstract class UITestCase extends TestCase {
 
 	public UITestCase(String testName) {
 		super(testName);
-		//		ErrorDialog.NO_UI = true;
-		testWindows = new ArrayList<>(3);
 	}
 
 	/**
@@ -174,26 +149,9 @@ public abstract class UITestCase extends TestCase {
 
 		if (status.isMultiStatus()) {
 			IStatus[] children = status.getChildren();
-			for (int i = 0; i < children.length; i++)
-				write(children[i], indent + 1);
-		}
-	}
-
-	/**
-	 * Adds a window listener to the workbench to keep track of
-	 * opened test windows.
-	 */
-	private void addWindowListener() {
-		windowListener = new TestWindowListener();
-		fWorkbench.addWindowListener(windowListener);
-	}
-
-	/**
-	 * Removes the listener added by <code>addWindowListener</code>.
-	 */
-	private void removeWindowListener() {
-		if (windowListener != null) {
-			fWorkbench.removeWindowListener(windowListener);
+			for (IStatus child : children) {
+				write(child, indent + 1);
+			}
 		}
 	}
 
@@ -220,10 +178,10 @@ public abstract class UITestCase extends TestCase {
 	@Override
 	public final void setUp() throws Exception {
 		super.setUp();
+		closeTestWindows.before();
 		fWorkbench = PlatformUI.getWorkbench();
 		String name = runningTest != null ? runningTest : this.getName();
 		trace(TestRunLogUtil.formatTestStartMessage(name));
-		addWindowListener();
 		doSetUp();
 
 	}
@@ -252,9 +210,22 @@ public abstract class UITestCase extends TestCase {
 	public final void tearDown() throws Exception {
 		String name = runningTest != null ? runningTest : this.getName();
 		trace(TestRunLogUtil.formatTestFinishedMessage(name));
-		removeWindowListener();
+		prefMemento.resetPreferences();
 		doTearDown();
 		fWorkbench = null;
+
+		// Check for modal shell leak.
+		List<String> leakedModalShellTitles = new ArrayList<>();
+		Shell[] shells = PlatformUI.getWorkbench().getDisplay().getShells();
+		for (Shell shell : shells) {
+			if (!shell.isDisposed() && shell.isVisible()
+					&& (shell.getStyle() & (SWT.APPLICATION_MODAL | SWT.PRIMARY_MODAL | SWT.SYSTEM_MODAL)) != 0) {
+				leakedModalShellTitles.add(shell.getText());
+				shell.close();
+			}
+		}
+		assertEquals("Test leaked modal shell: [" + String.join(", ", leakedModalShellTitles) + "]", 0,
+				leakedModalShellTitles.size());
 	}
 
 	/**
@@ -265,9 +236,7 @@ public abstract class UITestCase extends TestCase {
 	 * Subclasses may extend.
 	 */
 	protected void doTearDown() throws Exception {
-		processEvents();
-		closeAllTestWindows();
-		processEvents();
+		closeTestWindows.after();
 	}
 
 	public static void processEvents() {
@@ -395,7 +364,7 @@ public abstract class UITestCase extends TestCase {
 		}
 	}
 
-	protected static interface Condition {
+	public static interface Condition {
 		public boolean compute();
 	}
 
@@ -407,9 +376,9 @@ public abstract class UITestCase extends TestCase {
 	 *            , -1 if forever
 	 * @return true if successful, false if time out or interrupted
 	 */
-	protected boolean processEventsUntil(Condition condition, long timeout) {
+	public static boolean processEventsUntil(Condition condition, long timeout) {
 		long startTime = System.currentTimeMillis();
-		Display display = getWorkbench().getDisplay();
+		Display display = PlatformUI.getWorkbench().getDisplay();
 		while (condition == null || !condition.compute()) {
 			if (timeout != -1
 					&& System.currentTimeMillis() - startTime > timeout) {
@@ -430,16 +399,16 @@ public abstract class UITestCase extends TestCase {
 	/**
 	 * Open a test window with the empty perspective.
 	 */
-	public IWorkbenchWindow openTestWindow() {
+	public static IWorkbenchWindow openTestWindow() {
 		return openTestWindow(EmptyPerspective.PERSP_ID);
 	}
 
 	/**
 	 * Open a test window with the provided perspective.
 	 */
-	public IWorkbenchWindow openTestWindow(String perspectiveId) {
+	public static IWorkbenchWindow openTestWindow(String perspectiveId) {
 		try {
-			IWorkbenchWindow window = fWorkbench.openWorkbenchWindow(
+			IWorkbenchWindow window = PlatformUI.getWorkbench().openWorkbenchWindow(
 					perspectiveId, getPageInput());
 			waitOnShell(window.getShell());
 			return window;
@@ -457,7 +426,7 @@ public abstract class UITestCase extends TestCase {
 	 *            the shell to wait on
 	 * @since 3.2
 	 */
-	private void waitOnShell(Shell shell) {
+	private static void waitOnShell(Shell shell) {
 		processEvents();
 		waitForJobs(100, 5000);
 	}
@@ -466,11 +435,7 @@ public abstract class UITestCase extends TestCase {
 	 * Close all test windows.
 	 */
 	public void closeAllTestWindows() {
-		List<IWorkbenchWindow> testWindowsCopy = new ArrayList<>(testWindows);
-		for (IWorkbenchWindow testWindow : testWindowsCopy) {
-			testWindow.close();
-		}
-		testWindows.clear();
+		closeTestWindows.closeAllTestWindows();
 	}
 
 	/**
@@ -516,7 +481,7 @@ public abstract class UITestCase extends TestCase {
 	 * Set whether the window listener will manage opening and closing of created windows.
 	 */
 	protected void manageWindows(boolean manage) {
-		windowListener.setEnabled(manage);
+		closeTestWindows.setEnabled(manage);
 	}
 
 	/**
@@ -528,4 +493,27 @@ public abstract class UITestCase extends TestCase {
 	protected IWorkbench getWorkbench() {
 		return fWorkbench;
 	}
+
+	/**
+	 * Change a preference value for this test run. The preference will be reset to
+	 * its value before test started automatically on {@link #tearDown()}.
+	 *
+	 * @param <T>   preference value type. The type must have a corresponding
+	 *              {@link IPreferenceStore} setter.
+	 * @param store preference store to manipulate (must not be <code>null</code>)
+	 * @param name  preference to change
+	 * @param value new preference value
+	 * @throws IllegalArgumentException when setting a type which is not supported
+	 *                                  by {@link IPreferenceStore}
+	 *
+	 * @see IPreferenceStore#setValue(String, double)
+	 * @see IPreferenceStore#setValue(String, float)
+	 * @see IPreferenceStore#setValue(String, int)
+	 * @see IPreferenceStore#setValue(String, long)
+	 * @see IPreferenceStore#setValue(String, boolean)
+	 * @see IPreferenceStore#setValue(String, String)
+	 */
+	protected <T> void setPreference(IPreferenceStore store, String name, T value) {
+		prefMemento.setValue(store, name, value);
+	}
 }
