@@ -15,6 +15,7 @@
 package org.eclipse.ui.tests.performance;
 
 import org.eclipse.ui.activities.IActivityManager;
+import org.junit.Test;
 
 /**
  * @since 3.1
@@ -22,33 +23,29 @@ import org.eclipse.ui.activities.IActivityManager;
  */
 public class GenerateIdentifiersTest extends BasicPerformanceTest {
 
-	private int count;
+	private static final int count = 10000;
 
-	public GenerateIdentifiersTest(int numberOfIdentifiers) {
-		super("Generate " + numberOfIdentifiers + " identifiers");
-		this.count = numberOfIdentifiers;
+	public GenerateIdentifiersTest() {
+		super("Generate " + count + " identifiers");
 	}
 
-	@Override
-	protected void runTest() throws Throwable {
+	@Test
+	public void test() throws Throwable {
 		final IActivityManager activityManager = fWorkbench.getActivitySupport().getActivityManager();
 
-		exercise(new TestRunnable() {
-			@Override
-			public void run() throws Exception {
-				// construct the Identifiers to test
-				final String [] ids = new String[count];
-				for (int i = 0; i < ids.length; i++) {
-					long timestamp = System.currentTimeMillis();
-					ids[i] = "org.eclipse.jdt.ui/" + i + timestamp;
-				}
-
-				startMeasuring();
-				for (String id : ids) {
-					activityManager.getIdentifier(id);
-				}
-				stopMeasuring();
+		exercise(() -> {
+			// construct the Identifiers to test
+			final String[] ids = new String[count];
+			for (int i = 0; i < ids.length; i++) {
+				long timestamp = System.currentTimeMillis();
+				ids[i] = "org.eclipse.jdt.ui/" + i + timestamp;
 			}
+
+			startMeasuring();
+			for (String id : ids) {
+				activityManager.getIdentifier(id);
+			}
+			stopMeasuring();
 		});
 		commitMeasurements();
 		assertPerformance();
