@@ -13,6 +13,9 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.performance;
 
+import java.util.Arrays;
+import java.util.Collection;
+
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.test.performance.Dimension;
@@ -23,40 +26,54 @@ import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.WorkbenchException;
 import org.eclipse.ui.ide.IDE;
 import org.eclipse.ui.internal.WorkbenchPlugin;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
+import org.junit.runners.Parameterized.Parameters;
 
 /**
  * Test perspective switching.
  */
+@RunWith(Parameterized.class)
 public class PerspectiveSwitchTest extends BasicPerformanceTest {
 
 	private String id1;
 	private String id2;
 	private String activeEditor;
 
-	/**
-	 * Constructor.
-	 *
-	 * @param id
-	 */
-	public PerspectiveSwitchTest(String [] ids, int tagging) {
-		super("testPerspectiveSwitch:" + ids[0] + "," + ids[1] + ",editor " + ids[2], tagging);
-		this.id1 = ids[0];
-		this.id2 = ids[1];
-		this.activeEditor = ids[2];
+	@Parameters
+	public static Collection<Object[]> data() {
+		return Arrays.asList(new Object[][] { // Test switching between the two most commonly used perspectives in the
+												// SDK
+				// (this is the most important
+				// perspective switch test, but it is easily affected by changes in JDT, etc.)
+				{ "org.eclipse.jdt.ui.JavaPerspective", "org.eclipse.debug.ui.DebugPerspective", "1.java" },
+
+				{ UIPerformanceTestSetup.PERSPECTIVE1, UIPerformanceTestSetup.PERSPECTIVE2, "1.perf_basic" },
+
+				// Test switching between a perspective with lots of actions and a perspective
+				// with none
+				{ "org.eclipse.jdt.ui.JavaPerspective", "org.eclipse.ui.tests.util.EmptyPerspective", "1.perf_basic" },
+
+				{ "org.eclipse.ui.resourcePerspective", "org.eclipse.jdt.ui.JavaPerspective", "1.java" } });
+	}
+
+	public PerspectiveSwitchTest(String id1, String id2, String activeEditor) {
+		super("testPerspectiveSwitch:" + id1 + "," + id2 + ",editor " + activeEditor, BasicPerformanceTest.NONE);
+		this.id1 = id1;
+		this.id2 = id2;
+		this.activeEditor = activeEditor;
 	}
 
 	/**
 	 * Test perspective switching performance.
 	 */
-	@Override
-	protected void runTest() throws CoreException, WorkbenchException {
+	@Test
+	public void test() throws CoreException, WorkbenchException {
 		// Get the two perspectives to switch between.
-		final IPerspectiveRegistry registry = WorkbenchPlugin.getDefault()
-				.getPerspectiveRegistry();
-		final IPerspectiveDescriptor perspective1 = registry
-				.findPerspectiveWithId(id1);
-		final IPerspectiveDescriptor perspective2 = registry
-				.findPerspectiveWithId(id2);
+		final IPerspectiveRegistry registry = WorkbenchPlugin.getDefault().getPerspectiveRegistry();
+		final IPerspectiveDescriptor perspective1 = registry.findPerspectiveWithId(id1);
+		final IPerspectiveDescriptor perspective2 = registry.findPerspectiveWithId(id2);
 
 		// Don't fail if we reference an unknown perspective ID. This can be
 		// a normal occurrance since the test suites reference JDT perspectives, which
@@ -79,7 +96,8 @@ public class PerspectiveSwitchTest extends BasicPerformanceTest {
 		assertNotNull(page);
 		page.setPerspective(perspective2);
 
-		//IFile aFile = getProject().getFile("1." + EditorPerformanceSuite.EDITOR_FILE_EXTENSIONS[0]);
+		// IFile aFile = getProject().getFile("1." +
+		// EditorPerformanceSuite.EDITOR_FILE_EXTENSIONS[0]);
 		IFile aFile = getProject().getFile(activeEditor);
 		assertTrue(aFile.exists());
 
@@ -87,18 +105,15 @@ public class PerspectiveSwitchTest extends BasicPerformanceTest {
 
 		tagIfNecessary("UI - Perspective Switch", Dimension.ELAPSED_PROCESS);
 
-		exercise(new TestRunnable() {
-			@Override
-			public void run() throws Exception {
-				processEvents();
+		exercise(() -> {
+			processEvents();
 
-				startMeasuring();
-				page.setPerspective(perspective1);
-				processEvents();
-				page.setPerspective(perspective2);
-				processEvents();
-				stopMeasuring();
-			}
+			startMeasuring();
+			page.setPerspective(perspective1);
+			processEvents();
+			page.setPerspective(perspective2);
+			processEvents();
+			stopMeasuring();
 		});
 
 		commitMeasurements();
