@@ -13,6 +13,11 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.activities;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.nio.charset.StandardCharsets;
@@ -36,14 +41,15 @@ import org.eclipse.ui.activities.NotDefinedException;
 import org.eclipse.ui.activities.WorkbenchTriggerPointAdvisor;
 import org.eclipse.ui.internal.activities.MutableActivityManager;
 import org.eclipse.ui.tests.TestPlugin;
-import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  *
  * The dynamic test manipualtes the categories, activities and their definitions
  * and ensures that their content and their listeners are behaving properly.
  */
-public class DynamicTest extends UITestCase {
+public class DynamicTest {
 	private MutableActivityManager activityManager;
 
 	private DynamicModelActivityRegistry fixedModelRegistry;
@@ -74,14 +80,8 @@ public class DynamicTest extends UITestCase {
 
 	static final int DEFAULT_ENABLED_CHANGED = 11;
 
-	/**
-	 * Constructor.
-	 *
-	 * @param testName
-	 *            Test's name.
-	 */
-	public DynamicTest(String testName) {
-		super(testName);
+	@Before
+	public void init() {
 		fixedModelRegistry = new DynamicModelActivityRegistry();
 		activityManager = new MutableActivityManager(new WorkbenchTriggerPointAdvisor(), fixedModelRegistry);
 		listenerType = -1;
@@ -91,6 +91,7 @@ public class DynamicTest extends UITestCase {
 	 * Test sizes of what has been read.
 	 *
 	 */
+	@Test
 	public void testSizes() {
 		assertTrue(activityManager.getDefinedCategoryIds().size() == 6);
 		assertTrue(activityManager.getDefinedActivityIds().size() == 18);
@@ -101,6 +102,7 @@ public class DynamicTest extends UITestCase {
 	 * Test activity bindings.
 	 *
 	 */
+	@Test
 	public void testActivityPatternBindings() {
 		IActivity first_activity = activityManager
 				.getActivity((String) activityManager.getDefinedActivityIds()
@@ -123,6 +125,7 @@ public class DynamicTest extends UITestCase {
 	 * Test the enabled activities.
 	 *
 	 */
+	@Test
 	public void testEnabledActivities() {
 		// Add an enabled activity
 		Set<String> compareSet;
@@ -142,6 +145,7 @@ public class DynamicTest extends UITestCase {
 	 * Test the identifier listener.
 	 *
 	 */
+	@Test
 	public void testIdentifiersListener() {
 		final IIdentifier enabledIdentifier = activityManager
 				.getIdentifier("org.eclipse.pattern3"); //$NON-NLS-1$
@@ -179,7 +183,7 @@ public class DynamicTest extends UITestCase {
 		// Add pattern binding
 		listenerType = 1;
 		fixedModelRegistry.addActivityPatternBinding("org.eclipse.activity1", //$NON-NLS-1$
-				"org.eclipse.pattern3"); //$NON-NLS-1$ //$NON-NLS-2$
+				"org.eclipse.pattern3"); //$NON-NLS-1$
 		assertTrue(listenerType == -1);
 		// Test correctenesss of identifier
 		Set<String> manipulatedIdentifiers = activityManager.getIdentifier(
@@ -198,6 +202,7 @@ public class DynamicTest extends UITestCase {
 	 * Test the activity manager listener.
 	 *
 	 */
+	@Test
 	public void testActivityManagerListener() {
 		activityManager.addActivityManagerListener(activityManagerEvent -> {
 			switch (listenerType) {
@@ -231,7 +236,7 @@ public class DynamicTest extends UITestCase {
 		// Remove category
 		listenerType = 3;
 		fixedModelRegistry.removeCategory("org.eclipse.category7", //$NON-NLS-1$
-				"Category 7"); //$NON-NLS-1$ //$NON-NLS-2$
+				"Category 7"); //$NON-NLS-1$
 		assertTrue(listenerType == -1);
 		// Add activity
 		listenerType = 4;
@@ -240,7 +245,7 @@ public class DynamicTest extends UITestCase {
 		// Remove activity
 		listenerType = 4;
 		fixedModelRegistry.removeActivity("org.eclipse.activity19", //$NON-NLS-1$
-				"Activity 19"); //$NON-NLS-1$ //$NON-NLS-2$
+				"Activity 19"); //$NON-NLS-1$
 		assertTrue(listenerType == -1);
 	}
 
@@ -248,6 +253,7 @@ public class DynamicTest extends UITestCase {
 	 * Test the activity listener.
 	 *
 	 */
+	@Test
 	public void testActivityListener() {
 		final String activity_to_listen_name = "Activity 18"; //$NON-NLS-1$
 		final IActivity activity_to_listen = activityManager
@@ -301,7 +307,7 @@ public class DynamicTest extends UITestCase {
 		// Add pattern binding
 		listenerType = 8;
 		fixedModelRegistry.addActivityPatternBinding("org.eclipse.activity18", //$NON-NLS-1$
-				"org.eclipse.pattern3"); //$NON-NLS-1$ //$NON-NLS-2$
+				"org.eclipse.pattern3"); //$NON-NLS-1$
 		assertTrue(listenerType == -1);
 		// Remove pattern binding
 		listenerType = 8;
@@ -311,7 +317,7 @@ public class DynamicTest extends UITestCase {
 		listenerType = 9;
 		fixedModelRegistry.addActivityRequirementBinding(
 				"org.eclipse.activity9", //$NON-NLS-1$
-				activity_to_listen.getId());//$NON-NLS-1$
+				activity_to_listen.getId());
 		assertTrue(listenerType == -1);
 		// Remove activity activity binding as parent
 		listenerType = 9;
@@ -353,6 +359,7 @@ public class DynamicTest extends UITestCase {
 	 * Test the category listener.
 	 *
 	 */
+	@Test
 	public void testCategoryListener() {
 		final ICategory category_to_listen = activityManager
 				.getCategory((String) activityManager.getDefinedCategoryIds()
@@ -377,7 +384,7 @@ public class DynamicTest extends UITestCase {
 		// Remove category, and change name
 		try {
 			fixedModelRegistry.removeCategory(category_to_listen.getId(),
-					category_to_listen.getName()); //$NON-NLS-1$
+					category_to_listen.getName());
 		} catch (NotDefinedException e) {
 			e.printStackTrace(System.err);
 		}
@@ -385,19 +392,19 @@ public class DynamicTest extends UITestCase {
 		// Add category
 		listenerType = 5;
 		fixedModelRegistry
-				.addCategory(category_to_listen.getId(), "Category 6"); //$NON-NLS-1$ //$NON-NLS-2$
+				.addCategory(category_to_listen.getId(), "Category 6"); //$NON-NLS-1$
 		assertTrue(listenerType == -1);
 		// Add category activity binding
 		listenerType = 8;
 		fixedModelRegistry.addCategoryActivityBinding((String) activityManager
 				.getDefinedActivityIds().toArray()[4], category_to_listen
-				.getId()); //$NON-NLS-1$
+				.getId());
 		assertTrue(listenerType == -1);
 		// Remove activity activity binding
 		listenerType = 8;
 		fixedModelRegistry.removeCategoryActivityBinding(
 				(String) activityManager.getDefinedActivityIds().toArray()[4],
-				category_to_listen.getId());//$NON-NLS-1$
+				category_to_listen.getId());
 		// Change category description
 		listenerType = 10;
 		fixedModelRegistry.updateCategoryDescription(
@@ -424,6 +431,7 @@ public class DynamicTest extends UITestCase {
 	/**
 	 * Tests to ensure dynamism with regard to the extension registry.
 	 */
+	@Test
 	public void testDynamicRegistry() {
 		IWorkbenchActivitySupport was = PlatformUI.getWorkbench()
 				.getActivitySupport();
@@ -451,7 +459,7 @@ public class DynamicTest extends UITestCase {
 				+ "<categoryActivityBinding categoryId = \"dynamic.category\" activityId = \"dynamic.activity\" />"
 				+ "<activityPatternBinding activityId=\"dynamic.activity\"  pattern=\"dynamic.activity/.*\"/>"
 				+ "<defaultEnablement id=\"dynamic.activity\"/>" + "</extension></plugin>";
-		byte[] bytes = ACTIVITY.toString().getBytes(StandardCharsets.UTF_8);
+		byte[] bytes = ACTIVITY.getBytes(StandardCharsets.UTF_8);
 		InputStream is = new ByteArrayInputStream(bytes);
 		IContributor contrib = ContributorFactoryOSGi.createContributor(TestPlugin.getDefault().getBundle());
 		ExtensionRegistry registry = (ExtensionRegistry) RegistryFactory.getRegistry();
@@ -490,7 +498,7 @@ public class DynamicTest extends UITestCase {
 		try {
 			assertTrue(activity.isDefaultEnabled());
 		} catch (NotDefinedException e) {
-			fail(e.getMessage(), e);
+			fail(e.getMessage());
 		}
 
 		Set<IActivityRequirementBinding> requirementBindings = activity.getActivityRequirementBindings();
