@@ -13,21 +13,19 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.api;
 
-import junit.framework.TestCase;
+import static org.junit.Assert.assertNotNull;
 
 import org.eclipse.ui.IEditorDescriptor;
 import org.eclipse.ui.IFileEditorMapping;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.tests.harness.util.ArrayUtil;
+import org.junit.Before;
+import org.junit.Test;
 
-public class IEditorDescriptorTest extends TestCase {
+public class IEditorDescriptorTest {
 	IEditorDescriptor[] fEditors;
 
-	public IEditorDescriptorTest(String testName) {
-		super(testName);
-	}
-
-	@Override
+	@Before
 	public void setUp() {
 		IFileEditorMapping mapping = (IFileEditorMapping) ArrayUtil
 				.pickRandom(PlatformUI.getWorkbench().getEditorRegistry()
@@ -35,18 +33,21 @@ public class IEditorDescriptorTest extends TestCase {
 		fEditors = mapping.getEditors();
 	}
 
+	@Test
 	public void testGetId() throws Throwable {
 		for (IEditorDescriptor fEditor : fEditors) {
 			assertNotNull(fEditor.getId());
 		}
 	}
 
+	@Test
 	public void testGetImageDescriptor() throws Throwable {
 		for (IEditorDescriptor fEditor : fEditors) {
 			assertNotNull(fEditor.getImageDescriptor());
 		}
 	}
 
+	@Test
 	public void testGetLabel() throws Throwable {
 		for (IEditorDescriptor fEditor : fEditors) {
 			assertNotNull(fEditor.getLabel());
