@@ -17,8 +17,14 @@ import org.eclipse.ui.IPerspectiveDescriptor;
 import org.eclipse.ui.IPerspectiveListener;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.tests.harness.util.EmptyPerspective;
 import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
+@RunWith(JUnit4.class)
 public class IPerspectiveListenerTest extends UITestCase implements
 		IPerspectiveListener {
 	private int fEvent;
@@ -35,8 +41,8 @@ public class IPerspectiveListenerTest extends UITestCase implements
 	public static final int NONE = 0x00, OPEN = 0x01, CLOSED = 0x02,
 			ACTIVATED = 0x04, CHANGED = 0x08;
 
-	public IPerspectiveListenerTest(String testName) {
-		super(testName);
+	public IPerspectiveListenerTest() {
+		super(IPerspectiveListenerTest.class.getSimpleName());
 	}
 
 	@Override
@@ -53,30 +59,32 @@ public class IPerspectiveListenerTest extends UITestCase implements
 		super.doTearDown();
 	}
 
+	@Test
+	@Ignore
 	public void testPerspectiveActivated() {
 		/*
-		 * Commented out because until test case can be updated to work
-		 * with new window/page/perspective implementation
-		 *
+		 * Commented out because until test case can be updated to work with new
+		 * window/page/perspective implementation
+		 */
 		 fPageMask = fWindow.getActivePage();
 		 fPerMask = fWorkbench.getPerspectiveRegistry().findPerspectiveWithId(EmptyPerspective.PERSP_ID );
 		 fPageMask.setPerspective( fPerMask );
 
 		 assertEquals( isActivated( fEvent ), true );
-		 */
 	}
 
+	@Test
+	@Ignore
 	public void testPerspectiveChanged() {
 		/*
-		 * Commented out because until test case can be updated to work
-		 * with new window/page/perspective implementation
-		 *
+		 * Commented out because until test case can be updated to work with new
+		 * window/page/perspective implementation
+		 */
 		 fPageMask = fWindow.getActivePage();
 		 fPerMask = fWorkbench.getPerspectiveRegistry().findPerspectiveWithId(EmptyPerspective.PERSP_ID );
 		 fPageMask.setPerspective( fPerMask );
 
 		 assertEquals( isActivated( fEvent ), true );
-		 */
 	}
 
 	/**
