@@ -13,8 +13,6 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.dialogs;
 
-import junit.framework.TestCase;
-
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.dialogs.YesNoCancelListSelectionDialog;
 import org.eclipse.ui.internal.WorkbenchMessages;
@@ -22,17 +20,15 @@ import org.eclipse.ui.model.AdaptableList;
 import org.eclipse.ui.model.WorkbenchContentProvider;
 import org.eclipse.ui.model.WorkbenchPartLabelProvider;
 import org.eclipse.ui.tests.harness.util.DialogCheck;
+import org.junit.Test;
 
-public class DeprecatedUIDialogsAuto extends TestCase {
-
-	public DeprecatedUIDialogsAuto(String name) {
-		super(name);
-	}
+public class DeprecatedUIDialogsAuto {
 
 	private Shell getShell() {
 		return DialogCheck.getShell();
 	}
 
+	@Test
 	public void testSaveAll() {
 		YesNoCancelListSelectionDialog dialog = new YesNoCancelListSelectionDialog(
 				getShell(), new AdaptableList(),
