@@ -13,9 +13,6 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.dnd;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.swt.SWT;
@@ -24,10 +21,18 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.IPageLayout;
 import org.eclipse.ui.tests.TestPlugin;
 import org.eclipse.ui.tests.autotests.AutoTestSuite;
+import org.junit.Ignore;
+import org.junit.runner.RunWith;
+import org.junit.runners.AllTests;
+
+import junit.framework.Test;
+import junit.framework.TestSuite;
 
 /**
  * @since 3.0
  */
+@RunWith(AllTests.class)
+@Ignore("DND support not implemented yet in E4")
 public class DragTestSuite extends AutoTestSuite {
 
 	/**
@@ -118,14 +123,12 @@ public class DragTestSuite extends AutoTestSuite {
 	}
 
 	private TestDropLocation[] getCommonDropTargets(IWorkbenchWindowProvider dragSource) {
-		TestDropLocation[] targets = {
+		return new TestDropLocation[] {
 			// Test dragging to the edges of the workbench window
 			new WindowDropTarget(dragSource, SWT.TOP),
 			new WindowDropTarget(dragSource, SWT.BOTTOM),
 			new WindowDropTarget(dragSource, SWT.LEFT),
 			new WindowDropTarget(dragSource, SWT.RIGHT) };
-
-		return targets;
 	}
 
 	/**
@@ -140,7 +143,7 @@ public class DragTestSuite extends AutoTestSuite {
 		String resNav = IPageLayout.ID_RES_NAV;
 		String probView = IPageLayout.ID_PROBLEM_VIEW;
 
-		TestDropLocation[] targets = new TestDropLocation[] {
+		return new TestDropLocation[] {
 			// Editor area
 			new EditorAreaDropTarget(dragSource, SWT.LEFT),
 			new EditorAreaDropTarget(dragSource, SWT.RIGHT),
@@ -171,8 +174,6 @@ public class DragTestSuite extends AutoTestSuite {
 			new ViewTabDropTarget(dragSource, probView),
 			new ViewTitleDropTarget(dragSource, probView),
 			};
-
-		return targets;
 	}
 
 	/**
@@ -183,15 +184,13 @@ public class DragTestSuite extends AutoTestSuite {
 	 * @since 3.1
 	 */
 	private TestDropLocation[] getDetachedWindowDropTargets(IWorkbenchWindowProvider dragSource) {
-		TestDropLocation[] targets = new TestDropLocation[] {
+		return new TestDropLocation[] {
 			// Editor area
 			new ViewDropTarget(dragSource, DragDropPerspectiveFactory.dropViewId1, SWT.CENTER),
 			new ViewDropTarget(dragSource, DragDropPerspectiveFactory.dropViewId3, SWT.CENTER),
 			new ViewTabDropTarget(dragSource, DragDropPerspectiveFactory.dropViewId1),
 			new DetachedDropTarget()
 		};
-
-		return targets;
 	}
 
 	private TestDropLocation[] getEditorDropTargets(IWorkbenchWindowProvider originatingWindow) {
