@@ -37,11 +37,17 @@ import org.eclipse.ui.services.IEvaluationService;
 import org.eclipse.ui.tests.api.MockReusableEditorPart;
 import org.eclipse.ui.tests.harness.util.FileUtil;
 import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
 /**
  * @since 3.5
  *
  */
+@RunWith(JUnit4.class)
+@Ignore("See bug 436755 and commit 0d6ce84b3d3a588733bdae43224c612239a0a9a7")
 public class EditorSourceTest extends UITestCase {
 
 	private static class MyEval implements IPropertyChangeListener {
@@ -84,8 +90,8 @@ public class EditorSourceTest extends UITestCase {
 	private IFile test1;
 	private IFile test2;
 
-	public EditorSourceTest(String testName) {
-		super(testName);
+	public EditorSourceTest() {
+		super(EditorSourceTest.class.getSimpleName());
 	}
 
 	@Override
@@ -96,6 +102,7 @@ public class EditorSourceTest extends UITestCase {
 		test2 = FileUtil.createFile("test2.mockr1", project);
 	}
 
+	@Test
 	public void testActiveEditor() throws Exception {
 		IWorkbenchWindow window = openTestWindow();
 		IEvaluationService es = window
