@@ -16,7 +16,6 @@ package org.eclipse.ui.tests.session;
 import java.io.File;
 import java.io.IOException;
 import java.net.URL;
-import java.util.HashMap;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.zip.ZipFile;
@@ -28,8 +27,6 @@ import org.eclipse.core.tests.session.SessionTestSuite;
 import org.eclipse.core.tests.session.Setup;
 import org.eclipse.core.tests.session.SetupManager;
 import org.eclipse.core.tests.session.SetupManager.SetupException;
-import org.eclipse.jface.util.Util;
-import org.eclipse.osgi.service.environment.Constants;
 import org.eclipse.ui.tests.TestPlugin;
 import org.eclipse.ui.tests.decorators.BadIndexDecorator;
 import org.eclipse.ui.tests.harness.util.FileTool;
@@ -121,18 +118,6 @@ public class WorkbenchSessionTest extends SessionTestSuite {
 					base.setEclipseArgument(key, value);
 				}
 			}
-
-			// <== Kludge for the bug 345127. Force spawned VM to be 32 bit
-			// if we are in a 32bit Eclipse
-			if (Util.isCocoa()) {
-				String arch = System.getProperty("osgi.arch");
-				if (Constants.ARCH_X86.equals(arch)) {
-					Map<String, String> vmArguments = new HashMap<>(1);
-					vmArguments.put("d32", null);
-					base.setVMArguments(vmArguments);
-				}
-			}
-			// ==> End of kludge for the bug 345127.
 		} catch (Exception e) {
 			throw SetupManager.getInstance().new SetupException(e.getMessage(),
 					e);
